{
  BASS 2.4 Delphi unit
  Copyright (c) 1999-2008 Un4seen Developments Ltd.

  See the BASS.CHM file for more detailed documentation

  How to install
  --------------
  Copy BASS.PAS to the \LIB subdirectory of your Delphi path or your project dir
}

unit Bass;

interface

uses
  kol,Share,Windows,DLLLoader;

const
  BASSVERSION = $204;             // API version
  BASSVERSIONTEXT = '2.4';

  // Use these to test for error from functions that return a DWORD or QWORD
  DW_ERROR = Cardinal(-1); // -1 (DWORD)
  QW_ERROR = Int64(-1);    // -1 (QWORD)

  // Error codes returned by BASS_ErrorGetCode()
  BASS_OK                 = 0;    // all is OK
  BASS_ERROR_MEM          = 1;    // memory error
  BASS_ERROR_FILEOPEN     = 2;    // can't open the file
  BASS_ERROR_DRIVER       = 3;    // can't find a free sound driver
  BASS_ERROR_BUFLOST      = 4;    // the sample buffer was lost
  BASS_ERROR_HANDLE       = 5;    // invalid handle
  BASS_ERROR_FORMAT       = 6;    // unsupported sample format
  BASS_ERROR_POSITION     = 7;    // invalid position
  BASS_ERROR_INIT         = 8;    // BASS_Init has not been successfully called
  BASS_ERROR_START        = 9;    // BASS_Start has not been successfully called
  BASS_ERROR_ALREADY      = 14;   // already initialized/paused/whatever
  BASS_ERROR_NOCHAN       = 18;   // can't get a free channel
  BASS_ERROR_ILLTYPE      = 19;   // an illegal type was specified
  BASS_ERROR_ILLPARAM     = 20;   // an illegal parameter was specified
  BASS_ERROR_NO3D         = 21;   // no 3D support
  BASS_ERROR_NOEAX        = 22;   // no EAX support
  BASS_ERROR_DEVICE       = 23;   // illegal device number
  BASS_ERROR_NOPLAY       = 24;   // not playing
  BASS_ERROR_FREQ         = 25;   // illegal sample rate
  BASS_ERROR_NOTFILE      = 27;   // the stream is not a file stream
  BASS_ERROR_NOHW         = 29;   // no hardware voices available
  BASS_ERROR_EMPTY        = 31;   // the MOD music has no sequence data
  BASS_ERROR_NONET        = 32;   // no internet connection could be opened
  BASS_ERROR_CREATE       = 33;   // couldn't create the file
  BASS_ERROR_NOFX         = 34;   // effects are not enabled
  BASS_ERROR_NOTAVAIL     = 37;   // requested data is not available
  BASS_ERROR_DECODE       = 38;   // the channel is a "decoding channel"
  BASS_ERROR_DX           = 39;   // a sufficient DirectX version is not installed
  BASS_ERROR_TIMEOUT      = 40;   // connection timedout
  BASS_ERROR_FILEFORM     = 41;   // unsupported file format
  BASS_ERROR_SPEAKER      = 42;   // unavailable speaker
  BASS_ERROR_VERSION      = 43;   // invalid BASS version (used by add-ons)
  BASS_ERROR_CODEC        = 44;   // codec is not available/supported
  BASS_ERROR_ENDED        = 45;   // the channel/file has ended
  BASS_ERROR_UNKNOWN      = -1;   // some other mystery problem

  // BASS_SetConfig options
  BASS_CONFIG_BUFFER        = 0;
  BASS_CONFIG_UPDATEPERIOD  = 1;
  BASS_CONFIG_GVOL_SAMPLE   = 4;
  BASS_CONFIG_GVOL_STREAM   = 5;
  BASS_CONFIG_GVOL_MUSIC    = 6;
  BASS_CONFIG_CURVE_VOL     = 7;
  BASS_CONFIG_CURVE_PAN     = 8;
  BASS_CONFIG_FLOATDSP      = 9;
  BASS_CONFIG_3DALGORITHM   = 10;
  BASS_CONFIG_NET_TIMEOUT   = 11;
  BASS_CONFIG_NET_BUFFER    = 12;
  BASS_CONFIG_PAUSE_NOPLAY  = 13;
  BASS_CONFIG_NET_PREBUF    = 15;
  BASS_CONFIG_NET_PASSIVE   = 18;
  BASS_CONFIG_REC_BUFFER    = 19;
  BASS_CONFIG_NET_PLAYLIST  = 21;
  BASS_CONFIG_MUSIC_VIRTUAL = 22;
  BASS_CONFIG_VERIFY        = 23;
  BASS_CONFIG_UPDATETHREADS = 24;

  // BASS_SetConfigPtr options
  BASS_CONFIG_NET_AGENT     = 16;
  BASS_CONFIG_NET_PROXY     = 17;

  // Initialization flags
  BASS_DEVICE_8BITS       = 1;    // use 8 bit resolution, else 16 bit
  BASS_DEVICE_MONO        = 2;    // use mono, else stereo
  BASS_DEVICE_3D          = 4;    // enable 3D functionality
  BASS_DEVICE_LATENCY     = 256;  // calculate device latency (BASS_INFO struct)
  BASS_DEVICE_CPSPEAKERS  = 1024; // detect speakers via Windows control panel
  BASS_DEVICE_SPEAKERS    = 2048; // force enabling of speaker assignment
  BASS_DEVICE_NOSPEAKER   = 4096; // ignore speaker arrangement

  // DirectSound interfaces (for use with BASS_GetDSoundObject)
  BASS_OBJECT_DS          = 1;   // IDirectSound
  BASS_OBJECT_DS3DL       = 2;   // IDirectSound3DListener

  // BASS_DEVICEINFO flags
  BASS_DEVICE_ENABLED     = 1;
  BASS_DEVICE_DEFAULT     = 2;
  BASS_DEVICE_INIT        = 4;

  // BASS_INFO flags (from DSOUND.H)
  DSCAPS_CONTINUOUSRATE   = $00000010;     // supports all sample rates between min/maxrate
  DSCAPS_EMULDRIVER       = $00000020;     // device does NOT have hardware DirectSound support
  DSCAPS_CERTIFIED        = $00000040;     // device driver has been certified by Microsoft
  DSCAPS_SECONDARYMONO    = $00000100;     // mono
  DSCAPS_SECONDARYSTEREO  = $00000200;     // stereo
  DSCAPS_SECONDARY8BIT    = $00000400;     // 8 bit
  DSCAPS_SECONDARY16BIT   = $00000800;     // 16 bit

  // BASS_RECORDINFO flags (from DSOUND.H)
  DSCCAPS_EMULDRIVER = DSCAPS_EMULDRIVER;  // device does NOT have hardware DirectSound recording support
  DSCCAPS_CERTIFIED = DSCAPS_CERTIFIED;    // device driver has been certified by Microsoft

  // defines for formats field of BASS_RECORDINFO (from MMSYSTEM.H)
  WAVE_FORMAT_1M08       = $00000001;      // 11.025 kHz, Mono,   8-bit
  WAVE_FORMAT_1S08       = $00000002;      // 11.025 kHz, Stereo, 8-bit
  WAVE_FORMAT_1M16       = $00000004;      // 11.025 kHz, Mono,   16-bit
  WAVE_FORMAT_1S16       = $00000008;      // 11.025 kHz, Stereo, 16-bit
  WAVE_FORMAT_2M08       = $00000010;      // 22.05  kHz, Mono,   8-bit
  WAVE_FORMAT_2S08       = $00000020;      // 22.05  kHz, Stereo, 8-bit
  WAVE_FORMAT_2M16       = $00000040;      // 22.05  kHz, Mono,   16-bit
  WAVE_FORMAT_2S16       = $00000080;      // 22.05  kHz, Stereo, 16-bit
  WAVE_FORMAT_4M08       = $00000100;      // 44.1   kHz, Mono,   8-bit
  WAVE_FORMAT_4S08       = $00000200;      // 44.1   kHz, Stereo, 8-bit
  WAVE_FORMAT_4M16       = $00000400;      // 44.1   kHz, Mono,   16-bit
  WAVE_FORMAT_4S16       = $00000800;      // 44.1   kHz, Stereo, 16-bit

  BASS_SAMPLE_8BITS       = 1;   // 8 bit
  BASS_SAMPLE_FLOAT       = 256; // 32-bit floating-point
  BASS_SAMPLE_MONO        = 2;   // mono
  BASS_SAMPLE_LOOP        = 4;   // looped
  BASS_SAMPLE_3D          = 8;   // 3D functionality
  BASS_SAMPLE_SOFTWARE    = 16;  // not using hardware mixing
  BASS_SAMPLE_MUTEMAX     = 32;  // mute at max distance (3D only)
  BASS_SAMPLE_VAM         = 64;  // DX7 voice allocation & management
  BASS_SAMPLE_FX          = 128; // old implementation of DX8 effects
  BASS_SAMPLE_OVER_VOL    = $10000; // override lowest volume
  BASS_SAMPLE_OVER_POS    = $20000; // override longest playing
  BASS_SAMPLE_OVER_DIST   = $30000; // override furthest from listener (3D only)

  BASS_STREAM_PRESCAN     = $20000; // enable pin-point seeking/length (MP3/MP2/MP1)
  BASS_MP3_SETPOS         = BASS_STREAM_PRESCAN;
  BASS_STREAM_AUTOFREE	  = $40000; // automatically free the stream when it stop/ends
  BASS_STREAM_RESTRATE	  = $80000; // restrict the download rate of internet file streams
  BASS_STREAM_BLOCK       = $100000;// download/play internet file stream in small blocks
  BASS_STREAM_DECODE      = $200000;// don't play the stream, only decode (BASS_ChannelGetData)
  BASS_STREAM_STATUS      = $800000;// give server status info (HTTP/ICY tags) in DOWNLOADPROC

  BASS_MUSIC_FLOAT        = BASS_SAMPLE_FLOAT;
  BASS_MUSIC_MONO         = BASS_SAMPLE_MONO;
  BASS_MUSIC_LOOP         = BASS_SAMPLE_LOOP;
  BASS_MUSIC_3D           = BASS_SAMPLE_3D;
  BASS_MUSIC_FX           = BASS_SAMPLE_FX;
  BASS_MUSIC_AUTOFREE     = BASS_STREAM_AUTOFREE;
  BASS_MUSIC_DECODE       = BASS_STREAM_DECODE;
  BASS_MUSIC_PRESCAN      = BASS_STREAM_PRESCAN; // calculate playback length
  BASS_MUSIC_CALCLEN      = BASS_MUSIC_PRESCAN;
  BASS_MUSIC_RAMP         = $200;  // normal ramping
  BASS_MUSIC_RAMPS        = $400;  // sensitive ramping
  BASS_MUSIC_SURROUND     = $800;  // surround sound
  BASS_MUSIC_SURROUND2    = $1000; // surround sound (mode 2)
  BASS_MUSIC_FT2MOD       = $2000; // play .MOD as FastTracker 2 does
  BASS_MUSIC_PT1MOD       = $4000; // play .MOD as ProTracker 1 does
  BASS_MUSIC_NONINTER     = $10000; // non-interpolated sample mixing
  BASS_MUSIC_SINCINTER    = $800000; // sinc interpolated sample mixing
  BASS_MUSIC_POSRESET     = $8000; // stop all notes when moving position
  BASS_MUSIC_POSRESETEX   = $400000; // stop all notes and reset bmp/etc when moving position
  BASS_MUSIC_STOPBACK     = $80000; // stop the music on a backwards jump effect
  BASS_MUSIC_NOSAMPLE     = $100000; // don't load the samples

  // Speaker assignment flags
  BASS_SPEAKER_FRONT      = $1000000;  // front speakers
  BASS_SPEAKER_REAR       = $2000000;  // rear/side speakers
  BASS_SPEAKER_CENLFE     = $3000000;  // center & LFE speakers (5.1)
  BASS_SPEAKER_REAR2      = $4000000;  // rear center speakers (7.1)
  BASS_SPEAKER_LEFT       = $10000000; // modifier: left
  BASS_SPEAKER_RIGHT      = $20000000; // modifier: right
  BASS_SPEAKER_FRONTLEFT  = BASS_SPEAKER_FRONT or BASS_SPEAKER_LEFT;
  BASS_SPEAKER_FRONTRIGHT = BASS_SPEAKER_FRONT or BASS_SPEAKER_RIGHT;
  BASS_SPEAKER_REARLEFT   = BASS_SPEAKER_REAR or BASS_SPEAKER_LEFT;
  BASS_SPEAKER_REARRIGHT  = BASS_SPEAKER_REAR or BASS_SPEAKER_RIGHT;
  BASS_SPEAKER_CENTER     = BASS_SPEAKER_CENLFE or BASS_SPEAKER_LEFT;
  BASS_SPEAKER_LFE        = BASS_SPEAKER_CENLFE or BASS_SPEAKER_RIGHT;
  BASS_SPEAKER_REAR2LEFT  = BASS_SPEAKER_REAR2 or BASS_SPEAKER_LEFT;
  BASS_SPEAKER_REAR2RIGHT = BASS_SPEAKER_REAR2 or BASS_SPEAKER_RIGHT;

  BASS_UNICODE            = $80000000;

  BASS_RECORD_PAUSE       = $8000; // start recording paused

  // DX7 voice allocation & management flags
  BASS_VAM_HARDWARE       = 1;
  BASS_VAM_SOFTWARE       = 2;
  BASS_VAM_TERM_TIME      = 4;
  BASS_VAM_TERM_DIST      = 8;
  BASS_VAM_TERM_PRIO      = 16;

  // BASS_CHANNELINFO types
  BASS_CTYPE_SAMPLE       = 1;
  BASS_CTYPE_RECORD       = 2;
  BASS_CTYPE_STREAM       = $10000;
  BASS_CTYPE_STREAM_OGG   = $10002;
  BASS_CTYPE_STREAM_MP1   = $10003;
  BASS_CTYPE_STREAM_MP2   = $10004;
  BASS_CTYPE_STREAM_MP3   = $10005;
  BASS_CTYPE_STREAM_AIFF  = $10006;
  BASS_CTYPE_STREAM_WAV   = $40000; // WAVE flag, LOWORD=codec
  BASS_CTYPE_STREAM_WAV_PCM = $50001;
  BASS_CTYPE_STREAM_WAV_FLOAT = $50003;
  BASS_CTYPE_MUSIC_MOD    = $20000;
  BASS_CTYPE_MUSIC_MTM    = $20001;
  BASS_CTYPE_MUSIC_S3M    = $20002;
  BASS_CTYPE_MUSIC_XM     = $20003;
  BASS_CTYPE_MUSIC_IT     = $20004;
  BASS_CTYPE_MUSIC_MO3    = $00100; // MO3 flag

  // 3D channel modes
  BASS_3DMODE_NORMAL      = 0; // normal 3D processing
  BASS_3DMODE_RELATIVE    = 1; // position is relative to the listener
  BASS_3DMODE_OFF         = 2; // no 3D processing

  // software 3D mixing algorithms (used with BASS_CONFIG_3DALGORITHM)
  BASS_3DALG_DEFAULT      = 0;
  BASS_3DALG_OFF          = 1;
  BASS_3DALG_FULL         = 2;
  BASS_3DALG_LIGHT        = 3;

  // EAX environments, use with BASS_SetEAXParameters
  EAX_ENVIRONMENT_GENERIC           = 0;
  EAX_ENVIRONMENT_PADDEDCELL        = 1;
  EAX_ENVIRONMENT_ROOM              = 2;
  EAX_ENVIRONMENT_BATHROOM          = 3;
  EAX_ENVIRONMENT_LIVINGROOM        = 4;
  EAX_ENVIRONMENT_STONEROOM         = 5;
  EAX_ENVIRONMENT_AUDITORIUM        = 6;
  EAX_ENVIRONMENT_CONCERTHALL       = 7;
  EAX_ENVIRONMENT_CAVE              = 8;
  EAX_ENVIRONMENT_ARENA             = 9;
  EAX_ENVIRONMENT_HANGAR            = 10;
  EAX_ENVIRONMENT_CARPETEDHALLWAY   = 11;
  EAX_ENVIRONMENT_HALLWAY           = 12;
  EAX_ENVIRONMENT_STONECORRIDOR     = 13;
  EAX_ENVIRONMENT_ALLEY             = 14;
  EAX_ENVIRONMENT_FOREST            = 15;
  EAX_ENVIRONMENT_CITY              = 16;
  EAX_ENVIRONMENT_MOUNTAINS         = 17;
  EAX_ENVIRONMENT_QUARRY            = 18;
  EAX_ENVIRONMENT_PLAIN             = 19;
  EAX_ENVIRONMENT_PARKINGLOT        = 20;
  EAX_ENVIRONMENT_SEWERPIPE         = 21;
  EAX_ENVIRONMENT_UNDERWATER        = 22;
  EAX_ENVIRONMENT_DRUGGED           = 23;
  EAX_ENVIRONMENT_DIZZY             = 24;
  EAX_ENVIRONMENT_PSYCHOTIC         = 25;
  // total number of environments
  EAX_ENVIRONMENT_COUNT             = 26;

  BASS_STREAMPROC_END = $80000000; // end of user stream flag


  // BASS_StreamCreateFileUser file systems
  STREAMFILE_NOBUFFER     = 0;
  STREAMFILE_BUFFER       = 1;
  STREAMFILE_BUFFERPUSH   = 2;

  // BASS_StreamPutFileData options
  BASS_FILEDATA_END       = 0; // end & close the file

  // BASS_StreamGetFilePosition modes
  BASS_FILEPOS_CURRENT    = 0;
  BASS_FILEPOS_DECODE     = BASS_FILEPOS_CURRENT;
  BASS_FILEPOS_DOWNLOAD   = 1;
  BASS_FILEPOS_END        = 2;
  BASS_FILEPOS_START      = 3;
  BASS_FILEPOS_CONNECTED  = 4;
  BASS_FILEPOS_BUFFER     = 5;

  // BASS_ChannelSetSync types
  BASS_SYNC_POS           = 0;
  BASS_SYNC_END           = 2;
  BASS_SYNC_META          = 4;
  BASS_SYNC_SLIDE         = 5;
  BASS_SYNC_STALL         = 6;
  BASS_SYNC_DOWNLOAD      = 7;
  BASS_SYNC_FREE          = 8;
  BASS_SYNC_SETPOS        = 11;
  BASS_SYNC_MUSICPOS      = 10;
  BASS_SYNC_MUSICINST     = 1;
  BASS_SYNC_MUSICFX       = 3;
  BASS_SYNC_OGG_CHANGE    = 12;
  BASS_SYNC_MIXTIME       = $40000000; // FLAG: sync at mixtime, else at playtime
  BASS_SYNC_ONETIME       = $80000000; // FLAG: sync only once, else continuously

  // BASS_ChannelIsActive return values
  BASS_ACTIVE_STOPPED = 0;
  BASS_ACTIVE_PLAYING = 1;
  BASS_ACTIVE_STALLED = 2;
  BASS_ACTIVE_PAUSED  = 3;

  // Channel attributes
  BASS_ATTRIB_FREQ                  = 1;
  BASS_ATTRIB_VOL                   = 2;
  BASS_ATTRIB_PAN                   = 3;
  BASS_ATTRIB_EAXMIX                = 4;
  BASS_ATTRIB_MUSIC_AMPLIFY         = $100;
  BASS_ATTRIB_MUSIC_PANSEP          = $101;
  BASS_ATTRIB_MUSIC_PSCALER         = $102;
  BASS_ATTRIB_MUSIC_BPM             = $103;
  BASS_ATTRIB_MUSIC_SPEED           = $104;
  BASS_ATTRIB_MUSIC_VOL_GLOBAL      = $105;
  BASS_ATTRIB_MUSIC_VOL_CHAN        = $200; // + channel #
  BASS_ATTRIB_MUSIC_VOL_INST        = $300; // + instrument #

  // BASS_ChannelGetData flags
  BASS_DATA_AVAILABLE = 0;        // query how much data is buffered
  BASS_DATA_FLOAT     = $40000000; // flag: return floating-point sample data
  BASS_DATA_FFT256    = $80000000; // 256 sample FFT
  BASS_DATA_FFT512    = $80000001; // 512 FFT
  BASS_DATA_FFT1024   = $80000002; // 1024 FFT
  BASS_DATA_FFT2048   = $80000003; // 2048 FFT
  BASS_DATA_FFT4096   = $80000004; // 4096 FFT
  BASS_DATA_FFT8192   = $80000005; // 8192 FFT
  BASS_DATA_FFT_INDIVIDUAL = $10; // FFT flag: FFT for each channel, else all combined
  BASS_DATA_FFT_NOWINDOW = $20;   // FFT flag: no Hanning window

  // BASS_ChannelGetTags types : what's returned
  BASS_TAG_ID3        = 0; // ID3v1 tags : 128 byte block
  BASS_TAG_ID3V2      = 1; // ID3v2 tags : variable length block
  BASS_TAG_OGG        = 2; // OGG comments : series of null-terminated strings
  BASS_TAG_HTTP       = 3; // HTTP headers : series of null-terminated strings
  BASS_TAG_ICY        = 4; // ICY headers : series of null-terminated strings
  BASS_TAG_META       = 5; // ICY metadata : null-terminated string
  BASS_TAG_VENDOR     = 9; // OGG encoder : null-terminated string
  BASS_TAG_LYRICS3    = 10; // Lyric3v2 tag : ASCII string
  BASS_TAG_RIFF_INFO  = $100; // RIFF/WAVE tags : series of null-terminated ANSI strings
  BASS_TAG_MUSIC_NAME = $10000;	// MOD music name : ANSI string
  BASS_TAG_MUSIC_MESSAGE = $10001; // MOD message : ANSI string
  BASS_TAG_MUSIC_INST = $10100;	// + instrument #, MOD instrument name : ANSI string
  BASS_TAG_MUSIC_SAMPLE = $10300; // + sample #, MOD sample name : ANSI string

  // BASS_ChannelGetLength/GetPosition/SetPosition modes
  BASS_POS_BYTE           = 0; // byte position
  BASS_POS_MUSIC_ORDER    = 1; // order.row position, MAKELONG(order,row)

  // BASS_RecordSetInput flags
  BASS_INPUT_OFF    = $10000;
  BASS_INPUT_ON     = $20000;

  BASS_INPUT_TYPE_MASK    = $FF000000;
  BASS_INPUT_TYPE_UNDEF   = $00000000;
  BASS_INPUT_TYPE_DIGITAL = $01000000;
  BASS_INPUT_TYPE_LINE    = $02000000;
  BASS_INPUT_TYPE_MIC     = $03000000;
  BASS_INPUT_TYPE_SYNTH   = $04000000;
  BASS_INPUT_TYPE_CD      = $05000000;
  BASS_INPUT_TYPE_PHONE   = $06000000;
  BASS_INPUT_TYPE_SPEAKER = $07000000;
  BASS_INPUT_TYPE_WAVE    = $08000000;
  BASS_INPUT_TYPE_AUX     = $09000000;
  BASS_INPUT_TYPE_ANALOG  = $0A000000;

  BASS_FX_DX8_CHORUS	  = 0;
  BASS_FX_DX8_COMPRESSOR  = 1;
  BASS_FX_DX8_DISTORTION  = 2;
  BASS_FX_DX8_ECHO        = 3;
  BASS_FX_DX8_FLANGER     = 4;
  BASS_FX_DX8_GARGLE      = 5;
  BASS_FX_DX8_I3DL2REVERB = 6;
  BASS_FX_DX8_PARAMEQ     = 7;
  BASS_FX_DX8_REVERB      = 8;

  BASS_DX8_PHASE_NEG_180 = 0;
  BASS_DX8_PHASE_NEG_90  = 1;
  BASS_DX8_PHASE_ZERO    = 2;
  BASS_DX8_PHASE_90      = 3;
  BASS_DX8_PHASE_180     = 4;

type
  DWORD = cardinal;
  BOOL = LongBool;
  FLOAT = Single;
  QWORD = int64;        // 64-bit (replace "int64" with "comp" if using Delphi 3)

  HMUSIC = DWORD;       // MOD music handle
  HSAMPLE = DWORD;      // sample handle
  HCHANNEL = DWORD;     // playing sample's channel handle
  HSTREAM = DWORD;      // sample stream handle
  HRECORD = DWORD;      // recording handle
  HSYNC = DWORD;        // synchronizer handle
  HDSP = DWORD;         // DSP handle
  HFX = DWORD;          // DX8 effect handle
  HPLUGIN = DWORD;      // Plugin handle

  // Device info structure
  BASS_DEVICEINFO = record
    name: PChar;        // description
    driver: PChar;      // driver
    flags: DWORD;
  end;

  BASS_INFO = record
    flags: DWORD;       // device capabilities (DSCAPS_xxx flags)
    hwsize: DWORD;      // size of total device hardware memory
    hwfree: DWORD;      // size of free device hardware memory
    freesam: DWORD;     // number of free sample slots in the hardware
    free3d: DWORD;      // number of free 3D sample slots in the hardware
    minrate: DWORD;     // min sample rate supported by the hardware
    maxrate: DWORD;     // max sample rate supported by the hardware
    eax: BOOL;          // device supports EAX? (always FALSE if BASS_DEVICE_3D was not used)
    minbuf: DWORD;      // recommended minimum buffer length in ms (requires BASS_DEVICE_LATENCY)
    dsver: DWORD;       // DirectSound version
    latency: DWORD;     // delay (in ms) before start of playback (requires BASS_DEVICE_LATENCY)
    initflags: DWORD;   // BASS_Init "flags" parameter
    speakers: DWORD;    // number of speakers available
    freq: DWORD;        // current output rate (OSX only)
  end;

  // Recording device info structure
  BASS_RECORDINFO = record
    flags: DWORD;       // device capabilities (DSCCAPS_xxx flags)
    formats: DWORD;     // supported standard formats (WAVE_FORMAT_xxx flags)
    inputs: DWORD;      // number of inputs
    singlein: BOOL;     // only 1 input can be set at a time
    driver: PChar;      // driver
    freq: DWORD;        // current input rate (OSX only)
  end;

  // Sample info structure
  BASS_SAMPLE = record
    freq: DWORD;        // default playback rate
    volume: FLOAT;      // default volume (0-100)
    pan: FLOAT;         // default pan (-100=left, 0=middle, 100=right)
    flags: DWORD;       // BASS_SAMPLE_xxx flags
    length: DWORD;      // length (in samples, not bytes)
    max: DWORD;         // maximum simultaneous playbacks
    origres: DWORD;     // original resolution
    chans: DWORD;       // number of channels
    mingap: DWORD;      // minimum gap (ms) between creating channels
    mode3d: DWORD;      // BASS_3DMODE_xxx mode
    mindist: FLOAT;     // minimum distance
    maxdist: FLOAT;     // maximum distance
    iangle: DWORD;      // angle of inside projection cone
    oangle: DWORD;      // angle of outside projection cone
    outvol: FLOAT;      // delta-volume outside the projection cone
    vam: DWORD;         // voice allocation/management flags (BASS_VAM_xxx)
    priority: DWORD;    // priority (0=lowest, $ffffffff=highest)
  end;

  // Channel info structure
  BASS_CHANNELINFO = record
    freq: DWORD;        // default playback rate
    chans: DWORD;       // channels
    flags: DWORD;       // BASS_SAMPLE/STREAM/MUSIC/SPEAKER flags
    ctype: DWORD;       // type of channel
    origres: DWORD;     // original resolution
    plugin: HPLUGIN;    // plugin
    sample: HSAMPLE;    // sample
    filename: PChar;    // filename
  end;

  BASS_PLUGINFORM = record
    ctype: DWORD;       // channel type
    name: PChar;        // format description
    exts: PChar;	    // file extension filter (*.ext1;*.ext2;etc...)
  end;
  PBASS_PLUGINFORMS = ^TBASS_PLUGINFORMS;
  TBASS_PLUGINFORMS = array[0..maxInt div sizeOf(BASS_PLUGINFORM) - 1] of BASS_PLUGINFORM;

  BASS_PLUGININFO = record
    version: DWORD;             // version (same form as BASS_GetVersion)
    formatc: DWORD;             // number of formats
    formats: PBASS_PLUGINFORMS; // the array of formats
  end;
  PBASS_PLUGININFO = ^BASS_PLUGININFO;

  // 3D vector (for 3D positions/velocities/orientations)
  BASS_3DVECTOR = record
    x: FLOAT;           // +=right, -=left
    y: FLOAT;           // +=up, -=down
    z: FLOAT;           // +=front, -=behind
  end;

  // User file stream callback functions
  FILECLOSEPROC = procedure(user: Pointer); stdcall;
  FILELENPROC = function(user: Pointer): QWORD; stdcall;
  FILEREADPROC = function(buffer: Pointer; length: DWORD; user: Pointer): DWORD; stdcall;
  FILESEEKPROC = function(offset: QWORD; user: Pointer): BOOL; stdcall;

  BASS_FILEPROCS = record
    close: FILECLOSEPROC;
    length: FILELENPROC;
    read: FILEREADPROC;
    seek: FILESEEKPROC;
  end;

  BASS_DX8_CHORUS = record
    fWetDryMix: FLOAT;
    fDepth: FLOAT;
    fFeedback: FLOAT;
    fFrequency: FLOAT;
    lWaveform: DWORD;   // 0=triangle, 1=sine
    fDelay: FLOAT;
    lPhase: DWORD;      // BASS_DX8_PHASE_xxx
  end;

  BASS_DX8_COMPRESSOR = record
    fGain: FLOAT;
    fAttack: FLOAT;
    fRelease: FLOAT;
    fThreshold: FLOAT;
    fRatio: FLOAT;
    fPredelay: FLOAT;
  end;

  BASS_DX8_DISTORTION = record
    fGain: FLOAT;
    fEdge: FLOAT;
    fPostEQCenterFrequency: FLOAT;
    fPostEQBandwidth: FLOAT;
    fPreLowpassCutoff: FLOAT;
  end;

  BASS_DX8_ECHO = record
    fWetDryMix: FLOAT;
    fFeedback: FLOAT;
    fLeftDelay: FLOAT;
    fRightDelay: FLOAT;
    lPanDelay: BOOL;
  end;

  BASS_DX8_FLANGER = record
    fWetDryMix: FLOAT;
    fDepth: FLOAT;
    fFeedback: FLOAT;
    fFrequency: FLOAT;
    lWaveform: DWORD;   // 0=triangle, 1=sine
    fDelay: FLOAT;
    lPhase: DWORD;      // BASS_DX8_PHASE_xxx
  end;

  BASS_DX8_GARGLE = record
    dwRateHz: DWORD;               // Rate of modulation in hz
    dwWaveShape: DWORD;            // 0=triangle, 1=square
  end;

  BASS_DX8_I3DL2REVERB = record
    lRoom: Longint;                // [-10000, 0]      default: -1000 mB
    lRoomHF: Longint;              // [-10000, 0]      default: 0 mB
    flRoomRolloffFactor: FLOAT;    // [0.0, 10.0]      default: 0.0
    flDecayTime: FLOAT;            // [0.1, 20.0]      default: 1.49s
    flDecayHFRatio: FLOAT;         // [0.1, 2.0]       default: 0.83
    lReflections: Longint;         // [-10000, 1000]   default: -2602 mB
    flReflectionsDelay: FLOAT;     // [0.0, 0.3]       default: 0.007 s
    lReverb: Longint;              // [-10000, 2000]   default: 200 mB
    flReverbDelay: FLOAT;          // [0.0, 0.1]       default: 0.011 s
    flDiffusion: FLOAT;            // [0.0, 100.0]     default: 100.0 %
    flDensity: FLOAT;              // [0.0, 100.0]     default: 100.0 %
    flHFReference: FLOAT;          // [20.0, 20000.0]  default: 5000.0 Hz
  end;

  BASS_DX8_PARAMEQ = record
    fCenter: FLOAT;
    fBandwidth: FLOAT;
    fGain: FLOAT;
  end;

  BASS_DX8_REVERB = record
    fInGain: FLOAT;                // [-96.0,0.0]            default: 0.0 dB
    fReverbMix: FLOAT;             // [-96.0,0.0]            default: 0.0 db
    fReverbTime: FLOAT;            // [0.001,3000.0]         default: 1000.0 ms
    fHighFreqRTRatio: FLOAT;       // [0.001,0.999]          default: 0.001
  end;

  // callback function types
  STREAMPROC = function(handle: HSTREAM; buffer: Pointer; length: DWORD; user: Pointer): DWORD; stdcall;
  {
    User stream callback function. NOTE: A stream function should obviously be as
    quick as possible, other streams (and MOD musics) can't be mixed until
    it's finished.
    handle : The stream that needs writing
    buffer : Buffer to write the samples in
    length : Number of bytes to write
    user   : The 'user' parameter value given when calling BASS_StreamCreate
    RETURN : Number of bytes written. Set the BASS_STREAMPROC_END flag to end
             the stream.
  }

const
  // special STREAMPROCs
  STREAMPROC_DUMMY : STREAMPROC = nil;  // "dummy" stream
  {$ifndef F_P}
  STREAMPROC_PUSH  : STREAMPROC = STREAMPROC(-1); // push stream
  {$endif}

type

  DOWNLOADPROC = procedure(buffer: Pointer; length: DWORD; user: Pointer); stdcall;
  {
    Internet stream download callback function.
    buffer : Buffer containing the downloaded data... NULL=end of download
    length : Number of bytes in the buffer
    user   : The 'user' parameter value given when calling BASS_StreamCreateURL
  }

  SYNCPROC = procedure(handle: HSYNC; channel, data: DWORD; user: Pointer); stdcall;
  {
    Sync callback function. NOTE: a sync callback function should be very
    quick as other syncs cannot be processed until it has finished. If the
    sync is a "mixtime" sync, then other streams and MOD musics can not be
    mixed until it's finished either.
    handle : The sync that has occured
    channel: Channel that the sync occured in
    data   : Additional data associated with the sync's occurance
    user   : The 'user' parameter given when calling BASS_ChannelSetSync
  }

  DSPPROC = procedure(handle: HDSP; channel: DWORD; buffer: Pointer; length: DWORD; user: Pointer); stdcall;
  {
    DSP callback function. NOTE: A DSP function should obviously be as quick
    as possible... other DSP functions, streams and MOD musics can not be
    processed until it's finished.
    handle : The DSP handle
    channel: Channel that the DSP is being applied to
    buffer : Buffer to apply the DSP to
    length : Number of bytes in the buffer
    user   : The 'user' parameter given when calling BASS_ChannelSetDSP
  }

  RECORDPROC = function(handle: HRECORD; buffer: Pointer; length: DWORD; user: Pointer): BOOL; stdcall;
  {
    Recording callback function.
    handle : The recording handle
    buffer : Buffer containing the recorded sample data
    length : Number of bytes
    user   : The 'user' parameter value given when calling BASS_RecordStart
    RETURN : TRUE = continue recording, FALSE = stop
  }


// Functions
// const
 function BASS_SPEAKER_N(n: DWORD): DWORD;
function BASS_SetEAXPreset(env: Integer): BOOL;

VAR bassDLL:TDLLLoader;
BASS_SetConfig: function(option, value: DWORD): BOOL; stdcall; 
BASS_GetConfig: function(option: DWORD): DWORD; stdcall; 
BASS_SetConfigPtr: function(option: DWORD; value: Pointer): BOOL; stdcall; 
BASS_GetConfigPtr: function(option: DWORD): Pointer; stdcall; 
BASS_GetVersion: function: DWORD; stdcall; 
BASS_ErrorGetCode: function: Integer; stdcall; 
BASS_GetDeviceInfo: function(device: DWORD; var info: BASS_DEVICEINFO): BOOL; stdcall; 
BASS_Init: function(device: Integer; freq, flags: DWORD; win: HWND; clsid: PGUID): BOOL; stdcall; 
BASS_SetDevice: function(device: DWORD): BOOL; stdcall; 
BASS_GetDevice: function: DWORD; stdcall; 
BASS_Free: function: BOOL; stdcall; 
BASS_GetDSoundObject: function(obj: DWORD): Pointer; stdcall; 
BASS_GetInfo: function(var info: BASS_INFO): BOOL; stdcall; 
BASS_Update: function(length: DWORD): BOOL; stdcall; 
BASS_GetCPU: function: FLOAT; stdcall; 
BASS_Start: function: BOOL; stdcall; 
BASS_Stop: function: BOOL; stdcall; 
BASS_Pause: function: BOOL; stdcall; 
BASS_SetVolume: function(volume: FLOAT): BOOL; stdcall; 
BASS_GetVolume: function: FLOAT; stdcall; 
BASS_PluginLoad: function(filename: PChar; flags: DWORD): HPLUGIN; stdcall; 
BASS_PluginFree: function(handle: HPLUGIN): BOOL; stdcall; 
BASS_PluginGetInfo: function(handle: HPLUGIN): PBASS_PLUGININFO; stdcall; 
BASS_Set3DFactors: function(distf, rollf, doppf: FLOAT): BOOL; stdcall; 
BASS_Get3DFactors: function(var distf, rollf, doppf: FLOAT): BOOL; stdcall; 
BASS_Set3DPosition: function(var pos, vel, front, top: BASS_3DVECTOR): BOOL; stdcall; 
BASS_Get3DPosition: function(var pos, vel, front, top: BASS_3DVECTOR): BOOL; stdcall; 
BASS_Apply3D: procedure; stdcall; 
BASS_SetEAXParameters: function(env: Integer; vol, decay, damp: FLOAT): BOOL; stdcall; 
BASS_GetEAXParameters: function(var env: DWORD; var vol, decay, damp: FLOAT): BOOL; stdcall; 
BASS_MusicLoad: function(mem: BOOL; f: Pointer; offset: QWORD; length, flags, freq: DWORD): HMUSIC; stdcall; 
BASS_MusicFree: function(handle: HMUSIC): BOOL; stdcall; 
BASS_SampleLoad: function(mem: BOOL; f: Pointer; offset: QWORD; length, max, flags: DWORD): HSAMPLE; stdcall; 
BASS_SampleCreate: function(length, freq, chans, max, flags: DWORD): HSAMPLE; stdcall; 
BASS_SampleFree: function(handle: HSAMPLE): BOOL; stdcall; 
BASS_SampleSetData: function(handle: HSAMPLE; buffer: Pointer): BOOL; stdcall; 
BASS_SampleGetData: function(handle: HSAMPLE; buffer: Pointer): BOOL; stdcall; 
BASS_SampleGetInfo: function(handle: HSAMPLE; var info: BASS_SAMPLE): BOOL; stdcall; 
BASS_SampleSetInfo: function(handle: HSAMPLE; var info: BASS_SAMPLE): BOOL; stdcall; 
BASS_SampleGetChannel: function(handle: HSAMPLE; onlynew: BOOL): HCHANNEL; stdcall; 
BASS_SampleGetChannels: function(handle: HSAMPLE; channels: Pointer): DWORD; stdcall; 
BASS_SampleStop: function(handle: HSAMPLE): BOOL; stdcall; 
BASS_StreamCreate: function(freq, chans, flags: DWORD; proc: STREAMPROC; user: Pointer): HSTREAM; stdcall; 
BASS_StreamCreateFile: function(mem: BOOL; f: Pointer; offset, length: QWORD; flags: DWORD): HSTREAM; stdcall; 
BASS_StreamCreateURL: function(url: PChar; offset: DWORD; flags: DWORD; proc: DOWNLOADPROC; user: Pointer):HSTREAM; stdcall; 
BASS_StreamCreateFileUser: function(system, flags: DWORD; var procs: BASS_FILEPROCS; user: Pointer): HSTREAM; stdcall; 
BASS_StreamFree: function(handle: HSTREAM): BOOL; stdcall; 
BASS_StreamGetFilePosition: function(handle: HSTREAM; mode: DWORD): QWORD; stdcall; 
BASS_StreamPutData: function(handle: HSTREAM; buffer: Pointer; length: DWORD): DWORD; stdcall; 
BASS_StreamPutFileData: function(handle: HSTREAM; buffer: Pointer; length: DWORD): DWORD; stdcall; 
BASS_RecordGetDeviceInfo: function(device: DWORD; var info: BASS_DEVICEINFO): BOOL; stdcall; 
BASS_RecordInit: function(device: Integer):BOOL; stdcall; 
BASS_RecordSetDevice: function(device: DWORD): BOOL; stdcall; 
BASS_RecordGetDevice: function: DWORD; stdcall; 
BASS_RecordFree: function: BOOL; stdcall; 
BASS_RecordGetInfo: function(var info: BASS_RECORDINFO): BOOL; stdcall; 
BASS_RecordGetInputName: function(input: Integer): PChar; stdcall; 
BASS_RecordSetInput: function(input: Integer; flags: DWORD; volume: FLOAT): BOOL; stdcall; 
BASS_RecordGetInput: function(input: Integer; var volume: FLOAT): DWORD; stdcall; 
BASS_RecordStart: function(freq, chans, flags: DWORD; proc: RECORDPROC; user: Pointer): HRECORD; stdcall; 
BASS_ChannelBytes2Seconds: function(handle: DWORD; pos: QWORD): Double; stdcall;
BASS_ChannelSeconds2Bytes: function(handle: DWORD; pos: Double): QWORD; stdcall;
BASS_ChannelGetDevice: function(handle: DWORD): DWORD; stdcall; 
BASS_ChannelSetDevice: function(handle, device: DWORD): BOOL; stdcall; 
BASS_ChannelIsActive: function(handle: DWORD): DWORD; stdcall;
BASS_ChannelGetInfo: function(handle: DWORD; var info: BASS_CHANNELINFO):BOOL;stdcall;
BASS_ChannelGetTags: function(handle: HSTREAM; tags: DWORD): PChar; stdcall; 
BASS_ChannelFlags: function(handle, flags, mask: DWORD): DWORD; stdcall; 
BASS_ChannelUpdate: function(handle, length: DWORD): BOOL; stdcall; 
BASS_ChannelLock: function(handle: DWORD; lock: BOOL): BOOL; stdcall; 
BASS_ChannelPlay: function(handle: DWORD; restart: BOOL): BOOL; stdcall; 
BASS_ChannelStop: function(handle: DWORD): BOOL; stdcall; 
BASS_ChannelPause: function(handle: DWORD): BOOL; stdcall; 
BASS_ChannelSetAttribute: function(handle, attrib: DWORD; value: FLOAT): BOOL; stdcall; 
BASS_ChannelGetAttribute: function(handle, attrib: DWORD; var value: FLOAT): BOOL; stdcall; 
BASS_ChannelSlideAttribute: function(handle, attrib: DWORD; value: FLOAT; time: DWORD): BOOL; stdcall; 
BASS_ChannelIsSliding: function(handle, attrib: DWORD): BOOL; stdcall;
BASS_ChannelSet3DAttributes: function(handle: DWORD; mode: Integer; min, max: FLOAT; iangle, oangle, outvol: Integer): BOOL; stdcall; 
BASS_ChannelGet3DAttributes: function(handle: DWORD; var mode: DWORD; var min, max: FLOAT; var iangle, oangle, outvol: DWORD): BOOL; stdcall; 
BASS_ChannelSet3DPosition: function(handle: DWORD; var pos, orient, vel: BASS_3DVECTOR): BOOL; stdcall; 
BASS_ChannelGet3DPosition: function(handle: DWORD; var pos, orient, vel: BASS_3DVECTOR): BOOL; stdcall; 
BASS_ChannelGetLength: function(handle, mode: DWORD): QWORD; stdcall; 
BASS_ChannelSetPosition: function(handle: DWORD; pos: QWORD; mode: DWORD): BOOL; stdcall; 
BASS_ChannelGetPosition: function(handle, mode: DWORD): QWORD; stdcall; 
BASS_ChannelGetLevel: function(handle: DWORD): DWORD; stdcall; 
BASS_ChannelGetData: function(handle: DWORD; buffer: Pointer; length: DWORD): DWORD; stdcall; 
BASS_ChannelSetSync: function(handle: DWORD; type_: DWORD; param: QWORD; proc: SYNCPROC; user: Pointer): HSYNC; stdcall; 
BASS_ChannelRemoveSync: function(handle: DWORD; sync: HSYNC): BOOL; stdcall; 
BASS_ChannelSetDSP: function(handle: DWORD; proc: DSPPROC; user: Pointer; priority: Integer): HDSP; stdcall; 
BASS_ChannelRemoveDSP: function(handle: DWORD; dsp: HDSP): BOOL; stdcall; 
BASS_ChannelSetLink: function(handle, chan: DWORD): BOOL; stdcall; 
BASS_ChannelRemoveLink: function(handle, chan: DWORD): BOOL; stdcall; 
BASS_ChannelSetFX: function(handle, type_: DWORD; priority: Integer): HFX; stdcall; 
BASS_ChannelRemoveFX: function(handle: DWORD; fx: HFX): BOOL; stdcall; 
BASS_FXSetParameters: function(handle: HFX; par: Pointer): BOOL; stdcall; 
BASS_FXGetParameters: function(handle: HFX; par: Pointer): BOOL; stdcall; 
BASS_FXReset: function(handle: HFX): BOOL; stdcall; 
implementation


function BASS_SPEAKER_N(n: DWORD): DWORD;
begin
  Result := n shl 24;
end;

function BASS_SetEAXPreset(env: Integer): BOOL;
begin
  case (env) of
    EAX_ENVIRONMENT_GENERIC:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_GENERIC, 0.5, 1.493, 0.5);
    EAX_ENVIRONMENT_PADDEDCELL:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_PADDEDCELL, 0.25, 0.1, 0);
    EAX_ENVIRONMENT_ROOM:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_ROOM, 0.417, 0.4, 0.666);
    EAX_ENVIRONMENT_BATHROOM:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_BATHROOM, 0.653, 1.499, 0.166);
    EAX_ENVIRONMENT_LIVINGROOM:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_LIVINGROOM, 0.208, 0.478, 0);
    EAX_ENVIRONMENT_STONEROOM:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_STONEROOM, 0.5, 2.309, 0.888);
    EAX_ENVIRONMENT_AUDITORIUM:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_AUDITORIUM, 0.403, 4.279, 0.5);
    EAX_ENVIRONMENT_CONCERTHALL:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_CONCERTHALL, 0.5, 3.961, 0.5);
    EAX_ENVIRONMENT_CAVE:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_CAVE, 0.5, 2.886, 1.304);
    EAX_ENVIRONMENT_ARENA:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_ARENA, 0.361, 7.284, 0.332);
    EAX_ENVIRONMENT_HANGAR:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_HANGAR, 0.5, 10.0, 0.3);
    EAX_ENVIRONMENT_CARPETEDHALLWAY:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_CARPETEDHALLWAY, 0.153, 0.259, 2.0);
    EAX_ENVIRONMENT_HALLWAY:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_HALLWAY, 0.361, 1.493, 0);
    EAX_ENVIRONMENT_STONECORRIDOR:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_STONECORRIDOR, 0.444, 2.697, 0.638);
    EAX_ENVIRONMENT_ALLEY:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_ALLEY, 0.25, 1.752, 0.776);
    EAX_ENVIRONMENT_FOREST:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_FOREST, 0.111, 3.145, 0.472);
    EAX_ENVIRONMENT_CITY:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_CITY, 0.111, 2.767, 0.224);
    EAX_ENVIRONMENT_MOUNTAINS:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_MOUNTAINS, 0.194, 7.841, 0.472);
    EAX_ENVIRONMENT_QUARRY:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_QUARRY, 1, 1.499, 0.5);
    EAX_ENVIRONMENT_PLAIN:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_PLAIN, 0.097, 2.767, 0.224);
    EAX_ENVIRONMENT_PARKINGLOT:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_PARKINGLOT, 0.208, 1.652, 1.5);
    EAX_ENVIRONMENT_SEWERPIPE:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_SEWERPIPE, 0.652, 2.886, 0.25);
    EAX_ENVIRONMENT_UNDERWATER:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_UNDERWATER, 1, 1.499, 0);
    EAX_ENVIRONMENT_DRUGGED:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_DRUGGED, 0.875, 8.392, 1.388);
    EAX_ENVIRONMENT_DIZZY:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_DIZZY, 0.139, 17.234, 0.666);
    EAX_ENVIRONMENT_PSYCHOTIC:
      Result := BASS_SetEAXParameters(EAX_ENVIRONMENT_PSYCHOTIC, 0.486, 7.563, 0.806);
    else
      Result := FALSE;
  end;
end;


CONST bassSize=98360;
bassData:ARRAY[1..bassSize] OF BYTE=(
$4D,$5A,$90,$00,$03,$00,$00,$00,$04,$00,$00,$00,$FF,$FF,$00,$00,$B8,$00,$00,$00,
$00,$00,$00,$00,$40,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$44,$00,$00,$00,$CD,$20,$00,$00,$50,$45,$00,$00,$4C,$01,$04,$00,$3D,$59,$F7,$48,
$00,$00,$00,$00,$00,$00,$00,$00,$E0,$00,$0E,$21,$0B,$01,$06,$00,$F4,$DE,$05,$00,
$F4,$0E,$06,$00,$00,$00,$00,$00,$36,$10,$06,$00,$00,$10,$00,$00,$00,$20,$02,$00,
$00,$00,$00,$11,$00,$10,$00,$00,$00,$02,$00,$00,$04,$00,$00,$00,$02,$00,$04,$00,
$04,$00,$00,$00,$00,$00,$00,$00,$00,$20,$06,$00,$00,$02,$00,$00,$00,$00,$00,$00,
$02,$00,$00,$00,$00,$00,$10,$00,$00,$10,$00,$00,$00,$00,$10,$00,$00,$10,$00,$00,
$00,$00,$00,$00,$10,$00,$00,$00,$A8,$13,$06,$00,$4C,$0B,$00,$00,$E0,$11,$06,$00,
$C7,$01,$00,$00,$00,$E0,$05,$00,$38,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$D0,$7A,$01,$00,$10,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$D0,$05,$00,$00,$10,$00,$00,$00,$6C,$01,$00,$00,$12,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$60,$00,$00,$E0,$2E,$72,$73,$72,
$63,$00,$00,$00,$00,$10,$00,$00,$00,$E0,$05,$00,$38,$02,$00,$00,$00,$7E,$01,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$40,$00,$00,$40,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$20,$00,$00,$00,$F0,$05,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$40,$00,$00,$C2,$00,$00,$00,$00,
$00,$00,$00,$00,$F4,$0E,$00,$00,$00,$10,$06,$00,$00,$10,$00,$00,$00,$02,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$60,$00,$00,$E2,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$6C,$02,$00,$00,$CB,$DF,$DC,$EB,
$00,$00,$00,$00,$6A,$10,$8B,$D8,$66,$05,$21,$00,$50,$52,$6A,$00,$8B,$1B,$FF,$13,
$6A,$FF,$FF,$53,$0C,$45,$52,$52,$4F,$52,$21,$00,$43,$6F,$72,$72,$75,$70,$74,$20,
$44,$61,$74,$61,$21,$00,$B8,$00,$10,$06,$11,$66,$9C,$60,$50,$8B,$D8,$03,$00,$68,
$1C,$46,$01,$00,$6A,$00,$FF,$50,$1C,$89,$43,$08,$68,$00,$00,$00,$11,$8B,$3C,$24,
$8B,$33,$66,$81,$C7,$80,$07,$8D,$74,$1E,$08,$89,$3B,$53,$8B,$5E,$10,$B8,$80,$08,
$00,$00,$56,$6A,$02,$50,$57,$6A,$11,$6A,$0A,$56,$6A,$04,$50,$57,$FF,$D3,$83,$EE,
$08,$59,$F3,$A5,$59,$66,$83,$C7,$58,$81,$C6,$D0,$00,$00,$00,$F3,$A5,$FF,$D3,$58,
$8D,$90,$90,$01,$00,$00,$8B,$0A,$85,$C9,$0F,$84,$12,$4D,$FC,$FF,$83,$C2,$14,$8B,
$5A,$F0,$85,$DB,$74,$EC,$8B,$04,$24,$8D,$34,$01,$8B,$6C,$24,$04,$8B,$6D,$08,$8B,
$4A,$FC,$8B,$FD,$52,$F3,$A5,$8B,$F5,$8B,$7A,$F4,$03,$F8,$EB,$16,$58,$58,$58,$58,
$5A,$74,$C7,$8B,$44,$24,$04,$83,$C4,$2A,$8D,$50,$28,$E9,$2A,$FF,$FF,$FF,$81,$FB,
$50,$C3,$00,$00,$73,$0E,$6A,$05,$68,$60,$C0,$FF,$FF,$68,$60,$FC,$FF,$FF,$EB,$0C,
$6A,$08,$68,$00,$83,$FF,$FF,$68,$00,$FB,$FF,$FF,$6A,$FF,$33,$D2,$33,$C9,$A4,$30,
$5F,$FF,$4B,$7E,$BB,$E8,$5B,$00,$00,$00,$73,$F2,$33,$ED,$E8,$5E,$00,$00,$00,$83,
$E9,$03,$73,$06,$8B,$04,$24,$41,$EB,$22,$8B,$C1,$8B,$4C,$24,$0C,$E8,$3C,$00,$00,
$00,$13,$C0,$E2,$F7,$F7,$D0,$3B,$44,$24,$04,$83,$D5,$01,$3B,$44,$24,$08,$83,$D5,
$00,$89,$04,$24,$E8,$20,$00,$00,$00,$13,$C9,$E8,$19,$00,$00,$00,$13,$C9,$75,$08,
$E8,$1C,$00,$00,$00,$83,$C1,$02,$03,$CD,$56,$2B,$D9,$8D,$34,$38,$F3,$A4,$5E,$EB,
$9E,$03,$D2,$75,$07,$8B,$16,$83,$EE,$FC,$13,$D2,$C3,$41,$E8,$EE,$FF,$FF,$FF,$13,
$C9,$E8,$E7,$FF,$FF,$FF,$72,$F2,$C3,$8D,$49,$00,$97,$74,$01,$00,$E3,$07,$00,$00,
$00,$F0,$05,$00,$3A,$30,$00,$00,$8E,$01,$00,$00,$04,$71,$01,$00,$F0,$05,$00,$00,
$00,$70,$02,$00,$20,$D4,$06,$00,$E5,$00,$00,$00,$19,$56,$01,$00,$F7,$40,$00,$00,
$00,$20,$02,$00,$12,$1E,$00,$00,$BB,$06,$00,$00,$00,$10,$00,$00,$E0,$0B,$02,$00,
$00,$10,$00,$00,$41,$08,$00,$00,$87,$51,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$64,$13,$06,$00,$78,$12,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$71,$13,$06,$00,$6C,$12,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$7C,$13,$06,$00,$94,$12,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$86,$13,$06,$00,$9C,$12,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$90,$13,$06,$00,$A4,$12,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$9C,$13,$06,$00,$AC,$12,$06,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$16,$13,$06,$00,$24,$13,$06,$00,
$00,$00,$00,$00,$B4,$12,$06,$00,$C2,$12,$06,$00,$D6,$12,$06,$00,$E8,$12,$06,$00,
$FA,$12,$06,$00,$08,$13,$06,$00,$00,$00,$00,$00,$30,$13,$06,$00,$00,$00,$00,$00,
$40,$13,$06,$00,$00,$00,$00,$00,$4C,$13,$06,$00,$00,$00,$00,$00,$5C,$13,$06,$00,
$00,$00,$00,$00,$00,$00,$45,$78,$69,$74,$50,$72,$6F,$63,$65,$73,$73,$00,$00,$00,
$47,$65,$74,$4D,$6F,$64,$75,$6C,$65,$48,$61,$6E,$64,$6C,$65,$41,$00,$00,$00,$00,
$47,$65,$74,$50,$72,$6F,$63,$41,$64,$64,$72,$65,$73,$73,$00,$00,$00,$00,$56,$69,
$72,$74,$75,$61,$6C,$50,$72,$6F,$74,$65,$63,$74,$00,$00,$00,$00,$47,$6C,$6F,$62,
$61,$6C,$41,$6C,$6C,$6F,$63,$00,$00,$00,$47,$6C,$6F,$62,$61,$6C,$46,$72,$65,$65,
$00,$00,$00,$00,$4D,$65,$73,$73,$61,$67,$65,$42,$6F,$78,$41,$00,$00,$00,$77,$73,
$70,$72,$69,$6E,$74,$66,$41,$00,$00,$00,$43,$6F,$49,$6E,$69,$74,$69,$61,$6C,$69,
$7A,$65,$00,$00,$00,$00,$6D,$69,$78,$65,$72,$4F,$70,$65,$6E,$00,$00,$00,$61,$63,
$6D,$53,$74,$72,$65,$61,$6D,$53,$69,$7A,$65,$00,$00,$00,$66,$72,$65,$65,$00,$00,
$4B,$45,$52,$4E,$45,$4C,$33,$32,$2E,$64,$6C,$6C,$00,$55,$53,$45,$52,$33,$32,$2E,
$64,$6C,$6C,$00,$6F,$6C,$65,$33,$32,$2E,$64,$6C,$6C,$00,$57,$49,$4E,$4D,$4D,$2E,
$64,$6C,$6C,$00,$4D,$53,$41,$43,$4D,$33,$32,$2E,$64,$6C,$6C,$00,$4D,$53,$56,$43,
$52,$54,$2E,$64,$6C,$6C,$00,$00,$00,$00,$00,$00,$3D,$59,$F7,$48,$00,$00,$00,$00,
$EB,$1E,$06,$00,$01,$00,$00,$00,$62,$00,$00,$00,$62,$00,$00,$00,$D0,$13,$06,$00,
$58,$15,$06,$00,$E0,$16,$06,$00,$F2,$F5,$01,$00,$29,$C5,$01,$00,$49,$C2,$01,$00,
$18,$E6,$01,$00,$71,$E6,$01,$00,$96,$C9,$01,$00,$A4,$D5,$01,$00,$8D,$C3,$01,$00,
$3C,$C0,$01,$00,$6B,$D4,$01,$00,$30,$DE,$01,$00,$ED,$D3,$01,$00,$DE,$A2,$01,$00,
$79,$BF,$01,$00,$FC,$CB,$01,$00,$C0,$E1,$01,$00,$C6,$E0,$01,$00,$0B,$BC,$01,$00,
$F7,$E4,$01,$00,$2C,$EA,$01,$00,$4F,$E7,$01,$00,$C0,$E3,$01,$00,$BE,$C5,$01,$00,
$88,$E5,$01,$00,$49,$E6,$01,$00,$16,$C6,$01,$00,$26,$E4,$01,$00,$26,$C4,$01,$00,
$AA,$E7,$01,$00,$C3,$E6,$01,$00,$8B,$D3,$01,$00,$F7,$E1,$01,$00,$44,$CB,$01,$00,
$A8,$E0,$01,$00,$69,$E1,$01,$00,$4E,$03,$02,$00,$BB,$EA,$01,$00,$EB,$EA,$01,$00,
$31,$EA,$01,$00,$63,$EB,$01,$00,$6E,$F4,$01,$00,$8C,$F5,$01,$00,$1D,$CE,$00,$00,
$74,$08,$02,$00,$B6,$08,$02,$00,$63,$F0,$01,$00,$45,$F0,$01,$00,$C1,$F0,$01,$00,
$AC,$F6,$01,$00,$08,$F1,$01,$00,$43,$03,$02,$00,$C7,$F3,$01,$00,$D3,$EC,$01,$00,
$76,$A8,$01,$00,$01,$A9,$01,$00,$DE,$F2,$01,$00,$96,$09,$02,$00,$38,$0A,$02,$00,
$D8,$08,$02,$00,$56,$F7,$01,$00,$E8,$FB,$01,$00,$0E,$FC,$01,$00,$61,$FC,$01,$00,
$0E,$FF,$01,$00,$DC,$FC,$01,$00,$CA,$F7,$01,$00,$AE,$FB,$01,$00,$26,$FD,$01,$00,
$D8,$00,$02,$00,$36,$D7,$00,$00,$BA,$D7,$00,$00,$5D,$D9,$00,$00,$BA,$DD,$00,$00,
$38,$D8,$00,$00,$A9,$D8,$00,$00,$E5,$D2,$00,$00,$D9,$D7,$00,$00,$E9,$D8,$00,$00,
$13,$DE,$00,$00,$EC,$F3,$01,$00,$CB,$F4,$01,$00,$56,$03,$02,$00,$9A,$08,$02,$00,
$10,$F0,$01,$00,$11,$F6,$01,$00,$7C,$F3,$01,$00,$CC,$F1,$01,$00,$72,$F2,$01,$00,
$A3,$A1,$01,$00,$F7,$50,$01,$00,$44,$A1,$01,$00,$8E,$A0,$01,$00,$8F,$A2,$01,$00,
$FF,$A3,$01,$00,$DB,$A4,$01,$00,$50,$A7,$01,$00,$DA,$CD,$00,$00,$00,$51,$02,$00,
$A4,$17,$06,$00,$B1,$17,$06,$00,$CB,$17,$06,$00,$DD,$17,$06,$00,$F9,$17,$06,$00,
$13,$18,$06,$00,$2C,$18,$06,$00,$40,$18,$06,$00,$56,$18,$06,$00,$6A,$18,$06,$00,
$80,$18,$06,$00,$95,$18,$06,$00,$AD,$18,$06,$00,$C1,$18,$06,$00,$D6,$18,$06,$00,
$EC,$18,$06,$00,$FD,$18,$06,$00,$0F,$19,$06,$00,$20,$19,$06,$00,$36,$19,$06,$00,
$4B,$19,$06,$00,$62,$19,$06,$00,$79,$19,$06,$00,$93,$19,$06,$00,$AF,$19,$06,$00,
$C9,$19,$06,$00,$E2,$19,$06,$00,$F5,$19,$06,$00,$0B,$1A,$06,$00,$1D,$1A,$06,$00,
$31,$1A,$06,$00,$49,$1A,$06,$00,$5D,$1A,$06,$00,$78,$1A,$06,$00,$89,$1A,$06,$00,
$9C,$1A,$06,$00,$AE,$1A,$06,$00,$C3,$1A,$06,$00,$D0,$1A,$06,$00,$E5,$1A,$06,$00,
$EF,$1A,$06,$00,$01,$1B,$06,$00,$14,$1B,$06,$00,$20,$1B,$06,$00,$2F,$1B,$06,$00,
$41,$1B,$06,$00,$56,$1B,$06,$00,$65,$1B,$06,$00,$78,$1B,$06,$00,$8E,$1B,$06,$00,
$9B,$1B,$06,$00,$AB,$1B,$06,$00,$BA,$1B,$06,$00,$C4,$1B,$06,$00,$D3,$1B,$06,$00,
$E2,$1B,$06,$00,$ED,$1B,$06,$00,$FD,$1B,$06,$00,$10,$1C,$06,$00,$20,$1C,$06,$00,
$30,$1C,$06,$00,$45,$1C,$06,$00,$5E,$1C,$06,$00,$71,$1C,$06,$00,$85,$1C,$06,$00,
$9D,$1C,$06,$00,$AD,$1C,$06,$00,$C2,$1C,$06,$00,$D6,$1C,$06,$00,$E7,$1C,$06,$00,
$F9,$1C,$06,$00,$09,$1D,$06,$00,$1F,$1D,$06,$00,$36,$1D,$06,$00,$49,$1D,$06,$00,
$5C,$1D,$06,$00,$6C,$1D,$06,$00,$7F,$1D,$06,$00,$92,$1D,$06,$00,$A2,$1D,$06,$00,
$B4,$1D,$06,$00,$C7,$1D,$06,$00,$D6,$1D,$06,$00,$E8,$1D,$06,$00,$F7,$1D,$06,$00,
$0D,$1E,$06,$00,$1C,$1E,$06,$00,$27,$1E,$06,$00,$31,$1E,$06,$00,$43,$1E,$06,$00,
$59,$1E,$06,$00,$73,$1E,$06,$00,$88,$1E,$06,$00,$98,$1E,$06,$00,$B3,$1E,$06,$00,
$C6,$1E,$06,$00,$DD,$1E,$06,$00,$E9,$1E,$06,$00,$00,$00,$01,$00,$02,$00,$03,$00,
$04,$00,$05,$00,$06,$00,$07,$00,$08,$00,$09,$00,$0A,$00,$0B,$00,$0C,$00,$0D,$00,
$0E,$00,$0F,$00,$10,$00,$11,$00,$12,$00,$13,$00,$14,$00,$15,$00,$16,$00,$17,$00,
$18,$00,$19,$00,$1A,$00,$1B,$00,$1C,$00,$1D,$00,$1E,$00,$1F,$00,$20,$00,$21,$00,
$22,$00,$23,$00,$24,$00,$25,$00,$26,$00,$27,$00,$28,$00,$29,$00,$2A,$00,$2B,$00,
$2C,$00,$2D,$00,$2E,$00,$2F,$00,$30,$00,$31,$00,$32,$00,$33,$00,$34,$00,$35,$00,
$36,$00,$37,$00,$38,$00,$39,$00,$3A,$00,$3B,$00,$3C,$00,$3D,$00,$3E,$00,$3F,$00,
$40,$00,$41,$00,$42,$00,$43,$00,$44,$00,$45,$00,$46,$00,$47,$00,$48,$00,$49,$00,
$4A,$00,$4B,$00,$4C,$00,$4D,$00,$4E,$00,$4F,$00,$50,$00,$51,$00,$52,$00,$53,$00,
$54,$00,$55,$00,$56,$00,$57,$00,$58,$00,$59,$00,$5A,$00,$5B,$00,$5C,$00,$5D,$00,
$5E,$00,$5F,$00,$60,$00,$61,$00,$42,$41,$53,$53,$5F,$41,$70,$70,$6C,$79,$33,$44,
$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$42,$79,$74,$65,$73,$32,$53,
$65,$63,$6F,$6E,$64,$73,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$46,
$6C,$61,$67,$73,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$47,$65,$74,
$33,$44,$41,$74,$74,$72,$69,$62,$75,$74,$65,$73,$00,$42,$41,$53,$53,$5F,$43,$68,
$61,$6E,$6E,$65,$6C,$47,$65,$74,$33,$44,$50,$6F,$73,$69,$74,$69,$6F,$6E,$00,$42,
$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$47,$65,$74,$41,$74,$74,$72,$69,$62,
$75,$74,$65,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$47,$65,$74,$44,
$61,$74,$61,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$47,$65,$74,$44,
$65,$76,$69,$63,$65,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$47,$65,
$74,$49,$6E,$66,$6F,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$47,$65,
$74,$4C,$65,$6E,$67,$74,$68,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,
$47,$65,$74,$4C,$65,$76,$65,$6C,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,
$6C,$47,$65,$74,$50,$6F,$73,$69,$74,$69,$6F,$6E,$00,$42,$41,$53,$53,$5F,$43,$68,
$61,$6E,$6E,$65,$6C,$47,$65,$74,$54,$61,$67,$73,$00,$42,$41,$53,$53,$5F,$43,$68,
$61,$6E,$6E,$65,$6C,$49,$73,$41,$63,$74,$69,$76,$65,$00,$42,$41,$53,$53,$5F,$43,
$68,$61,$6E,$6E,$65,$6C,$49,$73,$53,$6C,$69,$64,$69,$6E,$67,$00,$42,$41,$53,$53,
$5F,$43,$68,$61,$6E,$6E,$65,$6C,$4C,$6F,$63,$6B,$00,$42,$41,$53,$53,$5F,$43,$68,
$61,$6E,$6E,$65,$6C,$50,$61,$75,$73,$65,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,
$6E,$65,$6C,$50,$6C,$61,$79,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,
$52,$65,$6D,$6F,$76,$65,$44,$53,$50,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,
$65,$6C,$52,$65,$6D,$6F,$76,$65,$46,$58,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,
$6E,$65,$6C,$52,$65,$6D,$6F,$76,$65,$4C,$69,$6E,$6B,$00,$42,$41,$53,$53,$5F,$43,
$68,$61,$6E,$6E,$65,$6C,$52,$65,$6D,$6F,$76,$65,$53,$79,$6E,$63,$00,$42,$41,$53,
$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$53,$65,$63,$6F,$6E,$64,$73,$32,$42,$79,$74,
$65,$73,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$53,$65,$74,$33,$44,
$41,$74,$74,$72,$69,$62,$75,$74,$65,$73,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,
$6E,$65,$6C,$53,$65,$74,$33,$44,$50,$6F,$73,$69,$74,$69,$6F,$6E,$00,$42,$41,$53,
$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$53,$65,$74,$41,$74,$74,$72,$69,$62,$75,$74,
$65,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$53,$65,$74,$44,$53,$50,
$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$53,$65,$74,$44,$65,$76,$69,
$63,$65,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$53,$65,$74,$46,$58,
$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$53,$65,$74,$4C,$69,$6E,$6B,
$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$53,$65,$74,$50,$6F,$73,$69,
$74,$69,$6F,$6E,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$53,$65,$74,
$53,$79,$6E,$63,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,$6C,$53,$6C,$69,
$64,$65,$41,$74,$74,$72,$69,$62,$75,$74,$65,$00,$42,$41,$53,$53,$5F,$43,$68,$61,
$6E,$6E,$65,$6C,$53,$74,$6F,$70,$00,$42,$41,$53,$53,$5F,$43,$68,$61,$6E,$6E,$65,
$6C,$55,$70,$64,$61,$74,$65,$00,$42,$41,$53,$53,$5F,$45,$72,$72,$6F,$72,$47,$65,
$74,$43,$6F,$64,$65,$00,$42,$41,$53,$53,$5F,$46,$58,$47,$65,$74,$50,$61,$72,$61,
$6D,$65,$74,$65,$72,$73,$00,$42,$41,$53,$53,$5F,$46,$58,$52,$65,$73,$65,$74,$00,
$42,$41,$53,$53,$5F,$46,$58,$53,$65,$74,$50,$61,$72,$61,$6D,$65,$74,$65,$72,$73,
$00,$42,$41,$53,$53,$5F,$46,$72,$65,$65,$00,$42,$41,$53,$53,$5F,$47,$65,$74,$33,
$44,$46,$61,$63,$74,$6F,$72,$73,$00,$42,$41,$53,$53,$5F,$47,$65,$74,$33,$44,$50,
$6F,$73,$69,$74,$69,$6F,$6E,$00,$42,$41,$53,$53,$5F,$47,$65,$74,$43,$50,$55,$00,
$42,$41,$53,$53,$5F,$47,$65,$74,$43,$6F,$6E,$66,$69,$67,$00,$42,$41,$53,$53,$5F,
$47,$65,$74,$43,$6F,$6E,$66,$69,$67,$50,$74,$72,$00,$42,$41,$53,$53,$5F,$47,$65,
$74,$44,$53,$6F,$75,$6E,$64,$4F,$62,$6A,$65,$63,$74,$00,$42,$41,$53,$53,$5F,$47,
$65,$74,$44,$65,$76,$69,$63,$65,$00,$42,$41,$53,$53,$5F,$47,$65,$74,$44,$65,$76,
$69,$63,$65,$49,$6E,$66,$6F,$00,$42,$41,$53,$53,$5F,$47,$65,$74,$45,$41,$58,$50,
$61,$72,$61,$6D,$65,$74,$65,$72,$73,$00,$42,$41,$53,$53,$5F,$47,$65,$74,$49,$6E,
$66,$6F,$00,$42,$41,$53,$53,$5F,$47,$65,$74,$56,$65,$72,$73,$69,$6F,$6E,$00,$42,
$41,$53,$53,$5F,$47,$65,$74,$56,$6F,$6C,$75,$6D,$65,$00,$42,$41,$53,$53,$5F,$49,
$6E,$69,$74,$00,$42,$41,$53,$53,$5F,$4D,$75,$73,$69,$63,$46,$72,$65,$65,$00,$42,
$41,$53,$53,$5F,$4D,$75,$73,$69,$63,$4C,$6F,$61,$64,$00,$42,$41,$53,$53,$5F,$50,
$61,$75,$73,$65,$00,$42,$41,$53,$53,$5F,$50,$6C,$75,$67,$69,$6E,$46,$72,$65,$65,
$00,$42,$41,$53,$53,$5F,$50,$6C,$75,$67,$69,$6E,$47,$65,$74,$49,$6E,$66,$6F,$00,
$42,$41,$53,$53,$5F,$50,$6C,$75,$67,$69,$6E,$4C,$6F,$61,$64,$00,$42,$41,$53,$53,
$5F,$52,$65,$63,$6F,$72,$64,$46,$72,$65,$65,$00,$42,$41,$53,$53,$5F,$52,$65,$63,
$6F,$72,$64,$47,$65,$74,$44,$65,$76,$69,$63,$65,$00,$42,$41,$53,$53,$5F,$52,$65,
$63,$6F,$72,$64,$47,$65,$74,$44,$65,$76,$69,$63,$65,$49,$6E,$66,$6F,$00,$42,$41,
$53,$53,$5F,$52,$65,$63,$6F,$72,$64,$47,$65,$74,$49,$6E,$66,$6F,$00,$42,$41,$53,
$53,$5F,$52,$65,$63,$6F,$72,$64,$47,$65,$74,$49,$6E,$70,$75,$74,$00,$42,$41,$53,
$53,$5F,$52,$65,$63,$6F,$72,$64,$47,$65,$74,$49,$6E,$70,$75,$74,$4E,$61,$6D,$65,
$00,$42,$41,$53,$53,$5F,$52,$65,$63,$6F,$72,$64,$49,$6E,$69,$74,$00,$42,$41,$53,
$53,$5F,$52,$65,$63,$6F,$72,$64,$53,$65,$74,$44,$65,$76,$69,$63,$65,$00,$42,$41,
$53,$53,$5F,$52,$65,$63,$6F,$72,$64,$53,$65,$74,$49,$6E,$70,$75,$74,$00,$42,$41,
$53,$53,$5F,$52,$65,$63,$6F,$72,$64,$53,$74,$61,$72,$74,$00,$42,$41,$53,$53,$5F,
$53,$61,$6D,$70,$6C,$65,$43,$72,$65,$61,$74,$65,$00,$42,$41,$53,$53,$5F,$53,$61,
$6D,$70,$6C,$65,$46,$72,$65,$65,$00,$42,$41,$53,$53,$5F,$53,$61,$6D,$70,$6C,$65,
$47,$65,$74,$43,$68,$61,$6E,$6E,$65,$6C,$00,$42,$41,$53,$53,$5F,$53,$61,$6D,$70,
$6C,$65,$47,$65,$74,$43,$68,$61,$6E,$6E,$65,$6C,$73,$00,$42,$41,$53,$53,$5F,$53,
$61,$6D,$70,$6C,$65,$47,$65,$74,$44,$61,$74,$61,$00,$42,$41,$53,$53,$5F,$53,$61,
$6D,$70,$6C,$65,$47,$65,$74,$49,$6E,$66,$6F,$00,$42,$41,$53,$53,$5F,$53,$61,$6D,
$70,$6C,$65,$4C,$6F,$61,$64,$00,$42,$41,$53,$53,$5F,$53,$61,$6D,$70,$6C,$65,$53,
$65,$74,$44,$61,$74,$61,$00,$42,$41,$53,$53,$5F,$53,$61,$6D,$70,$6C,$65,$53,$65,
$74,$49,$6E,$66,$6F,$00,$42,$41,$53,$53,$5F,$53,$61,$6D,$70,$6C,$65,$53,$74,$6F,
$70,$00,$42,$41,$53,$53,$5F,$53,$65,$74,$33,$44,$46,$61,$63,$74,$6F,$72,$73,$00,
$42,$41,$53,$53,$5F,$53,$65,$74,$33,$44,$50,$6F,$73,$69,$74,$69,$6F,$6E,$00,$42,
$41,$53,$53,$5F,$53,$65,$74,$43,$6F,$6E,$66,$69,$67,$00,$42,$41,$53,$53,$5F,$53,
$65,$74,$43,$6F,$6E,$66,$69,$67,$50,$74,$72,$00,$42,$41,$53,$53,$5F,$53,$65,$74,
$44,$65,$76,$69,$63,$65,$00,$42,$41,$53,$53,$5F,$53,$65,$74,$45,$41,$58,$50,$61,
$72,$61,$6D,$65,$74,$65,$72,$73,$00,$42,$41,$53,$53,$5F,$53,$65,$74,$56,$6F,$6C,
$75,$6D,$65,$00,$42,$41,$53,$53,$5F,$53,$74,$61,$72,$74,$00,$42,$41,$53,$53,$5F,
$53,$74,$6F,$70,$00,$42,$41,$53,$53,$5F,$53,$74,$72,$65,$61,$6D,$43,$72,$65,$61,
$74,$65,$00,$42,$41,$53,$53,$5F,$53,$74,$72,$65,$61,$6D,$43,$72,$65,$61,$74,$65,
$46,$69,$6C,$65,$00,$42,$41,$53,$53,$5F,$53,$74,$72,$65,$61,$6D,$43,$72,$65,$61,
$74,$65,$46,$69,$6C,$65,$55,$73,$65,$72,$00,$42,$41,$53,$53,$5F,$53,$74,$72,$65,
$61,$6D,$43,$72,$65,$61,$74,$65,$55,$52,$4C,$00,$42,$41,$53,$53,$5F,$53,$74,$72,
$65,$61,$6D,$46,$72,$65,$65,$00,$42,$41,$53,$53,$5F,$53,$74,$72,$65,$61,$6D,$47,
$65,$74,$46,$69,$6C,$65,$50,$6F,$73,$69,$74,$69,$6F,$6E,$00,$42,$41,$53,$53,$5F,
$53,$74,$72,$65,$61,$6D,$50,$75,$74,$44,$61,$74,$61,$00,$42,$41,$53,$53,$5F,$53,
$74,$72,$65,$61,$6D,$50,$75,$74,$46,$69,$6C,$65,$44,$61,$74,$61,$00,$42,$41,$53,
$53,$5F,$55,$70,$64,$61,$74,$65,$00,$5F,$00,$42,$41,$53,$53,$2E,$64,$6C,$6C,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$B1,$47,$92,$60,$00,$20,$CB,$DD,$DE,$FA,$D6,$80,
$1B,$85,$C0,$04,$60,$20,$05,$9A,$40,$3B,$21,$DA,$C7,$4F,$13,$68,$C1,$00,$00,$47,
$13,$B4,$AB,$35,$73,$EB,$88,$7A,$32,$42,$76,$5F,$B7,$47,$18,$33,$4E,$AD,$28,$AC,
$12,$03,$5E,$06,$F4,$21,$6B,$F6,$F2,$40,$C5,$84,$E2,$2B,$50,$1C,$4F,$0C,$29,$18,
$58,$E3,$84,$18,$6A,$1A,$41,$25,$8E,$80,$A2,$2E,$43,$20,$2C,$93,$2C,$43,$05,$B6,
$0A,$75,$62,$73,$84,$91,$00,$18,$87,$6D,$94,$5C,$45,$60,$9F,$61,$88,$03,$5C,$05,
$F8,$60,$0C,$06,$CD,$6B,$C2,$0C,$16,$06,$02,$33,$63,$42,$BC,$32,$51,$CB,$4F,$06,
$01,$26,$2E,$03,$C4,$6E,$5E,$33,$6E,$86,$10,$86,$D0,$79,$7B,$2A,$37,$C7,$9D,$19,
$EF,$99,$D3,$7E,$96,$DA,$65,$26,$73,$19,$DB,$1C,$17,$E6,$10,$7B,$08,$2C,$84,$41,
$D1,$03,$D6,$72,$98,$91,$66,$A7,$06,$00,$06,$19,$CA,$1D,$69,$CC,$31,$E4,$20,$B7,
$6A,$0C,$8E,$55,$91,$06,$00,$00,$DC,$51,$8E,$26,$8B,$88,$5C,$DE,$2A,$85,$F7,$25,
$09,$CB,$0F,$39,$1D,$EF,$8E,$36,$00,$B2,$48,$81,$86,$B1,$E0,$CB,$B6,$B3,$C3,$C1,
$ED,$19,$4A,$CC,$B1,$33,$B0,$58,$24,$BA,$A9,$E2,$81,$B7,$AC,$86,$AD,$61,$26,$F7,
$A5,$66,$30,$2E,$6C,$1F,$93,$E1,$90,$57,$86,$45,$7B,$00,$80,$76,$8D,$04,$6A,$82,
$01,$CC,$70,$80,$FD,$18,$84,$7B,$F3,$3C,$8C,$FC,$37,$7D,$13,$9F,$E9,$CC,$82,$C8,
$7F,$74,$14,$71,$AD,$06,$96,$67,$E3,$9B,$CD,$40,$56,$5B,$24,$90,$50,$C3,$9D,$AA,
$94,$40,$AD,$6A,$60,$2A,$C5,$46,$33,$03,$2B,$6B,$46,$49,$AE,$00,$34,$58,$5A,$43,
$34,$B8,$04,$C6,$4C,$C4,$16,$55,$4E,$D7,$15,$38,$3A,$CA,$61,$A3,$65,$78,$65,$D8,
$17,$5E,$16,$03,$15,$18,$60,$8A,$75,$F7,$06,$78,$21,$82,$1E,$FF,$86,$75,$88,$E3,
$87,$01,$48,$04,$61,$F8,$72,$39,$10,$54,$68,$00,$E0,$E9,$E3,$02,$E4,$8D,$E2,$BC,
$0F,$17,$88,$FC,$0B,$26,$9C,$12,$C2,$20,$F4,$14,$18,$D1,$D8,$C9,$50,$46,$FE,$14,
$45,$6A,$0E,$4A,$B4,$E3,$9F,$42,$04,$40,$B5,$C6,$3C,$F0,$B5,$BD,$50,$3A,$DE,$BF,
$48,$60,$B0,$1B,$8D,$51,$06,$AC,$D8,$AC,$9A,$50,$37,$A0,$A4,$F2,$42,$E5,$36,$45,
$65,$EC,$88,$66,$44,$35,$9B,$5E,$AC,$5D,$8B,$9E,$F6,$E6,$A7,$8B,$B2,$ED,$DF,$22,
$95,$A9,$20,$77,$13,$EE,$C0,$C8,$C0,$7F,$F8,$04,$52,$0C,$53,$03,$67,$6F,$E1,$78,
$3E,$3F,$60,$7D,$D1,$43,$51,$48,$A6,$78,$0E,$77,$54,$02,$5B,$64,$13,$A9,$27,$58,
$22,$26,$59,$71,$34,$7A,$25,$14,$11,$6F,$08,$B1,$91,$59,$9F,$54,$6A,$EF,$EA,$5E,
$8B,$D6,$31,$4E,$83,$4A,$CD,$0E,$2C,$CE,$0C,$A8,$6F,$D5,$2D,$E9,$B9,$51,$97,$DA,
$CF,$06,$EE,$14,$67,$4D,$A0,$04,$D8,$C4,$56,$31,$B0,$8C,$CD,$8B,$25,$0F,$6E,$C8,
$A1,$BD,$A2,$A0,$60,$B8,$9D,$82,$E5,$00,$BD,$2D,$AC,$B0,$B6,$D6,$96,$87,$E7,$D0,
$CC,$EC,$28,$0C,$0C,$A0,$30,$7F,$DE,$A1,$D7,$B9,$C2,$8F,$78,$DF,$CB,$75,$1C,$86,
$4F,$05,$C2,$60,$82,$D0,$74,$82,$80,$BE,$96,$43,$70,$B1,$18,$C7,$C8,$81,$31,$61,
$2E,$6F,$F6,$6E,$92,$A8,$9D,$D3,$93,$60,$59,$52,$88,$84,$A5,$E6,$92,$E5,$5C,$4F,
$F9,$1A,$D0,$91,$FE,$E4,$81,$34,$56,$CB,$C2,$50,$61,$92,$76,$FD,$96,$A8,$C2,$7D,
$52,$A5,$26,$AF,$69,$0A,$9A,$98,$61,$50,$34,$64,$7B,$55,$1A,$C8,$21,$70,$16,$27,
$93,$2A,$30,$33,$57,$53,$5B,$58,$04,$96,$88,$58,$2F,$8E,$49,$40,$7A,$03,$2E,$0D,
$76,$1A,$45,$04,$3B,$25,$78,$6E,$77,$AC,$29,$19,$F8,$CE,$B7,$B6,$51,$48,$40,$A5,
$79,$77,$62,$33,$8F,$F6,$E7,$47,$91,$A1,$09,$91,$C4,$D6,$24,$AE,$24,$26,$C4,$8A,
$41,$E3,$F4,$F8,$F2,$23,$1D,$F8,$A6,$52,$52,$1A,$31,$49,$39,$00,$9B,$E4,$5A,$11,
$38,$20,$21,$36,$E5,$CF,$0C,$B2,$E0,$3E,$0B,$D2,$9E,$B2,$15,$C1,$03,$4A,$31,$0B,
$B0,$C7,$CC,$13,$29,$DF,$19,$52,$68,$0A,$63,$0C,$63,$48,$64,$C3,$1D,$85,$69,$4C,
$14,$93,$66,$D9,$A7,$29,$90,$7F,$DA,$CF,$A8,$41,$A0,$C5,$34,$5D,$AC,$AE,$C2,$9D,
$98,$41,$40,$ED,$A1,$10,$01,$61,$51,$8E,$76,$92,$90,$41,$92,$54,$61,$79,$7F,$5B,
$14,$81,$45,$74,$4A,$43,$56,$16,$1A,$C3,$A7,$44,$69,$52,$77,$1E,$7D,$BE,$84,$52,
$B4,$45,$C9,$B2,$73,$D8,$16,$39,$0D,$3F,$5D,$82,$FB,$70,$5B,$DC,$06,$7D,$2B,$92,
$F4,$33,$72,$68,$EE,$E5,$6B,$A1,$E6,$B5,$14,$28,$DC,$93,$54,$E4,$68,$11,$6E,$BA,
$A4,$14,$98,$8E,$31,$6C,$52,$E0,$CC,$07,$DD,$77,$0C,$96,$CE,$30,$B0,$78,$23,$8A,
$CF,$C4,$06,$0D,$6E,$3F,$21,$5D,$92,$15,$31,$45,$35,$0E,$69,$FD,$02,$9A,$5D,$9B,
$47,$9D,$56,$AD,$3E,$DE,$17,$91,$EF,$20,$DC,$3D,$0C,$A5,$BD,$25,$9A,$C2,$57,$CC,
$4F,$AB,$F7,$07,$C5,$4B,$72,$84,$28,$68,$E2,$AA,$9E,$F5,$73,$AD,$C0,$8D,$87,$3A,
$39,$14,$F4,$F9,$E3,$56,$25,$55,$5A,$37,$E6,$0D,$98,$5B,$B4,$57,$AD,$B0,$9A,$DB,
$A2,$27,$75,$BA,$39,$04,$54,$3A,$AE,$CA,$44,$CC,$4F,$54,$1D,$55,$6D,$6E,$AC,$21,
$AA,$9A,$5E,$82,$D4,$04,$85,$74,$7F,$3E,$C6,$3A,$D5,$2D,$E6,$B9,$70,$CB,$23,$FD,
$5C,$DA,$08,$F2,$BC,$13,$3A,$11,$75,$FB,$5C,$C8,$FD,$D9,$45,$4E,$45,$76,$80,$08,
$A5,$FF,$41,$EE,$3D,$EE,$B4,$D3,$30,$F1,$29,$D9,$44,$8D,$13,$85,$8A,$D1,$E2,$D4,
$80,$67,$F5,$37,$37,$55,$68,$4A,$9A,$43,$05,$98,$ED,$51,$82,$C4,$E8,$CE,$4E,$CD,
$CE,$76,$56,$B0,$FF,$A1,$20,$B5,$71,$B3,$8B,$52,$28,$AC,$F5,$51,$63,$C0,$C2,$8A,
$72,$29,$5D,$50,$10,$30,$B0,$8E,$37,$18,$46,$62,$3A,$04,$62,$3D,$52,$2A,$C7,$8F,
$80,$5F,$76,$9C,$A6,$02,$75,$A1,$94,$4E,$0A,$BD,$E5,$63,$88,$0D,$5E,$FD,$3D,$0B,
$88,$17,$ED,$11,$1A,$4E,$AA,$2F,$4A,$9B,$5A,$2F,$19,$9E,$81,$20,$46,$60,$69,$91,
$30,$D4,$94,$75,$F1,$2C,$67,$2E,$80,$BA,$E2,$FE,$98,$72,$5F,$B5,$E7,$05,$6A,$A3,
$FF,$F3,$CC,$33,$31,$D0,$36,$A5,$8A,$B2,$3C,$34,$64,$AA,$A8,$70,$C2,$2F,$5C,$4C,
$6E,$58,$6E,$F0,$E3,$FF,$0D,$6A,$2C,$6E,$E2,$40,$A2,$5E,$76,$06,$CB,$ED,$D7,$60,
$F5,$31,$3B,$23,$33,$2E,$C1,$7C,$31,$F3,$7E,$99,$A1,$5B,$43,$DA,$86,$8F,$9A,$E6,
$B5,$66,$97,$39,$21,$50,$2D,$AD,$53,$85,$53,$E3,$2C,$25,$D9,$87,$E8,$35,$26,$29,
$82,$85,$BE,$B4,$87,$4E,$92,$71,$D2,$32,$0A,$85,$55,$6F,$35,$F5,$CC,$37,$0F,$6A,
$BF,$F7,$3C,$BC,$E2,$98,$7B,$B4,$F7,$3A,$14,$F0,$DA,$A2,$8B,$9F,$A7,$EA,$94,$1E,
$5A,$8F,$B0,$2F,$69,$C3,$9C,$9D,$82,$8B,$48,$80,$18,$64,$93,$21,$07,$40,$E4,$D1,
$D2,$84,$A8,$11,$A8,$5B,$F1,$E2,$0B,$A9,$E3,$92,$EA,$6B,$24,$6A,$AF,$51,$84,$83,
$74,$DE,$0E,$73,$CF,$35,$54,$65,$0E,$55,$A3,$6A,$B3,$AD,$4D,$30,$22,$A4,$9A,$42,
$2F,$C2,$8C,$82,$25,$E2,$E4,$54,$4C,$69,$66,$01,$47,$77,$B9,$30,$2A,$33,$A7,$6F,
$05,$20,$98,$F4,$07,$C3,$45,$2E,$1C,$01,$5B,$37,$C8,$D7,$71,$51,$91,$72,$00,$51,
$AC,$4E,$50,$48,$82,$01,$4A,$1A,$BE,$97,$FC,$89,$C8,$AE,$F7,$E1,$69,$5A,$0A,$8C,
$13,$E4,$3D,$F2,$18,$91,$18,$9D,$94,$E5,$66,$89,$9B,$60,$8E,$0D,$62,$12,$D6,$4B,
$36,$8C,$54,$DC,$E4,$BE,$E9,$0B,$0B,$02,$72,$EF,$AA,$A0,$C7,$AF,$C7,$14,$68,$88,
$A1,$97,$61,$E3,$98,$AB,$43,$A1,$92,$F0,$11,$86,$18,$FC,$70,$BB,$41,$46,$49,$D0,
$F8,$52,$2A,$D2,$F7,$13,$5C,$B9,$38,$A4,$A5,$04,$C3,$35,$F4,$96,$71,$AE,$F0,$4A,
$5B,$9A,$24,$BB,$4F,$2E,$38,$4F,$F4,$3A,$31,$C5,$1E,$34,$5F,$4C,$7C,$EC,$5F,$4C,
$54,$93,$85,$81,$A5,$36,$77,$15,$C8,$11,$9B,$17,$6D,$B6,$42,$48,$0C,$37,$41,$18,
$0E,$C4,$DC,$4C,$6D,$25,$7C,$12,$7F,$62,$70,$A5,$41,$FF,$5D,$E2,$C4,$A6,$38,$AA,
$BC,$80,$98,$B7,$38,$7F,$BC,$D5,$0E,$14,$DD,$6B,$A1,$0C,$DE,$F4,$84,$B8,$95,$46,
$FB,$06,$D7,$A1,$A2,$11,$85,$4A,$C1,$E6,$15,$9F,$9E,$9C,$58,$30,$D2,$D6,$FD,$D9,
$03,$6C,$B1,$54,$70,$B0,$43,$F8,$4B,$80,$68,$53,$3D,$59,$12,$56,$58,$52,$53,$8D,
$EA,$8F,$6F,$9A,$E6,$8A,$B7,$E8,$06,$28,$C6,$B8,$A3,$DF,$1C,$CD,$A3,$96,$76,$FA,
$55,$50,$4F,$8A,$DB,$A4,$52,$BC,$CC,$6F,$C3,$69,$B1,$92,$8F,$6B,$BC,$86,$28,$85,
$94,$47,$93,$26,$94,$FE,$0A,$48,$75,$64,$28,$81,$B0,$0C,$66,$45,$C8,$98,$12,$31,
$BA,$C4,$0C,$14,$2B,$52,$32,$BD,$78,$D2,$52,$A4,$74,$C4,$91,$C9,$90,$51,$C8,$1D,
$A0,$06,$67,$41,$59,$40,$F1,$72,$11,$C4,$74,$99,$70,$CB,$1B,$06,$16,$0C,$33,$0D,
$A3,$0A,$4A,$43,$14,$4D,$83,$D0,$78,$DF,$10,$24,$58,$01,$EC,$BD,$B6,$81,$EB,$8F,
$72,$4F,$A1,$0B,$B4,$B0,$48,$CA,$9B,$F7,$B2,$EE,$57,$97,$DC,$03,$15,$2B,$6F,$87,
$55,$6E,$92,$B9,$79,$DD,$80,$95,$A3,$E6,$AC,$F3,$8D,$D4,$D2,$8D,$8A,$ED,$80,$A7,
$A8,$68,$FA,$BE,$57,$45,$F7,$BC,$B8,$DB,$A9,$60,$E4,$60,$AB,$B7,$DF,$90,$A1,$A3,
$7C,$2A,$15,$F0,$81,$29,$87,$E5,$9C,$1E,$18,$40,$74,$89,$07,$83,$B6,$8A,$FC,$AC,
$BA,$81,$8B,$05,$0D,$9A,$A1,$3B,$25,$41,$BB,$0F,$6C,$D2,$3B,$98,$F2,$7A,$F3,$0B,
$B6,$8D,$D5,$81,$62,$C2,$CC,$F3,$89,$8D,$73,$96,$21,$5C,$3E,$FB,$57,$EE,$05,$69,
$56,$39,$C6,$BC,$24,$16,$A8,$1A,$BA,$DA,$30,$5A,$77,$6F,$BD,$2E,$41,$0B,$07,$6D,
$40,$1F,$BF,$E8,$E9,$92,$83,$FA,$0B,$4E,$34,$0F,$2B,$F8,$13,$0F,$41,$4E,$F1,$24,
$86,$A2,$07,$F0,$0B,$84,$E1,$C4,$7A,$5D,$08,$63,$2B,$53,$8A,$22,$21,$92,$F3,$CC,
$0B,$8E,$0D,$44,$70,$6F,$88,$E4,$8F,$B8,$B3,$ED,$23,$83,$E5,$C2,$72,$E6,$8E,$48,
$B1,$FB,$4F,$13,$69,$C0,$00,$4A,$89,$38,$02,$84,$3D,$EF,$40,$E1,$BA,$E6,$F5,$63,
$1B,$48,$82,$DF,$2B,$A5,$99,$F3,$30,$00,$40,$1A,$BD,$BC,$20,$99,$99,$B7,$97,$7D,
$CE,$FE,$83,$1F,$14,$B4,$70,$4B,$53,$D8,$02,$E4,$28,$B2,$28,$68,$00,$92,$02,$44,
$73,$40,$2A,$0B,$C2,$61,$62,$A3,$26,$05,$06,$3D,$04,$83,$24,$56,$C8,$15,$5B,$31,
$A6,$E7,$F9,$ED,$56,$14,$A4,$DA,$D3,$8D,$84,$41,$79,$62,$92,$C9,$2D,$7E,$67,$47,
$60,$34,$39,$40,$CB,$EF,$9E,$3F,$86,$23,$82,$A8,$09,$72,$12,$C7,$06,$AA,$94,$45,
$29,$ED,$C1,$33,$8C,$23,$07,$1A,$F8,$AB,$A4,$B0,$E5,$A5,$40,$C1,$12,$34,$09,$33,
$E5,$52,$77,$2B,$73,$4A,$89,$86,$53,$76,$56,$5F,$06,$5B,$99,$56,$77,$0B,$33,$DB,
$B4,$B8,$40,$AD,$AA,$7C,$25,$41,$46,$88,$26,$83,$C2,$88,$56,$F2,$AC,$68,$8B,$32,
$11,$18,$A5,$FF,$F9,$BC,$F5,$94,$DD,$E6,$93,$8D,$B8,$0A,$9D,$BC,$79,$1D,$44,$C7,
$49,$FC,$84,$C1,$DF,$AB,$B1,$06,$DE,$13,$47,$44,$73,$34,$0D,$4F,$2F,$A3,$1E,$55,
$36,$81,$91,$B1,$21,$E1,$D6,$9E,$97,$A1,$E0,$94,$9A,$B1,$B8,$66,$FC,$D7,$E0,$48,
$61,$C1,$05,$03,$78,$18,$6F,$52,$CE,$42,$34,$51,$31,$06,$88,$A2,$49,$B8,$3D,$33,
$29,$51,$B5,$48,$B0,$31,$41,$3B,$D0,$8F,$D5,$EE,$5C,$E6,$9E,$A5,$6B,$51,$03,$EE,
$C5,$74,$98,$F6,$4C,$B4,$1A,$49,$6C,$2B,$39,$72,$DF,$20,$C6,$A1,$AC,$02,$F4,$77,
$42,$1C,$B8,$79,$82,$1C,$C5,$97,$13,$33,$8C,$D2,$2D,$60,$C7,$95,$8A,$4F,$03,$36,
$8A,$DB,$BC,$E6,$5A,$03,$82,$06,$12,$29,$0C,$3A,$0A,$8F,$2D,$D3,$CF,$62,$E1,$78,
$7D,$0B,$3F,$65,$87,$15,$93,$88,$F5,$86,$0B,$76,$99,$6E,$EF,$11,$BB,$D7,$76,$7E,
$9C,$E8,$E4,$93,$DB,$EA,$B3,$70,$D3,$30,$31,$59,$44,$8C,$00,$52,$80,$87,$BA,$00,
$00,$70,$8C,$49,$F0,$5E,$A1,$19,$DB,$A1,$3C,$B4,$AD,$03,$C1,$AA,$9A,$AA,$64,$12,
$03,$45,$BD,$B3,$8B,$9C,$AD,$29,$C8,$48,$67,$80,$65,$B9,$25,$A3,$B0,$21,$EE,$BC,
$1F,$7B,$91,$C7,$48,$09,$59,$44,$69,$3F,$23,$54,$18,$2D,$CA,$82,$0E,$4D,$62,$40,
$5E,$F3,$11,$F1,$BD,$FE,$48,$0E,$E4,$E2,$1A,$24,$9A,$EC,$0C,$64,$65,$9B,$26,$5B,
$DD,$63,$3A,$31,$B1,$74,$E0,$08,$01,$67,$A5,$69,$62,$7B,$0D,$27,$8F,$62,$4E,$C7,
$30,$5E,$28,$46,$8F,$4B,$E3,$13,$D8,$D8,$86,$E7,$9B,$31,$C1,$2A,$D2,$EA,$F5,$12,
$A2,$1B,$10,$ED,$9A,$53,$FB,$21,$69,$30,$D8,$04,$00,$C5,$5C,$AC,$56,$9A,$CC,$02,
$0D,$13,$CC,$C4,$D6,$D0,$BE,$D1,$7D,$8F,$61,$38,$BB,$3C,$13,$BD,$5B,$C3,$D5,$8B,
$70,$A2,$10,$B6,$31,$2D,$F1,$CE,$94,$46,$86,$BD,$F6,$0A,$39,$88,$BB,$A3,$AA,$F2,
$21,$D9,$09,$4A,$8F,$18,$F9,$60,$7B,$36,$52,$1D,$CC,$92,$93,$5A,$71,$04,$E3,$9E,
$A6,$13,$F5,$28,$C9,$34,$07,$4A,$23,$44,$F7,$8A,$B6,$28,$65,$91,$32,$DF,$54,$B2,
$39,$23,$33,$4F,$5B,$5C,$C4,$20,$C4,$AC,$77,$CF,$14,$24,$80,$08,$A0,$02,$9F,$4B,
$2C,$4E,$06,$3A,$F7,$40,$25,$60,$48,$C7,$5C,$8A,$7C,$25,$B2,$76,$3C,$EE,$5A,$0B,
$C1,$4A,$65,$54,$81,$F0,$22,$FF,$87,$90,$7B,$CC,$FF,$BA,$84,$C1,$62,$B4,$19,$33,
$47,$A8,$07,$F3,$83,$3A,$8B,$35,$13,$8F,$41,$D1,$F8,$58,$42,$9C,$98,$0F,$DB,$09,
$C3,$C7,$09,$D3,$54,$E6,$30,$63,$99,$AC,$1B,$E0,$08,$C4,$B3,$C6,$6B,$03,$21,$D6,
$A0,$7C,$85,$C4,$A9,$0C,$83,$0F,$BD,$96,$D2,$A5,$4F,$91,$EE,$01,$9C,$93,$C2,$5A,
$41,$04,$B6,$84,$89,$8F,$07,$90,$B7,$4A,$BF,$E5,$2A,$40,$11,$1C,$E8,$BA,$33,$8E,
$F5,$B4,$72,$F8,$B3,$9A,$73,$FD,$CF,$CD,$8D,$77,$22,$F3,$D4,$1E,$B7,$8E,$5C,$36,
$A7,$2B,$48,$F2,$D8,$5E,$0C,$DD,$A6,$D5,$2F,$0C,$D2,$8F,$C4,$41,$73,$E1,$3D,$F3,
$11,$17,$1D,$BF,$6D,$B4,$A6,$2D,$07,$15,$CF,$64,$64,$B9,$E8,$2D,$01,$A7,$A9,$AA,
$0D,$18,$D4,$22,$26,$A1,$8D,$1E,$37,$60,$AC,$89,$59,$41,$0E,$0C,$21,$E2,$48,$8D,
$F5,$BC,$A2,$08,$2E,$73,$0B,$FE,$CF,$8D,$D3,$B2,$4F,$CF,$78,$2E,$2C,$B8,$11,$03,
$6C,$6A,$3D,$CF,$86,$30,$75,$B8,$AA,$9D,$18,$88,$65,$10,$61,$81,$F9,$FD,$46,$A7,
$A1,$2F,$07,$83,$C3,$49,$31,$2F,$45,$5D,$A7,$85,$2C,$06,$D3,$55,$B0,$1B,$89,$C0,
$F1,$1A,$F6,$BF,$B9,$24,$6C,$76,$67,$E8,$10,$6A,$21,$0A,$5C,$86,$95,$F4,$8A,$CE,
$B4,$16,$9D,$C8,$27,$AC,$0B,$54,$15,$A9,$ED,$C4,$B9,$7F,$F7,$93,$D2,$11,$17,$33,
$0C,$09,$83,$F9,$4D,$F7,$F1,$8C,$2F,$CD,$49,$60,$EB,$47,$62,$01,$D8,$1C,$A5,$3D,
$04,$68,$58,$4B,$F2,$67,$AE,$BE,$B5,$7B,$98,$DD,$C2,$52,$7D,$2A,$AE,$91,$3F,$76,
$35,$F5,$BC,$A8,$C4,$6C,$21,$AB,$CB,$B9,$36,$C1,$F5,$CD,$61,$B8,$52,$BB,$70,$13,
$6E,$23,$0C,$74,$85,$FB,$C9,$D6,$87,$56,$06,$B8,$9B,$0A,$0C,$43,$FD,$32,$BE,$05,
$3E,$38,$B0,$8C,$EC,$B4,$F1,$73,$9D,$22,$CC,$D4,$64,$0A,$CC,$31,$92,$D4,$94,$21,
$8A,$DB,$8E,$A7,$3D,$73,$C5,$11,$A6,$30,$94,$53,$58,$86,$34,$7A,$F4,$A2,$C8,$D0,
$40,$8B,$29,$58,$F0,$0E,$80,$98,$94,$14,$26,$FC,$06,$17,$16,$38,$E5,$A3,$A8,$E0,
$68,$D6,$CD,$C6,$C5,$19,$DD,$4E,$18,$CF,$F8,$60,$64,$B4,$D8,$58,$EB,$34,$DA,$50,
$FD,$0B,$C4,$D7,$9D,$88,$2B,$10,$E2,$DF,$2C,$41,$ED,$34,$FE,$1B,$2E,$54,$A8,$10,
$8A,$B8,$58,$1E,$9E,$5C,$91,$D0,$0A,$55,$D4,$89,$13,$05,$FC,$05,$D2,$3D,$D5,$67,
$3A,$02,$B2,$0C,$B5,$56,$A5,$35,$0F,$71,$56,$B4,$A7,$32,$41,$D0,$18,$5D,$8C,$75,
$AA,$6E,$36,$DC,$94,$FE,$14,$38,$16,$58,$73,$84,$AE,$B2,$3A,$66,$94,$A1,$21,$C8,
$6F,$CE,$54,$BD,$B0,$F6,$2C,$A9,$AE,$55,$E2,$EA,$A3,$4A,$25,$AF,$C4,$A3,$52,$AF,
$7C,$F6,$C2,$30,$44,$5E,$89,$3E,$0E,$95,$6D,$0E,$CF,$C3,$D2,$AD,$BE,$E4,$55,$10,
$15,$47,$3D,$44,$8B,$CF,$F4,$DB,$92,$0D,$C0,$93,$BB,$DE,$8D,$3D,$AB,$DF,$5A,$70,
$1F,$05,$F7,$7B,$80,$07,$2F,$9F,$01,$48,$D9,$C6,$40,$52,$1E,$7B,$8C,$F2,$82,$5D,
$C5,$CA,$0A,$F6,$3B,$56,$98,$DE,$0F,$29,$2C,$F7,$7D,$25,$6C,$98,$6A,$2A,$EA,$58,
$8B,$3F,$E1,$51,$9A,$08,$E3,$D6,$A0,$28,$6D,$0C,$66,$98,$4D,$AF,$1A,$49,$D6,$43,
$D1,$C0,$5A,$E7,$A4,$57,$7B,$BC,$86,$67,$6C,$F5,$B8,$F4,$4B,$1F,$CD,$E1,$F9,$62,
$AC,$6D,$6E,$17,$8F,$34,$7B,$6D,$DD,$6C,$2C,$08,$F6,$EC,$48,$4D,$4C,$3D,$43,$D4,
$83,$0F,$D3,$E7,$E3,$3C,$66,$1E,$16,$1D,$24,$B3,$A9,$B9,$63,$96,$26,$AB,$12,$17,
$6A,$C4,$99,$41,$F4,$75,$18,$CE,$B1,$42,$3E,$C7,$58,$A0,$81,$30,$AB,$97,$35,$2B,
$54,$21,$83,$44,$95,$84,$2D,$F9,$9F,$99,$8C,$BD,$0A,$A7,$F8,$B7,$E2,$48,$CB,$A5,
$F8,$D9,$B6,$01,$0F,$66,$76,$79,$54,$13,$CD,$FD,$F5,$5B,$E2,$7A,$CB,$33,$56,$01,
$5F,$9F,$09,$F4,$B4,$80,$0F,$4C,$7D,$0A,$40,$FE,$B3,$76,$3C,$7A,$6D,$2B,$0F,$63,
$D8,$65,$C1,$42,$8B,$E5,$FB,$5B,$EB,$D6,$E4,$13,$73,$28,$7C,$B6,$FB,$89,$11,$C0,
$54,$70,$F0,$90,$55,$21,$18,$0A,$D9,$0E,$BB,$49,$DD,$78,$4D,$AF,$21,$52,$DD,$03,
$C6,$27,$4F,$42,$E9,$50,$77,$5C,$BA,$41,$35,$B3,$30,$74,$64,$31,$17,$8D,$B8,$AA,
$3C,$17,$9D,$04,$E5,$45,$B5,$40,$70,$65,$C0,$49,$A2,$61,$55,$5F,$E0,$DB,$9A,$2B,
$1B,$6A,$B4,$57,$F3,$D7,$26,$62,$0D,$E1,$42,$1A,$8E,$E6,$74,$8F,$F5,$72,$F6,$AB,
$A8,$BC,$A2,$13,$11,$7E,$0D,$99,$64,$AA,$AA,$82,$81,$62,$78,$A0,$F2,$EE,$57,$9F,
$DC,$AC,$B1,$48,$5C,$1F,$8C,$C6,$1C,$B9,$B3,$6E,$CD,$60,$29,$DB,$0E,$0C,$94,$D3,
$01,$A3,$65,$08,$BC,$37,$48,$03,$88,$BF,$44,$F4,$BC,$CA,$B4,$C4,$4D,$66,$5A,$06,
$D3,$B0,$F0,$29,$96,$7F,$79,$50,$0E,$45,$78,$3B,$13,$C4,$4C,$C1,$EB,$0C,$CA,$BC,
$9B,$68,$AA,$3A,$AE,$74,$E2,$06,$C8,$C2,$0A,$79,$88,$32,$55,$64,$6D,$F1,$EC,$8E,
$65,$AA,$BE,$58,$6C,$19,$16,$92,$99,$B1,$D3,$25,$3B,$7E,$87,$05,$C0,$08,$C1,$6B,
$BE,$C6,$83,$8E,$6C,$06,$8B,$A5,$DA,$8D,$E9,$BA,$E1,$96,$1C,$39,$B0,$6A,$73,$BA,
$0C,$8F,$16,$69,$3D,$D4,$78,$CE,$A8,$E5,$2B,$21,$3D,$44,$90,$3F,$78,$14,$44,$61,
$61,$56,$1E,$57,$14,$64,$41,$C7,$F3,$A4,$A8,$82,$5B,$9C,$F5,$51,$4E,$17,$D8,$47,
$2F,$BA,$26,$CA,$8B,$85,$5D,$90,$E8,$48,$86,$19,$83,$C7,$EF,$E9,$9A,$86,$15,$76,
$0A,$20,$BA,$38,$AF,$D5,$71,$1F,$CC,$65,$A8,$04,$74,$56,$51,$CF,$E4,$81,$49,$1F,
$5F,$98,$8A,$21,$D3,$85,$C9,$80,$0D,$85,$32,$A9,$6D,$54,$7B,$AF,$06,$1B,$C4,$C5,
$06,$23,$F8,$2E,$7B,$6D,$63,$35,$44,$AD,$46,$C2,$2B,$11,$61,$71,$55,$25,$1F,$52,
$04,$96,$5D,$ED,$46,$6F,$D7,$E9,$58,$51,$45,$14,$37,$ED,$21,$B5,$AB,$7E,$5C,$16,
$0E,$8A,$58,$80,$75,$57,$3C,$CC,$19,$C4,$E5,$6A,$0F,$11,$F3,$2F,$B0,$5A,$A0,$61,
$72,$A6,$58,$E3,$E2,$5B,$03,$74,$B9,$4D,$15,$CD,$31,$50,$8E,$85,$04,$FB,$76,$14,
$85,$F3,$DC,$8E,$10,$88,$73,$30,$F4,$79,$9C,$F5,$81,$F4,$9B,$60,$95,$CD,$A8,$65,
$AE,$10,$FF,$FC,$C4,$51,$6D,$96,$E7,$87,$DF,$F0,$65,$97,$75,$DC,$7F,$8F,$16,$C7,
$6A,$10,$47,$4E,$B7,$A3,$0C,$3E,$87,$DA,$D6,$E6,$B9,$CC,$0C,$11,$35,$F5,$A4,$30,
$8C,$F8,$48,$FE,$6A,$D7,$B2,$B6,$94,$E2,$F7,$8D,$69,$F3,$3E,$32,$16,$DE,$33,$03,
$F4,$5C,$8B,$BD,$8E,$1B,$A4,$8A,$C1,$0C,$3D,$C7,$64,$6F,$89,$8A,$62,$32,$E0,$1A,
$BF,$44,$61,$2B,$A3,$28,$0A,$4D,$28,$DE,$7A,$04,$2F,$6C,$25,$00,$52,$4B,$30,$0C,
$90,$54,$7F,$95,$0B,$ED,$94,$53,$B8,$8E,$A6,$A0,$57,$AC,$8A,$16,$6E,$67,$81,$1A,
$57,$5B,$3C,$C9,$3B,$E7,$02,$04,$4D,$44,$CA,$CA,$4E,$D5,$FF,$76,$BE,$70,$77,$5E,
$4A,$94,$9A,$D5,$C5,$D9,$0D,$28,$4C,$4B,$75,$2E,$C3,$19,$44,$09,$98,$5A,$62,$EE,
$F3,$54,$F4,$E1,$9C,$BC,$0C,$62,$15,$9E,$4C,$12,$47,$F4,$39,$47,$4E,$E9,$5A,$CC,
$AD,$7C,$4B,$73,$B6,$6A,$7E,$8B,$F9,$89,$D2,$26,$0A,$12,$AD,$6C,$D1,$32,$17,$ED,
$D8,$4A,$90,$F2,$69,$66,$E6,$49,$EB,$5E,$89,$C4,$01,$D7,$6D,$D3,$31,$E3,$4B,$06,
$06,$10,$73,$EE,$82,$E9,$28,$8A,$44,$D1,$9A,$BD,$CD,$3C,$A5,$82,$02,$F8,$9A,$0B,
$A7,$D1,$AA,$20,$6A,$5E,$4B,$A8,$F4,$B8,$A2,$0E,$08,$8A,$F0,$97,$C0,$7C,$B8,$FF,
$92,$68,$C5,$52,$66,$65,$A8,$DD,$4E,$F3,$76,$65,$D2,$0E,$DC,$E7,$61,$A5,$7D,$2D,
$2D,$52,$85,$99,$D4,$FD,$43,$25,$8E,$4A,$A0,$AA,$81,$68,$46,$F2,$14,$16,$B9,$B5,
$FE,$B0,$BC,$8A,$02,$17,$94,$5D,$78,$90,$2A,$1C,$71,$AD,$50,$82,$95,$4F,$98,$73,
$F6,$07,$8E,$08,$20,$52,$76,$2F,$52,$77,$27,$63,$4F,$FE,$AE,$9F,$3C,$7A,$6C,$0B,
$77,$63,$00,$9C,$9D,$68,$72,$13,$00,$48,$E6,$AD,$42,$A9,$40,$19,$4F,$FF,$94,$53,
$13,$59,$F3,$73,$50,$2A,$25,$04,$2C,$D5,$75,$29,$8A,$7B,$C2,$6A,$B7,$6D,$F8,$5D,
$3C,$A8,$0B,$39,$CE,$C3,$B0,$41,$83,$BE,$AC,$28,$C8,$12,$CA,$21,$DE,$2D,$35,$4F,
$0F,$0B,$C4,$C6,$AB,$98,$12,$AE,$C8,$62,$9A,$16,$13,$06,$9D,$C2,$E8,$A6,$B4,$74,
$81,$37,$56,$8C,$C1,$BA,$FD,$25,$F8,$B6,$95,$0B,$76,$A9,$B5,$CB,$3D,$86,$13,$8D,
$69,$F6,$79,$A4,$6A,$CA,$C6,$58,$2F,$69,$92,$48,$B6,$DC,$71,$E3,$95,$B9,$B2,$AC,
$0A,$60,$25,$75,$2D,$A9,$6E,$77,$F7,$0D,$65,$87,$69,$64,$1B,$BD,$CD,$51,$E4,$B5,
$BD,$75,$CA,$02,$1D,$BD,$D0,$3A,$59,$27,$40,$12,$5C,$83,$81,$C1,$1D,$F5,$2C,$38,
$67,$8B,$D4,$23,$5A,$3C,$30,$A8,$DC,$A9,$24,$C4,$E9,$CE,$9D,$A4,$DB,$69,$7D,$07,
$EB,$B4,$52,$2B,$5E,$72,$A0,$16,$2A,$D1,$7A,$15,$5C,$31,$B8,$CC,$A0,$70,$C5,$BC,
$E5,$0A,$02,$D5,$6B,$C1,$28,$2C,$8D,$E9,$81,$F5,$9C,$CE,$A8,$F6,$CB,$B2,$62,$47,
$A8,$B2,$B2,$04,$64,$25,$52,$F9,$31,$F5,$96,$01,$2C,$06,$C4,$9D,$41,$A9,$80,$56,
$A4,$91,$89,$5F,$36,$F2,$99,$39,$B8,$FB,$75,$7E,$8F,$74,$A3,$ED,$A9,$1C,$A3,$FD,
$B1,$31,$CB,$0C,$5E,$C5,$90,$B7,$1D,$A1,$9D,$25,$26,$6D,$63,$05,$8D,$0E,$B8,$3E,
$EA,$BD,$18,$40,$62,$62,$10,$F0,$8A,$8D,$59,$4F,$42,$61,$09,$D5,$A6,$82,$CF,$5B,
$AA,$01,$7B,$66,$CA,$B4,$08,$21,$BA,$8C,$83,$96,$C1,$E8,$BE,$65,$E5,$DD,$A4,$03,
$BC,$76,$C3,$03,$73,$14,$2F,$22,$2C,$47,$39,$15,$76,$09,$6A,$8A,$33,$F4,$93,$C6,
$25,$41,$93,$F3,$5D,$C8,$86,$57,$3F,$DA,$83,$19,$EB,$A4,$C9,$97,$50,$DA,$CA,$5F,
$E6,$2E,$16,$8B,$C0,$88,$0F,$6E,$4E,$AA,$16,$11,$F3,$DA,$D6,$2B,$F6,$90,$68,$AB,
$51,$F1,$C2,$77,$5D,$14,$9C,$2B,$5F,$9A,$11,$A8,$A5,$42,$63,$CE,$BD,$DE,$68,$D2,
$52,$25,$59,$F8,$FB,$22,$DA,$A1,$07,$C7,$B5,$B5,$74,$8D,$04,$8C,$8C,$BE,$27,$FC,
$1E,$34,$B1,$A2,$F5,$8D,$99,$62,$D2,$9D,$E3,$16,$45,$36,$17,$EC,$9E,$95,$67,$58,
$28,$F8,$E9,$B3,$5F,$E0,$CD,$5B,$E1,$F2,$D1,$92,$87,$2D,$21,$87,$B2,$D0,$8C,$89,
$F5,$4B,$B5,$F8,$01,$75,$EC,$80,$B5,$C0,$6C,$84,$D6,$34,$65,$A3,$B2,$B0,$59,$36,
$AA,$94,$B6,$00,$D8,$97,$6E,$5A,$56,$EF,$CB,$1B,$8B,$FE,$33,$4C,$42,$E7,$4C,$D1,
$20,$05,$AB,$77,$EF,$33,$E6,$42,$14,$D3,$24,$6B,$69,$22,$A8,$35,$E7,$34,$90,$39,
$4D,$5A,$37,$51,$20,$1D,$56,$2F,$45,$22,$7A,$29,$94,$45,$37,$44,$90,$34,$62,$5A,
$3D,$3B,$58,$DB,$EB,$D5,$42,$59,$DB,$E6,$91,$8D,$8F,$0C,$08,$45,$36,$7F,$52,$55,
$F8,$E5,$48,$2D,$DD,$6B,$41,$A0,$5B,$67,$8D,$60,$EB,$90,$F6,$2D,$99,$CB,$A0,$23,
$0E,$CB,$BA,$CF,$85,$DC,$60,$12,$92,$3C,$86,$6F,$A7,$91,$FA,$98,$AC,$27,$C5,$3B,
$35,$FD,$91,$1E,$06,$82,$3B,$EE,$F5,$93,$AD,$70,$A6,$A7,$62,$2D,$F8,$D9,$B1,$C2,
$AC,$3E,$D7,$DA,$84,$84,$80,$3A,$CD,$59,$CE,$75,$A0,$7A,$67,$83,$40,$C5,$33,$02,
$AE,$6D,$9A,$A3,$DB,$6C,$61,$23,$8B,$01,$22,$88,$07,$77,$05,$25,$1A,$32,$97,$1C,
$2B,$33,$CA,$80,$4A,$3D,$08,$30,$CE,$4D,$78,$17,$F5,$21,$FB,$05,$36,$88,$66,$41,
$D6,$82,$B5,$72,$7A,$06,$97,$83,$52,$9B,$61,$0C,$63,$F3,$A5,$05,$8A,$4E,$C8,$D6,
$B9,$6A,$F1,$F1,$12,$28,$AD,$D3,$68,$C0,$04,$33,$B4,$D3,$64,$64,$D5,$A7,$7A,$50,
$14,$90,$B2,$15,$29,$D7,$A3,$BF,$51,$88,$AA,$89,$7F,$57,$86,$23,$C8,$2A,$5A,$88,
$7D,$4E,$98,$04,$50,$80,$06,$0D,$D9,$B6,$A8,$B1,$CE,$B6,$9F,$B4,$6F,$46,$79,$CB,
$BA,$D0,$80,$DC,$9B,$05,$2A,$E6,$3D,$8C,$B8,$D9,$8D,$AB,$5D,$D3,$8B,$91,$2A,$C4,
$2A,$D9,$E2,$66,$9F,$0B,$20,$14,$FF,$89,$57,$15,$E4,$E6,$1C,$DF,$FF,$BC,$05,$81,
$6D,$52,$47,$E8,$66,$F0,$2E,$78,$C5,$97,$6F,$83,$C1,$98,$FB,$6E,$E5,$B2,$60,$DC,
$02,$EE,$8D,$06,$F4,$16,$47,$3D,$76,$D2,$16,$EF,$8D,$A4,$43,$D7,$00,$69,$24,$BE,
$75,$6A,$45,$8C,$1E,$AC,$6C,$15,$92,$31,$47,$8A,$E6,$EB,$A8,$11,$AE,$25,$EE,$9E,
$15,$54,$19,$D8,$DE,$95,$55,$02,$FC,$55,$FB,$D6,$5A,$4B,$AE,$67,$5A,$91,$C4,$E8,
$9A,$EA,$50,$1B,$E5,$04,$27,$30,$AD,$FC,$2C,$4D,$06,$79,$25,$B6,$8B,$BA,$DC,$CF,
$E1,$99,$5B,$C5,$2D,$26,$B5,$6A,$89,$39,$33,$BA,$70,$83,$BC,$EF,$BD,$EE,$64,$F7,
$31,$75,$90,$BA,$B2,$20,$0D,$F0,$C5,$56,$AA,$E3,$DD,$CA,$48,$E0,$5B,$82,$CA,$65,
$24,$6C,$2D,$13,$C3,$BF,$A1,$59,$26,$B7,$59,$07,$FC,$01,$CC,$B2,$41,$F0,$B7,$A4,
$C7,$A3,$15,$C6,$18,$47,$29,$8F,$53,$BC,$88,$65,$73,$AF,$F4,$69,$EB,$8C,$36,$C1,
$3D,$39,$38,$5E,$D8,$52,$09,$9A,$8A,$C2,$50,$86,$C6,$A3,$58,$F2,$8A,$F5,$76,$88,
$7B,$1D,$B3,$44,$8E,$97,$5E,$F7,$3F,$B1,$1F,$1C,$0F,$67,$78,$A4,$31,$9D,$37,$A4,
$E1,$D4,$17,$7E,$5C,$DE,$16,$A0,$74,$F7,$B3,$0A,$E4,$8A,$7F,$15,$C3,$27,$BE,$40,
$5E,$0D,$72,$A6,$B1,$6E,$C5,$B2,$C1,$0A,$A3,$BD,$1D,$AE,$50,$22,$72,$6F,$36,$69,
$DF,$D4,$E9,$01,$19,$2B,$95,$57,$DE,$E1,$F9,$4A,$19,$F0,$E4,$0C,$64,$53,$2F,$74,
$92,$34,$18,$E8,$2D,$15,$37,$5C,$76,$33,$0F,$BD,$39,$C7,$5E,$8C,$5A,$E4,$4E,$C6,
$B7,$1B,$F9,$07,$7C,$8B,$F4,$A2,$A5,$F3,$02,$5D,$94,$1B,$9A,$41,$84,$E1,$E1,$DE,
$12,$C5,$6C,$CA,$A5,$85,$A6,$97,$D4,$82,$D9,$B0,$C2,$E1,$9A,$4B,$A5,$11,$25,$33,
$F7,$AC,$B4,$43,$43,$B3,$ED,$B3,$38,$46,$70,$0F,$21,$F8,$B4,$A4,$B0,$F6,$9A,$94,
$75,$AC,$84,$D2,$AF,$F7,$4C,$2A,$E0,$2F,$4E,$5A,$DF,$40,$11,$9D,$7B,$49,$89,$49,
$7C,$49,$91,$C6,$0E,$69,$C0,$0E,$8B,$FA,$69,$60,$4A,$BA,$19,$66,$84,$8E,$1E,$62,
$C1,$EE,$1A,$C9,$49,$D5,$83,$14,$11,$DD,$22,$2F,$6B,$CE,$2A,$8D,$26,$92,$1D,$DA,
$E4,$A8,$8B,$22,$6C,$77,$83,$3C,$54,$E4,$72,$B4,$E5,$8A,$6F,$95,$B5,$A2,$31,$6C,
$31,$5C,$B2,$98,$63,$6C,$47,$4C,$A2,$65,$98,$20,$29,$9A,$57,$D0,$62,$57,$74,$A1,
$1A,$83,$70,$6D,$54,$6A,$FC,$63,$54,$F9,$F4,$3C,$0E,$AF,$AC,$28,$9B,$8E,$F4,$4E,
$23,$4F,$81,$3F,$06,$00,$52,$A1,$F0,$C6,$A2,$F7,$88,$C5,$8F,$DC,$CD,$BB,$FC,$85,
$C7,$1A,$EE,$88,$43,$16,$B0,$89,$9E,$F8,$70,$DD,$56,$0D,$86,$82,$25,$6E,$5B,$FD,
$94,$07,$54,$F4,$B2,$C3,$87,$54,$29,$4B,$F1,$87,$E8,$A8,$74,$0A,$31,$AD,$DD,$1C,
$35,$E0,$AD,$29,$9D,$D6,$B8,$F5,$E6,$93,$50,$DF,$B8,$83,$5E,$0B,$DD,$13,$D7,$1A,
$BB,$A9,$A8,$55,$80,$E8,$80,$50,$DE,$22,$9A,$87,$FF,$5D,$FA,$50,$BD,$1C,$8D,$92,
$29,$E4,$E9,$D4,$7E,$7E,$43,$09,$70,$AA,$F6,$FD,$6E,$28,$80,$3E,$5E,$2A,$DD,$13,
$8D,$5B,$2E,$AE,$4A,$B8,$BC,$A3,$13,$97,$86,$95,$EF,$97,$2B,$B2,$AC,$92,$09,$1A,
$52,$64,$35,$FB,$27,$19,$3E,$9C,$A6,$66,$50,$B0,$45,$41,$8C,$DE,$12,$05,$75,$30,
$46,$0C,$42,$CF,$56,$14,$78,$AF,$B8,$C8,$DA,$2B,$50,$B1,$A0,$D4,$25,$54,$14,$28,
$05,$3B,$C8,$A9,$7F,$60,$F7,$D1,$E0,$6C,$A8,$02,$40,$61,$D9,$ED,$2F,$1A,$36,$F6,
$79,$01,$9E,$1D,$95,$88,$D7,$59,$82,$9D,$F5,$26,$55,$D0,$BF,$6D,$14,$C1,$25,$3A,
$39,$54,$10,$28,$AB,$E8,$CA,$04,$56,$16,$D7,$80,$E5,$E0,$A9,$3B,$74,$16,$1F,$57,
$F3,$8A,$BD,$CD,$D9,$80,$CC,$D4,$7A,$19,$35,$BC,$27,$F2,$56,$3C,$0D,$BA,$9F,$8E,
$EA,$B1,$F9,$99,$61,$15,$45,$52,$A0,$53,$77,$D7,$AE,$28,$EB,$C1,$62,$66,$E9,$5A,
$35,$3A,$AD,$2A,$C6,$79,$0B,$ED,$D1,$5E,$A0,$48,$DF,$08,$02,$03,$63,$A5,$C1,$CA,
$6E,$7D,$4A,$C0,$44,$84,$4F,$93,$18,$17,$23,$CD,$E3,$39,$35,$43,$7D,$06,$21,$16,
$B9,$1C,$73,$9B,$4F,$75,$B1,$B0,$F3,$7D,$19,$96,$A0,$81,$A8,$73,$2F,$45,$40,$CC,
$B8,$8C,$CA,$85,$50,$7A,$C7,$47,$2E,$E8,$A5,$59,$08,$D0,$D9,$24,$45,$5C,$B2,$3F,
$57,$6E,$56,$2D,$D9,$B4,$6C,$29,$52,$18,$22,$2B,$40,$7B,$47,$5A,$E4,$47,$9E,$6C,
$CD,$D1,$1F,$FA,$00,$04,$E1,$59,$65,$E1,$E3,$A1,$EA,$DE,$35,$E8,$25,$AE,$1B,$DA,
$80,$91,$7F,$B7,$C9,$2D,$CC,$56,$05,$EB,$A9,$32,$88,$0A,$23,$31,$9B,$6B,$3B,$F7,
$4E,$44,$D6,$68,$47,$09,$CC,$E7,$A0,$3B,$02,$54,$99,$4B,$FD,$B5,$1B,$2D,$5E,$CB,
$08,$2A,$53,$80,$A4,$4B,$C6,$1F,$91,$63,$97,$E2,$37,$0D,$9C,$BE,$4E,$03,$B7,$44,
$A7,$68,$9D,$86,$8E,$F9,$85,$9D,$C6,$42,$0D,$12,$BD,$9C,$52,$7D,$43,$57,$29,$2C,
$F7,$8F,$15,$A9,$91,$11,$48,$93,$9A,$82,$95,$50,$93,$23,$4B,$19,$07,$03,$00,$5D,
$B9,$31,$7B,$9C,$6D,$8D,$5F,$90,$19,$AA,$32,$9F,$46,$6C,$4E,$F2,$4A,$9D,$72,$90,
$79,$64,$55,$94,$9D,$21,$BA,$F1,$04,$69,$7C,$76,$70,$A7,$CB,$D0,$A8,$A5,$72,$68,
$C0,$56,$21,$CA,$19,$EC,$77,$69,$D5,$48,$37,$1E,$AA,$97,$B2,$04,$A6,$1B,$36,$BC,
$14,$9D,$60,$88,$A3,$72,$09,$EE,$A6,$AF,$28,$7F,$11,$90,$EF,$B0,$E3,$0C,$EE,$88,
$1E,$45,$06,$49,$D1,$87,$E1,$CF,$9E,$E7,$6F,$00,$74,$79,$A7,$3F,$52,$B9,$CD,$A8,
$FE,$32,$BA,$B3,$D4,$FD,$C6,$F0,$93,$45,$C6,$B3,$B2,$82,$EB,$C0,$DF,$B2,$14,$E6,
$89,$07,$15,$BA,$FE,$68,$EC,$89,$33,$A9,$43,$C9,$6B,$03,$38,$F6,$08,$CB,$B3,$01,
$B8,$D7,$D8,$CC,$35,$7A,$14,$30,$18,$50,$CD,$C8,$20,$83,$3A,$52,$4A,$1E,$B7,$29,
$56,$59,$13,$78,$0D,$50,$2B,$DA,$9B,$EA,$C0,$50,$61,$00,$0C,$C8,$20,$83,$0C,$68,
$64,$70,$7C,$2B,$3D,$36,$2A,$68,$06,$86,$A0,$20,$16,$F4,$89,$71,$48,$07,$51,$6F,
$95,$2F,$66,$8B,$44,$3C,$BE,$70,$88,$50,$E1,$CF,$B5,$E8,$11,$40,$B5,$14,$B6,$13,
$3A,$F9,$28,$B6,$B9,$5F,$3C,$CE,$2E,$9B,$05,$2B,$8D,$58,$19,$A7,$4A,$E1,$51,$DD,
$13,$23,$29,$8A,$9D,$E6,$81,$8C,$EC,$05,$27,$50,$BE,$D3,$AC,$5C,$D8,$42,$37,$5C,
$C5,$3B,$BD,$24,$E7,$A7,$AB,$83,$D2,$CE,$83,$E9,$E2,$D2,$45,$11,$AC,$21,$AA,$08,
$C9,$3F,$B9,$57,$E1,$A0,$AA,$F0,$B0,$EB,$32,$F0,$D2,$25,$02,$3F,$F6,$0F,$7D,$ED,
$FA,$CD,$E2,$29,$F2,$96,$3F,$D7,$7F,$39,$01,$1F,$6E,$8E,$2A,$E8,$E1,$34,$B9,$7A,
$87,$A9,$9A,$3C,$DD,$5D,$15,$B0,$90,$55,$58,$48,$55,$05,$9E,$57,$23,$64,$9B,$1B,
$2C,$4A,$19,$60,$05,$50,$B1,$E1,$0C,$39,$33,$04,$A3,$51,$9D,$01,$43,$C5,$FE,$A1,
$50,$06,$25,$07,$D9,$0D,$8B,$BC,$52,$1E,$71,$E3,$48,$2A,$15,$EA,$88,$16,$03,$9F,
$46,$09,$C1,$88,$85,$3B,$01,$5C,$14,$F3,$4A,$0B,$0E,$48,$1E,$C2,$C4,$44,$83,$0D,
$F8,$45,$AF,$D4,$EB,$EB,$B6,$81,$15,$B4,$7B,$82,$E4,$E4,$2F,$E8,$E5,$F4,$CF,$5E,
$FD,$CD,$3A,$28,$EF,$A5,$DA,$D3,$05,$4B,$F5,$D3,$15,$92,$94,$1C,$5F,$6B,$B3,$A7,
$2B,$22,$CB,$80,$1C,$56,$45,$A2,$C1,$9F,$BE,$4C,$5E,$1C,$DC,$97,$73,$11,$A8,$5A,
$05,$8A,$BB,$C9,$90,$07,$7F,$2C,$44,$F6,$91,$CA,$B8,$57,$0E,$B8,$8C,$4F,$29,$DB,
$D5,$A3,$8F,$F5,$C2,$28,$2E,$7E,$C9,$BD,$0A,$5A,$8C,$28,$FD,$30,$9B,$5E,$62,$E0,
$F1,$5A,$81,$05,$EA,$4B,$34,$6A,$71,$ED,$1B,$67,$3E,$07,$8D,$E8,$97,$10,$69,$6B,
$24,$F8,$20,$56,$D8,$8B,$C7,$F3,$D1,$25,$2E,$89,$B8,$27,$08,$06,$03,$5D,$BB,$15,
$C7,$83,$B4,$27,$E5,$6F,$E6,$10,$AC,$16,$70,$6D,$BA,$B0,$11,$DB,$2F,$BF,$B6,$F9,
$86,$39,$A2,$37,$2D,$2C,$63,$E3,$38,$AA,$11,$C7,$CE,$92,$A9,$31,$4D,$58,$7B,$18,
$91,$37,$44,$45,$35,$51,$10,$53,$E3,$66,$5B,$00,$38,$12,$E3,$C4,$3F,$75,$88,$FE,
$1A,$07,$B1,$04,$0D,$AF,$D6,$22,$97,$29,$36,$19,$6C,$87,$CF,$FD,$8C,$B0,$25,$BB,
$23,$B7,$05,$6C,$D7,$49,$A1,$C0,$E6,$97,$88,$B8,$1A,$2E,$44,$CF,$C1,$AB,$94,$6E,
$E9,$D5,$67,$DD,$B0,$2C,$00,$00,$84,$2E,$E7,$B3,$A7,$23,$7F,$E1,$5C,$7A,$9C,$91,
$69,$DA,$14,$6C,$91,$E8,$7D,$11,$57,$C4,$81,$BA,$CE,$48,$3A,$7C,$3B,$E6,$40,$85,
$C8,$1D,$58,$38,$28,$41,$14,$9A,$61,$A5,$63,$31,$3A,$3C,$3D,$96,$07,$80,$9A,$E4,
$19,$B7,$30,$28,$26,$19,$04,$8A,$11,$9C,$1E,$61,$62,$D6,$21,$AD,$67,$77,$E6,$C5,
$36,$BE,$DA,$B6,$4E,$F9,$1B,$BD,$01,$74,$7C,$92,$A1,$7B,$E5,$85,$0D,$D3,$BE,$A2,
$2A,$47,$E6,$C6,$5C,$B7,$62,$F8,$13,$26,$9A,$6C,$17,$C1,$28,$C1,$1A,$E1,$37,$C0,
$40,$D0,$95,$45,$EA,$4D,$49,$AC,$AA,$23,$7F,$A5,$53,$D1,$0F,$11,$96,$24,$F7,$D6,
$B3,$DD,$E3,$10,$0C,$E5,$14,$50,$C5,$06,$9F,$9B,$92,$9C,$A7,$A2,$B9,$7E,$43,$5A,
$22,$40,$94,$37,$30,$60,$5D,$F9,$22,$66,$43,$89,$01,$47,$ED,$EA,$EA,$32,$C4,$ED,
$71,$48,$C6,$22,$90,$ED,$5F,$48,$A3,$DC,$E0,$B4,$2B,$44,$95,$B9,$29,$EF,$BD,$A9,
$34,$49,$05,$1A,$7D,$CC,$16,$9E,$A2,$C8,$97,$54,$A2,$CE,$71,$AE,$B2,$8A,$43,$34,
$48,$BB,$E9,$06,$65,$91,$46,$95,$0D,$EC,$54,$85,$DE,$8A,$F9,$1C,$70,$FD,$74,$53,
$71,$65,$10,$01,$51,$6D,$8C,$E6,$36,$6A,$60,$EA,$25,$5F,$26,$86,$13,$D7,$9C,$54,
$39,$37,$1A,$F8,$C5,$70,$BF,$42,$EC,$14,$BD,$43,$85,$44,$58,$81,$48,$6F,$35,$42,
$6F,$9C,$52,$0F,$22,$25,$02,$F7,$34,$B8,$05,$1B,$63,$E1,$9F,$42,$3D,$02,$50,$C3,
$16,$00,$0B,$08,$AA,$7E,$36,$4A,$CF,$DD,$5D,$99,$48,$93,$D7,$12,$67,$91,$C0,$01,
$19,$9E,$16,$16,$4C,$CC,$38,$02,$41,$27,$62,$66,$73,$92,$BF,$B8,$78,$84,$41,$B0,
$5B,$67,$6E,$B9,$55,$00,$65,$6A,$DC,$B4,$9E,$99,$A5,$13,$FF,$E1,$6C,$55,$F7,$1A,
$F6,$9F,$5D,$EB,$C7,$00,$CE,$FD,$4F,$83,$8C,$40,$01,$41,$AA,$B6,$F6,$CD,$ED,$E8,
$2C,$60,$81,$49,$FB,$F3,$1A,$39,$DC,$FC,$F5,$52,$C4,$96,$31,$BB,$63,$62,$58,$24,
$F8,$B6,$74,$B5,$A0,$51,$2E,$0B,$40,$08,$45,$18,$AB,$A7,$6D,$75,$59,$64,$60,$B8,
$FE,$0C,$08,$4B,$B7,$19,$4E,$E6,$25,$68,$4D,$71,$A4,$C5,$64,$31,$E0,$4C,$EB,$C7,
$BA,$2C,$BF,$1C,$89,$8D,$B2,$E2,$17,$E3,$CD,$F8,$D7,$0E,$C1,$E2,$51,$6D,$09,$5A,
$4F,$30,$28,$0A,$97,$DE,$22,$9A,$2C,$5A,$AB,$E5,$BE,$8D,$ED,$1A,$ED,$87,$7A,$CF,
$E4,$4B,$A1,$7A,$4F,$95,$22,$C0,$76,$4C,$75,$6E,$80,$C3,$7A,$4A,$41,$A2,$2F,$AD,
$AD,$A4,$C5,$79,$A7,$91,$A2,$FF,$04,$A0,$DD,$63,$F8,$2C,$14,$2D,$23,$8F,$B1,$16,
$8D,$D7,$31,$5E,$A0,$4D,$8B,$15,$D1,$B5,$88,$ED,$C1,$D9,$05,$CA,$BB,$35,$E5,$AA,
$0B,$9E,$D8,$77,$CC,$C8,$D4,$DF,$56,$21,$15,$20,$FA,$9A,$55,$21,$08,$DA,$22,$C2,
$C6,$0F,$90,$9E,$4C,$8E,$E9,$06,$D0,$45,$CC,$A0,$AE,$69,$94,$84,$D6,$8A,$D6,$7B,
$EA,$E8,$CC,$6E,$07,$78,$32,$04,$A4,$82,$73,$1C,$0C,$22,$90,$2A,$9A,$0B,$0F,$C2,
$1F,$BA,$97,$BA,$77,$DA,$AB,$B6,$64,$7F,$B8,$67,$6E,$C3,$BD,$8C,$AD,$04,$31,$13,
$F2,$8D,$58,$FC,$00,$41,$F8,$22,$5D,$03,$2C,$65,$29,$A9,$68,$DE,$79,$81,$E6,$37,
$6B,$19,$9C,$56,$14,$02,$54,$A4,$63,$30,$0A,$11,$29,$B6,$5F,$81,$41,$0D,$7F,$0E,
$05,$0A,$93,$24,$77,$5D,$F7,$FC,$31,$C0,$DE,$09,$AF,$24,$A6,$37,$45,$FD,$80,$C0,
$28,$8F,$9A,$E4,$8B,$F4,$6C,$23,$77,$62,$45,$45,$FB,$16,$BF,$43,$B5,$05,$3D,$13,
$DD,$2B,$9D,$EC,$13,$B3,$A5,$24,$E3,$FD,$A3,$58,$77,$AE,$9E,$F6,$9E,$C2,$A8,$1D,
$E4,$22,$5E,$CB,$74,$A5,$CB,$29,$8A,$12,$8C,$D4,$D2,$68,$C2,$2C,$E0,$C4,$69,$AF,
$55,$C1,$48,$37,$15,$E6,$B9,$FA,$78,$DE,$1A,$2E,$88,$AA,$DD,$57,$2B,$A7,$00,$97,
$7A,$3A,$F9,$C1,$63,$5E,$8F,$8C,$37,$85,$6A,$DF,$BB,$58,$D8,$EE,$55,$33,$0E,$30,
$48,$C6,$98,$28,$2B,$02,$55,$59,$20,$D8,$57,$3A,$28,$43,$C9,$C4,$6C,$14,$6A,$2E,
$38,$1F,$8D,$77,$13,$A0,$28,$34,$B9,$66,$D2,$A2,$DF,$B0,$0C,$5A,$4B,$32,$B5,$51,
$43,$94,$FC,$04,$AC,$04,$4B,$D9,$9E,$83,$49,$C3,$A4,$D7,$CC,$91,$E2,$C8,$97,$28,
$B2,$C7,$9F,$B8,$43,$C9,$02,$A8,$10,$5B,$76,$4C,$CC,$38,$13,$1D,$B9,$2D,$0D,$7D,
$72,$25,$55,$63,$D2,$5C,$CF,$6F,$07,$8B,$46,$1F,$A8,$0C,$6C,$1E,$53,$82,$19,$E1,
$F4,$2D,$98,$61,$53,$14,$6E,$19,$C4,$10,$9E,$FB,$4F,$94,$3F,$98,$9D,$D3,$12,$30,
$FF,$B1,$1F,$20,$AB,$DC,$FD,$3A,$72,$C2,$A6,$81,$42,$A6,$BF,$2C,$D2,$16,$F5,$91,
$13,$A2,$B4,$40,$CC,$93,$22,$15,$A3,$17,$5A,$64,$85,$89,$7E,$D2,$91,$B4,$FE,$B7,
$AA,$34,$A0,$52,$8F,$1B,$88,$78,$7D,$27,$0F,$BA,$42,$22,$35,$64,$D1,$0D,$E1,$EC,
$D6,$83,$65,$68,$EF,$72,$06,$E6,$14,$D7,$A5,$F9,$45,$FE,$18,$53,$96,$CA,$BE,$52,
$53,$D6,$60,$B5,$17,$B1,$D7,$2D,$74,$BA,$73,$75,$B4,$0A,$C3,$DD,$40,$01,$54,$A1,
$9A,$11,$94,$65,$80,$95,$B5,$32,$C5,$48,$92,$94,$93,$E8,$E5,$DE,$4D,$0F,$85,$1E,
$0E,$12,$C3,$CD,$9C,$BA,$0C,$AE,$6F,$C0,$E0,$10,$08,$4D,$5B,$01,$70,$85,$C8,$D0,
$B9,$A9,$9D,$BF,$A5,$54,$A5,$20,$49,$8F,$25,$05,$41,$A5,$23,$B4,$E7,$8C,$1C,$12,
$BC,$AA,$29,$26,$B2,$B8,$33,$BE,$8D,$69,$12,$26,$8E,$12,$15,$E1,$8F,$5D,$85,$36,
$97,$E1,$0E,$E9,$3F,$A5,$CB,$02,$86,$F7,$48,$D5,$8D,$8E,$5D,$17,$16,$29,$7D,$D6,
$38,$A4,$E3,$BE,$55,$DB,$D3,$F4,$E2,$58,$98,$E5,$A2,$CE,$7E,$85,$6F,$41,$B7,$A8,
$D4,$B8,$18,$58,$4B,$4B,$5A,$F3,$C4,$91,$1B,$14,$28,$6F,$35,$96,$97,$67,$CC,$36,
$D0,$52,$43,$AC,$0E,$2B,$14,$15,$C5,$A2,$E4,$04,$C4,$7E,$0A,$B6,$74,$59,$0F,$1E,
$E4,$B2,$4A,$54,$43,$90,$77,$64,$F1,$F4,$45,$CE,$37,$CF,$17,$C8,$5B,$18,$45,$BE,
$2E,$DA,$9C,$B2,$76,$15,$74,$87,$2B,$70,$6D,$10,$4E,$24,$E6,$0A,$89,$F1,$7F,$86,
$18,$E9,$EA,$BE,$D8,$D2,$80,$96,$E6,$25,$6F,$C8,$45,$13,$A1,$F1,$62,$63,$E6,$62,
$B6,$EB,$5D,$59,$54,$A5,$CE,$D2,$11,$A5,$E5,$66,$CD,$A1,$9A,$DA,$77,$C1,$85,$CF,
$4F,$35,$40,$7B,$54,$83,$BB,$3F,$85,$F5,$F8,$E3,$99,$75,$9B,$5C,$FE,$9A,$85,$6A,
$8C,$45,$A3,$75,$28,$02,$C8,$36,$B4,$4D,$A2,$85,$38,$4C,$41,$1C,$FF,$2C,$27,$C3,
$A2,$9E,$93,$29,$5C,$6B,$03,$24,$73,$37,$34,$6C,$E6,$76,$F0,$B7,$34,$59,$2D,$08,
$D1,$7E,$FD,$56,$25,$FE,$45,$BD,$6B,$B6,$CB,$C9,$5F,$15,$63,$2E,$AA,$7F,$FC,$F7,
$BE,$40,$63,$C3,$F9,$52,$28,$62,$A3,$13,$5F,$CE,$DF,$83,$5F,$E4,$2B,$F9,$95,$1A,
$08,$36,$67,$B1,$50,$9C,$32,$E3,$52,$3F,$02,$5A,$16,$5F,$FC,$89,$B6,$E2,$28,$C7,
$26,$9F,$E1,$0F,$98,$9C,$94,$C1,$F8,$94,$A0,$0E,$E7,$1C,$A8,$F9,$D4,$CB,$AC,$6E,
$CA,$7A,$70,$82,$50,$28,$88,$23,$89,$C1,$8D,$CD,$D1,$DE,$42,$BB,$F0,$98,$61,$81,
$06,$02,$D3,$2E,$4C,$8D,$EA,$E9,$2C,$D0,$F7,$AF,$55,$17,$64,$13,$9F,$ED,$9A,$84,
$37,$E3,$B5,$6A,$DD,$69,$52,$85,$8C,$A7,$95,$31,$53,$25,$BB,$81,$48,$B5,$67,$C9,
$7E,$A6,$4F,$63,$48,$59,$8B,$31,$0B,$0B,$0E,$69,$35,$8D,$42,$45,$D5,$00,$52,$04,
$7C,$59,$89,$85,$4D,$62,$BE,$75,$16,$0D,$98,$F6,$EC,$A1,$1C,$F1,$B8,$60,$84,$0D,
$6F,$8F,$23,$06,$68,$93,$2E,$20,$E3,$AB,$2F,$97,$16,$5D,$5B,$E4,$CB,$41,$05,$99,
$E1,$37,$65,$E0,$22,$3A,$4F,$C6,$A2,$69,$53,$16,$85,$91,$B1,$04,$84,$3C,$9B,$A9,
$02,$43,$04,$F0,$89,$FA,$BD,$FD,$71,$03,$36,$D3,$7B,$27,$C5,$22,$ED,$A0,$CA,$04,
$95,$22,$9B,$EB,$B1,$9F,$35,$AC,$68,$56,$AC,$F3,$61,$01,$F2,$ED,$A0,$E6,$A4,$DD,
$B0,$8B,$58,$37,$5C,$76,$E2,$F8,$F1,$66,$BC,$D3,$F0,$A2,$BF,$2C,$74,$6D,$A6,$D2,
$A1,$88,$59,$69,$D2,$86,$D4,$70,$A9,$5C,$65,$3F,$C5,$D0,$81,$84,$08,$FD,$16,$79,
$9E,$C0,$63,$17,$02,$79,$F0,$AF,$C3,$42,$B4,$79,$CA,$4A,$36,$63,$4F,$FD,$03,$20,
$63,$BC,$2E,$6E,$2C,$D0,$33,$2C,$09,$F2,$56,$ED,$C2,$C7,$FD,$E1,$C8,$FA,$61,$68,
$1E,$27,$57,$25,$ED,$CF,$3B,$B8,$36,$FB,$85,$71,$60,$30,$3B,$7D,$20,$04,$91,$C1,
$6B,$E6,$08,$CE,$2A,$04,$84,$20,$F5,$23,$85,$CC,$42,$33,$D8,$4E,$43,$33,$B8,$74,
$EA,$21,$08,$08,$41,$72,$36,$76,$5D,$FE,$69,$21,$20,$04,$01,$B8,$C5,$B0,$97,$9A,
$C1,$66,$79,$F6,$06,$B7,$40,$15,$02,$22,$02,$6D,$85,$05,$84,$63,$85,$80,$0C,$74,
$87,$19,$44,$06,$CB,$F0,$72,$3E,$79,$C6,$08,$01,$A9,$6C,$75,$1A,$A4,$83,$33,$E6,
$04,$01,$11,$26,$36,$9B,$13,$FE,$42,$7B,$E6,$04,$35,$74,$AA,$50,$9D,$2A,$4E,$71,
$6E,$6B,$13,$05,$45,$B5,$BB,$C5,$30,$0A,$10,$2B,$06,$7C,$14,$20,$0F,$06,$6A,$04,
$76,$1B,$24,$53,$4B,$9A,$E0,$8F,$30,$A6,$E7,$4A,$7C,$7E,$D7,$C7,$C6,$61,$02,$B3,
$02,$FE,$74,$99,$A4,$C9,$CF,$18,$18,$CA,$87,$FB,$A3,$E1,$A3,$D1,$FD,$AC,$22,$95,
$CF,$2A,$EE,$C2,$02,$DF,$12,$BC,$70,$FF,$76,$01,$C6,$F5,$2B,$92,$12,$CB,$C0,$12,
$9B,$A4,$0B,$A4,$FB,$B0,$B8,$F5,$A1,$77,$A8,$71,$73,$98,$95,$CE,$3E,$E6,$15,$C7,
$D9,$97,$1C,$52,$93,$44,$0A,$B1,$18,$6C,$13,$DF,$DE,$67,$91,$80,$23,$1C,$CB,$8C,
$A6,$C0,$FF,$66,$4A,$D5,$DD,$A4,$94,$C3,$5F,$D6,$80,$4A,$5A,$B1,$5C,$0F,$B3,$7C,
$04,$A6,$4F,$7D,$76,$33,$7C,$2D,$9E,$7E,$7D,$E3,$05,$25,$7A,$59,$A0,$E9,$09,$42,
$F3,$9A,$97,$55,$9B,$13,$B7,$61,$E2,$21,$44,$40,$8C,$1A,$2C,$5C,$C2,$04,$59,$61,
$14,$E1,$A5,$01,$C8,$17,$23,$A4,$2F,$28,$8B,$31,$AE,$E1,$5B,$C0,$98,$28,$52,$C2,
$28,$4F,$2E,$8F,$62,$EB,$02,$B9,$68,$8B,$23,$54,$76,$92,$5D,$B1,$83,$AA,$48,$57,
$30,$2B,$C4,$C4,$2B,$3A,$90,$C1,$DF,$2D,$09,$D6,$BA,$78,$50,$90,$9D,$AA,$92,$2A,
$77,$7E,$2C,$1F,$E3,$AA,$70,$3F,$03,$B3,$52,$91,$9B,$FA,$C1,$74,$4D,$67,$D7,$BB,
$3C,$E3,$4A,$AF,$32,$91,$64,$F7,$AD,$18,$D6,$31,$39,$74,$69,$1A,$E2,$F3,$0D,$D9,
$76,$8C,$88,$72,$A8,$8C,$32,$48,$9D,$55,$D1,$A8,$CD,$C4,$AB,$76,$F7,$5C,$74,$EF,
$72,$E9,$9E,$86,$8A,$C9,$B8,$D7,$83,$18,$42,$55,$E0,$86,$0A,$E1,$11,$86,$95,$02,
$70,$64,$CC,$49,$3E,$95,$98,$C9,$12,$BB,$23,$43,$90,$62,$E6,$18,$6E,$A3,$87,$21,
$6F,$AD,$97,$6E,$E8,$2D,$76,$62,$1B,$E4,$AB,$96,$56,$07,$E5,$1B,$5F,$2C,$E8,$2E,
$0B,$D3,$9F,$A4,$1A,$67,$28,$99,$E6,$99,$AD,$23,$3D,$B2,$4B,$5C,$3D,$1B,$F4,$90,
$23,$2F,$60,$E9,$B7,$5E,$97,$EC,$52,$A3,$C6,$6C,$67,$FD,$93,$18,$B8,$5A,$AF,$15,
$58,$B1,$F3,$AA,$81,$AE,$9E,$9B,$AB,$C8,$F7,$F3,$EB,$CA,$DE,$DD,$E3,$1C,$8D,$8E,
$B3,$43,$5E,$09,$00,$53,$1A,$14,$AA,$C3,$7F,$55,$CC,$36,$D8,$95,$8C,$E2,$1A,$89,
$CC,$49,$EE,$26,$EB,$C0,$14,$E7,$BA,$B7,$94,$68,$41,$22,$21,$3B,$AE,$B0,$3E,$59,
$A2,$A0,$CC,$B7,$CD,$AF,$E8,$03,$00,$2A,$E6,$9A,$9E,$4B,$5A,$7F,$9A,$15,$A3,$54,
$AE,$61,$E5,$9A,$DB,$25,$DD,$66,$45,$36,$A6,$3C,$02,$F9,$4A,$87,$73,$E1,$15,$90,
$29,$53,$97,$FD,$87,$5C,$0D,$68,$A8,$28,$8C,$96,$22,$77,$CB,$0C,$01,$7A,$2B,$B8,
$88,$62,$AA,$2F,$51,$8C,$52,$46,$A7,$3E,$1E,$84,$66,$49,$89,$6A,$59,$95,$D5,$9B,
$71,$53,$16,$B7,$53,$92,$AD,$F4,$5C,$9A,$7B,$0C,$01,$B0,$EA,$D7,$11,$B4,$3A,$CD,
$D0,$05,$DA,$6B,$62,$42,$51,$8A,$AB,$A4,$71,$4B,$F5,$7C,$45,$04,$24,$F5,$4C,$8B,
$3A,$F8,$AF,$2D,$CA,$D2,$59,$31,$54,$D0,$91,$C8,$E2,$31,$D7,$FC,$DF,$87,$02,$CE,
$86,$47,$63,$74,$B3,$7B,$5A,$75,$34,$39,$85,$06,$09,$03,$0A,$75,$36,$29,$98,$CC,
$57,$14,$19,$2D,$02,$24,$40,$16,$A2,$A5,$CE,$1A,$7F,$F6,$E9,$71,$BA,$8E,$F6,$2B,
$61,$AE,$75,$A1,$54,$F1,$E1,$DF,$EE,$1B,$A5,$17,$D0,$3B,$51,$5D,$06,$15,$AB,$EA,
$29,$06,$13,$48,$A0,$8D,$A6,$6F,$EE,$94,$9F,$5F,$74,$41,$C2,$72,$92,$68,$86,$7A,
$C1,$47,$64,$87,$47,$41,$C6,$F8,$68,$F2,$E4,$29,$DA,$D5,$C9,$7A,$B2,$C5,$E4,$D7,
$AE,$C8,$08,$EA,$7A,$6D,$81,$85,$64,$80,$4A,$E6,$50,$2C,$D4,$46,$BE,$38,$33,$AB,
$4E,$E0,$B3,$A4,$28,$BE,$2A,$D2,$6C,$99,$87,$58,$2D,$0D,$CA,$47,$25,$89,$70,$04,
$DC,$E5,$C4,$09,$28,$5D,$AD,$2A,$98,$6A,$DD,$9B,$69,$0E,$C6,$BA,$A0,$F1,$2C,$44,
$E1,$83,$4D,$D3,$86,$1F,$84,$56,$6F,$95,$E3,$8C,$89,$90,$0A,$E5,$14,$6A,$83,$32,
$F8,$33,$C9,$0B,$89,$17,$7A,$85,$E7,$0A,$00,$DB,$C2,$7C,$22,$70,$F7,$62,$1E,$B1,
$D2,$A4,$60,$69,$89,$CF,$88,$AA,$DB,$04,$37,$6B,$01,$D2,$10,$FA,$79,$D0,$0D,$CF,
$0E,$BB,$10,$21,$88,$B0,$2A,$4A,$50,$82,$3E,$44,$C6,$CA,$7C,$C7,$C5,$62,$B5,$3A,
$B9,$83,$DC,$11,$A1,$6B,$72,$0E,$F4,$D2,$58,$85,$B3,$AF,$8E,$3E,$8C,$51,$3D,$97,
$36,$81,$4D,$DB,$DB,$07,$18,$EE,$0E,$82,$F4,$BF,$2F,$8A,$CF,$3B,$FA,$30,$0C,$64,
$E3,$D1,$54,$66,$E1,$99,$7B,$B1,$26,$50,$1A,$A9,$23,$06,$5B,$55,$D8,$6E,$23,$36,
$23,$DB,$2B,$42,$8B,$70,$11,$0D,$0E,$9D,$6B,$5E,$61,$D8,$6E,$5E,$77,$B3,$68,$55,
$7A,$B3,$43,$A5,$13,$BA,$F5,$10,$3D,$2A,$D0,$0C,$FE,$37,$00,$20,$1C,$EB,$9C,$E5,
$06,$60,$22,$9B,$26,$57,$70,$71,$46,$61,$44,$CC,$DA,$16,$00,$1D,$A7,$57,$15,$83,
$5D,$17,$30,$D0,$75,$2E,$7D,$13,$4C,$45,$8E,$20,$BB,$F1,$E6,$B8,$1C,$A9,$D8,$33,
$8E,$1E,$79,$C7,$73,$B0,$5C,$BE,$78,$ED,$9F,$9D,$AA,$44,$A0,$DC,$E9,$5C,$96,$CE,
$8A,$BC,$BA,$C8,$2E,$D3,$01,$2A,$D5,$FB,$0B,$D1,$03,$51,$38,$F8,$85,$D7,$B4,$8B,
$AA,$C0,$A5,$39,$62,$6F,$11,$38,$6D,$F8,$3F,$F6,$02,$F2,$BC,$E4,$C4,$E2,$4A,$2E,
$6C,$59,$7C,$FD,$A3,$26,$5F,$3D,$9A,$D5,$96,$D8,$E9,$94,$5D,$48,$A5,$FE,$B8,$DA,
$A3,$BA,$2B,$8E,$F6,$E7,$F7,$C3,$66,$AE,$2A,$B8,$F5,$2B,$7E,$70,$26,$DC,$02,$81,
$59,$42,$3B,$77,$C5,$BD,$81,$56,$60,$14,$30,$31,$2C,$66,$2F,$45,$C5,$E0,$EA,$D3,
$56,$51,$2A,$88,$BA,$7B,$C5,$0F,$44,$82,$53,$A6,$4A,$7D,$0C,$AF,$54,$9C,$E6,$60,
$7B,$EC,$3D,$C1,$28,$83,$4E,$30,$BB,$5C,$0A,$BD,$5A,$72,$36,$E0,$25,$6B,$02,$A0,
$C2,$23,$C3,$D3,$0B,$A5,$A1,$FB,$F9,$15,$65,$C1,$F3,$E7,$17,$49,$92,$54,$81,$C2,
$01,$D8,$0B,$C1,$55,$92,$24,$EA,$ED,$18,$47,$F7,$7F,$E7,$29,$FA,$95,$AE,$F7,$AA,
$86,$6A,$A5,$22,$B5,$90,$EA,$00,$AE,$5B,$C9,$B2,$F6,$41,$82,$D4,$EC,$08,$B1,$E8,
$63,$B1,$AD,$C5,$BC,$EC,$38,$A6,$AA,$8C,$0A,$9E,$AA,$62,$98,$B2,$70,$1B,$AE,$A4,
$91,$51,$19,$9A,$53,$05,$64,$AA,$32,$BE,$E5,$E0,$B2,$AB,$6F,$29,$CF,$1E,$B1,$0A,
$0A,$41,$F3,$0D,$F1,$60,$7F,$00,$75,$88,$65,$54,$66,$41,$A8,$E6,$49,$F9,$E7,$BB,
$2A,$31,$F7,$AD,$51,$D5,$0E,$7F,$28,$62,$31,$58,$15,$BB,$A1,$EC,$A7,$DF,$4B,$62,
$45,$69,$72,$29,$4D,$40,$55,$A0,$56,$67,$A3,$C7,$5D,$CA,$CC,$4C,$B9,$8D,$74,$C9,
$C3,$A0,$0B,$68,$C2,$20,$15,$70,$32,$C6,$43,$D8,$B7,$CD,$CD,$B8,$73,$D3,$30,$94,
$B6,$60,$3A,$EE,$9C,$83,$ED,$C6,$DD,$90,$C2,$AA,$04,$3D,$C4,$63,$2A,$30,$68,$CD,
$AA,$91,$E9,$11,$73,$03,$F3,$87,$45,$F4,$8B,$75,$FB,$77,$26,$36,$36,$59,$AE,$C1,
$FA,$4C,$41,$17,$C1,$33,$86,$EA,$54,$57,$54,$B2,$F7,$C2,$65,$35,$58,$52,$17,$D8,
$5C,$51,$FC,$BD,$9C,$20,$8A,$02,$72,$19,$2F,$FC,$ED,$ED,$11,$38,$85,$AA,$D5,$98,
$FB,$29,$4F,$14,$35,$8D,$F8,$B4,$30,$87,$E2,$90,$E2,$B0,$B8,$1A,$1E,$15,$D0,$86,
$F5,$4E,$9E,$D1,$57,$DF,$0A,$1A,$29,$65,$CE,$AA,$08,$56,$0B,$E7,$E4,$86,$1D,$41,
$04,$06,$00,$99,$0F,$87,$44,$76,$0B,$CB,$48,$81,$FF,$6D,$80,$0B,$6F,$A8,$85,$4A,
$87,$FB,$F4,$3A,$27,$E1,$94,$29,$73,$70,$1A,$BB,$01,$3C,$1A,$65,$2B,$6C,$E1,$B8,
$1D,$26,$4C,$10,$1F,$8C,$2C,$DC,$A7,$C7,$06,$6C,$7C,$B1,$1E,$B3,$34,$E1,$14,$38,
$FF,$42,$2B,$19,$84,$C8,$85,$F0,$B2,$36,$E6,$BC,$78,$E3,$36,$50,$90,$4A,$45,$FB,
$35,$EF,$A4,$2E,$E0,$FF,$E7,$44,$79,$D3,$DC,$10,$9A,$52,$F9,$76,$4D,$98,$93,$12,
$F6,$E5,$CD,$43,$4C,$82,$89,$5D,$DC,$24,$2A,$6E,$F3,$FE,$81,$83,$F6,$24,$CA,$A4,
$F5,$67,$E0,$2E,$6C,$91,$75,$62,$8F,$8D,$A2,$34,$7C,$C7,$1B,$3D,$BC,$93,$A4,$AA,
$F0,$25,$8E,$74,$05,$1F,$0F,$2F,$CE,$CD,$D8,$14,$6E,$AB,$D9,$0B,$49,$41,$B8,$A8,
$BB,$72,$32,$76,$29,$01,$9B,$C9,$AA,$FD,$66,$90,$24,$B3,$B4,$85,$5F,$18,$13,$6A,
$21,$49,$0E,$86,$96,$A7,$A0,$0A,$03,$2A,$B0,$4E,$7E,$33,$84,$84,$84,$84,$39,$37,
$35,$03,$96,$DC,$9F,$84,$39,$58,$44,$A9,$8F,$6D,$D9,$D4,$E5,$63,$E1,$73,$38,$05,
$E6,$75,$BE,$4E,$2E,$6A,$B1,$0F,$BC,$EE,$79,$43,$DE,$5A,$C6,$D3,$94,$C3,$F4,$5A,
$21,$6C,$50,$40,$A6,$AC,$1B,$7A,$73,$94,$C1,$A3,$2D,$59,$15,$EB,$3B,$C9,$9F,$4A,
$CB,$13,$14,$CD,$90,$F7,$8A,$E9,$4E,$ED,$66,$39,$BA,$8D,$78,$91,$7C,$FC,$00,$AD,
$59,$B5,$26,$DB,$71,$36,$16,$88,$00,$70,$1A,$BB,$92,$81,$67,$D4,$19,$2E,$DD,$A0,
$C4,$18,$13,$A1,$12,$54,$F1,$2D,$46,$AA,$D8,$67,$D7,$B8,$33,$8B,$C1,$E8,$BE,$F7,
$45,$49,$30,$19,$3F,$66,$43,$14,$F3,$B1,$2F,$4B,$9B,$45,$06,$45,$5A,$CA,$B6,$BA,
$89,$3E,$13,$14,$EC,$5A,$05,$DC,$87,$14,$F8,$5A,$1A,$D7,$23,$31,$B1,$5A,$D3,$83,
$58,$27,$17,$19,$75,$5E,$4F,$43,$02,$16,$EF,$E0,$85,$91,$F6,$62,$14,$C6,$05,$DD,
$04,$45,$9E,$6A,$90,$FE,$FE,$59,$37,$5C,$B3,$28,$75,$67,$97,$20,$AE,$74,$3B,$2B,
$E9,$1E,$A4,$7B,$30,$0A,$F5,$A0,$98,$4A,$32,$F2,$21,$D1,$2E,$BA,$49,$58,$00,$50,
$8C,$94,$8A,$B2,$8C,$89,$4A,$A2,$A6,$F8,$2B,$59,$19,$74,$AC,$25,$47,$60,$D7,$DC,
$45,$78,$17,$A8,$69,$73,$F5,$A8,$D1,$53,$17,$29,$55,$50,$1B,$D1,$55,$F2,$36,$AD,
$E0,$DF,$0A,$F2,$AC,$96,$C9,$1C,$55,$68,$C7,$2C,$81,$B6,$66,$AC,$25,$D9,$95,$5F,
$9D,$08,$F5,$88,$23,$7D,$98,$A5,$F7,$79,$CE,$61,$3C,$26,$AA,$9D,$93,$98,$48,$E1,
$94,$94,$5B,$53,$E9,$7A,$92,$E2,$FF,$A3,$1C,$F0,$C8,$07,$1C,$51,$17,$0B,$3F,$EA,
$0E,$47,$43,$2E,$56,$BC,$08,$1E,$4A,$42,$50,$11,$BB,$62,$10,$4B,$B7,$48,$F6,$73,
$A0,$20,$B2,$F8,$F2,$3E,$BE,$18,$32,$58,$7D,$4A,$53,$2E,$DA,$CA,$10,$31,$66,$4D,
$AB,$D4,$83,$3C,$AC,$1C,$50,$1B,$DB,$95,$78,$8D,$11,$54,$28,$09,$02,$55,$C9,$7E,
$47,$75,$57,$6B,$9F,$A0,$84,$91,$88,$E9,$F1,$13,$74,$A4,$34,$FD,$C6,$3A,$EB,$00,
$63,$F1,$88,$51,$13,$B2,$86,$65,$12,$65,$71,$0B,$B9,$66,$F2,$D2,$A8,$8B,$D1,$CE,
$BF,$45,$6B,$BF,$DA,$66,$DE,$AB,$77,$59,$3C,$C5,$37,$56,$20,$4F,$6E,$21,$02,$AB,
$48,$30,$50,$6F,$C8,$CB,$03,$19,$61,$1C,$3A,$A3,$E7,$F1,$34,$6D,$15,$DB,$B7,$C3,
$74,$57,$CF,$56,$C1,$B9,$54,$88,$F8,$23,$92,$FE,$F9,$7B,$EA,$03,$20,$FA,$5D,$D2,
$4E,$03,$DD,$03,$DC,$3E,$13,$A5,$0D,$5F,$D2,$32,$EA,$5F,$CE,$0B,$49,$CE,$35,$E0,
$AF,$05,$5D,$80,$DF,$AA,$A0,$B2,$33,$22,$90,$5F,$80,$81,$9E,$1E,$1C,$AC,$DF,$46,
$16,$C4,$65,$01,$79,$65,$7D,$90,$3D,$8B,$B1,$36,$F9,$86,$A5,$02,$D4,$43,$C5,$BF,
$F8,$5C,$6F,$FD,$5F,$65,$A3,$CD,$8C,$31,$B4,$90,$F5,$2C,$08,$70,$C3,$B4,$E6,$79,
$A1,$6B,$ED,$5E,$E1,$69,$19,$C1,$B5,$3D,$A1,$14,$0C,$96,$B8,$EC,$A6,$23,$91,$6E,
$AC,$2A,$27,$67,$BF,$22,$5A,$A9,$1E,$9D,$71,$1F,$8F,$7D,$A4,$03,$7F,$AE,$E0,$65,
$4D,$2B,$C5,$7E,$F3,$6E,$E3,$13,$48,$62,$DD,$14,$3C,$00,$3A,$A7,$3B,$36,$04,$20,
$AB,$4E,$5B,$B3,$31,$05,$F3,$B1,$A2,$28,$FC,$ED,$F2,$F3,$17,$B5,$41,$7E,$D2,$1A,
$68,$C9,$E1,$DE,$20,$DB,$FA,$24,$A4,$0A,$28,$C6,$11,$06,$C0,$F9,$CF,$5B,$E5,$CC,
$0A,$09,$38,$22,$E3,$7A,$0E,$D5,$7F,$EF,$B8,$10,$1D,$98,$82,$7C,$85,$C1,$47,$C5,
$C2,$50,$A9,$01,$EB,$42,$2A,$AE,$28,$EC,$57,$05,$98,$76,$B4,$10,$9A,$95,$D5,$60,
$3D,$25,$66,$48,$65,$C1,$D5,$9F,$74,$85,$0F,$8B,$8A,$CA,$EE,$5D,$93,$AE,$5A,$7E,
$C7,$6A,$A2,$59,$FC,$08,$79,$74,$71,$96,$74,$1C,$D4,$C9,$BA,$A4,$28,$8A,$92,$20,
$CE,$AA,$5D,$D8,$91,$8E,$2D,$D2,$53,$E7,$CD,$09,$18,$C9,$5B,$0D,$64,$6D,$1A,$12,
$A4,$2A,$F2,$6A,$09,$F7,$94,$87,$10,$51,$69,$69,$14,$94,$B8,$2A,$AF,$65,$9C,$B5,
$6D,$57,$D1,$E2,$4E,$AD,$1B,$87,$14,$6D,$EE,$D2,$63,$41,$DD,$5D,$1A,$5D,$D2,$C1,
$6A,$B0,$45,$9A,$C6,$D2,$80,$43,$6E,$46,$04,$7D,$9C,$38,$E8,$23,$70,$B3,$D6,$2D,
$9A,$62,$AF,$C0,$0C,$47,$9F,$72,$88,$0C,$04,$A1,$63,$11,$7F,$6F,$3F,$BF,$89,$21,
$D1,$1F,$07,$55,$A4,$6C,$A4,$83,$3E,$BD,$A0,$14,$0E,$2B,$1E,$C3,$EC,$98,$C3,$8C,
$5E,$21,$67,$6C,$D1,$62,$B9,$13,$6A,$60,$BF,$17,$E1,$D0,$E3,$3A,$BD,$4B,$FD,$E3,
$6D,$71,$EF,$BE,$F6,$0D,$62,$4B,$C8,$A4,$3F,$F9,$48,$E1,$03,$48,$DA,$D2,$AA,$E9,
$2A,$69,$A3,$E9,$D0,$50,$40,$80,$D6,$2D,$9E,$16,$96,$42,$11,$91,$C9,$51,$01,$E4,
$42,$4D,$C5,$FA,$0B,$55,$60,$64,$05,$83,$1E,$9B,$C8,$A7,$C9,$C4,$2C,$7E,$4A,$D5,
$DC,$07,$A9,$B9,$AE,$AD,$8B,$68,$57,$84,$39,$48,$0B,$97,$8F,$DE,$9A,$9B,$3D,$6B,
$75,$F1,$9C,$A5,$3C,$03,$B2,$ED,$06,$41,$C1,$98,$3C,$5B,$42,$B5,$EA,$3D,$12,$29,
$B6,$90,$76,$87,$B8,$3E,$68,$E1,$05,$52,$0D,$70,$D4,$BF,$20,$79,$3F,$5D,$D6,$73,
$52,$4B,$24,$4C,$CF,$CA,$80,$C6,$C4,$1E,$59,$16,$8A,$03,$35,$21,$37,$6C,$D0,$0D,
$8D,$52,$BF,$82,$BB,$C4,$48,$D1,$1E,$FA,$74,$DF,$30,$09,$8E,$2C,$92,$F7,$E9,$66,
$AB,$88,$FF,$76,$99,$94,$0B,$8A,$47,$7C,$0E,$1C,$F6,$16,$22,$54,$FF,$6C,$97,$CB,
$35,$71,$65,$A6,$4D,$FB,$C6,$C8,$D3,$86,$2A,$0C,$CD,$57,$CA,$54,$22,$43,$3D,$B1,
$0A,$C1,$49,$5F,$62,$93,$94,$5E,$85,$35,$0B,$FA,$5B,$F2,$E4,$C1,$99,$77,$6E,$5C,
$E2,$E8,$D6,$0A,$3A,$45,$FE,$81,$D8,$EE,$BC,$9D,$D6,$6C,$1D,$97,$F8,$AF,$81,$6A,
$4C,$59,$23,$64,$39,$39,$2D,$2B,$E6,$9B,$B4,$22,$50,$E2,$89,$FB,$57,$99,$69,$64,
$23,$0D,$19,$EF,$68,$68,$E8,$53,$91,$6B,$D0,$FA,$17,$54,$D4,$35,$17,$EF,$1E,$43,
$49,$DC,$27,$0B,$88,$BB,$2C,$40,$54,$E1,$A5,$2F,$66,$18,$3E,$B5,$D1,$AA,$06,$03,
$75,$1E,$53,$30,$6F,$0F,$4D,$A2,$46,$6A,$0D,$72,$02,$74,$EC,$FB,$C7,$BD,$A1,$C4,
$FB,$CF,$4A,$68,$CD,$96,$91,$23,$0D,$27,$70,$7F,$36,$09,$C6,$E0,$06,$B6,$03,$3C,
$2B,$7F,$D6,$8A,$7A,$EC,$0B,$D3,$89,$A1,$7F,$19,$F5,$AD,$FC,$57,$DA,$23,$2B,$62,
$CA,$0F,$6B,$D7,$A2,$2E,$45,$BA,$51,$F5,$96,$30,$0C,$49,$39,$41,$E3,$02,$1A,$B5,
$D3,$E5,$61,$2A,$E5,$77,$6B,$E9,$C2,$FC,$B5,$4E,$81,$AF,$5F,$49,$E2,$5B,$2C,$33,
$BD,$39,$15,$B7,$1D,$9E,$C0,$28,$55,$D8,$7A,$E7,$1C,$D5,$23,$83,$E0,$0A,$F0,$86,
$56,$8A,$AA,$26,$BA,$73,$D3,$AE,$06,$65,$47,$5B,$60,$F0,$B9,$BE,$49,$CB,$9B,$8B,
$9B,$AA,$B2,$77,$1E,$ED,$8D,$BB,$F8,$3D,$51,$ED,$12,$6D,$05,$DA,$8D,$22,$94,$EF,
$54,$E9,$45,$91,$A6,$39,$42,$1F,$D4,$6C,$4C,$24,$BC,$F3,$EA,$51,$0F,$3B,$49,$90,
$FA,$C3,$7B,$42,$22,$34,$7D,$BA,$AD,$04,$BA,$02,$40,$11,$E6,$1D,$B1,$48,$2C,$26,
$DE,$7B,$FF,$E3,$86,$5F,$CF,$1E,$1C,$9E,$BD,$49,$02,$E4,$8E,$A0,$E7,$68,$EA,$64,
$F6,$0C,$0B,$9C,$94,$C8,$89,$C8,$40,$87,$D4,$1E,$CA,$C1,$18,$F1,$F6,$04,$8C,$25,
$43,$CF,$7A,$A1,$C4,$13,$17,$06,$BF,$FC,$C4,$E3,$DF,$82,$0A,$D7,$29,$D0,$BE,$06,
$C6,$13,$E7,$8B,$86,$83,$55,$54,$70,$0D,$8B,$30,$2B,$42,$53,$0D,$7D,$AC,$E5,$78,
$AD,$40,$BF,$77,$5D,$BC,$80,$21,$9C,$81,$55,$AD,$58,$00,$9B,$A4,$A2,$A7,$90,$B7,
$0A,$E0,$19,$12,$6C,$4A,$C2,$EC,$93,$92,$BF,$60,$28,$E1,$01,$84,$52,$6A,$0C,$2C,
$80,$D9,$2B,$EB,$12,$74,$FE,$BD,$78,$77,$5A,$AB,$62,$F2,$C0,$6D,$71,$5B,$8E,$3A,
$44,$28,$8E,$83,$61,$93,$43,$A1,$8C,$7F,$92,$31,$C7,$00,$E3,$C2,$BA,$9C,$DF,$A8,
$D2,$CE,$9D,$54,$25,$00,$3E,$54,$85,$60,$06,$93,$0F,$73,$D2,$78,$D5,$2B,$73,$79,
$6B,$A6,$4D,$ED,$03,$85,$A9,$EF,$79,$82,$23,$B1,$58,$1C,$5E,$51,$EA,$CB,$B8,$87,
$98,$28,$8E,$51,$50,$65,$2C,$22,$EE,$D9,$2A,$33,$B5,$C8,$20,$15,$0B,$C7,$2C,$9E,
$83,$A0,$FF,$1D,$8A,$A0,$77,$E5,$5D,$FC,$5A,$35,$DF,$7D,$04,$14,$37,$89,$8B,$56,
$2E,$9C,$86,$13,$3F,$97,$89,$3E,$03,$36,$6C,$70,$5D,$B2,$2C,$AF,$EC,$E8,$B2,$BE,
$55,$36,$76,$C8,$E0,$D9,$FE,$09,$FA,$81,$51,$17,$15,$19,$D3,$A8,$9B,$CC,$5D,$AA,
$6C,$3E,$43,$2C,$3B,$C1,$3A,$6B,$0C,$7D,$0F,$3F,$06,$84,$E9,$D6,$C3,$4E,$F3,$11,
$12,$34,$EC,$10,$1A,$C7,$41,$E5,$01,$67,$C2,$06,$66,$5C,$95,$9C,$FA,$66,$16,$AA,
$75,$BE,$18,$83,$3A,$F8,$18,$BA,$71,$49,$FD,$D8,$14,$C4,$7E,$C0,$18,$0C,$87,$AB,
$F0,$E0,$EC,$E9,$CF,$CB,$C6,$6A,$83,$10,$37,$6D,$E6,$3B,$EA,$7A,$17,$EC,$05,$F9,
$43,$35,$C6,$E7,$E0,$90,$B9,$09,$8A,$1C,$06,$D8,$CE,$6C,$08,$93,$A9,$81,$82,$A3,
$F2,$C9,$1E,$1A,$2B,$E4,$43,$63,$E5,$D8,$A0,$E2,$10,$9A,$A3,$F7,$AB,$0C,$9C,$4A,
$D2,$2A,$2B,$56,$A9,$31,$D7,$8D,$4A,$5A,$12,$85,$38,$2A,$C7,$47,$47,$BE,$07,$7E,
$43,$23,$B2,$77,$68,$67,$F0,$F2,$54,$95,$C1,$47,$15,$9F,$78,$B5,$19,$81,$76,$FA,
$37,$C0,$07,$09,$5B,$37,$A2,$DA,$24,$5F,$AA,$00,$A8,$F1,$52,$E1,$6A,$F7,$09,$F0,
$AA,$7A,$00,$98,$F3,$6B,$5C,$0F,$8A,$3A,$C0,$66,$6A,$D4,$AC,$50,$07,$36,$A8,$5C,
$8F,$1B,$3A,$E0,$73,$33,$9F,$F4,$90,$0D,$A1,$2B,$57,$D3,$4A,$D7,$5E,$B7,$38,$7A,
$4F,$D3,$1C,$65,$E8,$1C,$7E,$B1,$59,$01,$5A,$85,$86,$81,$F9,$84,$03,$05,$34,$0A,
$FC,$73,$12,$6D,$0D,$5C,$EA,$C5,$70,$CD,$1E,$0F,$CE,$FC,$C2,$34,$46,$D1,$8F,$C0,
$26,$54,$5E,$A1,$2E,$4C,$B2,$28,$F8,$41,$0A,$E2,$3A,$68,$C7,$DE,$9A,$4F,$C7,$73,
$EB,$FA,$63,$66,$B0,$78,$9B,$DE,$2C,$7D,$E8,$3A,$65,$01,$FC,$B2,$2C,$DB,$BC,$27,
$5E,$A3,$DF,$B0,$D2,$E7,$28,$1C,$84,$96,$05,$86,$21,$7F,$7A,$94,$E7,$43,$E2,$78,
$79,$54,$A9,$57,$99,$57,$82,$A1,$03,$49,$B0,$72,$F8,$6A,$FD,$E0,$90,$C8,$32,$69,
$75,$BD,$91,$B7,$8D,$52,$DA,$5A,$5C,$01,$22,$30,$9E,$ED,$06,$A1,$78,$90,$7A,$82,
$7C,$AF,$56,$A7,$50,$33,$04,$8C,$33,$91,$D7,$96,$A5,$31,$11,$7D,$10,$35,$E0,$B2,
$2F,$0A,$02,$ED,$48,$38,$13,$D4,$84,$37,$BB,$C5,$38,$DB,$55,$10,$3A,$A1,$A3,$D1,
$E1,$C5,$C5,$D4,$FE,$57,$1F,$B6,$FA,$42,$22,$EE,$A5,$8D,$56,$E6,$B5,$DB,$E9,$84,
$66,$09,$E4,$F4,$BB,$A3,$D5,$A8,$55,$42,$0D,$79,$EF,$47,$2F,$07,$83,$33,$62,$23,
$56,$BB,$D1,$71,$4B,$1E,$0A,$15,$17,$AC,$66,$40,$1F,$3A,$C7,$D8,$D6,$85,$E5,$5A,
$A5,$57,$CD,$A1,$2C,$B6,$A4,$38,$F5,$99,$CD,$6C,$14,$21,$E8,$E2,$80,$EC,$A8,$A7,
$8D,$32,$F4,$AF,$68,$30,$06,$E2,$6E,$45,$64,$73,$DC,$2F,$25,$76,$91,$AF,$C8,$16,
$05,$5B,$22,$63,$8B,$92,$81,$69,$BC,$98,$4A,$5E,$97,$0B,$1A,$54,$C5,$4C,$4A,$43,
$70,$10,$5C,$3E,$46,$8C,$A2,$81,$56,$41,$61,$54,$45,$8E,$28,$BE,$A8,$92,$CC,$5C,
$FC,$E1,$68,$77,$33,$7E,$30,$5E,$34,$2F,$CB,$85,$12,$14,$19,$0A,$D8,$D4,$17,$25,
$51,$13,$47,$22,$15,$38,$61,$17,$2C,$39,$72,$0C,$A8,$1B,$5C,$47,$E8,$CB,$67,$E9,
$B1,$AD,$DF,$7F,$5B,$93,$17,$C7,$22,$BF,$AB,$E8,$90,$AA,$71,$13,$89,$0D,$58,$5E,
$45,$32,$C7,$6A,$8D,$C4,$22,$58,$1B,$25,$0A,$73,$90,$CC,$AA,$60,$B0,$86,$BD,$66,
$CD,$C5,$59,$6F,$FC,$61,$4C,$37,$1A,$2F,$96,$35,$AF,$02,$03,$44,$32,$EE,$90,$B2,
$6E,$FA,$B0,$26,$3D,$5B,$E8,$AE,$0F,$89,$BC,$0F,$2C,$29,$58,$55,$15,$7C,$B1,$DA,
$10,$75,$9D,$30,$87,$F8,$CA,$E4,$24,$92,$C9,$A4,$C1,$3A,$70,$BF,$2D,$00,$CC,$C2,
$BD,$97,$9C,$F1,$C0,$EA,$68,$77,$1F,$78,$5C,$37,$82,$27,$D5,$4F,$69,$BF,$46,$A5,
$29,$7A,$B9,$2A,$3D,$2B,$45,$F7,$AE,$D6,$6D,$CE,$8C,$23,$D4,$79,$41,$4C,$2A,$9C,
$D7,$55,$0A,$54,$8C,$D4,$A0,$0C,$38,$0F,$F3,$CF,$B0,$D2,$39,$8C,$BB,$E9,$13,$06,
$E4,$BB,$81,$27,$8E,$28,$5A,$6C,$03,$D7,$E6,$95,$69,$3D,$F4,$11,$F4,$94,$E4,$31,
$4B,$4C,$76,$5B,$43,$93,$AA,$42,$C3,$25,$1C,$6D,$37,$7F,$DC,$04,$41,$2A,$62,$E7,
$9D,$2A,$FD,$4B,$5D,$4E,$52,$6E,$48,$1A,$AD,$F5,$16,$18,$45,$1D,$CA,$DB,$00,$81,
$5A,$7E,$40,$14,$89,$02,$BB,$43,$43,$DB,$5D,$BE,$41,$E5,$66,$45,$FC,$87,$15,$D2,
$38,$9B,$F9,$9D,$CA,$AE,$3F,$86,$87,$62,$63,$74,$EA,$13,$7D,$2C,$BA,$7E,$89,$31,
$5F,$54,$26,$93,$1B,$61,$E7,$9F,$B0,$01,$77,$4D,$91,$15,$0D,$C2,$6E,$4F,$0A,$EC,
$AE,$E1,$34,$90,$F4,$50,$9B,$99,$7A,$A4,$9E,$01,$E5,$EB,$EC,$51,$9F,$CE,$8A,$D7,
$19,$73,$BB,$D6,$21,$CF,$86,$88,$6C,$49,$E9,$80,$41,$21,$91,$E5,$B3,$57,$65,$A4,
$95,$A2,$85,$99,$79,$66,$84,$CB,$1E,$29,$52,$68,$DB,$1B,$86,$73,$A9,$3D,$06,$C5,
$4E,$41,$40,$91,$0C,$A4,$16,$10,$18,$C8,$9E,$31,$0D,$F1,$C8,$A5,$C6,$B3,$79,$71,
$90,$01,$EC,$DD,$C1,$DF,$33,$0D,$01,$CB,$7A,$D0,$50,$4B,$4F,$94,$4D,$1A,$17,$E1,
$0E,$32,$8E,$78,$F0,$BC,$8A,$A1,$89,$20,$F3,$79,$7A,$58,$18,$C8,$79,$02,$28,$A2,
$40,$F6,$C2,$01,$08,$C8,$E3,$97,$4E,$06,$E0,$4B,$CB,$B5,$58,$13,$84,$12,$45,$A2,
$51,$78,$83,$5A,$24,$64,$CA,$1B,$5A,$B4,$B5,$D0,$F4,$1A,$4A,$8C,$7D,$82,$D1,$00,
$5D,$A4,$E9,$37,$15,$8B,$12,$D4,$D0,$03,$5F,$22,$6A,$34,$7E,$C1,$39,$72,$38,$1B,
$AC,$18,$8C,$C2,$DA,$2D,$23,$0C,$6E,$0A,$CE,$82,$14,$84,$69,$48,$8A,$12,$2A,$7E,
$8B,$57,$FA,$D5,$BF,$E9,$1C,$B1,$3B,$E2,$F1,$A7,$EB,$EC,$9D,$F3,$6B,$6E,$19,$26,
$4E,$5F,$3D,$F6,$27,$F4,$0A,$E0,$4A,$8C,$A7,$83,$04,$CF,$BA,$BB,$05,$21,$97,$65,
$B7,$1A,$00,$F4,$41,$1B,$56,$CD,$51,$D0,$3F,$91,$81,$EC,$75,$AD,$51,$7A,$3F,$59,
$BA,$A2,$3D,$3C,$81,$58,$BD,$2B,$EB,$05,$0B,$5C,$A8,$7A,$B3,$30,$43,$30,$83,$C1,
$CD,$0F,$70,$AB,$5E,$6A,$26,$4D,$99,$20,$C9,$69,$35,$36,$47,$55,$5C,$6D,$C5,$3D,
$A1,$75,$C3,$70,$E5,$FC,$37,$EE,$CA,$84,$F2,$36,$E2,$F7,$A1,$E1,$89,$68,$1F,$FC,
$0B,$84,$3B,$08,$0A,$1F,$0C,$77,$04,$72,$F1,$BC,$95,$F5,$C5,$D7,$CC,$AD,$6F,$79,
$5C,$79,$18,$1E,$57,$EA,$A7,$99,$5E,$57,$C8,$D8,$1B,$C0,$51,$45,$CE,$E6,$2E,$EC,
$B3,$AE,$0C,$1D,$A7,$40,$4E,$CD,$FE,$4E,$B4,$2C,$BE,$22,$10,$D5,$F3,$A2,$80,$F6,
$A7,$94,$D8,$C5,$C0,$33,$4C,$D1,$BD,$20,$2A,$9E,$AE,$D8,$72,$49,$55,$3B,$B4,$E1,
$CB,$F8,$AB,$5C,$B5,$5F,$C2,$B3,$0B,$2A,$C7,$61,$86,$13,$AF,$5C,$79,$3E,$AD,$00,
$90,$AC,$FF,$99,$7B,$7A,$BA,$A6,$9F,$00,$81,$B0,$E9,$C4,$69,$25,$0D,$4A,$EC,$78,
$D0,$BE,$54,$8D,$97,$DE,$33,$A5,$B9,$7E,$DF,$DC,$41,$C4,$16,$51,$C5,$75,$5B,$55,
$2C,$B5,$C0,$5E,$41,$2A,$EA,$5D,$7D,$29,$53,$F7,$F8,$0E,$D6,$8B,$BF,$7E,$5B,$F4,
$6C,$DD,$BC,$94,$B5,$26,$05,$20,$37,$6B,$5F,$1C,$E0,$E6,$00,$9E,$55,$A5,$74,$6E,
$7B,$3C,$64,$B5,$02,$49,$14,$1F,$8A,$9B,$B8,$1C,$BF,$02,$12,$32,$20,$EC,$11,$FF,
$F7,$4F,$15,$9A,$5B,$B7,$9D,$E6,$00,$80,$22,$36,$51,$5F,$5D,$99,$CB,$CF,$58,$3F,
$37,$5B,$35,$F6,$77,$66,$D9,$42,$C4,$36,$43,$8A,$05,$44,$1A,$FF,$39,$A0,$22,$B1,
$29,$BF,$6C,$2A,$3A,$74,$1C,$D6,$25,$A5,$CC,$31,$ED,$59,$2A,$D0,$7C,$E4,$DC,$27,
$25,$61,$50,$68,$69,$A2,$6A,$55,$9E,$71,$A1,$B6,$D0,$2B,$CF,$57,$EF,$0B,$D0,$EB,
$A4,$31,$F4,$4A,$31,$D3,$EB,$C1,$59,$F7,$67,$38,$CD,$06,$50,$E6,$3B,$F8,$78,$08,
$D7,$47,$33,$09,$EE,$AE,$8D,$5E,$3C,$9A,$58,$7F,$DD,$73,$93,$0B,$F7,$7E,$C2,$CD,
$14,$8D,$78,$AA,$36,$A9,$56,$2A,$8E,$AA,$1B,$5C,$6D,$75,$BF,$C7,$BA,$70,$7E,$D5,
$EA,$5A,$1D,$4E,$21,$F1,$2D,$AE,$C0,$0F,$15,$71,$51,$7E,$7C,$E8,$4B,$64,$2D,$AA,
$D5,$1B,$3A,$6D,$BC,$14,$E6,$94,$57,$FC,$3C,$5F,$74,$93,$AD,$94,$07,$CE,$8A,$3D,
$46,$6B,$78,$A5,$FC,$2A,$53,$E8,$FA,$5C,$B5,$61,$B5,$E7,$1B,$82,$95,$09,$9D,$BB,
$F5,$54,$FD,$67,$69,$77,$20,$57,$1C,$A2,$9B,$9C,$74,$B0,$68,$91,$82,$0A,$D7,$D9,
$34,$94,$3C,$3D,$FA,$60,$D5,$FE,$A8,$D5,$6A,$0C,$E9,$66,$A4,$D0,$2C,$AE,$2E,$2B,
$F7,$3F,$CC,$F5,$A3,$3C,$58,$8B,$37,$B7,$C6,$FF,$11,$6F,$6B,$6F,$DA,$7C,$5B,$84,
$C2,$2C,$44,$01,$9F,$C1,$79,$06,$17,$42,$E4,$99,$3B,$49,$6B,$FD,$C3,$F2,$DA,$9F,
$4F,$4A,$5F,$54,$BC,$49,$44,$0A,$DC,$A5,$44,$FC,$A1,$6F,$1A,$DF,$AE,$92,$70,$D8,
$AE,$EA,$70,$11,$25,$AD,$45,$51,$8A,$26,$81,$86,$6B,$57,$F9,$31,$50,$1A,$AE,$90,
$B8,$FA,$84,$25,$5D,$AF,$94,$FB,$9A,$50,$4E,$A3,$02,$9A,$06,$12,$95,$02,$45,$F0,
$B5,$35,$BA,$D7,$EB,$5E,$1A,$1C,$C2,$65,$39,$22,$99,$8B,$83,$37,$0B,$2A,$2C,$8F,
$8D,$68,$D2,$54,$17,$15,$1C,$7F,$F8,$4C,$33,$03,$E7,$F9,$22,$FF,$7C,$44,$F2,$2A,
$E3,$E4,$15,$57,$73,$2C,$7C,$B0,$BC,$9F,$11,$1D,$50,$E2,$B2,$98,$85,$12,$55,$50,
$AD,$51,$86,$34,$9B,$89,$0D,$47,$84,$DA,$58,$12,$C9,$BA,$33,$B9,$FB,$9F,$E8,$32,
$22,$1D,$67,$4D,$A5,$6E,$CF,$1D,$F9,$39,$BC,$C0,$1A,$B1,$97,$DB,$A8,$17,$76,$D4,
$91,$2D,$5D,$03,$99,$FB,$B4,$6C,$8C,$DE,$EC,$D9,$EB,$2C,$85,$6C,$A6,$1D,$ED,$E6,
$17,$C1,$AB,$58,$2F,$56,$6F,$56,$01,$28,$29,$90,$2A,$B0,$09,$8C,$CE,$9C,$64,$EB,
$AD,$6B,$15,$9D,$02,$61,$5D,$0B,$4B,$6C,$B9,$81,$25,$98,$C9,$D4,$18,$DC,$FA,$1A,
$30,$1A,$AF,$16,$C5,$5D,$9C,$76,$C0,$CB,$78,$6B,$74,$10,$BB,$FD,$9D,$8C,$E6,$60,
$05,$ED,$EE,$A1,$63,$19,$77,$24,$A1,$0A,$1D,$A4,$75,$58,$6C,$9B,$2D,$F4,$0F,$CC,
$AD,$3A,$B2,$77,$1E,$87,$C5,$14,$58,$0E,$2B,$CF,$87,$5C,$83,$A2,$3A,$6D,$D3,$B0,
$2A,$5D,$6B,$C4,$6C,$E3,$28,$72,$1F,$D4,$44,$DE,$60,$49,$23,$98,$B0,$BB,$C9,$F8,
$8E,$F7,$DA,$98,$CF,$BD,$5C,$C6,$DD,$C8,$8F,$F6,$D4,$20,$8D,$BF,$70,$15,$4F,$56,
$E5,$7A,$EE,$66,$F2,$F5,$86,$35,$BE,$FE,$B8,$FB,$F1,$A5,$5A,$BD,$F3,$76,$AC,$34,
$E1,$A8,$EF,$55,$21,$F1,$E7,$78,$32,$C3,$3E,$59,$99,$CB,$8E,$5C,$AA,$E3,$6C,$1E,
$B9,$53,$4A,$56,$FE,$D0,$3D,$DF,$3A,$51,$CF,$CB,$06,$43,$89,$F1,$79,$81,$4B,$92,
$ED,$BE,$B0,$45,$69,$19,$5A,$8F,$3A,$E2,$9F,$0D,$55,$35,$6D,$C0,$1C,$45,$3F,$B6,
$2D,$F3,$F9,$E6,$2E,$36,$05,$6F,$11,$26,$09,$3B,$11,$6C,$32,$78,$30,$90,$BB,$BF,
$7D,$FD,$D0,$3C,$A9,$22,$70,$01,$85,$03,$45,$AA,$27,$EE,$7E,$C9,$16,$3E,$D6,$3D,
$8F,$70,$51,$15,$46,$50,$D2,$98,$98,$30,$61,$4D,$A9,$C9,$59,$CD,$65,$2B,$11,$AE,
$3A,$44,$0F,$3E,$82,$AB,$13,$CD,$4B,$25,$56,$4C,$04,$50,$48,$AE,$F2,$5B,$90,$37,
$24,$60,$01,$4A,$2C,$A5,$A4,$FA,$92,$42,$96,$B4,$C6,$79,$15,$24,$B0,$44,$C3,$52,
$1F,$86,$86,$3B,$9B,$1A,$89,$DC,$58,$E2,$59,$3E,$CD,$A4,$AB,$12,$06,$15,$FD,$EE,
$3A,$BB,$B8,$2F,$58,$44,$B2,$A5,$B1,$63,$38,$2F,$6E,$95,$94,$90,$D2,$70,$17,$B4,
$6F,$A5,$69,$67,$6C,$B5,$58,$E0,$8F,$89,$3B,$43,$E1,$48,$B9,$2A,$41,$5B,$9B,$0A,
$E5,$96,$EB,$AB,$2D,$5F,$6C,$82,$E1,$9D,$22,$8F,$0B,$2A,$DF,$F9,$32,$DC,$29,$96,
$11,$6A,$6E,$F5,$0E,$0E,$D7,$B5,$85,$7E,$A5,$87,$7B,$3C,$58,$5D,$44,$2F,$E5,$4B,
$48,$98,$11,$FE,$46,$5C,$39,$30,$EA,$B2,$B5,$09,$15,$83,$AF,$20,$13,$29,$1A,$CA,
$BA,$9D,$EB,$4E,$40,$5C,$B1,$E0,$F2,$58,$06,$73,$D0,$3D,$35,$8C,$82,$22,$0A,$05,
$0D,$0C,$D6,$60,$29,$64,$2A,$32,$B0,$AD,$20,$A6,$02,$03,$E8,$C5,$DA,$EC,$9D,$DF,
$E6,$90,$D9,$A0,$E1,$2B,$BB,$A9,$28,$D0,$E3,$E3,$41,$E0,$42,$24,$40,$92,$D3,$E7,
$8A,$91,$94,$BE,$C0,$BD,$25,$89,$42,$40,$F7,$AD,$4D,$0A,$16,$A7,$82,$B3,$DA,$7F,
$2F,$65,$ED,$5B,$F1,$B7,$B2,$16,$56,$AB,$23,$A8,$AD,$93,$AF,$84,$A1,$B1,$B5,$23,
$3B,$73,$23,$58,$98,$E6,$FE,$61,$E6,$51,$FD,$34,$0A,$C5,$B3,$55,$AB,$D0,$83,$20,
$17,$25,$13,$25,$42,$5E,$DC,$3B,$4B,$9F,$09,$ED,$77,$19,$84,$B2,$D2,$A2,$06,$2A,
$95,$43,$57,$66,$6B,$B0,$8C,$62,$84,$9D,$4E,$F4,$F8,$CA,$79,$C3,$B2,$B4,$6E,$FB,
$54,$2E,$29,$EB,$80,$C3,$AC,$7A,$2D,$C9,$EE,$C6,$1C,$44,$C3,$E4,$AD,$BC,$A9,$40,
$7E,$5A,$08,$B1,$72,$EB,$FB,$4D,$F0,$80,$0C,$67,$E5,$68,$6A,$AD,$98,$46,$45,$A2,
$E8,$57,$53,$96,$B3,$0A,$AB,$5B,$E9,$45,$8C,$D3,$CB,$0B,$D6,$C4,$0C,$B8,$2A,$26,
$10,$41,$C7,$61,$81,$5B,$22,$6C,$AB,$A6,$08,$57,$2C,$E0,$18,$D0,$37,$56,$61,$89,
$EF,$2B,$62,$31,$BC,$45,$A0,$C0,$9E,$00,$8D,$CE,$E1,$97,$0B,$B5,$56,$89,$0A,$2A,
$48,$C7,$45,$01,$2D,$87,$AE,$11,$8B,$E0,$28,$2C,$A2,$51,$6B,$D2,$B6,$73,$35,$34,
$18,$CF,$67,$D8,$68,$73,$70,$B8,$37,$53,$A0,$F0,$CC,$BD,$7F,$E4,$92,$2F,$BA,$56,
$D1,$69,$55,$03,$9D,$FF,$B8,$6A,$CF,$6B,$AD,$F4,$9B,$13,$3A,$63,$8C,$55,$64,$6F,
$78,$E5,$49,$7F,$16,$58,$08,$D8,$19,$39,$FB,$58,$0E,$CE,$A2,$BA,$B5,$12,$B2,$0E,
$52,$5D,$9F,$38,$19,$70,$7C,$5F,$F3,$1D,$89,$55,$25,$EA,$F9,$87,$99,$AE,$68,$C1,
$AF,$FB,$6B,$AE,$7C,$C6,$9F,$28,$8B,$77,$B1,$95,$5B,$07,$52,$B4,$4B,$F7,$8B,$77,
$83,$73,$FD,$DA,$B4,$A7,$E8,$2A,$17,$63,$6D,$98,$C4,$AD,$A8,$38,$42,$7F,$65,$27,
$F9,$46,$25,$EA,$C2,$22,$15,$01,$7A,$9C,$58,$86,$67,$20,$1B,$14,$FB,$C6,$AB,$26,
$B2,$49,$2C,$CA,$BE,$8A,$AD,$E3,$68,$0C,$6C,$AA,$B6,$64,$53,$40,$B2,$BB,$05,$1F,
$FD,$18,$16,$18,$62,$03,$63,$5C,$AF,$12,$92,$A3,$F3,$AE,$07,$08,$07,$93,$B0,$A7,
$9D,$BA,$AA,$1E,$84,$B9,$A1,$09,$E7,$E1,$2F,$73,$85,$8F,$AE,$C2,$06,$89,$46,$64,
$0E,$09,$9C,$6E,$60,$26,$98,$5E,$8B,$27,$0D,$58,$27,$3F,$A5,$18,$D0,$19,$F1,$DB,
$0F,$99,$B8,$00,$F3,$C3,$EA,$61,$62,$C7,$57,$0C,$F0,$63,$72,$C6,$21,$D1,$C6,$DE,
$01,$8F,$72,$F5,$27,$07,$71,$FF,$4A,$27,$01,$31,$D7,$25,$8C,$D8,$3A,$AD,$88,$31,
$46,$34,$06,$11,$44,$F9,$98,$1A,$3C,$03,$10,$06,$36,$03,$1D,$6A,$C2,$05,$18,$27,
$04,$01,$0B,$15,$A8,$96,$EA,$CB,$88,$14,$94,$37,$F3,$A1,$F1,$35,$6E,$36,$19,$9B,
$A7,$65,$DA,$E8,$8F,$52,$57,$0B,$36,$ED,$EA,$F7,$F0,$A4,$ED,$23,$B0,$F0,$4C,$5D,
$BF,$C7,$C1,$DB,$DE,$32,$55,$A8,$35,$F0,$ED,$20,$18,$5F,$5F,$D7,$F4,$D3,$28,$E7,
$0B,$4C,$F1,$3A,$3A,$B8,$9F,$75,$97,$0C,$BD,$6A,$33,$57,$F7,$F0,$C7,$9A,$34,$B7,
$9E,$BF,$C9,$AC,$10,$2D,$23,$66,$C2,$9B,$16,$0C,$F5,$8F,$D4,$35,$0D,$DA,$EA,$94,
$48,$80,$91,$B5,$A1,$C1,$AA,$98,$B3,$11,$16,$C1,$AC,$EA,$FB,$6C,$AD,$39,$04,$FA,
$E8,$ED,$12,$4C,$26,$9A,$00,$E7,$69,$D4,$C0,$45,$E3,$8C,$07,$28,$BE,$D6,$F0,$D5,
$02,$1B,$23,$16,$FA,$D6,$89,$FB,$F1,$73,$22,$D6,$35,$0C,$48,$98,$5D,$37,$9B,$15,
$36,$A6,$E2,$99,$D9,$EE,$CE,$2D,$43,$56,$10,$4F,$10,$7C,$33,$D7,$4B,$07,$6D,$F9,
$47,$EF,$81,$64,$7F,$22,$9D,$41,$1C,$9A,$15,$D6,$69,$19,$C4,$54,$E0,$10,$FC,$87,
$85,$6E,$B7,$15,$FA,$F0,$2E,$F4,$19,$06,$7A,$21,$06,$12,$7E,$7E,$27,$F4,$7A,$FD,
$11,$06,$EF,$C8,$61,$37,$35,$C8,$BE,$BD,$DE,$3A,$E8,$C7,$C1,$DE,$11,$B7,$A5,$B0,
$AF,$46,$F1,$ED,$75,$30,$44,$45,$A2,$19,$5E,$E2,$C7,$56,$84,$A0,$EA,$BD,$3E,$0F,
$F0,$0A,$07,$60,$87,$4E,$0F,$A3,$7F,$19,$C9,$BE,$19,$99,$5B,$97,$A7,$1B,$BA,$FD,
$CB,$C0,$55,$C8,$49,$E2,$87,$29,$0F,$6C,$EC,$87,$2A,$8E,$E6,$27,$F2,$8C,$BE,$F4,
$8B,$7D,$A0,$F4,$7B,$40,$05,$13,$AD,$86,$E9,$63,$AE,$68,$2D,$7F,$C5,$78,$99,$42,
$DD,$C4,$B0,$8F,$E7,$A2,$D8,$AF,$6F,$CA,$D2,$B5,$13,$18,$16,$40,$C8,$CB,$EF,$13,
$F7,$8B,$0B,$9E,$FF,$6F,$05,$84,$F0,$E5,$64,$DD,$9B,$9C,$1A,$6B,$CF,$DB,$6A,$4C,
$3F,$EA,$8D,$F8,$59,$50,$2E,$71,$3B,$D4,$AC,$4E,$23,$D4,$BD,$16,$A3,$1A,$5B,$8F,
$D5,$4A,$AA,$2A,$D4,$7F,$8D,$BC,$49,$58,$91,$6A,$33,$99,$06,$B7,$4F,$96,$4A,$76,
$44,$45,$3E,$62,$E5,$13,$94,$F0,$AE,$27,$EE,$55,$16,$D7,$DE,$C0,$10,$59,$7A,$A8,
$62,$27,$8D,$85,$3A,$CA,$C9,$77,$11,$97,$14,$8A,$93,$D0,$BD,$0C,$9F,$AE,$8E,$01,
$EE,$ED,$75,$28,$8B,$B9,$82,$4F,$23,$53,$77,$82,$6B,$30,$80,$DD,$F6,$8C,$D1,$5A,
$F4,$50,$91,$38,$AB,$3B,$05,$99,$54,$3F,$5B,$69,$D1,$D1,$82,$74,$AC,$00,$A2,$B6,
$A9,$A0,$3E,$3A,$CA,$63,$E4,$F5,$3A,$B7,$60,$63,$80,$85,$16,$75,$EB,$79,$DE,$A9,
$53,$F0,$AB,$B3,$25,$55,$B9,$9D,$DE,$A9,$02,$22,$B5,$30,$E9,$D8,$29,$3B,$94,$3F,
$3E,$C7,$86,$F8,$4F,$5E,$2F,$58,$70,$7C,$98,$7E,$64,$46,$7D,$E3,$2A,$00,$50,$B0,
$96,$F3,$16,$2B,$AC,$1F,$D6,$DD,$89,$21,$5A,$CD,$16,$9A,$DB,$CF,$54,$3A,$A4,$E3,
$EF,$CC,$CA,$9A,$0B,$DE,$1B,$A1,$48,$5C,$A7,$CF,$F6,$40,$5F,$C9,$BE,$B7,$3F,$BB,
$9A,$C2,$7E,$75,$8A,$9C,$82,$FA,$27,$6F,$AD,$27,$6D,$20,$C6,$10,$BA,$DF,$86,$84,
$B5,$62,$28,$C3,$27,$DC,$8B,$E3,$C5,$F9,$00,$DF,$9D,$5D,$82,$77,$EC,$FB,$65,$EA,
$A0,$8A,$2B,$DC,$9A,$38,$07,$DE,$AA,$40,$EA,$16,$F5,$6F,$69,$72,$EB,$82,$CC,$2F,
$EB,$9E,$30,$37,$7F,$25,$14,$BA,$18,$C2,$B8,$46,$D8,$C3,$E3,$21,$6B,$C9,$52,$49,
$AB,$8F,$53,$C4,$8E,$D4,$F9,$11,$49,$09,$18,$FD,$C0,$9E,$AE,$A2,$DE,$84,$6E,$55,
$54,$57,$6C,$16,$8C,$2C,$7C,$74,$BC,$02,$22,$08,$48,$C1,$84,$0B,$8C,$9E,$FE,$67,
$09,$AF,$15,$ED,$EB,$87,$2E,$27,$47,$58,$CA,$35,$94,$E6,$E4,$4A,$F2,$27,$C5,$E4,
$A3,$D6,$13,$D5,$C7,$C2,$F7,$0E,$02,$70,$BA,$F6,$05,$A3,$A1,$DF,$68,$ED,$95,$E7,
$EB,$D4,$44,$8A,$ED,$A3,$80,$28,$02,$32,$DD,$1F,$85,$38,$0F,$24,$4F,$C5,$65,$3D,
$E2,$74,$F7,$AD,$11,$17,$7F,$35,$5F,$28,$AA,$A2,$84,$AC,$EE,$D2,$52,$AB,$10,$3F,
$9D,$5F,$0C,$B5,$B2,$5F,$36,$63,$37,$95,$93,$42,$77,$6C,$CD,$F0,$9D,$E6,$E3,$0C,
$40,$A0,$CB,$AA,$0E,$BD,$4B,$BF,$1F,$96,$65,$5E,$D1,$BB,$1D,$90,$4B,$92,$43,$5A,
$D4,$F8,$D3,$12,$E2,$3C,$75,$FD,$B1,$C3,$A8,$C7,$DE,$83,$4F,$AF,$4E,$DD,$98,$AA,
$05,$D7,$9C,$57,$34,$8E,$3E,$BC,$90,$31,$5C,$88,$CE,$66,$21,$2B,$21,$F7,$3C,$BA,
$EA,$12,$C7,$55,$80,$13,$53,$98,$9C,$D4,$49,$06,$1F,$38,$D9,$43,$B1,$3F,$B8,$07,
$6F,$B4,$AA,$44,$3B,$86,$3C,$41,$6E,$94,$72,$BF,$98,$70,$B8,$67,$13,$A2,$F1,$D2,
$58,$48,$B3,$4B,$6C,$75,$FE,$22,$C1,$CB,$10,$F1,$A4,$93,$AC,$03,$75,$93,$A0,$63,
$2F,$71,$9F,$A4,$C9,$3D,$D0,$28,$92,$F7,$28,$97,$1B,$94,$A0,$D6,$85,$A7,$CB,$C3,
$BE,$98,$D8,$EF,$20,$50,$1F,$47,$13,$28,$8B,$78,$4C,$FA,$F8,$AE,$36,$E6,$B9,$93,
$C7,$4A,$B0,$7A,$C6,$42,$55,$27,$B4,$D6,$A7,$78,$45,$26,$33,$93,$31,$F6,$5A,$48,
$1E,$AA,$5D,$80,$AC,$E4,$BD,$AB,$98,$81,$F6,$26,$F0,$8D,$35,$9B,$43,$E5,$8D,$E9,
$CD,$3B,$20,$98,$1E,$E8,$DC,$5E,$85,$66,$A7,$66,$71,$5A,$65,$63,$57,$DA,$19,$B1,
$07,$EF,$05,$97,$5D,$3D,$B8,$6C,$79,$98,$81,$F4,$6D,$6B,$6C,$F2,$6B,$CF,$AF,$21,
$AD,$63,$82,$13,$26,$F7,$CF,$36,$A6,$E3,$17,$40,$4D,$97,$62,$FA,$95,$4B,$84,$AE,
$1F,$B6,$C2,$33,$88,$1F,$9D,$6B,$8B,$A4,$41,$5B,$40,$A1,$D0,$41,$65,$CA,$20,$9E,
$E2,$25,$22,$D0,$A7,$2C,$E9,$0D,$48,$9F,$48,$E8,$5F,$96,$86,$A1,$50,$9C,$34,$37,
$A0,$0A,$06,$AC,$74,$E1,$85,$72,$C0,$1A,$69,$65,$0A,$9E,$DB,$CA,$67,$59,$0D,$79,
$5C,$75,$AD,$2B,$89,$14,$83,$37,$51,$C4,$B1,$4A,$05,$F9,$B4,$EE,$55,$DF,$8D,$DB,
$8B,$A0,$0C,$A9,$2A,$18,$74,$30,$E2,$C1,$D5,$80,$AC,$7C,$94,$67,$33,$31,$2E,$D5,
$BB,$8C,$3B,$E4,$BB,$DD,$C1,$20,$11,$76,$85,$B0,$8C,$DE,$7D,$87,$81,$48,$2D,$74,
$F9,$8B,$5B,$70,$7F,$5E,$6D,$87,$9B,$A6,$5E,$81,$09,$40,$73,$AF,$77,$FC,$2B,$5F,
$50,$9E,$FD,$6B,$E0,$EC,$8E,$41,$58,$58,$26,$EE,$31,$86,$13,$8A,$24,$6D,$F6,$CB,
$BA,$5D,$57,$E8,$42,$4F,$CE,$81,$CC,$78,$5E,$9B,$E4,$D9,$94,$B5,$EE,$7D,$7C,$80,
$BA,$01,$B1,$F4,$34,$27,$B6,$30,$6E,$7F,$FB,$90,$43,$FA,$D0,$37,$3D,$A3,$7F,$FD,
$DA,$F4,$C5,$AF,$66,$7C,$AF,$6E,$CB,$22,$1A,$20,$1C,$B9,$A0,$55,$7A,$D1,$23,$CB,
$26,$71,$05,$92,$D0,$F3,$06,$D9,$7A,$16,$A9,$80,$AE,$9D,$05,$B1,$0F,$A1,$DC,$A1,
$ED,$04,$9F,$A6,$4F,$AB,$98,$9F,$A4,$E2,$E6,$DB,$EF,$08,$95,$6B,$CE,$5C,$11,$9C,
$BE,$EF,$5F,$9E,$64,$69,$0B,$8F,$33,$74,$C5,$4C,$D3,$84,$38,$D7,$62,$BF,$9E,$3A,
$24,$53,$58,$70,$44,$66,$F3,$BB,$20,$65,$6C,$2E,$7D,$C8,$AB,$CB,$E3,$CA,$46,$DE,
$74,$A7,$EE,$D7,$C1,$E4,$A2,$DD,$66,$63,$20,$37,$DD,$98,$52,$7E,$B1,$2E,$82,$55,
$1F,$D8,$ED,$FC,$D7,$A8,$49,$CB,$71,$DA,$64,$63,$11,$5F,$FB,$FD,$4F,$1B,$82,$C9,
$BF,$52,$EC,$B9,$8D,$AD,$D8,$C1,$11,$8B,$D9,$0D,$74,$75,$70,$AD,$0D,$3F,$4F,$41,
$2B,$C1,$65,$59,$E1,$C7,$1B,$DE,$CB,$A8,$5F,$99,$69,$78,$BE,$C5,$7B,$85,$39,$2D,
$BB,$84,$51,$C9,$09,$8D,$F7,$8A,$E4,$7A,$A1,$3E,$43,$1D,$F4,$05,$A2,$5C,$18,$3B,
$EE,$C5,$0D,$05,$87,$AE,$10,$25,$05,$A4,$3F,$93,$F8,$9D,$9A,$37,$86,$FC,$46,$C1,
$01,$D1,$7C,$53,$A6,$DD,$E9,$C7,$AA,$14,$BB,$8A,$57,$61,$89,$9E,$61,$4F,$14,$51,
$7B,$55,$A1,$4B,$42,$24,$46,$94,$57,$6E,$8D,$0E,$C7,$7E,$4A,$16,$98,$95,$97,$7C,
$F7,$2C,$79,$FE,$AA,$D7,$7B,$DB,$B7,$AC,$95,$FE,$16,$8F,$44,$4B,$90,$6E,$CD,$84,
$FA,$45,$63,$4D,$8E,$52,$D0,$C1,$12,$B1,$49,$58,$CF,$60,$03,$20,$CB,$04,$45,$9A,
$5E,$CF,$7B,$41,$EC,$2B,$A6,$43,$35,$95,$EB,$22,$55,$11,$B0,$76,$29,$B9,$0C,$2C,
$E9,$41,$05,$27,$C8,$19,$CE,$60,$11,$31,$F6,$1B,$C6,$32,$FD,$D0,$13,$13,$5B,$10,
$AB,$C8,$54,$09,$8E,$C8,$0F,$D7,$4E,$10,$29,$31,$B1,$88,$80,$29,$FC,$3E,$19,$55,
$8D,$A6,$EA,$80,$96,$B6,$AE,$50,$17,$0E,$06,$67,$55,$D0,$BF,$0C,$AA,$5F,$2F,$8A,
$18,$12,$29,$35,$B3,$BE,$CC,$95,$45,$19,$A9,$18,$4A,$3C,$1D,$AB,$65,$73,$4A,$88,
$C8,$43,$F2,$C5,$D4,$50,$CA,$85,$8B,$1C,$43,$02,$07,$86,$C0,$F5,$74,$BA,$53,$25,
$2E,$33,$DC,$73,$DB,$2B,$2C,$1E,$BD,$87,$EE,$57,$64,$E1,$65,$9C,$33,$D7,$0B,$B9,
$5F,$68,$34,$CF,$36,$2D,$B3,$B8,$95,$40,$1D,$20,$10,$2F,$1C,$D8,$1A,$E3,$11,$CC,
$B0,$95,$B7,$7C,$AB,$2D,$F0,$16,$EC,$EE,$53,$E5,$C0,$E4,$BC,$25,$55,$D0,$23,$AF,
$4B,$06,$70,$9A,$1A,$10,$90,$09,$82,$80,$78,$C4,$F8,$86,$D1,$A1,$77,$E8,$4B,$15,
$78,$0C,$8D,$99,$D9,$E7,$9D,$80,$32,$50,$62,$70,$97,$D7,$AE,$30,$75,$8E,$13,$34,
$8A,$2D,$CA,$0C,$1D,$0B,$05,$F2,$5E,$2A,$8C,$54,$5C,$B8,$DA,$80,$29,$65,$92,$29,
$D4,$75,$38,$4A,$96,$80,$8F,$F4,$47,$18,$2F,$C5,$04,$71,$15,$07,$4C,$9D,$3B,$0F,
$FE,$ED,$7A,$78,$56,$99,$FC,$0A,$63,$55,$39,$6B,$EA,$C3,$AF,$14,$49,$0C,$73,$AB,
$9A,$55,$3D,$95,$5D,$9C,$F4,$68,$D4,$3F,$35,$AA,$A3,$61,$16,$57,$10,$A6,$11,$E9,
$FB,$72,$B0,$03,$6F,$78,$41,$34,$44,$43,$C0,$ED,$12,$72,$9A,$A7,$6B,$92,$02,$0E,
$A7,$B8,$7A,$2A,$D6,$3F,$AE,$7D,$B9,$52,$F4,$15,$A8,$88,$08,$56,$98,$DD,$F3,$18,
$A5,$16,$AF,$49,$82,$02,$A4,$AE,$2A,$DC,$3D,$0F,$49,$9D,$03,$45,$08,$D4,$38,$3A,
$BE,$D3,$3F,$D1,$F1,$39,$36,$AF,$47,$C7,$75,$49,$A7,$27,$56,$8B,$89,$8E,$F6,$97,
$78,$76,$ED,$74,$DF,$B4,$B9,$6B,$BD,$AF,$27,$05,$E3,$5E,$5B,$58,$9B,$03,$15,$B5,
$7A,$F8,$1C,$28,$12,$E1,$57,$E9,$9F,$41,$E6,$49,$D5,$49,$30,$DE,$F9,$D7,$14,$7F,
$CC,$2F,$98,$C0,$DE,$9F,$EA,$88,$CF,$62,$98,$AB,$E6,$EE,$4D,$29,$69,$38,$08,$6F,
$0B,$5B,$E5,$AE,$00,$D4,$99,$22,$85,$7C,$CE,$C3,$59,$54,$66,$9F,$00,$B6,$BD,$8A,
$04,$33,$0C,$DD,$B7,$D8,$F1,$DF,$C6,$B2,$08,$D5,$80,$3F,$BB,$28,$3A,$94,$4E,$83,
$E6,$E2,$3F,$12,$84,$55,$9A,$06,$C6,$37,$26,$0C,$9B,$46,$3D,$CF,$57,$04,$6F,$9D,
$A0,$32,$E4,$C5,$A6,$26,$D2,$3B,$C9,$7D,$F0,$97,$FF,$BA,$37,$AD,$88,$BF,$C2,$5D,
$28,$6F,$BE,$CB,$6F,$A2,$4E,$EF,$8B,$90,$8E,$EC,$EF,$CD,$78,$37,$3D,$6C,$5D,$1D,
$15,$90,$00,$89,$23,$58,$4C,$86,$42,$4D,$BF,$DB,$81,$65,$11,$77,$60,$C3,$57,$F2,
$90,$BF,$D2,$DB,$57,$FB,$74,$ED,$69,$C3,$17,$1E,$D8,$EF,$49,$F2,$06,$65,$98,$09,
$9C,$C5,$6A,$94,$F7,$31,$1E,$10,$8C,$92,$11,$AA,$0C,$B1,$BA,$4D,$84,$7A,$83,$BC,
$85,$0D,$3B,$07,$05,$77,$B5,$FC,$AA,$46,$45,$4E,$66,$E7,$46,$B2,$D7,$EE,$3F,$A2,
$1A,$E3,$42,$20,$1F,$2E,$27,$D9,$C7,$1E,$22,$1C,$E4,$61,$92,$9B,$CD,$43,$CF,$C9,
$BA,$19,$D3,$05,$2F,$4F,$A8,$EE,$85,$1F,$FB,$4D,$AB,$2B,$12,$31,$4D,$44,$FE,$B7,
$7C,$E4,$E8,$D8,$3F,$4D,$A1,$DC,$61,$13,$BB,$88,$D6,$AE,$18,$C0,$F8,$27,$0C,$4C,
$F2,$0B,$F9,$00,$99,$17,$30,$06,$15,$61,$76,$1D,$01,$62,$53,$EE,$72,$29,$24,$8A,
$37,$8B,$A2,$6F,$F9,$33,$07,$A3,$27,$60,$91,$30,$91,$7F,$54,$F3,$86,$49,$DF,$06,
$29,$EC,$5A,$ED,$48,$44,$CF,$50,$F3,$94,$D5,$9D,$45,$A9,$CD,$54,$88,$55,$41,$6E,
$40,$92,$E1,$E6,$7A,$63,$30,$4F,$FB,$A7,$D0,$EF,$57,$49,$A0,$51,$8E,$48,$3F,$D6,
$5A,$5A,$D3,$05,$94,$59,$00,$88,$0B,$07,$C5,$09,$27,$E1,$F4,$3D,$E5,$02,$FB,$34,
$26,$BA,$98,$5B,$B4,$AA,$36,$3B,$16,$95,$31,$2F,$B4,$4E,$3D,$53,$BF,$1A,$EF,$5A,
$09,$D2,$C3,$DC,$84,$B9,$6B,$D8,$06,$EE,$A6,$67,$89,$68,$A5,$C8,$58,$76,$F6,$DB,
$FF,$7A,$E9,$3A,$11,$19,$C0,$40,$D7,$D3,$5C,$3F,$AA,$F1,$AE,$FE,$E3,$13,$43,$6F,
$82,$E3,$6E,$31,$14,$8C,$66,$1B,$A8,$76,$09,$7E,$EC,$A1,$6B,$A6,$E5,$61,$CD,$70,
$CE,$EC,$10,$0F,$74,$81,$CD,$A5,$F0,$17,$57,$A9,$CA,$15,$DB,$52,$C9,$1F,$E2,$E3,
$2E,$97,$A9,$14,$4C,$31,$64,$F4,$1A,$B7,$61,$57,$42,$8A,$DC,$8D,$C9,$B4,$02,$C1,
$AC,$4E,$78,$EF,$C0,$A3,$F7,$08,$0E,$B1,$10,$0C,$94,$DC,$93,$49,$92,$2A,$B0,$B4,
$A9,$82,$AF,$EA,$5C,$EF,$24,$88,$AD,$A3,$85,$75,$65,$05,$82,$04,$76,$A9,$5A,$2E,
$2D,$88,$AC,$23,$08,$FD,$75,$57,$4E,$86,$9D,$39,$4E,$6C,$AD,$26,$2D,$4B,$27,$B1,
$23,$5C,$95,$B2,$F1,$D3,$74,$94,$42,$4B,$21,$E7,$5D,$C6,$1E,$C0,$72,$60,$0A,$6A,
$D9,$A6,$F5,$EA,$D4,$2B,$A9,$D0,$FE,$B7,$2D,$57,$1E,$11,$23,$DE,$CC,$6B,$93,$4E,
$5F,$E6,$5F,$00,$DE,$8D,$9E,$CF,$57,$37,$47,$D1,$EA,$57,$DA,$5E,$B5,$60,$04,$13,
$27,$0C,$27,$3B,$25,$98,$1B,$1D,$2C,$08,$85,$DE,$E1,$D0,$F9,$99,$64,$34,$03,$E9,
$37,$0E,$AE,$D9,$25,$DF,$61,$5E,$3E,$2D,$38,$52,$6A,$3D,$0A,$72,$70,$CD,$86,$35,
$C8,$B2,$3B,$D5,$C2,$5D,$B2,$A0,$D7,$8E,$FD,$BA,$CA,$59,$74,$1B,$6C,$7F,$08,$06,
$19,$64,$EF,$F5,$29,$51,$49,$E4,$67,$45,$44,$70,$91,$4A,$CB,$77,$5F,$D9,$14,$91,
$C2,$30,$42,$7F,$78,$85,$7E,$B3,$D2,$57,$3F,$25,$6D,$79,$56,$95,$C3,$2D,$B2,$F3,
$5C,$F9,$AC,$A9,$8E,$BF,$E2,$A0,$80,$84,$18,$03,$A4,$96,$5A,$67,$EC,$B9,$4A,$8C,
$11,$4F,$0A,$C9,$1B,$83,$07,$9E,$E4,$22,$B8,$FC,$CA,$0B,$CB,$F0,$60,$72,$42,$1A,
$AF,$1E,$FE,$16,$D2,$65,$F6,$A5,$62,$EF,$92,$56,$27,$85,$4C,$31,$C9,$FF,$34,$25,
$27,$5B,$E4,$42,$22,$D4,$FA,$27,$13,$CD,$B6,$A8,$74,$2C,$2D,$00,$72,$B5,$BA,$31,
$7C,$26,$7C,$B0,$CA,$F6,$06,$22,$CC,$11,$BD,$4C,$3C,$38,$A7,$D3,$CE,$87,$64,$5F,
$D4,$DF,$5C,$99,$A3,$0B,$6C,$6F,$76,$45,$67,$0C,$8F,$C3,$55,$60,$00,$15,$B6,$64,
$FD,$B3,$62,$F8,$A0,$AD,$29,$58,$0B,$16,$D2,$B1,$CF,$D9,$15,$49,$BD,$BA,$89,$48,
$C3,$2D,$1B,$62,$79,$63,$51,$42,$7B,$82,$E8,$CA,$C0,$86,$55,$60,$8D,$98,$D3,$85,
$8A,$97,$45,$91,$1F,$26,$84,$84,$43,$41,$3E,$A3,$5B,$BD,$21,$34,$0C,$77,$69,$7F,
$81,$0B,$71,$22,$6E,$74,$9D,$54,$60,$75,$97,$62,$8A,$D8,$27,$06,$99,$4D,$46,$03,
$81,$3C,$0D,$F4,$8B,$49,$43,$8D,$50,$53,$67,$AC,$58,$AE,$82,$89,$24,$DA,$99,$5D,
$1F,$56,$16,$13,$30,$BD,$99,$8B,$16,$81,$F4,$0D,$06,$F2,$C5,$09,$07,$2C,$66,$06,
$BE,$E9,$73,$48,$26,$16,$4D,$6A,$C6,$66,$09,$2E,$D7,$85,$1D,$EC,$6B,$DE,$28,$0C,
$7B,$96,$DB,$36,$D2,$12,$B0,$B2,$21,$ED,$3E,$CC,$7B,$A1,$EF,$31,$5D,$81,$09,$ED,
$6F,$6C,$E6,$36,$E3,$97,$FD,$C0,$21,$B8,$08,$BC,$1D,$29,$4B,$03,$4D,$1B,$0A,$96,
$74,$17,$63,$89,$58,$9F,$B0,$0A,$CC,$43,$9D,$82,$DF,$F8,$41,$5F,$CF,$AD,$42,$70,
$11,$1E,$B0,$AA,$10,$BE,$CB,$49,$90,$F2,$82,$E5,$B5,$95,$FE,$A9,$BB,$81,$A2,$0B,
$7A,$21,$26,$62,$9E,$F9,$CA,$F9,$76,$A2,$9A,$A2,$48,$8C,$08,$7A,$6A,$6F,$12,$16,
$72,$A2,$98,$B5,$86,$A0,$24,$AF,$68,$6D,$95,$D9,$B1,$2F,$12,$97,$75,$D3,$B0,$77,
$23,$AC,$FF,$8E,$20,$9C,$03,$BA,$2B,$E1,$67,$6C,$0B,$8A,$03,$56,$11,$86,$7F,$51,
$B4,$0A,$9A,$F1,$84,$6A,$67,$D1,$04,$28,$D9,$41,$82,$45,$B0,$43,$F2,$D7,$E1,$1C,
$FC,$82,$07,$1F,$40,$AC,$16,$31,$08,$86,$B3,$06,$29,$B9,$D7,$DA,$5B,$68,$09,$93,
$17,$EA,$84,$C5,$30,$C1,$9A,$29,$D8,$EF,$98,$31,$DD,$A3,$63,$91,$99,$78,$16,$24,
$E3,$90,$57,$A7,$FA,$41,$02,$33,$A3,$0F,$AE,$36,$5C,$6C,$C8,$64,$61,$77,$FD,$56,
$3B,$66,$90,$C1,$91,$75,$B6,$9A,$11,$61,$98,$2B,$D8,$20,$06,$8E,$7D,$02,$48,$F2,
$C3,$79,$52,$89,$07,$C2,$7E,$EF,$C1,$EE,$D8,$42,$72,$93,$6C,$C7,$77,$CF,$2B,$CC,
$55,$27,$AC,$76,$D0,$D7,$AF,$90,$3C,$CE,$D9,$7D,$45,$9E,$1E,$9C,$81,$B6,$C6,$AB,
$C7,$D5,$A0,$D1,$0F,$B3,$6E,$B5,$F1,$B0,$52,$64,$17,$C1,$5B,$93,$40,$C1,$02,$56,
$70,$74,$54,$68,$D4,$47,$26,$26,$30,$91,$F1,$E2,$6B,$D0,$EF,$34,$83,$D1,$CD,$4F,
$0E,$D8,$B6,$5D,$B1,$04,$E5,$53,$24,$36,$15,$64,$F8,$9E,$49,$53,$34,$45,$0E,$B8,
$00,$B2,$16,$13,$6C,$BB,$78,$63,$AD,$E2,$15,$EE,$71,$AC,$E8,$D1,$57,$0C,$F4,$8D,
$D2,$26,$B1,$8B,$31,$22,$38,$B1,$B9,$58,$05,$C9,$EA,$71,$93,$B4,$53,$50,$F6,$A6,
$6F,$4C,$7C,$43,$BA,$E0,$EC,$81,$8D,$63,$B9,$AC,$E3,$25,$A0,$73,$88,$9B,$1C,$13,
$92,$E6,$67,$66,$DB,$15,$2C,$88,$31,$2F,$DD,$60,$60,$3F,$7C,$40,$DF,$B8,$52,$51,
$21,$91,$68,$00,$4A,$95,$63,$22,$32,$24,$5A,$A6,$7D,$D0,$46,$96,$85,$BA,$B1,$BC,
$13,$02,$05,$74,$40,$CD,$2C,$EB,$F4,$38,$8F,$EB,$92,$0B,$FB,$A5,$79,$BB,$28,$49,
$57,$3D,$94,$BF,$09,$1F,$2F,$EB,$D9,$65,$9D,$C3,$40,$25,$D4,$CC,$FD,$CE,$E2,$90,
$E0,$56,$D2,$7B,$77,$22,$C5,$08,$7F,$39,$67,$79,$BD,$13,$54,$7C,$80,$0A,$77,$4D,
$83,$2A,$C9,$40,$82,$59,$7F,$7B,$86,$4C,$D0,$D7,$FD,$A1,$97,$79,$D6,$F2,$5C,$A3,
$76,$91,$8D,$A4,$41,$82,$91,$9F,$BA,$AC,$56,$B8,$A2,$3C,$3F,$9F,$3F,$7C,$98,$4C,
$1F,$A5,$83,$42,$CE,$53,$DA,$57,$E4,$B4,$FA,$A4,$00,$A6,$52,$B2,$6F,$A7,$20,$2C,
$F3,$97,$13,$B1,$17,$DA,$AE,$F4,$3B,$16,$D7,$90,$24,$89,$99,$AB,$81,$33,$89,$17,
$03,$A6,$67,$8F,$C3,$1B,$FF,$3F,$49,$29,$1D,$58,$23,$A4,$7C,$92,$C0,$4D,$58,$7A,
$67,$EE,$D7,$86,$F5,$EE,$69,$06,$AE,$22,$37,$09,$1B,$8B,$24,$18,$A2,$EF,$52,$8C,
$70,$8F,$33,$A2,$4A,$13,$59,$4D,$DC,$B8,$93,$CC,$F0,$2C,$C5,$3C,$F9,$E0,$B3,$CC,
$A3,$08,$8D,$38,$33,$A2,$56,$7B,$A5,$45,$07,$9B,$CC,$DA,$2C,$06,$B7,$C5,$2A,$DC,
$6C,$32,$F7,$BF,$62,$48,$DA,$CC,$C8,$3F,$C6,$FB,$62,$BC,$05,$37,$C0,$58,$FD,$B6,
$38,$75,$2A,$FB,$58,$21,$EA,$90,$75,$9D,$2B,$0D,$F9,$CC,$E8,$9F,$76,$F5,$30,$36,
$22,$B0,$B4,$90,$D6,$FC,$68,$25,$CA,$C7,$7B,$7F,$CD,$89,$B2,$82,$83,$BE,$84,$C8,
$D2,$A2,$5C,$B4,$1D,$5A,$46,$0E,$4E,$65,$6C,$5D,$06,$E6,$03,$9D,$53,$8D,$CA,$C4,
$BA,$34,$B5,$BE,$BF,$D9,$54,$57,$4D,$80,$C0,$24,$A9,$78,$92,$A7,$96,$50,$4E,$AA,
$A8,$AD,$81,$84,$F0,$0A,$EB,$ED,$65,$C1,$88,$D9,$60,$44,$31,$67,$81,$CC,$C4,$C2,
$A0,$60,$18,$E0,$97,$93,$64,$C4,$F1,$EA,$82,$3D,$62,$03,$E3,$20,$49,$23,$43,$00,
$11,$6F,$9F,$87,$8D,$1A,$8B,$BC,$1B,$E7,$B0,$BD,$AE,$11,$39,$1E,$5A,$51,$C9,$DA,
$6B,$E7,$1D,$E7,$82,$B1,$3C,$58,$39,$08,$FA,$AD,$87,$8D,$AD,$C4,$AC,$E8,$57,$4B,
$CB,$F4,$ED,$3D,$DE,$BE,$32,$0C,$69,$06,$4B,$A0,$98,$52,$82,$75,$60,$A0,$63,$98,
$A0,$65,$01,$54,$6D,$64,$FD,$48,$1B,$BB,$F7,$64,$47,$CD,$C7,$07,$39,$C4,$60,$8D,
$7B,$49,$8E,$FC,$60,$BA,$F7,$EE,$00,$84,$52,$85,$24,$55,$65,$9A,$6B,$11,$BA,$21,
$CB,$15,$54,$76,$A8,$A2,$42,$6D,$36,$2D,$45,$95,$A2,$92,$34,$27,$EA,$0E,$26,$89,
$47,$44,$61,$09,$48,$2C,$4F,$16,$94,$DA,$87,$99,$58,$96,$AA,$02,$EB,$56,$2B,$27,
$21,$49,$DA,$69,$66,$67,$79,$C4,$81,$8D,$4D,$FD,$21,$61,$86,$F0,$A0,$C8,$CC,$B1,
$64,$10,$39,$29,$8A,$C5,$4A,$EA,$C7,$F7,$B0,$28,$9C,$83,$05,$8A,$58,$77,$B0,$B8,
$41,$14,$FC,$54,$AB,$92,$ED,$68,$05,$44,$83,$CA,$C0,$1D,$F7,$66,$5A,$B0,$2C,$9C,
$83,$F8,$46,$9D,$91,$76,$D2,$C9,$EB,$DD,$67,$A3,$D0,$5A,$C7,$40,$06,$09,$80,$94,
$92,$16,$B2,$32,$3C,$42,$07,$55,$17,$06,$49,$40,$0D,$D9,$02,$12,$17,$90,$95,$74,
$91,$15,$1A,$5C,$0C,$A4,$C2,$5A,$6A,$A1,$56,$D2,$59,$60,$61,$5E,$72,$B0,$D0,$7B,
$7A,$76,$75,$B7,$D2,$8A,$E4,$C3,$66,$CC,$B5,$1D,$5A,$7B,$FF,$4C,$4F,$70,$F5,$63,
$FF,$BC,$DF,$1A,$8F,$49,$A2,$A3,$21,$98,$0E,$8E,$AE,$46,$5C,$22,$B4,$84,$90,$37,
$A7,$DE,$38,$89,$C7,$C8,$6A,$41,$2E,$54,$C1,$67,$9C,$FC,$A7,$AC,$A2,$E2,$B5,$F0,
$EC,$3C,$2E,$EB,$ED,$D4,$D2,$76,$08,$57,$8C,$F2,$CE,$34,$62,$86,$02,$8A,$0C,$E0,
$DD,$B1,$D6,$20,$77,$BC,$12,$23,$67,$AA,$D4,$EF,$57,$B2,$99,$3A,$15,$20,$68,$D3,
$19,$C6,$BB,$71,$AA,$D5,$23,$24,$04,$24,$94,$15,$4B,$0E,$1C,$54,$86,$5A,$24,$3A,
$24,$7F,$41,$3A,$95,$B0,$38,$23,$95,$1E,$2C,$99,$27,$EC,$09,$09,$81,$3A,$5A,$50,
$50,$F0,$1C,$5C,$BF,$5C,$D2,$C1,$8F,$44,$B2,$C8,$B1,$08,$E2,$B3,$53,$25,$0F,$F0,
$C2,$42,$12,$43,$9A,$95,$8E,$72,$BC,$22,$2F,$54,$C9,$83,$2C,$B0,$A6,$B9,$98,$90,
$EC,$E5,$9D,$8A,$74,$83,$49,$7E,$73,$D2,$D1,$66,$F4,$38,$D2,$9B,$67,$5B,$E0,$0E,
$71,$5A,$EE,$62,$94,$53,$08,$E8,$A2,$2A,$1E,$1F,$C1,$71,$37,$8A,$0A,$5B,$BA,$CD,
$EA,$03,$AC,$CA,$30,$01,$1F,$1D,$DB,$15,$18,$CB,$B4,$42,$30,$B5,$D2,$1D,$70,$1F,
$00,$79,$33,$E8,$15,$6B,$60,$55,$19,$AA,$56,$63,$83,$C4,$F0,$15,$49,$2A,$78,$51,
$19,$59,$46,$6A,$24,$A1,$02,$47,$9B,$59,$14,$49,$AB,$8B,$AA,$A3,$5C,$C9,$11,$80,
$41,$9F,$7E,$9A,$B3,$24,$16,$87,$5F,$B3,$41,$8B,$FA,$B1,$B5,$2E,$6F,$E5,$12,$AC,
$65,$E8,$5F,$1C,$F3,$9F,$B4,$52,$9F,$75,$39,$88,$88,$D2,$60,$E6,$93,$AE,$86,$B4,
$A8,$66,$3D,$B0,$2D,$98,$DB,$5A,$55,$30,$90,$C0,$7D,$B4,$32,$EC,$F5,$B6,$64,$A1,
$69,$61,$32,$E8,$A9,$D8,$B2,$AE,$5C,$F3,$9F,$1C,$35,$60,$CF,$4E,$7F,$C3,$5E,$08,
$2B,$BB,$E3,$05,$C2,$C8,$95,$5F,$3D,$8C,$82,$74,$24,$40,$F2,$51,$88,$1B,$52,$34,
$83,$E5,$0B,$CB,$32,$FF,$C4,$6C,$75,$2D,$40,$BF,$00,$AD,$4D,$AE,$6D,$87,$2A,$F2,
$F4,$24,$DD,$04,$43,$A8,$03,$1B,$39,$5A,$C3,$44,$0A,$3C,$7C,$21,$74,$64,$B7,$BF,
$24,$02,$F6,$97,$FB,$12,$09,$C5,$8F,$60,$1E,$2A,$9C,$27,$A7,$7B,$5F,$2D,$A9,$5D,
$FB,$F8,$AD,$29,$16,$A5,$6A,$03,$F0,$90,$05,$71,$90,$08,$38,$CC,$6F,$8B,$2C,$51,
$FD,$7D,$6E,$D2,$12,$D3,$9B,$13,$45,$E0,$AF,$D3,$4C,$0B,$85,$B1,$DC,$7F,$EA,$D2,
$AB,$A7,$80,$FE,$BE,$2D,$A0,$36,$E3,$96,$7C,$57,$AA,$B6,$C8,$BE,$F2,$F2,$F7,$55,
$5C,$56,$B6,$F5,$A0,$7B,$5F,$25,$52,$96,$57,$3B,$B5,$03,$6F,$F9,$9F,$B8,$22,$03,
$A7,$E0,$E8,$9C,$87,$3D,$F8,$B8,$BC,$12,$AE,$C1,$FB,$93,$4E,$F1,$BE,$5E,$5F,$49,
$22,$29,$01,$40,$59,$29,$2A,$23,$48,$F9,$9E,$92,$39,$98,$40,$46,$2D,$C5,$5D,$4A,
$80,$85,$2E,$0B,$14,$3D,$77,$C2,$89,$26,$EE,$37,$88,$BF,$E8,$4C,$21,$49,$1C,$94,
$CA,$BE,$ED,$46,$34,$71,$3E,$A9,$84,$86,$5F,$58,$7C,$8D,$AB,$54,$E8,$49,$6A,$C1,
$2C,$FE,$44,$E2,$6E,$2C,$9A,$11,$C9,$6E,$83,$FC,$1D,$DF,$89,$98,$80,$4F,$37,$13,
$89,$11,$99,$BE,$33,$9D,$5B,$B7,$EB,$83,$87,$89,$82,$FE,$E1,$F6,$0B,$A4,$0C,$3E,
$C8,$6A,$CD,$9D,$F2,$2D,$54,$68,$E4,$47,$5D,$28,$D1,$A5,$97,$A0,$03,$AE,$61,$65,
$5D,$E5,$7D,$C3,$9E,$E3,$3C,$C7,$AA,$A4,$16,$B5,$4B,$75,$07,$33,$25,$CB,$48,$7F,
$15,$A0,$73,$D6,$C5,$14,$A6,$96,$7F,$61,$5C,$11,$AD,$22,$0D,$F8,$60,$72,$A9,$A3,
$B2,$16,$0C,$29,$82,$7E,$ED,$87,$E8,$55,$61,$3B,$71,$97,$5C,$31,$79,$4C,$6C,$58,
$55,$6F,$06,$47,$15,$B8,$99,$D6,$8D,$9E,$AA,$5C,$83,$19,$1C,$14,$77,$65,$DD,$DB,
$7B,$29,$46,$05,$78,$A2,$F4,$17,$68,$41,$DC,$B8,$59,$21,$38,$5B,$D4,$13,$F2,$A0,
$BE,$92,$F1,$0D,$94,$90,$FF,$A5,$6F,$C6,$18,$B1,$6E,$51,$21,$5D,$8F,$B5,$10,$0F,
$74,$55,$C6,$EE,$26,$7A,$EA,$42,$2F,$70,$F4,$8E,$B8,$C6,$FF,$DD,$AB,$B7,$34,$B5,
$03,$F4,$66,$BA,$00,$CA,$7D,$ED,$E9,$5C,$15,$62,$FD,$B4,$E8,$6B,$0D,$70,$BD,$0B,
$CC,$D0,$DA,$9A,$50,$9B,$FF,$59,$82,$5C,$4B,$D4,$AF,$72,$97,$C8,$53,$59,$5A,$CB,
$DD,$57,$4E,$B6,$CB,$2E,$6C,$C2,$10,$15,$AA,$C6,$B0,$87,$4B,$25,$FD,$A8,$65,$67,
$0D,$26,$BC,$A9,$87,$35,$D7,$87,$4D,$A3,$C6,$62,$C4,$E4,$A2,$A8,$3E,$6C,$BF,$C8,
$D8,$BF,$DB,$37,$52,$F7,$58,$F7,$D8,$81,$5F,$0D,$7E,$0C,$6C,$99,$9C,$D4,$11,$7C,
$4E,$37,$48,$A3,$5E,$B8,$A2,$12,$DC,$9D,$C9,$7D,$2B,$5B,$CD,$55,$80,$31,$5B,$5D,
$9B,$0D,$82,$1D,$A6,$E6,$F0,$86,$78,$14,$35,$4F,$10,$03,$AB,$2D,$DF,$2A,$3D,$BA,
$D8,$0B,$4A,$77,$A5,$F8,$95,$A2,$07,$C4,$D4,$68,$2A,$E8,$6B,$36,$E6,$96,$6A,$51,
$BF,$DD,$E3,$AA,$D2,$25,$E5,$69,$1D,$9B,$96,$97,$6E,$1E,$0F,$75,$E3,$71,$48,$D6,
$4B,$1E,$93,$90,$F9,$4D,$C6,$62,$19,$E0,$F6,$CC,$ED,$13,$0E,$2A,$F1,$63,$48,$3B,
$BB,$29,$3A,$DC,$A2,$6F,$D2,$90,$72,$58,$8A,$53,$EF,$DC,$C0,$AB,$16,$18,$8E,$ED,
$96,$C8,$04,$63,$B2,$B8,$8C,$60,$86,$A2,$C5,$62,$56,$18,$56,$63,$94,$81,$49,$E6,
$79,$68,$E7,$53,$53,$D7,$77,$BC,$87,$89,$84,$98,$09,$D9,$73,$FB,$0B,$29,$D7,$77,
$F7,$F4,$23,$D3,$2D,$CE,$16,$AB,$E0,$AD,$DA,$A7,$9D,$0E,$2E,$C4,$7F,$7E,$4C,$D6,
$A3,$07,$00,$DC,$CE,$19,$B3,$05,$62,$5E,$FE,$B0,$10,$81,$B1,$79,$8A,$58,$0F,$20,
$5A,$D6,$05,$69,$36,$B7,$E5,$7F,$91,$D9,$44,$C6,$62,$C9,$C0,$14,$64,$10,$79,$4F,
$37,$4D,$C6,$52,$0E,$AE,$82,$BF,$C3,$41,$FA,$0B,$7D,$1A,$D5,$33,$1D,$24,$0F,$99,
$C9,$57,$A9,$FF,$15,$47,$88,$36,$FB,$C0,$DF,$FE,$09,$52,$EB,$68,$3D,$4D,$B7,$FD,
$3D,$41,$2A,$74,$98,$BF,$85,$58,$FD,$25,$5B,$8D,$4A,$1C,$B0,$27,$F4,$BD,$A8,$EC,
$8A,$C6,$B2,$90,$AE,$51,$D1,$74,$42,$A7,$6A,$A0,$CF,$88,$31,$BE,$72,$63,$CD,$5D,
$43,$D3,$93,$57,$17,$0F,$A5,$66,$8E,$CD,$1E,$49,$0B,$1C,$73,$B4,$5D,$69,$CE,$17,
$55,$36,$9E,$5D,$F4,$6D,$46,$35,$F6,$08,$0D,$A8,$44,$07,$4E,$68,$06,$66,$DB,$1E,
$CF,$75,$C2,$B4,$EF,$54,$7E,$5F,$B6,$BC,$BA,$A0,$C8,$14,$2F,$FA,$02,$75,$94,$68,
$68,$27,$48,$2A,$B5,$1B,$E0,$02,$7D,$B5,$A0,$B4,$98,$5C,$5C,$0D,$F5,$10,$63,$7F,
$AC,$F6,$88,$2B,$63,$BB,$84,$E3,$8B,$7F,$CF,$1A,$9D,$6C,$BF,$CA,$C1,$A0,$2E,$AB,
$91,$85,$82,$84,$FE,$55,$2D,$08,$FB,$1D,$84,$61,$D7,$E9,$A5,$C6,$1A,$5E,$C5,$EA,
$45,$45,$F1,$4E,$2C,$E9,$86,$E5,$B0,$6B,$FB,$82,$54,$1C,$B2,$23,$2D,$30,$50,$2B,
$9B,$4F,$DA,$43,$69,$26,$05,$68,$57,$A1,$22,$A0,$6D,$AD,$5A,$15,$09,$C3,$5A,$B8,
$34,$9B,$56,$77,$64,$CD,$E4,$57,$CA,$08,$8A,$C2,$A6,$45,$29,$AB,$BF,$57,$B0,$2B,
$35,$CA,$92,$3D,$52,$42,$C8,$92,$FD,$8F,$B1,$DE,$9D,$61,$F3,$10,$20,$47,$44,$A5,
$19,$13,$CB,$6A,$F7,$B8,$C0,$09,$5F,$9A,$0C,$9C,$8C,$5D,$B4,$DA,$51,$DA,$FE,$8A,
$88,$6B,$29,$1F,$EB,$42,$53,$72,$83,$B3,$95,$D2,$CB,$94,$56,$07,$52,$A4,$ED,$E6,
$68,$5B,$55,$75,$84,$B1,$A8,$1C,$38,$2B,$A5,$0C,$3F,$6E,$E5,$77,$0F,$9E,$60,$79,
$F9,$85,$72,$9E,$EA,$DD,$D4,$F7,$72,$98,$F6,$9B,$15,$66,$A7,$F3,$04,$0A,$15,$32,
$05,$9C,$25,$28,$5C,$27,$9C,$C9,$C4,$5B,$70,$AA,$75,$10,$36,$BD,$A6,$28,$88,$82,
$34,$4C,$28,$48,$73,$7E,$D4,$84,$6A,$EC,$9E,$1D,$75,$65,$41,$69,$E5,$E7,$42,$77,
$AB,$24,$A0,$B0,$5A,$34,$60,$E8,$D8,$BC,$7F,$F1,$AE,$FD,$9A,$5D,$A3,$94,$60,$00,
$AC,$0D,$B7,$38,$D3,$85,$3B,$44,$A4,$48,$55,$D6,$20,$45,$A2,$41,$58,$3A,$16,$CF,
$EB,$FA,$2E,$6C,$5B,$69,$EF,$94,$7B,$DE,$54,$66,$FB,$4B,$D8,$11,$F5,$95,$88,$7F,
$24,$AA,$0A,$9F,$02,$E4,$54,$36,$40,$49,$01,$0E,$75,$3F,$4F,$03,$0B,$89,$34,$E3,
$05,$7E,$22,$17,$D5,$7E,$15,$05,$EE,$A3,$1C,$FC,$6B,$70,$5B,$7E,$01,$40,$A6,$A7,
$99,$07,$88,$98,$04,$BF,$48,$36,$7B,$0F,$76,$E2,$BE,$72,$71,$55,$5C,$E2,$AB,$6A,
$E3,$3C,$B5,$6F,$8D,$35,$E4,$B2,$AB,$6A,$E4,$E3,$2B,$A0,$C5,$8B,$EB,$24,$E7,$B4,
$B6,$FE,$FA,$E6,$22,$F2,$E3,$EB,$DC,$25,$87,$21,$99,$E4,$AB,$C4,$C3,$79,$58,$C8,
$CE,$F5,$84,$FD,$81,$BC,$25,$C4,$3F,$5F,$8B,$A1,$FA,$0A,$33,$75,$A5,$5F,$37,$91,
$4A,$64,$75,$C8,$E4,$88,$C4,$73,$D2,$5A,$FD,$AA,$16,$AA,$03,$FF,$B6,$BC,$FA,$8B,
$D1,$20,$96,$AC,$2E,$22,$70,$09,$CB,$63,$1D,$ED,$11,$75,$A7,$12,$9D,$37,$E7,$8B,
$0C,$70,$E8,$FA,$82,$08,$32,$87,$07,$A9,$5E,$8B,$6A,$9A,$22,$5B,$68,$41,$C2,$CC,
$48,$E7,$BA,$30,$39,$21,$A0,$48,$4E,$3A,$CD,$37,$82,$1C,$E2,$21,$1B,$34,$16,$B8,
$36,$BE,$22,$E3,$CC,$FE,$FE,$66,$AA,$F5,$82,$AA,$55,$70,$35,$D4,$B7,$B6,$1D,$4F,
$CF,$AF,$03,$F6,$EC,$5F,$8A,$32,$E1,$DD,$2A,$92,$1D,$DE,$10,$11,$46,$7D,$01,$80,
$D6,$E2,$45,$EA,$5F,$61,$7B,$E1,$FB,$9F,$AF,$CC,$A5,$5B,$F4,$F6,$61,$48,$05,$CF,
$1F,$E8,$7A,$78,$D4,$A9,$CB,$F7,$66,$F4,$3D,$F0,$A2,$03,$DF,$19,$28,$35,$70,$BC,
$3A,$D0,$E1,$16,$9E,$03,$6E,$CC,$F1,$C2,$88,$E1,$06,$F4,$23,$A6,$5F,$29,$ED,$75,
$53,$43,$F5,$A9,$4D,$10,$4E,$10,$96,$73,$1B,$F9,$3C,$6D,$75,$C5,$A3,$D8,$3E,$AF,
$0A,$B8,$2F,$48,$0D,$27,$5B,$10,$AF,$50,$BD,$FA,$B1,$5A,$10,$C0,$70,$5C,$9C,$29,
$64,$AF,$85,$2D,$36,$88,$30,$45,$11,$25,$2C,$72,$F8,$15,$78,$54,$CC,$18,$36,$10,
$88,$F0,$46,$39,$12,$31,$8A,$D3,$F5,$57,$AD,$E1,$C7,$FF,$A4,$F2,$90,$DF,$CE,$88,
$0D,$D7,$02,$28,$82,$F2,$B5,$1F,$19,$55,$0A,$7C,$17,$43,$CC,$36,$BA,$49,$DC,$A9,
$EB,$74,$4C,$85,$D1,$31,$68,$17,$F8,$B2,$0E,$C7,$BB,$08,$D0,$D1,$4A,$F2,$3A,$A5,
$73,$6C,$FF,$99,$65,$57,$F0,$91,$6C,$58,$7B,$D6,$E9,$D8,$48,$E0,$CF,$FE,$D3,$BB,
$81,$64,$41,$14,$0B,$66,$6E,$71,$1F,$41,$16,$46,$80,$65,$E2,$51,$FC,$AF,$7A,$98,
$3E,$1C,$83,$E9,$DB,$3F,$13,$65,$5E,$26,$A4,$C7,$F3,$B4,$22,$1C,$46,$60,$2D,$59,
$4A,$3C,$51,$2C,$8F,$DD,$01,$9A,$E3,$8D,$73,$D7,$82,$04,$01,$13,$BF,$64,$1C,$3C,
$C3,$A6,$A5,$C9,$59,$89,$85,$BF,$20,$6F,$B9,$A5,$C1,$59,$DD,$E0,$61,$7D,$99,$58,
$43,$39,$6C,$1F,$2E,$81,$E9,$9A,$AD,$A2,$65,$02,$ED,$2E,$FB,$F8,$B1,$57,$FF,$F9,
$55,$42,$C2,$3E,$A1,$35,$6D,$EB,$CD,$F2,$BE,$31,$2E,$0B,$E5,$99,$C1,$FC,$80,$FD,
$67,$03,$C3,$5A,$A4,$DC,$EA,$4A,$CB,$D4,$F6,$CC,$E9,$7F,$A1,$73,$B9,$9C,$0E,$D5,
$BA,$C6,$A4,$90,$63,$2B,$A1,$32,$B1,$87,$6D,$C4,$C8,$91,$6C,$6A,$7F,$D4,$AA,$FF,
$7B,$B8,$0E,$58,$B4,$D6,$05,$58,$AF,$9E,$98,$66,$29,$ED,$4D,$74,$4D,$93,$82,$8C,
$5F,$13,$37,$EC,$5F,$8E,$D7,$EC,$6E,$5C,$44,$52,$DD,$38,$E1,$FA,$87,$98,$E2,$54,
$6E,$EB,$A1,$C1,$A0,$7F,$46,$B1,$B3,$BD,$15,$43,$92,$D3,$C4,$4C,$7F,$51,$65,$EC,
$AF,$CA,$0D,$EB,$69,$B5,$FC,$01,$78,$A3,$33,$B4,$32,$A5,$33,$07,$FE,$06,$90,$33,
$FF,$42,$4E,$C1,$E8,$9F,$41,$B3,$74,$0D,$C6,$B0,$FB,$23,$98,$E9,$25,$33,$63,$40,
$D9,$E1,$41,$A7,$89,$A0,$B3,$9A,$82,$DD,$3F,$85,$8E,$00,$B2,$A3,$EE,$C4,$35,$27,
$C8,$6B,$5E,$C7,$34,$FE,$84,$A9,$F4,$3F,$9C,$AE,$56,$96,$3A,$E7,$90,$84,$0D,$4D,
$3C,$5E,$3F,$21,$71,$43,$1C,$C4,$09,$C5,$F4,$DC,$D0,$64,$05,$C0,$CA,$EB,$BF,$B2,
$41,$AA,$C4,$85,$96,$DD,$6E,$89,$72,$14,$F9,$50,$3E,$79,$11,$FF,$A2,$48,$BB,$59,
$A3,$A0,$92,$58,$CE,$7F,$AA,$30,$57,$DC,$55,$18,$68,$30,$61,$07,$41,$14,$24,$51,
$38,$31,$3E,$61,$F9,$25,$B1,$5F,$14,$81,$01,$AE,$23,$1A,$72,$25,$5D,$34,$14,$3C,
$46,$38,$67,$43,$6E,$0C,$82,$E0,$14,$7E,$92,$2F,$E3,$96,$FF,$FB,$85,$B5,$19,$EC,
$F9,$98,$AC,$03,$C1,$D7,$4D,$E9,$00,$B0,$6D,$5E,$2A,$CD,$10,$06,$18,$69,$D3,$22,
$2F,$D0,$4E,$0F,$09,$06,$A8,$B8,$AA,$BF,$9B,$C4,$41,$3E,$20,$A7,$22,$E7,$C5,$72,
$B0,$41,$7F,$C4,$D1,$60,$05,$3D,$5B,$69,$89,$80,$42,$01,$6D,$D6,$17,$7D,$09,$69,
$3F,$3E,$43,$8A,$4E,$FE,$1B,$75,$A5,$C0,$77,$FE,$C0,$EB,$24,$65,$07,$09,$F8,$D7,
$08,$8E,$0A,$25,$E7,$01,$25,$41,$FB,$04,$48,$C9,$B0,$4D,$3D,$6E,$B9,$69,$57,$5B,
$27,$E1,$5D,$24,$F2,$BF,$DD,$3B,$5F,$A5,$15,$F3,$38,$A1,$8D,$AA,$DA,$45,$40,$CD,
$46,$A7,$1F,$D1,$FA,$37,$8F,$4A,$90,$FB,$CE,$63,$BA,$4F,$F4,$A1,$EA,$2F,$0A,$93,
$EF,$0A,$DF,$FA,$01,$45,$D5,$21,$24,$72,$F6,$C5,$BA,$A4,$F7,$FF,$3C,$75,$EC,$38,
$03,$83,$CE,$54,$90,$6E,$C0,$60,$EB,$23,$1E,$5D,$01,$5B,$47,$5F,$3F,$05,$3E,$D8,
$02,$56,$3D,$59,$99,$DF,$03,$5D,$14,$F5,$B6,$7A,$64,$1E,$DA,$41,$7D,$C2,$A3,$3C,
$77,$F5,$B9,$E5,$57,$91,$F8,$B8,$E1,$D0,$BA,$07,$9C,$B6,$E5,$91,$D7,$AE,$62,$58,
$12,$D3,$E7,$72,$B5,$91,$EA,$AD,$24,$82,$92,$12,$49,$26,$98,$E2,$87,$8A,$9E,$F3,
$CF,$93,$34,$30,$69,$8A,$98,$77,$65,$A6,$0C,$CC,$29,$78,$52,$60,$18,$9F,$33,$93,
$4F,$10,$43,$24,$45,$40,$25,$98,$F1,$58,$9A,$11,$C3,$3E,$C0,$1F,$B6,$E1,$29,$06,
$CC,$F0,$A9,$81,$ED,$57,$E2,$0B,$84,$E7,$77,$E9,$D5,$28,$77,$53,$20,$A3,$32,$12,
$07,$23,$18,$00,$BA,$D5,$48,$5C,$1D,$82,$62,$F1,$07,$45,$C2,$CD,$2D,$1A,$03,$F6,
$57,$A4,$F2,$F6,$26,$B5,$7B,$30,$98,$B0,$6B,$DA,$F8,$AD,$02,$83,$63,$11,$A0,$80,
$A8,$CE,$A7,$C3,$BD,$D2,$8C,$4E,$54,$15,$61,$8C,$FF,$A7,$E1,$48,$72,$84,$62,$12,
$5D,$53,$36,$38,$90,$4C,$A6,$AA,$D2,$D7,$9B,$A9,$A2,$9C,$A2,$AE,$41,$05,$9C,$51,
$10,$9D,$EB,$9D,$48,$A2,$C8,$13,$AB,$93,$D2,$B9,$FF,$C7,$D2,$62,$E8,$F9,$0A,$F7,
$A8,$D1,$76,$24,$FD,$19,$92,$CF,$F6,$C2,$68,$3C,$1B,$5E,$A3,$E6,$D0,$81,$69,$04,
$08,$48,$18,$04,$12,$59,$04,$57,$34,$43,$42,$16,$F1,$8B,$C8,$48,$57,$A3,$7E,$37,
$62,$18,$22,$19,$B8,$B9,$12,$A4,$A1,$EA,$12,$12,$6A,$C1,$07,$DF,$3C,$74,$12,$12,
$12,$D0,$29,$C5,$22,$19,$4C,$7C,$88,$D9,$72,$45,$08,$12,$8A,$80,$42,$DA,$28,$C9,
$24,$14,$4D,$84,$EB,$DD,$65,$F5,$EA,$20,$A1,$32,$0C,$E4,$F9,$84,$C1,$84,$22,$7E,
$8E,$F8,$80,$12,$8A,$80,$84,$EF,$10,$96,$D6,$8A,$80,$84,$08,$A4,$DD,$3B,$BE,$C4,
$84,$08,$12,$D4,$4B,$23,$20,$80,$84,$C4,$48,$32,$D3,$E4,$5A,$1D,$43,$2D,$10,$DC,
$01,$2A,$67,$88,$17,$0B,$DA,$BE,$C0,$70,$9F,$EE,$54,$D5,$71,$B7,$39,$AE,$58,$41,
$BF,$F2,$70,$94,$A4,$4C,$4B,$40,$CC,$6A,$29,$06,$39,$2F,$4B,$09,$D0,$23,$D5,$35,
$E2,$50,$3A,$99,$5D,$30,$E2,$B0,$8D,$EC,$F4,$15,$F5,$79,$64,$01,$0C,$4C,$2C,$5B,
$FB,$F4,$54,$8A,$A2,$F7,$46,$F1,$55,$60,$9A,$58,$BA,$FA,$E7,$76,$5A,$92,$24,$F0,
$F5,$FE,$D8,$0A,$E4,$AF,$FB,$24,$55,$60,$88,$CE,$5F,$98,$E9,$C5,$F2,$3E,$26,$49,
$92,$D4,$F7,$DF,$FC,$26,$B5,$62,$92,$A5,$FC,$A2,$F2,$2E,$49,$52,$05,$AC,$F8,$8E,
$91,$B2,$AD,$D6,$1A,$E4,$84,$EA,$82,$BB,$10,$E7,$8C,$27,$9E,$B9,$F4,$BF,$1A,$EB,
$B0,$30,$5A,$18,$91,$A9,$99,$EE,$CB,$B7,$31,$92,$E4,$F3,$F1,$B4,$C5,$7D,$7A,$02,
$E6,$8A,$08,$54,$6A,$60,$10,$4E,$5F,$EE,$BC,$1F,$4F,$FC,$26,$32,$57,$DB,$FF,$8E,
$FE,$C2,$C3,$F7,$31,$07,$54,$BB,$CF,$0D,$7C,$48,$3A,$65,$8A,$16,$2C,$5F,$35,$CE,
$D6,$29,$10,$DF,$11,$AE,$21,$74,$FE,$DA,$30,$F1,$C6,$24,$DA,$17,$10,$B8,$2A,$29,
$E1,$FB,$C1,$25,$DB,$B5,$50,$20,$CB,$E7,$52,$02,$14,$37,$A9,$93,$B5,$82,$EC,$42,
$43,$25,$1E,$79,$4E,$62,$57,$EA,$D9,$D7,$04,$0F,$DA,$C2,$87,$FB,$08,$52,$39,$75,
$F7,$88,$81,$B7,$AE,$A7,$FA,$2F,$C0,$C3,$81,$E5,$51,$8D,$25,$50,$CE,$DC,$BE,$E2,
$1D,$4F,$8B,$20,$AF,$8D,$FA,$2A,$37,$69,$B0,$EB,$94,$3A,$B0,$80,$79,$51,$3E,$C1,
$90,$80,$F0,$41,$AB,$61,$D4,$A2,$78,$19,$DB,$79,$FD,$47,$C7,$74,$FE,$8D,$0D,$DD,
$75,$9C,$27,$77,$3E,$70,$08,$9E,$DA,$F2,$1E,$1C,$38,$6B,$BA,$FA,$1E,$A9,$30,$13,
$6D,$5C,$14,$D6,$BD,$BB,$2B,$22,$46,$67,$6A,$20,$0C,$9E,$CC,$71,$63,$89,$11,$16,
$83,$3A,$1A,$C1,$47,$5C,$09,$3C,$67,$5D,$11,$1C,$D7,$FD,$B7,$C0,$CA,$FA,$8B,$8F,
$5C,$7C,$86,$F9,$A5,$38,$2B,$30,$5D,$41,$09,$F7,$59,$1D,$21,$B4,$3C,$AB,$60,$15,
$88,$5A,$28,$C5,$B0,$9A,$91,$95,$F0,$40,$8E,$31,$18,$C9,$59,$FD,$38,$44,$7B,$6A,
$97,$1D,$E8,$33,$24,$E4,$24,$80,$CC,$81,$FB,$54,$BC,$1A,$80,$C2,$EC,$07,$AB,$D2,
$E5,$77,$76,$BE,$A0,$BA,$B3,$70,$16,$5F,$C9,$78,$91,$70,$CE,$EA,$82,$8C,$F6,$0F,
$92,$9A,$A1,$45,$E8,$6E,$AB,$4D,$31,$59,$5D,$9A,$DA,$DA,$E1,$6A,$83,$DB,$9F,$6D,
$AD,$C7,$83,$31,$E4,$A0,$C7,$F3,$87,$97,$9F,$A6,$86,$28,$84,$38,$E9,$86,$48,$15,
$82,$45,$E1,$4E,$27,$E6,$18,$94,$44,$2D,$52,$17,$43,$34,$70,$A2,$E3,$2E,$50,$AB,
$D5,$03,$09,$61,$22,$4D,$9B,$3F,$6B,$15,$15,$08,$66,$B2,$FD,$A6,$49,$72,$57,$40,
$76,$2F,$8F,$43,$16,$05,$44,$87,$BD,$AA,$44,$50,$E9,$66,$14,$BF,$CF,$67,$3C,$EA,
$B4,$4B,$69,$67,$43,$E9,$F3,$B2,$FC,$A1,$D1,$9D,$20,$69,$29,$57,$D0,$30,$61,$66,
$DC,$44,$34,$47,$47,$54,$35,$CF,$0E,$D0,$51,$C9,$3D,$4E,$8E,$56,$B7,$7A,$E4,$E9,
$D1,$96,$E5,$0F,$19,$E4,$9F,$F9,$3C,$0B,$85,$86,$BA,$D9,$63,$EB,$AA,$D2,$3F,$C7,
$00,$ED,$9F,$D1,$DF,$AD,$25,$96,$54,$16,$23,$5F,$48,$40,$1B,$95,$92,$6B,$33,$ED,
$BE,$FA,$F7,$40,$15,$2F,$28,$B1,$A2,$11,$0B,$35,$45,$A4,$FF,$07,$C0,$5B,$2B,$97,
$E7,$EA,$FE,$E1,$D1,$C9,$1F,$71,$BF,$E8,$2B,$24,$67,$01,$C1,$AC,$9E,$E0,$8C,$13,
$D9,$BB,$C3,$8D,$4C,$12,$B2,$BE,$A8,$54,$8B,$19,$A0,$0B,$53,$D3,$38,$71,$F8,$BF,
$71,$F9,$05,$1B,$A8,$62,$8A,$C3,$0E,$A2,$9B,$59,$E5,$7F,$23,$E4,$98,$A0,$2D,$98,
$E2,$A5,$1D,$64,$7F,$1F,$0A,$E3,$AE,$85,$D8,$2E,$96,$B2,$2E,$9E,$DF,$BA,$56,$0C,
$BE,$08,$FA,$E5,$C0,$99,$90,$4E,$16,$8A,$B2,$05,$46,$EC,$BA,$90,$11,$A1,$6B,$67,
$D0,$B1,$AF,$7C,$7A,$7D,$B6,$22,$9A,$0B,$E5,$70,$4F,$2B,$05,$E4,$F9,$1D,$F4,$33,
$9A,$7D,$15,$99,$5F,$5E,$1F,$1B,$C0,$EF,$17,$8B,$03,$57,$B5,$D0,$2C,$35,$91,$C1,
$2F,$70,$80,$6B,$5F,$B1,$C3,$28,$4A,$EF,$D8,$19,$BB,$33,$DB,$57,$11,$A3,$3A,$AC,
$07,$B5,$FB,$24,$C8,$23,$1F,$D7,$65,$50,$DC,$1D,$76,$6C,$08,$0D,$C1,$2F,$B4,$25,
$FC,$7D,$01,$A1,$01,$25,$FF,$59,$E2,$03,$AB,$1E,$BF,$C5,$C2,$6E,$D5,$05,$DC,$62,
$A5,$82,$BB,$0F,$9F,$FD,$CC,$EC,$94,$C8,$80,$4F,$F1,$5D,$02,$DA,$25,$32,$6C,$C2,
$31,$06,$6B,$F1,$BF,$38,$72,$75,$E1,$BA,$5E,$E0,$6D,$56,$92,$AF,$C7,$AF,$74,$A6,
$14,$0C,$ED,$2E,$A8,$97,$0C,$87,$3B,$B5,$69,$B5,$C6,$12,$56,$85,$FD,$D5,$26,$42,
$32,$B0,$9A,$F6,$A5,$FD,$AA,$FC,$4E,$62,$18,$61,$01,$67,$FE,$4E,$32,$18,$25,$67,
$17,$DB,$6C,$7E,$D1,$8E,$43,$17,$2F,$54,$E3,$4A,$76,$05,$74,$87,$F3,$9A,$14,$D4,
$A9,$A5,$E0,$5C,$79,$2E,$72,$EE,$DF,$04,$B0,$EE,$A8,$BB,$50,$FE,$E4,$93,$67,$01,
$3E,$73,$DB,$B2,$02,$63,$B2,$C8,$15,$33,$41,$1D,$43,$2E,$8D,$CB,$BE,$4A,$2A,$FE,
$D5,$9F,$CD,$B6,$A7,$38,$CD,$70,$AF,$4F,$DB,$A5,$AD,$67,$99,$6E,$5E,$AE,$87,$A3,
$82,$A7,$2B,$E6,$BF,$F5,$19,$D7,$86,$07,$4B,$EC,$C4,$BA,$D3,$36,$97,$E0,$13,$96,
$C9,$28,$8F,$09,$88,$E2,$D6,$E5,$D5,$38,$93,$96,$8F,$6A,$79,$E8,$BC,$79,$CF,$C5,
$07,$AF,$E4,$22,$9F,$37,$72,$73,$15,$60,$C7,$74,$60,$D5,$E9,$9D,$FA,$13,$28,$98,
$4F,$3B,$59,$C6,$DF,$37,$60,$0D,$4C,$CC,$69,$2B,$36,$83,$98,$37,$FB,$D7,$30,$BD,
$75,$FF,$8A,$3C,$A3,$73,$9E,$41,$86,$A2,$52,$A2,$47,$11,$BF,$FD,$D7,$68,$64,$15,
$69,$6A,$45,$81,$78,$7F,$4C,$80,$DA,$32,$E4,$FE,$18,$76,$6F,$DF,$BC,$57,$33,$09,
$C3,$8C,$97,$85,$B8,$B4,$C0,$57,$21,$89,$6D,$12,$94,$E7,$60,$45,$46,$E5,$DE,$F6,
$69,$00,$18,$50,$57,$AE,$C4,$79,$A6,$D9,$5A,$00,$BE,$0B,$24,$1F,$25,$41,$BF,$CC,
$D9,$7F,$8D,$D3,$AF,$F5,$C3,$69,$90,$A2,$C2,$60,$BD,$C0,$A6,$19,$6A,$E9,$BE,$92,
$6C,$EA,$49,$E3,$AE,$E5,$4B,$FF,$1C,$27,$AA,$50,$1B,$1C,$D0,$EC,$7E,$AD,$47,$2D,
$1A,$BD,$58,$48,$BF,$88,$33,$43,$7D,$E6,$FA,$71,$49,$BA,$AB,$B0,$B2,$A5,$04,$2C,
$8E,$97,$7E,$A5,$3B,$00,$D1,$6F,$5C,$B6,$AA,$21,$98,$02,$DA,$00,$36,$20,$EF,$EB,
$2E,$E9,$2F,$81,$38,$6F,$67,$AA,$82,$88,$5E,$33,$A4,$D6,$41,$1F,$CE,$75,$FA,$E2,
$98,$C0,$3F,$BA,$1B,$B4,$D3,$B4,$78,$B6,$B6,$A6,$C0,$B8,$2F,$3E,$E0,$CE,$2B,$C9,
$7C,$A9,$AE,$9C,$FB,$A2,$EB,$EF,$B0,$8A,$B0,$35,$28,$CA,$D1,$37,$7B,$1E,$D7,$0C,
$66,$DA,$5D,$1A,$66,$62,$F5,$03,$41,$53,$39,$83,$9F,$F8,$6A,$5B,$EB,$92,$B0,$74,
$14,$06,$BB,$50,$0C,$17,$86,$05,$A2,$0D,$CF,$8E,$22,$EB,$CD,$46,$F5,$A2,$87,$5C,
$27,$16,$C4,$C3,$98,$52,$68,$B7,$FB,$07,$03,$71,$22,$EE,$DB,$BC,$1B,$E9,$00,$60,
$92,$0E,$50,$2E,$2E,$6B,$14,$D0,$30,$1B,$E7,$3D,$99,$1F,$DE,$54,$81,$95,$60,$6F,
$34,$73,$38,$2A,$49,$92,$2B,$77,$2E,$A9,$BE,$9C,$2C,$87,$33,$8E,$55,$EF,$CE,$39,
$B7,$86,$1E,$5C,$88,$FF,$09,$1A,$BE,$F1,$87,$5C,$D8,$C9,$D2,$94,$8E,$89,$AB,$E1,
$FB,$3E,$49,$92,$24,$49,$FE,$32,$FB,$26,$E0,$21,$AC,$06,$0B,$09,$E7,$5F,$0B,$67,
$A2,$26,$99,$BD,$E6,$A4,$64,$2C,$04,$81,$9F,$A0,$85,$60,$C0,$60,$F4,$91,$CA,$B9,
$FB,$24,$09,$A9,$C0,$62,$3E,$9B,$68,$86,$1B,$08,$33,$18,$1C,$45,$BC,$FE,$A7,$5E,
$CD,$24,$4D,$23,$45,$9B,$73,$4C,$F4,$D6,$25,$6E,$39,$A1,$34,$D5,$DA,$5F,$B0,$DC,
$28,$A0,$D1,$08,$20,$50,$B7,$31,$8D,$80,$0B,$CC,$1B,$EB,$DD,$46,$87,$DD,$1E,$B9,
$9C,$BC,$A1,$4F,$D5,$3A,$25,$AE,$92,$9B,$EF,$AB,$B8,$92,$97,$50,$EC,$9F,$53,$98,
$F9,$D4,$65,$20,$9D,$3E,$F5,$05,$1A,$80,$A8,$73,$BF,$09,$14,$A9,$D0,$3B,$C7,$6F,
$3B,$85,$D5,$4C,$F9,$CB,$60,$00,$10,$82,$34,$7C,$51,$04,$68,$EE,$23,$4D,$6F,$BB,
$17,$7C,$60,$A8,$CA,$BB,$E2,$2E,$7F,$5F,$30,$29,$01,$CB,$40,$49,$9E,$6B,$8A,$94,
$52,$5D,$5B,$17,$91,$0C,$0E,$46,$47,$4D,$60,$2E,$D3,$0A,$59,$24,$A8,$45,$05,$13,
$B6,$4A,$3E,$FF,$12,$B2,$48,$20,$6F,$C5,$0B,$28,$52,$2B,$1B,$2D,$24,$C4,$75,$75,
$B1,$27,$A1,$6D,$AF,$65,$F9,$25,$6D,$0C,$86,$92,$D6,$43,$37,$25,$5C,$8B,$9F,$8E,
$19,$DE,$6D,$58,$D5,$5C,$B8,$2E,$A7,$DA,$66,$4A,$9F,$16,$03,$C6,$1F,$36,$82,$E5,
$9A,$E4,$85,$8D,$FF,$15,$58,$D1,$0D,$57,$C9,$9A,$24,$AC,$0C,$B7,$06,$7A,$80,$05,
$64,$23,$5F,$32,$0E,$BB,$95,$40,$2A,$23,$31,$FF,$88,$78,$A0,$E5,$C2,$95,$A3,$15,
$A8,$2E,$9A,$88,$FF,$55,$8D,$57,$95,$28,$43,$F1,$DE,$76,$A3,$77,$91,$98,$55,$71,
$67,$30,$8A,$70,$54,$27,$1B,$93,$8C,$4B,$4C,$51,$97,$33,$AF,$E2,$EC,$A5,$52,$97,
$5D,$27,$6C,$24,$39,$6C,$A6,$5F,$FC,$BC,$42,$F4,$00,$88,$B1,$37,$0D,$D2,$33,$BD,
$20,$B5,$CE,$39,$B8,$AE,$8E,$8C,$3C,$3F,$6E,$DA,$58,$D8,$35,$6B,$A0,$43,$CE,$55,
$1E,$6F,$68,$64,$14,$5E,$00,$40,$9E,$9C,$B4,$FE,$75,$2E,$51,$59,$56,$57,$7B,$27,
$7F,$BD,$1A,$F5,$AE,$28,$62,$2E,$0F,$3A,$2E,$74,$28,$88,$F9,$65,$78,$18,$BA,$B0,
$0A,$0F,$D3,$84,$DC,$57,$36,$14,$BE,$C1,$B6,$D1,$22,$FF,$12,$44,$FC,$3C,$7D,$F5,
$84,$29,$92,$32,$48,$40,$DE,$29,$CF,$F0,$FC,$F1,$3A,$1A,$98,$68,$84,$E8,$C1,$A9,
$C5,$C9,$91,$0F,$C1,$A2,$4B,$22,$AF,$52,$CA,$A3,$C6,$DF,$01,$10,$19,$01,$A0,$54,
$AE,$78,$0C,$7E,$FA,$9E,$72,$5A,$F7,$A2,$0B,$81,$FB,$1F,$40,$5E,$7C,$47,$5A,$0E,
$70,$36,$38,$00,$86,$98,$CB,$70,$40,$5C,$4B,$C2,$D0,$83,$EB,$16,$58,$97,$66,$4A,
$89,$BC,$08,$36,$5E,$B1,$AE,$00,$89,$91,$75,$45,$01,$22,$5B,$D3,$6E,$50,$70,$3C,
$4A,$8B,$6A,$71,$4B,$6A,$DD,$BF,$65,$F9,$BD,$99,$7E,$F5,$E7,$58,$0C,$3D,$6B,$B1,
$E9,$5F,$9E,$EE,$C1,$A7,$68,$73,$A1,$AF,$31,$2D,$D7,$40,$D2,$2F,$7D,$EA,$E9,$1F,
$EB,$D4,$9B,$96,$84,$B8,$37,$70,$2A,$03,$FD,$70,$D7,$16,$79,$DF,$82,$C5,$E5,$26,
$EF,$42,$07,$46,$7C,$FB,$10,$E8,$2F,$96,$82,$B1,$7C,$A9,$FD,$13,$92,$81,$55,$ED,
$1C,$EA,$D9,$64,$E4,$32,$A6,$73,$6E,$DD,$9E,$BF,$CB,$B8,$80,$92,$9F,$A6,$0B,$8E,
$8E,$9B,$04,$08,$EE,$FC,$FB,$D4,$AD,$31,$B5,$5F,$47,$EA,$45,$6F,$32,$4D,$41,$6A,
$D5,$3D,$C6,$B7,$AE,$4B,$86,$75,$F3,$46,$1B,$EE,$80,$5D,$7C,$92,$95,$7E,$8C,$1C,
$9D,$6D,$78,$CA,$B9,$F0,$AB,$BE,$81,$FA,$CE,$35,$B5,$7A,$52,$B7,$7F,$09,$01,$A7,
$2A,$9E,$18,$70,$5A,$A9,$E7,$E3,$0E,$5E,$39,$23,$0A,$A3,$71,$4D,$9E,$D0,$DE,$31,
$53,$1F,$76,$A8,$27,$87,$DA,$54,$FD,$0B,$47,$C2,$42,$1D,$B4,$AF,$A3,$9E,$2D,$EF,
$6D,$09,$2E,$D9,$52,$54,$11,$0B,$DA,$B0,$43,$5B,$F0,$57,$37,$D0,$94,$FE,$9D,$FC,
$61,$DB,$00,$BF,$89,$55,$DF,$1E,$1C,$18,$D3,$D7,$AA,$84,$F6,$FB,$C6,$5A,$74,$CC,
$E2,$46,$C3,$AF,$8E,$EB,$53,$B3,$28,$6C,$A4,$76,$85,$16,$FD,$4E,$23,$AA,$02,$91,
$AC,$AA,$86,$15,$61,$A4,$03,$FC,$CD,$92,$DB,$75,$91,$7F,$8A,$81,$7E,$2D,$E5,$D6,
$76,$B0,$65,$51,$AB,$23,$FB,$01,$1C,$AF,$40,$C1,$AD,$39,$3D,$F0,$C5,$C5,$F1,$AD,
$F6,$52,$F5,$C9,$D1,$EA,$DA,$7A,$09,$C1,$52,$AF,$A4,$5F,$E8,$59,$D5,$15,$AA,$7D,
$CF,$8A,$21,$22,$16,$E6,$76,$5E,$02,$9A,$35,$57,$35,$AB,$B3,$4C,$84,$0D,$75,$61,
$FB,$97,$16,$56,$97,$FC,$5A,$F1,$86,$0D,$1C,$B1,$8D,$D7,$9F,$99,$B8,$82,$99,$EC,
$DA,$F0,$2A,$FE,$DC,$7E,$D6,$5E,$8A,$BF,$A4,$EE,$00,$E0,$50,$C0,$99,$CC,$95,$3F,
$5F,$C4,$A1,$5D,$35,$53,$C9,$FC,$00,$14,$0E,$CA,$BD,$32,$E3,$D8,$B6,$BC,$74,$61,
$77,$5B,$C0,$F1,$DD,$B0,$BD,$2D,$FE,$33,$14,$BD,$79,$7C,$C8,$D1,$54,$26,$E8,$51,
$56,$DD,$68,$A0,$3E,$39,$6C,$5F,$9B,$FA,$D0,$B4,$53,$FC,$2F,$D7,$B6,$6F,$4D,$06,
$DD,$20,$DC,$95,$63,$54,$77,$B2,$0C,$C6,$06,$A0,$75,$C5,$ED,$FB,$D5,$CF,$49,$77,
$11,$57,$1A,$CD,$FD,$F9,$94,$42,$56,$9B,$E9,$8D,$AB,$F6,$3B,$C0,$A8,$8E,$13,$B5,
$D8,$DF,$CF,$A8,$03,$CA,$B4,$88,$D9,$06,$B7,$4D,$78,$5A,$B3,$2F,$64,$52,$5C,$AE,
$65,$17,$41,$2D,$60,$92,$30,$3D,$A8,$2F,$9F,$A5,$F8,$0A,$F2,$D0,$97,$A8,$83,$E7,
$5E,$BF,$06,$00,$5B,$B0,$DB,$FF,$9F,$9E,$AC,$40,$6F,$94,$32,$8E,$6A,$D0,$BD,$93,
$5F,$B3,$C5,$61,$8D,$CC,$5D,$A0,$16,$8A,$78,$07,$0B,$91,$49,$C7,$90,$C7,$A4,$F6,
$CD,$3D,$D2,$76,$19,$1C,$89,$41,$81,$21,$82,$01,$1B,$96,$B7,$50,$B8,$BC,$0D,$A6,
$4B,$05,$83,$0E,$66,$75,$F5,$56,$A9,$9E,$F4,$25,$0C,$40,$0F,$8D,$24,$D1,$EE,$89,
$17,$DD,$E6,$CC,$0B,$83,$EB,$BC,$3F,$C1,$37,$3F,$B0,$08,$08,$50,$0B,$01,$AE,$AD,
$81,$C3,$36,$10,$7D,$E8,$D3,$D0,$4C,$80,$47,$0B,$01,$8E,$C2,$08,$23,$34,$5F,$59,
$73,$73,$5F,$41,$8B,$F4,$EE,$8B,$DC,$86,$D8,$A3,$4A,$5E,$24,$A3,$9E,$F0,$90,$A4,
$A8,$03,$E5,$F4,$E8,$DA,$A8,$F7,$00,$00,$A4,$64,$6A,$A2,$66,$CF,$3E,$A2,$62,$CA,
$3A,$A2,$7E,$D9,$26,$A2,$7A,$DC,$22,$A2,$76,$A7,$18,$71,$18,$DA,$2E,$A2,$DC,$B4,
$E0,$80,$94,$80,$49,$EC,$8F,$85,$9B,$30,$56,$A9,$D9,$A9,$C8,$8D,$8B,$C0,$A7,$27,
$DE,$88,$02,$A3,$06,$03,$E5,$EE,$F5,$94,$EB,$DB,$94,$ED,$D9,$8D,$7E,$BC,$23,$95,
$E0,$92,$92,$BD,$5C,$39,$02,$40,$42,$A9,$37,$AA,$6F,$A6,$33,$AF,$6B,$5E,$F4,$BF,
$68,$8C,$56,$8D,$45,$83,$A2,$3C,$01,$C3,$7E,$52,$6F,$19,$79,$19,$8F,$68,$05,$78,
$62,$D2,$51,$1A,$C3,$00,$A5,$EE,$4D,$4F,$36,$42,$6E,$77,$C2,$B8,$95,$AE,$C7,$51,
$18,$F5,$CF,$AA,$3B,$80,$07,$8C,$E7,$D6,$A7,$41,$A6,$69,$9A,$26,$B2,$BF,$B9,$88,
$8C,$8C,$84,$AC,$69,$9A,$A4,$A6,$DD,$10,$65,$F8,$DF,$0D,$16,$C4,$30,$21,$BD,$3A,
$D3,$C7,$30,$4C,$24,$F3,$82,$E1,$59,$3B,$56,$C5,$C0,$65,$54,$F2,$08,$63,$E6,$D9,
$17,$4A,$BD,$C1,$00,$43,$85,$21,$05,$6B,$89,$5E,$C1,$D5,$0D,$7C,$43,$09,$0E,$BC,
$CF,$46,$04,$C7,$2A,$7C,$2F,$D5,$33,$C3,$A0,$E3,$94,$46,$54,$76,$88,$E7,$84,$5F,
$E3,$E4,$23,$9A,$00,$7F,$D9,$3A,$03,$9E,$5B,$C8,$10,$89,$12,$4D,$15,$2F,$B5,$58,
$00,$76,$9B,$90,$49,$AA,$63,$D4,$FB,$BC,$7A,$FA,$E6,$0E,$C2,$A5,$8A,$85,$D5,$C2,
$D0,$CD,$D9,$DB,$71,$EE,$4A,$63,$C6,$91,$2D,$A3,$2A,$74,$88,$57,$D0,$9C,$77,$98,
$FE,$FC,$40,$6B,$A6,$D7,$00,$81,$B7,$42,$5D,$C4,$4F,$40,$E8,$51,$70,$36,$70,$BF,
$CF,$87,$61,$D9,$E5,$E0,$24,$A8,$02,$97,$01,$B6,$CD,$E8,$BA,$43,$25,$A8,$66,$17,
$EB,$0E,$86,$09,$5B,$3B,$68,$EA,$2B,$34,$42,$0A,$1A,$F9,$C2,$76,$8F,$EA,$67,$95,
$49,$8D,$32,$98,$2E,$F9,$60,$DF,$85,$EE,$12,$C3,$71,$98,$51,$2C,$68,$E1,$95,$F4,
$8D,$F6,$42,$46,$20,$9B,$02,$29,$9C,$83,$9E,$B8,$B5,$F7,$B3,$11,$3F,$D5,$07,$FE,
$81,$85,$F8,$8E,$B3,$E2,$7A,$BC,$04,$A4,$82,$83,$B6,$05,$4B,$FD,$7C,$58,$9A,$46,
$50,$80,$24,$5D,$EE,$82,$EA,$08,$2C,$0C,$E8,$A0,$D1,$BD,$D1,$B8,$ED,$DD,$6E,$5B,
$BD,$15,$01,$D8,$CF,$D0,$B9,$82,$36,$CE,$AA,$26,$8F,$22,$1E,$83,$11,$4A,$3A,$30,
$39,$F7,$93,$7D,$97,$B0,$4C,$6C,$08,$97,$B5,$08,$EA,$84,$58,$22,$E6,$23,$55,$55,
$BC,$0B,$BD,$6A,$10,$54,$76,$73,$0D,$12,$33,$E2,$07,$41,$5B,$B0,$EE,$6B,$11,$C9,
$8F,$B8,$A2,$0E,$28,$F3,$40,$C5,$DC,$87,$8B,$5E,$D9,$5B,$3C,$4F,$32,$B0,$51,$31,
$69,$F6,$DA,$26,$1F,$8F,$B6,$F1,$F0,$7F,$90,$5E,$4D,$D3,$77,$24,$E3,$79,$B9,$6E,
$A6,$ED,$55,$C6,$30,$7F,$66,$A0,$A7,$37,$7B,$BB,$FA,$8B,$BE,$60,$55,$69,$57,$E3,
$94,$D9,$94,$B5,$F9,$40,$C2,$F7,$2E,$39,$70,$75,$AA,$E1,$AE,$96,$0B,$BE,$48,$62,
$42,$F0,$3E,$0B,$84,$C8,$15,$75,$95,$39,$C5,$BE,$62,$BD,$20,$9A,$0C,$53,$75,$18,
$23,$1F,$A5,$7A,$11,$7C,$45,$A7,$70,$A9,$26,$EC,$20,$8D,$6E,$C2,$86,$A8,$DC,$81,
$EC,$7C,$64,$6A,$08,$C8,$B2,$5F,$FB,$4A,$44,$04,$A4,$4E,$13,$E4,$5F,$FE,$99,$1D,
$01,$EB,$22,$FC,$3E,$1C,$41,$5A,$07,$3B,$E2,$9D,$40,$A9,$91,$AE,$81,$60,$BB,$2A,
$A8,$62,$E0,$1F,$25,$DD,$D7,$30,$BC,$62,$66,$AC,$2A,$EF,$50,$A1,$DD,$BA,$26,$60,
$BD,$50,$49,$65,$1B,$63,$DD,$7F,$62,$7C,$27,$8A,$05,$A5,$D0,$8D,$F7,$93,$4A,$24,
$EF,$ED,$DF,$65,$8A,$20,$EC,$D1,$94,$BD,$E2,$92,$5A,$AC,$B8,$8B,$2E,$DF,$2C,$A9,
$BB,$B4,$44,$BA,$4E,$63,$25,$4C,$45,$66,$77,$B1,$D6,$B5,$FE,$81,$0A,$54,$BB,$56,
$CD,$43,$7C,$94,$C3,$20,$E5,$D3,$F1,$53,$B6,$D6,$24,$1B,$14,$3D,$7F,$B9,$03,$0A,
$A0,$20,$61,$AB,$14,$62,$A2,$60,$B9,$74,$9D,$96,$15,$DC,$1D,$26,$0B,$43,$14,$F1,
$81,$94,$D2,$94,$0A,$4B,$C3,$1E,$67,$22,$2A,$64,$4C,$7D,$7B,$63,$75,$73,$35,$92,
$7E,$D9,$41,$25,$16,$12,$44,$58,$17,$77,$46,$DC,$1B,$02,$E4,$65,$11,$13,$0A,$40,
$C1,$09,$4B,$CB,$B7,$BE,$D4,$95,$71,$C2,$83,$A1,$41,$D2,$D6,$93,$B0,$7A,$05,$15,
$58,$CE,$17,$46,$70,$0B,$2A,$A0,$93,$2E,$CA,$57,$10,$48,$CB,$AC,$A6,$63,$24,$75,
$14,$66,$1C,$46,$48,$17,$D5,$8A,$55,$E9,$8A,$03,$DA,$5C,$A5,$07,$42,$2C,$D1,$C5,
$CE,$7C,$B4,$F7,$E0,$A9,$DF,$23,$8B,$EC,$76,$F5,$1E,$AA,$35,$5D,$82,$CB,$FF,$63,
$18,$92,$A5,$18,$F6,$B2,$45,$F6,$F4,$EC,$4F,$E0,$C0,$82,$7F,$BB,$31,$33,$A0,$4D,
$0E,$C8,$E6,$B7,$34,$52,$A2,$71,$5A,$67,$24,$E5,$AB,$23,$14,$82,$D9,$60,$E0,$AB,
$A2,$B7,$47,$15,$98,$9D,$9F,$D8,$F6,$47,$13,$D7,$89,$DF,$F5,$85,$5E,$47,$24,$76,
$76,$FD,$AE,$E4,$F0,$7A,$13,$D2,$5D,$D5,$7A,$17,$6F,$A7,$90,$88,$A8,$57,$F5,$BA,
$7F,$BD,$9B,$DB,$F5,$D5,$A0,$26,$AB,$5A,$62,$46,$5F,$DE,$3B,$5E,$85,$7B,$32,$5E,
$5B,$44,$93,$70,$77,$63,$18,$06,$E2,$AC,$70,$8D,$46,$3C,$81,$97,$47,$7D,$1D,$FB,
$0A,$66,$7A,$46,$69,$BB,$24,$09,$3C,$D1,$26,$5C,$7B,$A5,$21,$51,$E0,$10,$D4,$51,
$48,$DE,$15,$CF,$77,$DC,$63,$7C,$85,$B4,$4B,$BA,$DA,$7F,$74,$40,$4B,$7A,$4D,$8A,
$56,$63,$77,$79,$60,$52,$58,$FE,$FD,$EA,$CA,$A5,$4A,$34,$C4,$F5,$AE,$C7,$2F,$E4,
$6E,$1D,$5B,$93,$F6,$BB,$06,$DF,$77,$31,$56,$DD,$26,$95,$EE,$32,$7C,$CE,$49,$59,
$68,$55,$FB,$4E,$16,$13,$F9,$41,$CA,$54,$AF,$45,$F7,$E5,$B7,$35,$90,$AA,$AB,$3B,
$45,$0C,$B7,$D8,$91,$88,$71,$65,$63,$06,$62,$57,$98,$14,$6C,$B9,$03,$0A,$07,$AB,
$42,$F1,$20,$CD,$E6,$60,$1E,$C0,$66,$36,$9A,$1A,$CD,$72,$33,$7D,$DA,$1B,$C4,$14,
$01,$74,$9D,$19,$A2,$9D,$6D,$0E,$8A,$A4,$B1,$B2,$F2,$16,$31,$F2,$E9,$C0,$F1,$74,
$67,$29,$CA,$BE,$70,$06,$D4,$A2,$30,$63,$F8,$C8,$CE,$66,$C9,$F1,$93,$66,$D1,$AE,
$71,$7B,$04,$75,$0C,$29,$FF,$4B,$1C,$04,$EE,$03,$C4,$45,$21,$AA,$AC,$28,$7F,$12,
$B8,$1A,$CE,$03,$91,$B9,$19,$BE,$E0,$10,$6D,$1C,$14,$26,$16,$27,$39,$BF,$E7,$14,
$F0,$55,$19,$16,$DE,$D8,$52,$87,$7E,$09,$97,$AB,$AF,$91,$45,$60,$29,$D2,$E4,$F9,
$36,$A2,$89,$70,$7F,$D9,$60,$2F,$3E,$01,$E7,$CE,$15,$64,$66,$A6,$9A,$02,$99,$2E,
$B4,$A3,$55,$CB,$1D,$F7,$09,$26,$37,$00,$19,$79,$C4,$1D,$88,$0F,$7D,$7D,$36,$47,
$89,$65,$41,$99,$98,$1C,$E9,$0C,$02,$AA,$9B,$AA,$4E,$E5,$27,$45,$44,$97,$65,$09,
$61,$4A,$10,$64,$5D,$E2,$F5,$B0,$B8,$21,$73,$F5,$8E,$52,$BA,$83,$60,$42,$97,$CE,
$12,$BA,$30,$40,$0C,$A6,$CA,$3D,$3E,$B3,$7D,$C4,$4C,$32,$32,$2D,$30,$DC,$59,$34,
$BB,$72,$9C,$07,$6A,$0A,$6F,$26,$6C,$E0,$2C,$52,$D5,$A4,$5D,$FE,$EA,$2C,$8D,$F5,
$91,$64,$4C,$4F,$17,$FC,$9E,$BC,$51,$52,$BF,$C3,$E4,$C0,$B9,$EF,$34,$D7,$62,$09,
$D3,$E9,$78,$A3,$FA,$A6,$33,$AC,$F9,$F4,$63,$85,$F0,$D7,$08,$60,$18,$CE,$B3,$FA,
$F0,$84,$36,$1B,$87,$2E,$AA,$E5,$C9,$A2,$DB,$77,$F1,$58,$A0,$21,$7A,$44,$8E,$C5,
$26,$CD,$0F,$95,$0C,$B3,$24,$DF,$92,$4A,$38,$CA,$98,$95,$0F,$00,$87,$18,$EC,$6B,
$7E,$19,$57,$FA,$A7,$17,$D4,$7B,$72,$07,$C5,$B8,$85,$42,$5D,$07,$D8,$EB,$C5,$BF,
$97,$5D,$5A,$55,$A0,$13,$86,$28,$4B,$9E,$12,$6E,$DD,$55,$C0,$BE,$B6,$5D,$51,$96,
$B3,$EA,$98,$F4,$CB,$C9,$84,$7D,$2A,$E9,$7B,$E6,$7C,$87,$0A,$C3,$CE,$FB,$D1,$81,
$6E,$8C,$17,$54,$F7,$02,$1F,$48,$38,$B1,$07,$0B,$40,$37,$F5,$34,$0B,$4A,$3D,$D4,
$DE,$6B,$A8,$55,$EF,$43,$12,$7D,$D3,$4E,$DB,$85,$E6,$AD,$09,$D8,$1D,$11,$5B,$43,
$FD,$3B,$86,$69,$8E,$55,$18,$E6,$15,$53,$3B,$16,$77,$1C,$68,$F7,$DB,$1A,$93,$8C,
$A3,$0A,$FF,$ED,$BD,$BC,$1B,$6F,$DC,$02,$9C,$CD,$DF,$43,$71,$60,$DD,$45,$A4,$AD,
$8F,$93,$48,$BB,$60,$8D,$0B,$7A,$06,$AE,$AB,$4B,$9D,$ED,$40,$F7,$81,$7D,$06,$18,
$FB,$58,$64,$F5,$C6,$5A,$D9,$B4,$EB,$34,$D4,$2B,$8E,$79,$55,$C2,$41,$65,$1C,$63,
$81,$08,$98,$83,$FA,$2A,$C6,$20,$13,$6B,$34,$9D,$60,$08,$3B,$09,$81,$75,$A5,$8A,
$89,$C4,$D3,$24,$5F,$7F,$FC,$88,$DC,$B7,$B0,$02,$D3,$0F,$C6,$9D,$E4,$6C,$A0,$96,
$DC,$7F,$32,$C8,$AF,$A6,$55,$6B,$2F,$3D,$4F,$56,$92,$90,$0E,$BE,$36,$23,$15,$F1,
$7F,$3E,$27,$11,$5C,$85,$27,$B5,$7F,$57,$85,$38,$24,$14,$82,$11,$6A,$0A,$2A,$3F,
$1D,$85,$51,$CB,$44,$D1,$06,$61,$3B,$30,$4A,$6B,$7A,$74,$EC,$A1,$FD,$27,$7A,$19,
$F0,$EB,$91,$CD,$A6,$F8,$BC,$76,$55,$9A,$FC,$BA,$47,$53,$3D,$8C,$92,$00,$53,$9F,
$CC,$24,$46,$62,$5D,$85,$55,$AB,$39,$45,$7B,$56,$13,$D3,$40,$C8,$4A,$D7,$E5,$50,
$46,$D0,$A3,$DA,$88,$2D,$14,$69,$85,$F8,$A9,$B2,$7F,$C5,$BE,$D0,$17,$A6,$84,$33,
$2A,$BA,$2D,$FD,$6F,$8B,$B7,$36,$74,$AD,$C0,$A4,$E6,$02,$AC,$99,$F9,$B7,$17,$40,
$32,$B8,$78,$88,$1D,$6C,$0F,$C9,$82,$5C,$D5,$ED,$F9,$A3,$C3,$7B,$A3,$C3,$6E,$C2,
$3F,$DA,$99,$88,$AE,$A9,$E7,$40,$62,$0E,$DC,$E1,$0C,$31,$AB,$3A,$5D,$36,$14,$CA,
$45,$04,$BA,$00,$1E,$A9,$75,$9E,$2F,$0E,$EA,$4F,$06,$0E,$18,$80,$7B,$2B,$A5,$B6,
$90,$36,$42,$33,$CB,$A6,$51,$0A,$2A,$58,$25,$71,$A2,$21,$09,$E2,$A7,$37,$1C,$B4,
$1F,$94,$45,$CC,$86,$19,$00,$EF,$06,$87,$09,$0A,$C5,$C2,$91,$05,$8D,$50,$08,$2E,
$3E,$76,$15,$00,$5E,$D9,$E6,$69,$7F,$B1,$59,$FE,$29,$C6,$EA,$50,$58,$D6,$9F,$83,
$44,$BD,$A6,$D8,$51,$5C,$C2,$87,$8F,$0B,$8E,$22,$88,$07,$3A,$53,$E8,$3B,$85,$C6,
$49,$7F,$36,$2F,$B7,$E1,$C1,$60,$30,$57,$72,$3B,$E2,$F9,$CC,$03,$20,$76,$52,$C3,
$2A,$4A,$51,$E9,$62,$23,$E1,$76,$90,$FD,$AB,$26,$63,$C2,$54,$C5,$81,$AE,$6F,$18,
$41,$EE,$92,$05,$1C,$BE,$10,$9D,$DD,$7C,$C4,$FF,$26,$A2,$46,$7D,$F5,$CA,$53,$DE,
$18,$F7,$CB,$7C,$45,$EC,$3E,$F8,$C0,$1A,$79,$E4,$8E,$51,$6E,$F4,$DE,$10,$C8,$5F,
$A3,$A5,$55,$85,$DD,$15,$B3,$67,$4A,$60,$64,$C2,$89,$A2,$95,$14,$2B,$70,$B1,$50,
$C7,$8B,$72,$7C,$BD,$EA,$BC,$35,$99,$63,$A5,$83,$2D,$76,$9C,$03,$EA,$FE,$A0,$30,
$FD,$BC,$AA,$77,$E8,$6C,$35,$5E,$A6,$9A,$C8,$B1,$BC,$2E,$33,$FD,$40,$D2,$D5,$DC,
$C4,$05,$95,$1F,$5F,$C3,$EE,$25,$C8,$44,$26,$0A,$59,$D2,$5E,$D7,$4A,$7B,$AD,$CE,
$02,$C3,$46,$07,$57,$E8,$70,$E2,$C5,$A6,$36,$F1,$99,$DB,$87,$40,$A4,$77,$28,$0C,
$19,$A8,$6E,$2B,$E2,$AE,$93,$92,$BD,$2E,$E0,$62,$E5,$E1,$AB,$1F,$BE,$C7,$81,$89,
$60,$7A,$C2,$6F,$9C,$A0,$1C,$2A,$D2,$DF,$61,$0E,$33,$51,$B9,$D7,$9C,$C1,$22,$E2,
$3F,$00,$77,$30,$EA,$66,$74,$D1,$9D,$70,$17,$29,$A5,$F9,$2A,$BF,$28,$76,$AE,$AA,
$78,$E7,$32,$A0,$B8,$8C,$ED,$1A,$40,$50,$D8,$3A,$8B,$C1,$EE,$54,$31,$49,$5A,$50,
$00,$B2,$00,$53,$64,$F1,$4F,$FB,$BE,$B2,$39,$9A,$18,$92,$C1,$36,$2F,$23,$25,$AE,
$46,$18,$1C,$97,$29,$D8,$05,$23,$90,$90,$FC,$24,$09,$85,$60,$05,$E6,$15,$E8,$17,
$18,$93,$24,$ED,$16,$7A,$71,$05,$32,$85,$83,$F3,$F3,$69,$55,$6B,$8E,$EF,$FE,$18,
$11,$0C,$C9,$3A,$86,$23,$9E,$81,$D6,$4F,$AF,$69,$25,$CC,$F0,$07,$1F,$A0,$37,$D5,
$B7,$14,$41,$5F,$2E,$C7,$5D,$0A,$07,$90,$96,$E9,$50,$A0,$69,$15,$76,$90,$BA,$9E,
$E1,$D7,$88,$69,$1A,$2E,$85,$21,$53,$46,$FE,$E3,$B5,$4F,$0B,$AD,$84,$0B,$0C,$B6,
$84,$02,$E2,$85,$4E,$92,$4D,$2C,$E8,$24,$09,$61,$5D,$3F,$D9,$F0,$50,$8D,$90,$41,
$7C,$90,$07,$E2,$34,$87,$40,$88,$02,$93,$8E,$2C,$1A,$01,$4A,$04,$30,$28,$86,$0A,
$BA,$14,$88,$26,$F8,$5C,$BF,$45,$49,$A5,$49,$EF,$B1,$FC,$48,$32,$C1,$C2,$F7,$AD,
$65,$23,$48,$22,$C0,$87,$CB,$72,$4F,$31,$D8,$9E,$C9,$53,$5C,$C6,$67,$0C,$3D,$BD,
$04,$84,$E9,$EB,$BA,$60,$29,$51,$13,$F9,$86,$F1,$85,$EB,$D5,$BA,$85,$49,$C5,$54,
$C5,$FD,$19,$98,$6D,$A8,$6B,$F4,$D6,$7D,$DA,$75,$D5,$0C,$09,$75,$63,$64,$53,$49,
$A7,$A5,$86,$30,$8E,$F4,$F2,$1C,$AE,$FE,$84,$4D,$46,$04,$23,$5E,$EA,$AD,$16,$7D,
$44,$15,$19,$53,$8C,$3E,$DC,$46,$91,$90,$B2,$F3,$85,$DA,$6E,$4A,$DF,$00,$B6,$7B,
$0E,$7B,$F5,$42,$D9,$B6,$60,$06,$BD,$D3,$34,$51,$18,$E3,$43,$3C,$F0,$7A,$BB,$2B,
$2F,$55,$68,$C2,$EE,$3E,$D2,$D2,$A0,$E7,$34,$97,$59,$FA,$76,$A1,$A1,$72,$8E,$E5,
$EF,$61,$7B,$D5,$EB,$DA,$A9,$55,$65,$80,$A6,$9A,$A8,$BF,$05,$6F,$96,$39,$FE,$57,
$A5,$11,$38,$3D,$34,$FE,$B3,$88,$1A,$D5,$EF,$57,$2A,$9C,$DC,$A5,$73,$BF,$DE,$B3,
$EA,$12,$75,$C0,$8E,$0A,$D2,$44,$B6,$B3,$56,$D4,$33,$FF,$CC,$46,$30,$50,$D0,$00,
$B9,$ED,$29,$E7,$A3,$24,$49,$92,$2A,$D2,$A4,$DB,$AD,$DC,$F5,$61,$93,$92,$B2,$AA,
$C0,$B4,$E0,$C7,$BF,$84,$49,$92,$24,$49,$4D,$6E,$43,$6C,$49,$29,$49,$92,$24,$72,
$2B,$2C,$21,$2A,$92,$06,$06,$0A,$1B,$57,$78,$89,$EF,$E5,$63,$44,$7E,$5B,$C9,$36,
$45,$FF,$BF,$AA,$48,$C1,$B9,$AA,$34,$B3,$F4,$D8,$5D,$AF,$DE,$33,$E8,$81,$0F,$D1,
$78,$AC,$49,$0D,$0D,$A8,$5C,$E0,$DE,$02,$3D,$08,$DA,$08,$0E,$01,$78,$1C,$F0,$0D,
$38,$70,$B0,$24,$05,$1E,$0A,$11,$83,$15,$6F,$24,$0D,$4A,$26,$0B,$6F,$09,$A6,$85,
$FD,$30,$4E,$58,$6E,$F4,$81,$1D,$76,$C2,$4E,$ED,$7A,$A3,$6E,$02,$C7,$E1,$F1,$92,
$64,$70,$38,$9E,$94,$28,$F8,$37,$EA,$85,$19,$62,$11,$E9,$D4,$C2,$26,$AA,$96,$CA,
$BC,$74,$B5,$25,$EF,$A8,$18,$31,$25,$F4,$1F,$47,$87,$DF,$B5,$7F,$0D,$C1,$00,$BA,
$81,$05,$62,$1D,$DB,$E1,$EE,$1D,$04,$75,$B4,$44,$06,$37,$D1,$56,$57,$3E,$1A,$23,
$B7,$7F,$BC,$23,$56,$51,$D0,$69,$E6,$0A,$89,$55,$2C,$EB,$9C,$48,$E3,$C7,$34,$CB,
$74,$15,$94,$95,$50,$B1,$22,$F8,$62,$1A,$56,$8C,$89,$4D,$55,$1B,$B6,$2B,$A9,$90,
$06,$43,$39,$4C,$46,$D1,$C6,$76,$EF,$30,$65,$A1,$5F,$F7,$E9,$E0,$17,$C7,$D5,$AA,
$4A,$B9,$E6,$D0,$E0,$DE,$9D,$31,$A1,$EC,$E2,$8B,$79,$F6,$AE,$5E,$2B,$2B,$16,$73,
$ED,$5A,$02,$95,$7B,$A9,$00,$78,$6D,$E5,$09,$69,$FC,$A8,$05,$98,$B8,$0C,$2C,$D6,
$37,$6C,$E1,$D6,$0D,$C2,$94,$64,$43,$84,$BF,$4A,$77,$FC,$C1,$06,$31,$8D,$B9,$67,
$CF,$A5,$3B,$11,$5A,$50,$C7,$A7,$52,$F7,$4F,$BD,$C0,$E5,$06,$ED,$68,$59,$2B,$29,
$B1,$17,$99,$15,$98,$0A,$6C,$16,$1A,$95,$C8,$82,$E4,$86,$19,$25,$86,$DE,$86,$08,
$0E,$03,$C5,$80,$7D,$2F,$33,$48,$88,$30,$66,$54,$07,$56,$84,$89,$51,$69,$E4,$C0,
$11,$4E,$08,$45,$C8,$F1,$ED,$89,$45,$19,$AB,$F4,$00,$2E,$AB,$71,$67,$FA,$58,$23,
$23,$CD,$3A,$A5,$00,$AD,$2A,$B4,$AC,$2C,$8A,$0E,$0C,$4F,$98,$E2,$40,$0F,$A5,$4C,
$DD,$18,$62,$28,$58,$FB,$55,$0D,$28,$F3,$FA,$39,$2A,$C7,$C4,$F8,$A5,$4E,$AC,$61,
$28,$E8,$3A,$45,$BD,$26,$1C,$AD,$FB,$46,$F9,$F6,$EB,$DD,$51,$15,$D2,$68,$BB,$0B,
$DE,$15,$D5,$E9,$4F,$EA,$D6,$1D,$63,$8C,$B9,$3C,$12,$27,$97,$91,$12,$70,$4D,$81,
$4C,$74,$9E,$DB,$7D,$DB,$A0,$61,$14,$48,$42,$18,$0E,$EC,$79,$0B,$8B,$56,$9F,$56,
$97,$88,$08,$48,$91,$7F,$AF,$B6,$0A,$5A,$F3,$22,$04,$BC,$6A,$DC,$75,$C2,$72,$7E,
$A9,$6D,$19,$5C,$B4,$D9,$B1,$E8,$82,$D8,$7B,$6C,$85,$DE,$D0,$2B,$23,$74,$EB,$20,
$3D,$F2,$C8,$AC,$2F,$9A,$0A,$2F,$66,$B0,$6B,$51,$62,$0B,$94,$BD,$A2,$71,$5B,$2A,
$38,$82,$99,$B3,$A9,$2F,$1D,$36,$71,$EB,$E5,$AA,$63,$02,$0C,$EE,$BC,$23,$B0,$4F,
$CF,$2C,$28,$BC,$3A,$F3,$B4,$1A,$70,$1B,$A8,$5B,$63,$73,$01,$87,$05,$80,$23,$50,
$D6,$B8,$9D,$1F,$2C,$3D,$45,$CD,$48,$54,$FE,$0F,$8C,$C2,$A0,$3C,$33,$A5,$32,$F7,
$91,$E1,$CE,$56,$6E,$0B,$E2,$A0,$C9,$61,$F5,$5B,$0C,$77,$D1,$8C,$9B,$0E,$C2,$41,
$C6,$AB,$C7,$BF,$2A,$0C,$FC,$57,$91,$7E,$F3,$A6,$0B,$90,$44,$50,$B3,$1E,$9B,$9F,
$7C,$F9,$05,$68,$F3,$3D,$B2,$CB,$CF,$F6,$83,$51,$C8,$35,$03,$94,$81,$41,$04,$E5,
$6F,$1B,$F3,$18,$E9,$81,$D5,$E9,$57,$17,$E5,$C4,$D4,$2F,$10,$F1,$72,$7A,$0F,$B6,
$07,$FC,$FD,$42,$9A,$C4,$87,$B7,$86,$F0,$30,$42,$B0,$1E,$80,$92,$9A,$CA,$17,$1B,
$57,$22,$29,$94,$21,$D6,$73,$93,$28,$65,$DF,$B0,$81,$01,$D4,$A8,$D0,$6C,$45,$1E,
$7C,$C4,$17,$88,$02,$31,$20,$80,$AE,$C9,$44,$29,$83,$70,$F0,$05,$61,$10,$EA,$87,
$C5,$2D,$18,$91,$14,$B3,$D8,$9E,$45,$40,$49,$16,$45,$40,$D7,$D6,$91,$40,$30,$45,
$3A,$99,$EF,$52,$9A,$22,$91,$1B,$00,$45,$18,$7A,$A0,$C2,$13,$60,$80,$7E,$21,$02,
$47,$52,$41,$B7,$30,$84,$59,$AA,$C3,$0D,$F0,$3F,$7B,$4B,$EA,$E6,$C2,$65,$D5,$47,
$FF,$FC,$CB,$84,$70,$17,$A8,$C7,$60,$BA,$DD,$1A,$9D,$E9,$3A,$79,$29,$E2,$E1,$E1,
$6E,$0D,$0C,$46,$18,$EF,$78,$F7,$4E,$AF,$2E,$0C,$A6,$30,$A2,$33,$5A,$8A,$19,$1A,
$85,$17,$D9,$4E,$DA,$C0,$A2,$23,$2F,$7E,$21,$3A,$B8,$11,$23,$6E,$93,$04,$DB,$81,
$B9,$60,$72,$15,$1F,$06,$D1,$F3,$BC,$2E,$E0,$52,$30,$00,$12,$B4,$44,$74,$5A,$B0,
$28,$14,$B1,$4C,$D5,$10,$B2,$3B,$18,$00,$7C,$47,$FC,$1F,$EE,$43,$DB,$1B,$D2,$5F,
$CB,$07,$D2,$A4,$58,$14,$45,$E1,$EA,$C9,$CE,$70,$EB,$57,$04,$FA,$AB,$D1,$D9,$75,
$51,$14,$45,$EA,$E1,$D7,$EE,$D2,$62,$51,$14,$01,$D2,$EC,$B2,$8A,$59,$14,$BD,$B2,
$5A,$98,$5C,$FD,$CA,$60,$9D,$5F,$4E,$A6,$2C,$EA,$3E,$3C,$6D,$C2,$F2,$AA,$1C,$93,
$81,$43,$6C,$D1,$CC,$84,$2C,$69,$D6,$B9,$21,$15,$4D,$0E,$98,$00,$CB,$F2,$E4,$F1,
$34,$4D,$D3,$34,$B8,$C2,$CF,$EF,$EC,$D3,$34,$4D,$D3,$E9,$91,$89,$81,$90,$4D,$D3,
$34,$4D,$A0,$D8,$D5,$C5,$C5,$D2,$9A,$A6,$69,$22,$98,$2A,$31,$39,$01,$39,$21,$3C,
$8E,$69,$3E,$3E,$E4,$13,$0D,$8D,$05,$0A,$90,$04,$D4,$81,$0A,$07,$04,$C0,$00,$40,
$12,$F9,$F0,$D3,$78,$B3,$F4,$B8,$66,$AC,$EE,$24,$A9,$02,$CB,$EC,$E5,$E1,$E4,$0E,
$0C,$49,$92,$DE,$DF,$D6,$E5,$2A,$44,$50,$2B,$FD,$B9,$E8,$9B,$41,$BA,$44,$8A,$27,
$1E,$99,$78,$C1,$94,$C2,$85,$4F,$52,$A5,$57,$E9,$05,$AA,$A1,$EA,$D4,$2B,$79,$B7,
$B1,$2A,$10,$86,$FB,$51,$D6,$4B,$F6,$F8,$E4,$16,$28,$88,$22,$DA,$8D,$F3,$DC,$CC,
$8E,$7D,$6B,$5C,$94,$89,$E2,$95,$88,$9E,$D5,$E4,$9B,$D0,$7F,$BB,$6B,$C3,$7C,$EA,
$A5,$81,$57,$39,$CC,$EB,$F5,$3D,$EA,$9C,$58,$54,$79,$13,$34,$AA,$2D,$5E,$07,$EF,
$41,$98,$22,$8A,$08,$C3,$89,$2A,$33,$BC,$0B,$E5,$69,$3A,$41,$0C,$DF,$4E,$98,$2F,
$84,$A2,$8B,$7E,$9C,$06,$D3,$9F,$21,$74,$85,$DC,$43,$95,$A4,$60,$88,$09,$66,$94,
$55,$FE,$A2,$0A,$D7,$65,$B5,$5E,$5D,$A3,$57,$14,$40,$15,$65,$07,$68,$8C,$71,$72,
$83,$DE,$5F,$1A,$AA,$21,$9E,$02,$0D,$34,$24,$2A,$83,$7A,$DF,$E6,$91,$24,$01,$49,
$A9,$B2,$DD,$05,$93,$E3,$E6,$04,$45,$00,$83,$66,$B4,$8D,$5A,$6C,$1F,$15,$4A,$5F,
$63,$08,$59,$25,$E8,$AD,$19,$55,$1E,$75,$4C,$F4,$B9,$70,$A8,$82,$22,$1D,$CE,$83,
$2F,$1C,$14,$5F,$B9,$1B,$15,$8F,$D9,$B6,$BD,$55,$B7,$C0,$59,$0E,$74,$FE,$DE,$13,
$10,$E5,$21,$6C,$81,$E4,$BB,$B1,$5E,$B2,$08,$8A,$01,$35,$2C,$57,$2E,$51,$AE,$4A,
$37,$58,$BA,$2A,$08,$42,$DD,$3E,$56,$16,$51,$21,$53,$29,$45,$4F,$A9,$0C,$22,$09,
$5E,$96,$25,$44,$89,$C9,$C1,$D9,$EF,$B0,$F5,$FD,$41,$53,$45,$51,$31,$55,$BE,$36,
$AE,$51,$38,$68,$9E,$89,$D2,$FD,$54,$98,$22,$5A,$49,$22,$A3,$F2,$E6,$7C,$1D,$30,
$46,$88,$17,$95,$15,$6D,$5E,$AC,$FC,$6B,$30,$9F,$EC,$5E,$F8,$9C,$22,$96,$2E,$A4,
$38,$C0,$57,$B1,$CF,$52,$52,$F5,$AB,$7E,$64,$58,$C2,$05,$FB,$4A,$93,$CE,$8E,$4D,
$0D,$75,$50,$27,$72,$36,$B3,$CF,$4E,$C1,$94,$B8,$28,$2D,$BB,$57,$A8,$0B,$80,$48,
$44,$0F,$37,$A9,$3E,$B7,$A5,$95,$B8,$59,$76,$B7,$6C,$8F,$62,$03,$A0,$2C,$AB,$14,
$B7,$2E,$AD,$55,$49,$29,$24,$91,$16,$D5,$0A,$86,$E8,$96,$96,$50,$11,$92,$0F,$C2,
$FD,$E9,$70,$28,$B9,$9A,$E7,$00,$55,$2D,$D8,$1D,$7E,$6A,$A2,$44,$FE,$BA,$0C,$07,
$3B,$C2,$CA,$C9,$FC,$1D,$87,$28,$61,$D4,$CF,$3B,$94,$48,$E3,$C1,$FA,$94,$0D,$0D,
$4C,$DB,$88,$9D,$52,$89,$52,$29,$CB,$BD,$1B,$9A,$08,$22,$57,$71,$47,$DD,$02,$68,
$55,$4F,$09,$95,$92,$47,$C8,$B9,$42,$53,$67,$54,$39,$A2,$73,$44,$34,$B0,$9A,$AC,
$BC,$3B,$76,$99,$F4,$1D,$19,$E8,$FC,$C7,$F2,$EA,$EA,$B6,$AE,$85,$91,$87,$62,$6D,
$B3,$EB,$55,$D5,$93,$29,$88,$FD,$9A,$8D,$0E,$54,$84,$84,$61,$A0,$46,$AF,$A6,$43,
$57,$35,$05,$F7,$41,$65,$71,$FD,$4A,$CF,$96,$3E,$A9,$FA,$2A,$EB,$10,$47,$1A,$9D,
$70,$38,$90,$BF,$CC,$60,$80,$0D,$31,$D9,$F3,$83,$24,$65,$C7,$3B,$6B,$74,$D5,$78,
$98,$58,$F4,$E8,$53,$B0,$9D,$10,$6C,$77,$61,$21,$3A,$40,$04,$A2,$03,$44,$F0,$C1,
$00,$8D,$C0,$8F,$5F,$7B,$F5,$B7,$70,$E0,$EA,$FE,$46,$BB,$14,$B3,$59,$EA,$AC,$11,
$D4,$2B,$A0,$40,$A7,$A0,$32,$8A,$73,$50,$59,$59,$A6,$CB,$09,$8B,$F0,$4F,$61,$A9,
$64,$9B,$85,$0F,$88,$BB,$82,$83,$0C,$B4,$CC,$07,$03,$38,$73,$69,$F9,$59,$E9,$DB,
$DF,$7E,$66,$CC,$15,$82,$73,$0F,$9E,$12,$5E,$6F,$94,$74,$91,$A8,$69,$1B,$C2,$D5,
$2E,$B8,$8B,$29,$AE,$F2,$83,$76,$01,$00,$1B,$52,$28,$2E,$47,$C4,$BE,$DC,$41,$0B,
$7A,$C4,$9A,$DD,$BC,$69,$27,$59,$36,$D2,$BD,$7F,$3E,$42,$CD,$92,$88,$58,$B5,$6B,
$D2,$AA,$63,$AD,$74,$83,$09,$0B,$19,$44,$D8,$6B,$50,$87,$CA,$F8,$84,$A3,$8D,$00,
$44,$D2,$FE,$BB,$31,$F6,$8B,$33,$0E,$CB,$8B,$56,$5E,$9B,$2A,$2B,$E5,$75,$A5,$E9,
$EA,$F3,$0B,$10,$2F,$AD,$67,$FB,$D0,$B4,$F6,$0B,$EA,$70,$11,$28,$AF,$E8,$A6,$B8,
$2E,$50,$94,$FE,$FD,$89,$37,$88,$47,$01,$78,$2C,$0C,$AE,$31,$2E,$4E,$AA,$64,$46,
$1D,$CE,$11,$72,$49,$A0,$F4,$26,$A1,$F6,$1C,$04,$B8,$0B,$8B,$22,$01,$31,$24,$0D,
$18,$75,$6D,$59,$10,$9D,$E4,$B1,$71,$55,$52,$E7,$14,$37,$24,$AA,$C0,$ED,$35,$2F,
$E4,$0B,$C1,$48,$91,$23,$0E,$8F,$22,$02,$22,$91,$A8,$02,$01,$B8,$19,$37,$10,$AA,
$52,$A2,$8F,$08,$96,$2B,$39,$14,$B8,$C5,$04,$40,$A3,$F7,$B5,$C8,$D9,$CD,$BA,$E3,
$48,$8C,$10,$89,$CF,$C4,$2B,$F7,$D0,$00,$42,$5B,$FF,$F0,$2E,$34,$AE,$12,$D6,$3F,
$AB,$0A,$14,$A8,$5F,$0B,$84,$6A,$7C,$89,$58,$13,$FD,$27,$79,$36,$5F,$90,$10,$05,
$50,$85,$43,$79,$9F,$FC,$8E,$02,$48,$FB,$3A,$38,$03,$91,$AF,$91,$CB,$AA,$C9,$7F,
$F2,$C0,$B5,$CD,$54,$8D,$C0,$5A,$28,$51,$AB,$45,$C5,$6B,$A0,$55,$FE,$25,$64,$07,
$41,$A8,$F3,$C7,$1F,$92,$4F,$13,$1A,$AB,$91,$09,$C8,$57,$EB,$EA,$21,$AD,$32,$33,
$80,$DA,$D7,$5B,$5F,$A0,$44,$33,$64,$65,$D9,$7C,$58,$55,$AC,$D5,$7B,$74,$1F,$6C,
$F3,$A1,$F8,$9B,$83,$AD,$E9,$89,$2E,$3D,$1B,$FA,$EE,$73,$81,$A1,$14,$2E,$7D,$E5,
$87,$BB,$6C,$58,$5C,$64,$06,$BB,$AC,$46,$46,$7F,$8A,$33,$A2,$06,$4C,$96,$CA,$32,
$7E,$F0,$A4,$E0,$C7,$75,$E3,$86,$0B,$B7,$EB,$98,$C6,$E8,$2F,$F8,$FB,$45,$7E,$D7,
$D6,$8A,$F8,$5F,$53,$D1,$82,$15,$31,$78,$5F,$9D,$40,$97,$C6,$81,$D1,$39,$FD,$90,
$C8,$DF,$2E,$B1,$16,$6C,$E1,$AC,$D4,$84,$B9,$C0,$E9,$F7,$A7,$82,$2C,$0D,$26,$B1,
$74,$2E,$5D,$05,$55,$2C,$F3,$75,$65,$37,$58,$80,$CB,$0F,$E7,$AE,$0D,$72,$94,$BA,
$47,$1C,$5A,$1F,$4C,$E6,$3E,$E0,$EF,$FD,$24,$71,$E4,$00,$3B,$06,$A8,$0A,$F6,$05,
$78,$66,$3D,$6A,$08,$03,$0D,$0C,$34,$99,$3C,$24,$62,$18,$99,$03,$1E,$AD,$C8,$60,
$11,$75,$ED,$AA,$13,$1B,$30,$48,$89,$FD,$44,$8B,$E1,$8D,$4A,$28,$BC,$6B,$1B,$17,
$EF,$67,$61,$BE,$36,$E0,$30,$1F,$D4,$02,$95,$0E,$0A,$C4,$17,$C6,$B1,$61,$45,$79,
$63,$0C,$65,$20,$98,$72,$41,$44,$32,$45,$4E,$81,$AE,$64,$1C,$18,$18,$62,$18,$43,
$91,$97,$90,$EE,$BC,$27,$F7,$3E,$3A,$EE,$0A,$7D,$85,$C2,$A8,$4A,$6C,$4D,$87,$C4,
$50,$78,$5E,$7C,$2A,$2A,$B5,$AA,$5E,$13,$A1,$24,$F7,$2B,$56,$ED,$16,$C0,$5D,$B6,
$B0,$0C,$C6,$36,$4A,$B3,$39,$EE,$7A,$5C,$18,$4B,$E6,$42,$94,$13,$DD,$D3,$F1,$28,
$80,$38,$9A,$5F,$47,$5F,$42,$5F,$11,$6B,$19,$71,$84,$1C,$22,$A4,$71,$67,$B5,$28,
$8A,$84,$84,$E9,$26,$3B,$3A,$45,$0F,$B0,$44,$C5,$EE,$37,$AA,$CE,$63,$3F,$35,$77,
$17,$15,$36,$38,$1E,$27,$4B,$12,$4D,$51,$5E,$7C,$1D,$43,$4F,$0A,$5C,$61,$DF,$19,
$ED,$D0,$25,$A2,$C1,$5D,$50,$8A,$E4,$E5,$DE,$46,$28,$B9,$50,$EE,$31,$73,$43,$09,
$7D,$81,$F2,$19,$7F,$EA,$5F,$61,$66,$D4,$55,$13,$D8,$72,$7C,$97,$32,$6C,$17,$0B,
$63,$CA,$25,$58,$85,$46,$44,$F6,$3B,$4D,$AD,$AD,$07,$21,$29,$C6,$DE,$3A,$6D,$E0,
$09,$68,$01,$45,$1C,$81,$F7,$D9,$0C,$96,$A2,$02,$93,$3F,$0B,$8F,$E9,$07,$0F,$5A,
$1E,$CA,$01,$E8,$CB,$EB,$ED,$3F,$95,$55,$45,$8F,$65,$91,$70,$8B,$AD,$A9,$B9,$9D,
$EF,$6D,$7F,$F1,$AC,$B4,$43,$CC,$51,$13,$5F,$91,$20,$CD,$96,$69,$5D,$8B,$CD,$FF,
$CA,$DC,$A8,$39,$02,$27,$44,$9B,$E5,$69,$81,$5E,$8F,$69,$46,$38,$F3,$9B,$3F,$18,
$B9,$FE,$98,$A2,$26,$39,$1D,$A0,$6A,$D0,$65,$29,$4F,$AC,$E1,$02,$64,$9B,$0A,$7A,
$28,$0B,$D5,$AA,$82,$ED,$63,$AF,$D2,$D9,$B3,$CD,$EF,$8B,$E6,$64,$F6,$C7,$15,$07,
$AF,$25,$83,$D5,$F5,$2A,$80,$65,$D0,$B6,$14,$EB,$5E,$61,$AF,$6C,$E1,$F9,$B4,$81,
$DB,$0D,$9E,$BE,$DB,$40,$54,$7E,$A7,$98,$DB,$2A,$97,$F1,$1B,$B3,$0A,$A2,$21,$10,
$32,$6B,$B0,$D9,$A4,$CC,$13,$91,$D4,$B3,$96,$95,$92,$E5,$0B,$30,$33,$AC,$32,$09,
$C5,$B0,$84,$6A,$3D,$C1,$BE,$38,$19,$03,$CC,$44,$F7,$91,$CD,$78,$5D,$88,$96,$E4,
$C4,$5A,$F5,$19,$3C,$46,$0D,$8F,$7D,$87,$36,$46,$75,$4F,$55,$8D,$05,$4F,$0D,$68,
$92,$4E,$04,$7E,$4C,$72,$56,$86,$9F,$86,$4C,$76,$5C,$B7,$F5,$97,$59,$9E,$34,$0C,
$BB,$29,$8C,$36,$37,$77,$4D,$03,$39,$8F,$86,$62,$2D,$43,$1A,$2A,$26,$AD,$01,$49,
$B6,$D2,$79,$D9,$DA,$32,$4D,$29,$86,$5D,$22,$C6,$D3,$DB,$DC,$44,$8D,$AD,$A2,$C7,
$54,$A3,$45,$9F,$EE,$99,$CB,$4F,$D4,$CA,$DA,$2D,$0A,$D6,$1D,$FC,$96,$6F,$B2,$2A,
$F3,$4C,$99,$58,$56,$59,$D5,$49,$0D,$B3,$46,$6A,$A7,$D2,$F3,$5D,$2F,$E8,$46,$4F,
$D6,$26,$AA,$89,$96,$83,$75,$F5,$A4,$56,$11,$24,$06,$9B,$9E,$72,$89,$7C,$58,$92,
$80,$01,$C3,$E3,$55,$84,$EB,$52,$87,$E5,$EB,$BF,$71,$5A,$69,$DD,$EF,$4A,$1D,$2D,
$E4,$58,$CB,$0F,$26,$5D,$E4,$31,$EA,$FA,$72,$05,$5D,$5F,$D0,$3A,$1C,$5D,$1F,$9A,
$4F,$46,$57,$26,$62,$A2,$DB,$25,$CA,$84,$2E,$B0,$41,$4F,$C4,$18,$6E,$95,$59,$E8,
$70,$E3,$B0,$32,$76,$44,$46,$01,$46,$9F,$DE,$23,$54,$DF,$26,$F3,$CA,$CB,$82,$01,
$59,$A3,$73,$18,$6C,$97,$2D,$00,$18,$9C,$8A,$61,$99,$17,$4A,$73,$10,$51,$E1,$0A,
$44,$D1,$38,$06,$19,$9A,$1D,$02,$26,$2A,$D3,$08,$18,$21,$D4,$80,$23,$51,$2D,$95,
$07,$02,$01,$2A,$02,$AE,$21,$2C,$4B,$BE,$2B,$B6,$AA,$6B,$15,$98,$22,$2C,$1B,$C2,
$04,$2B,$CA,$4A,$C0,$15,$0C,$1C,$2C,$2C,$F3,$01,$4F,$AE,$18,$C9,$5E,$53,$E2,$B1,
$5C,$AC,$CF,$78,$4F,$DC,$92,$85,$60,$65,$63,$A8,$25,$B1,$16,$C8,$19,$58,$17,$93,
$65,$F0,$56,$8A,$B5,$4A,$EB,$0D,$4F,$F7,$02,$8D,$8F,$38,$2C,$B2,$31,$42,$7A,$F2,
$9D,$1D,$1D,$44,$13,$6C,$A9,$91,$21,$69,$4C,$5B,$D1,$DA,$35,$FE,$0A,$F8,$5E,$83,
$66,$F0,$CF,$FB,$5D,$69,$3A,$92,$71,$0D,$A7,$75,$4C,$42,$13,$34,$8C,$90,$EA,$64,
$29,$D4,$EA,$A8,$A7,$18,$DD,$E9,$02,$55,$67,$20,$F3,$53,$0D,$55,$D7,$FA,$95,$C2,
$E3,$53,$76,$2C,$3F,$3D,$53,$41,$0C,$02,$3D,$EE,$C8,$FB,$DC,$50,$11,$5B,$07,$EE,
$84,$B9,$0E,$42,$80,$65,$E1,$B4,$0F,$13,$BD,$1B,$B4,$53,$6F,$4D,$B9,$F9,$24,$09,
$4D,$13,$29,$29,$2D,$7B,$76,$18,$98,$B1,$1D,$60,$77,$8F,$56,$60,$29,$72,$B1,$04,
$90,$69,$EA,$90,$C9,$20,$C2,$B6,$40,$C6,$24,$21,$89,$C6,$93,$8A,$8C,$87,$2C,$F9,
$64,$84,$02,$4F,$43,$50,$4A,$25,$0F,$2A,$8F,$7D,$DF,$4C,$6D,$FB,$ED,$41,$CC,$BF,
$89,$56,$6C,$7A,$80,$2C,$F7,$05,$49,$C0,$6B,$50,$65,$EF,$77,$34,$51,$3F,$8C,$BB,
$70,$43,$66,$CA,$0A,$C2,$8B,$F8,$F7,$53,$5B,$2F,$D5,$2F,$16,$5E,$66,$C7,$E6,$FA,
$8A,$10,$37,$49,$FD,$0B,$E4,$EB,$B7,$35,$BE,$FE,$16,$CD,$3E,$63,$9E,$B5,$34,$CA,
$2C,$74,$07,$3A,$E4,$F0,$84,$AE,$56,$6F,$DA,$4B,$64,$40,$43,$A3,$27,$54,$90,$65,
$0F,$57,$E9,$2B,$C2,$B7,$D7,$42,$85,$D2,$02,$9D,$C0,$75,$E2,$41,$0F,$92,$15,$D0,
$E5,$77,$C3,$EC,$4A,$0D,$16,$7E,$29,$AE,$0B,$DD,$15,$65,$ED,$14,$02,$A4,$C6,$17,
$90,$CC,$E0,$33,$A9,$39,$1F,$00,$1F,$45,$2E,$25,$38,$AC,$4C,$6D,$13,$EE,$85,$FC,
$AF,$28,$3E,$B9,$4C,$23,$6A,$F5,$27,$88,$A1,$10,$82,$B1,$B4,$E6,$14,$D7,$4C,$6E,
$AE,$C0,$2E,$CB,$AD,$7D,$75,$00,$AE,$21,$5A,$FE,$3E,$3E,$8A,$E3,$24,$D6,$41,$D3,
$77,$70,$F2,$B5,$B0,$76,$20,$83,$94,$FB,$35,$14,$A4,$AE,$F4,$92,$5D,$AA,$7C,$BA,
$66,$48,$8A,$86,$83,$A2,$26,$BD,$91,$70,$C8,$54,$00,$B4,$19,$92,$69,$C4,$DE,$83,
$D2,$6E,$CC,$C8,$D1,$9D,$51,$79,$19,$02,$6A,$FC,$DC,$A6,$20,$A2,$B5,$AD,$28,$6D,
$7E,$F6,$08,$1B,$E8,$CE,$6A,$47,$51,$C8,$B2,$21,$EE,$DB,$72,$B4,$57,$B8,$5B,$8A,
$DC,$FC,$20,$62,$5D,$05,$5D,$95,$1C,$C3,$9C,$2E,$54,$9B,$05,$24,$CA,$9D,$13,$CD,
$D3,$22,$D9,$67,$41,$56,$15,$58,$78,$D8,$38,$AC,$34,$B0,$5C,$0D,$18,$78,$E2,$E4,
$E0,$5C,$28,$E0,$6D,$B9,$39,$C3,$F4,$5D,$52,$ED,$18,$C4,$51,$98,$2C,$6C,$68,$E7,
$74,$C8,$54,$66,$39,$4C,$17,$6E,$31,$3A,$03,$EB,$BE,$82,$32,$F1,$59,$2F,$2B,$BA,
$AE,$46,$1C,$B6,$C0,$19,$A9,$66,$60,$3A,$B2,$07,$38,$AA,$B8,$D6,$82,$35,$70,$1B,
$1A,$62,$30,$91,$42,$84,$1D,$08,$9B,$3B,$DC,$DA,$31,$A4,$AD,$3D,$64,$55,$BC,$F4,
$69,$8D,$72,$4C,$C1,$D7,$45,$8A,$5B,$EB,$69,$58,$5C,$97,$6A,$A4,$01,$47,$31,$FF,
$5E,$5A,$39,$68,$5C,$83,$4A,$DA,$62,$D7,$1C,$9D,$F7,$04,$80,$AE,$8B,$27,$56,$B7,
$27,$AD,$0C,$0E,$C6,$A7,$EA,$82,$0E,$2F,$31,$E5,$23,$16,$DB,$55,$85,$B2,$6D,$15,
$22,$11,$64,$A4,$08,$3D,$2D,$36,$BA,$78,$FF,$15,$14,$60,$75,$0C,$4E,$3C,$54,$1A,
$90,$95,$0C,$94,$90,$C9,$81,$FA,$4A,$03,$A9,$AC,$6F,$62,$80,$F2,$34,$C5,$68,$55,
$01,$59,$24,$60,$A9,$EE,$08,$F0,$23,$4B,$A6,$DD,$87,$25,$D4,$5D,$9E,$6D,$0F,$D5,
$A5,$9B,$5D,$DE,$04,$03,$44,$60,$09,$48,$0C,$57,$21,$70,$39,$AB,$58,$B5,$EA,$C2,
$EE,$89,$E8,$04,$6C,$A5,$32,$82,$11,$DB,$BE,$16,$0D,$06,$13,$BD,$F2,$02,$E4,$ED,
$5F,$9F,$E8,$C1,$E0,$53,$BF,$B8,$85,$8B,$21,$9B,$FA,$DB,$A2,$71,$7D,$B4,$F2,$BE,
$6A,$CB,$C8,$22,$84,$7D,$39,$B8,$BC,$C0,$8A,$A9,$8F,$FD,$FB,$1D,$2C,$B6,$EC,$A2,
$F9,$05,$96,$8D,$BA,$04,$16,$49,$52,$84,$89,$B2,$9E,$49,$60,$7E,$77,$31,$F4,$3A,
$BB,$14,$CA,$77,$8B,$FF,$6E,$3D,$46,$3E,$7E,$86,$FF,$60,$27,$AE,$18,$6F,$6B,$B8,
$AC,$CE,$82,$85,$85,$25,$3D,$F8,$46,$DA,$7C,$AA,$42,$4A,$55,$A2,$D9,$AB,$E4,$CA,
$2B,$A1,$BA,$20,$2C,$31,$87,$64,$4F,$12,$F4,$DD,$71,$B1,$C0,$08,$26,$22,$36,$93,
$C0,$6A,$A2,$79,$2B,$1D,$0C,$00,$5D,$1B,$D7,$56,$3A,$1B,$46,$0A,$6F,$0E,$6C,$1F,
$22,$61,$07,$64,$1E,$D0,$E9,$AA,$28,$16,$98,$12,$0C,$A2,$11,$C6,$E0,$EA,$82,$19,
$8C,$14,$1B,$5C,$64,$B8,$FE,$E8,$E1,$FD,$F2,$68,$FC,$DF,$82,$15,$F0,$79,$F6,$95,
$B0,$62,$E2,$FA,$02,$6E,$0E,$A6,$31,$5D,$A5,$CD,$AF,$CA,$BB,$5A,$47,$01,$30,$0D,
$72,$3F,$C5,$C0,$4A,$98,$55,$4D,$C5,$3D,$B2,$61,$A1,$30,$D4,$ED,$91,$39,$44,$34,
$5C,$5D,$E4,$39,$CA,$EC,$B9,$0A,$24,$CC,$D4,$50,$47,$00,$63,$A9,$18,$E1,$F0,$85,
$C1,$1C,$65,$18,$E9,$32,$97,$4C,$57,$1B,$71,$2D,$FA,$3F,$13,$BD,$A9,$C7,$F5,$C8,
$0C,$B6,$69,$04,$16,$0C,$4A,$C0,$6A,$B0,$E8,$C9,$EE,$73,$DC,$24,$49,$EF,$D0,$C9,
$4C,$55,$B0,$25,$3D,$33,$FD,$FE,$8F,$BE,$D2,$A3,$54,$98,$44,$A7,$AB,$0A,$11,$AD,
$AC,$A3,$EA,$02,$58,$AA,$25,$5A,$74,$88,$82,$FE,$4A,$7D,$95,$77,$7D,$96,$FE,$55,
$08,$56,$3C,$7F,$E0,$05,$26,$06,$F5,$F6,$97,$24,$49,$52,$7B,$F4,$71,$C2,$47,$E2,
$0A,$D1,$D9,$34,$97,$AE,$94,$A9,$36,$EF,$B4,$1D,$1C,$AE,$8A,$87,$94,$B2,$F0,$87,
$85,$6C,$81,$69,$80,$91,$7B,$70,$4B,$01,$45,$F4,$9D,$F6,$9F,$F3,$A9,$18,$00,$B0,
$2B,$5A,$91,$64,$6C,$94,$C6,$F9,$6A,$56,$8C,$57,$C5,$54,$78,$B1,$8E,$D2,$73,$D1,
$FE,$5B,$FE,$2B,$B9,$52,$B5,$22,$D0,$57,$81,$28,$45,$15,$E2,$B5,$E2,$40,$FC,$81,
$D2,$B5,$66,$51,$F3,$FB,$55,$0D,$18,$88,$B3,$97,$BB,$0D,$F8,$30,$4A,$B8,$E5,$D2,
$46,$D1,$43,$0C,$8B,$4E,$65,$EC,$42,$48,$72,$B3,$D5,$D2,$29,$27,$05,$ED,$7E,$C8,
$C4,$82,$23,$0A,$36,$CD,$D8,$10,$46,$AD,$1C,$1C,$0B,$EC,$0B,$15,$0C,$E5,$60,$CB,
$E5,$23,$27,$21,$08,$34,$BF,$1B,$5D,$6C,$43,$4E,$EE,$C6,$5B,$51,$C9,$9E,$92,$0A,
$D5,$EB,$3E,$52,$77,$B9,$CA,$5B,$9C,$7B,$60,$76,$2B,$01,$73,$C2,$28,$13,$54,$44,
$43,$3A,$16,$65,$AD,$2F,$80,$92,$34,$E0,$44,$8C,$3A,$83,$7E,$2C,$3A,$75,$86,$FB,
$7E,$D8,$61,$5E,$07,$6B,$D5,$EF,$DE,$2E,$80,$64,$AC,$CB,$19,$9E,$47,$1D,$72,$3E,
$EC,$EE,$76,$3B,$0C,$CC,$B1,$2F,$E0,$8A,$C8,$11,$A6,$67,$7D,$00,$13,$C1,$57,$8D,
$BE,$E6,$AA,$42,$D5,$8A,$29,$C2,$0E,$50,$E3,$8B,$05,$4D,$77,$FD,$D9,$E1,$90,$5C,
$F7,$3A,$B0,$E0,$81,$E3,$BF,$B9,$E3,$BD,$58,$55,$CA,$31,$1D,$D8,$88,$A3,$AB,$0A,
$65,$8E,$DA,$53,$88,$D9,$86,$97,$0A,$D7,$2B,$BA,$95,$78,$3D,$3B,$F7,$C3,$F6,$08,
$80,$AF,$DB,$C0,$B4,$6C,$60,$CC,$B4,$FA,$E3,$89,$A7,$F6,$15,$E1,$B1,$E9,$DD,$CE,
$2C,$F4,$F8,$BB,$84,$65,$C3,$EE,$A6,$61,$FF,$22,$FE,$4D,$B6,$48,$DD,$55,$70,$5D,
$53,$18,$DC,$2E,$8A,$F0,$3E,$27,$F8,$C5,$29,$87,$6E,$D0,$1D,$2A,$09,$68,$FF,$B8,
$F2,$FA,$42,$3F,$6D,$B0,$0B,$46,$E1,$FF,$2C,$42,$A6,$F1,$77,$3F,$30,$B0,$99,$03,
$A7,$60,$89,$CD,$EA,$CF,$5F,$63,$B2,$B6,$21,$04,$AA,$41,$AE,$31,$4B,$EA,$33,$E8,
$C1,$BB,$4C,$10,$E9,$5F,$31,$C7,$8A,$D4,$EB,$9C,$FA,$E1,$ED,$DF,$F5,$06,$79,$78,
$3E,$06,$F8,$73,$65,$F8,$FB,$3F,$7D,$23,$D3,$BF,$8B,$B2,$08,$CB,$7E,$C5,$6B,$77,
$82,$F6,$0A,$4F,$7A,$5F,$E2,$72,$0F,$10,$13,$E3,$7B,$EC,$37,$DB,$BE,$0A,$92,$0D,
$99,$1C,$2B,$FF,$13,$06,$CC,$18,$6E,$DE,$A0,$C8,$FF,$5D,$4A,$7E,$C7,$FE,$34,$B0,
$86,$D9,$5F,$84,$DE,$CD,$9F,$7D,$15,$2A,$78,$9E,$7C,$61,$DC,$A5,$43,$13,$04,$99,
$C2,$1F,$8B,$FF,$46,$70,$24,$66,$25,$AB,$42,$C2,$CE,$D8,$A0,$A1,$74,$F6,$6D,$38,
$09,$F6,$34,$FF,$FF,$FD,$CA,$A8,$D0,$FF,$E0,$EF,$DE,$C4,$31,$7D,$B9,$85,$F3,$2F,
$58,$B0,$5D,$DF,$B8,$E5,$5F,$1C,$7C,$5D,$60,$EB,$85,$EE,$E0,$C2,$15,$EB,$BC,$42,
$C9,$03,$84,$C7,$C8,$95,$AF,$60,$D8,$53,$15,$45,$75,$A8,$73,$A9,$C9,$21,$2D,$51,
$C2,$82,$50,$C5,$FE,$7C,$47,$81,$81,$68,$01,$21,$C4,$8C,$CD,$68,$D3,$51,$CD,$29,
$72,$1F,$09,$EB,$67,$6C,$37,$FD,$05,$DB,$4E,$FF,$B8,$84,$A0,$0D,$2E,$4E,$A3,$3B,
$41,$50,$09,$A5,$98,$64,$C8,$CC,$AD,$47,$FE,$7B,$C2,$1E,$20,$65,$55,$A0,$B0,$F0,
$E8,$BA,$CA,$FF,$35,$0C,$E8,$73,$8B,$17,$37,$29,$FC,$94,$7A,$63,$7D,$CF,$B4,$3B,
$76,$BC,$7D,$87,$05,$C0,$F8,$46,$4A,$73,$48,$DF,$52,$48,$55,$5D,$5B,$5D,$6F,$81,
$5C,$70,$DE,$AB,$8B,$06,$B4,$01,$97,$D6,$19,$9B,$22,$DD,$04,$C2,$66,$2D,$6E,$5D,
$D9,$0C,$64,$C4,$DE,$24,$17,$5A,$2D,$6B,$73,$DC,$C6,$50,$3A,$81,$21,$2A,$6B,$98,
$AE,$5B,$D1,$90,$8D,$BB,$E0,$63,$A4,$14,$C8,$52,$24,$FA,$4D,$BE,$56,$99,$62,$B1,
$B2,$C6,$76,$29,$2C,$8B,$4B,$85,$78,$A3,$BE,$A2,$F4,$97,$D9,$3A,$B8,$F5,$3E,$D9,
$69,$49,$DA,$E1,$FD,$A0,$9E,$FE,$61,$D0,$E2,$85,$FA,$40,$C1,$8B,$DF,$85,$19,$EB,
$F4,$F4,$EA,$CA,$6F,$BF,$C3,$59,$18,$FC,$DD,$B0,$B8,$8B,$FE,$2B,$10,$CA,$8F,$EB,
$FA,$7F,$BA,$88,$12,$F9,$83,$69,$1F,$E8,$8A,$76,$CF,$EA,$B0,$9B,$BE,$1E,$15,$92,
$7B,$0E,$5A,$9C,$4B,$17,$85,$FA,$9B,$9B,$FB,$03,$CB,$7E,$B5,$70,$AE,$A1,$DD,$57,
$43,$EB,$AE,$9E,$FD,$6B,$9E,$7F,$D7,$72,$82,$39,$0E,$D6,$44,$06,$74,$18,$40,$AC,
$70,$8C,$1E,$ED,$27,$18,$C1,$0C,$47,$B9,$BB,$79,$28,$43,$8A,$78,$CA,$36,$9F,$25,
$A7,$05,$9B,$AD,$BA,$F5,$B3,$B2,$75,$85,$D2,$65,$37,$20,$A5,$CE,$54,$5D,$1C,$23,
$47,$50,$A4,$2B,$0A,$5E,$7A,$37,$42,$39,$5D,$95,$26,$BE,$B2,$F5,$FF,$EE,$FB,$AE,
$1E,$ED,$D8,$C0,$CA,$01,$14,$91,$D2,$E9,$79,$CF,$77,$E6,$8B,$42,$F6,$9A,$2B,$6D,
$84,$9A,$33,$E9,$65,$FD,$96,$C2,$5E,$EA,$CA,$05,$54,$6E,$B9,$0B,$70,$35,$4E,$DE,
$3B,$4E,$EA,$72,$73,$01,$B4,$70,$46,$52,$EE,$1C,$62,$99,$9B,$A0,$2C,$6C,$DF,$1D,
$8E,$33,$C1,$FB,$06,$FB,$A0,$CE,$FD,$8D,$9F,$28,$28,$E2,$F6,$49,$DD,$36,$9C,$5F,
$4C,$85,$B0,$B4,$AE,$BE,$D9,$AC,$A2,$5F,$D5,$5D,$E2,$B8,$1F,$6A,$59,$81,$9A,$DC,
$AD,$32,$6A,$1C,$5B,$C7,$63,$2E,$5A,$8C,$27,$18,$49,$0C,$03,$56,$72,$05,$D7,$C9,
$EE,$49,$2B,$E3,$73,$51,$20,$2C,$4A,$3D,$F2,$71,$DF,$6E,$FF,$45,$82,$C7,$2D,$6F,
$D5,$75,$C7,$AE,$F5,$61,$15,$00,$71,$32,$55,$39,$CE,$F7,$2F,$A3,$18,$4B,$E9,$ED,
$71,$1B,$5F,$00,$02,$B2,$61,$16,$DF,$49,$E7,$D8,$74,$E0,$27,$B8,$A9,$BE,$61,$DA,
$34,$85,$D8,$54,$1C,$A0,$31,$B1,$28,$7A,$F1,$59,$F8,$F2,$40,$40,$06,$68,$99,$F2,
$C9,$26,$D4,$AF,$DF,$B1,$D0,$81,$BB,$0A,$31,$F8,$15,$38,$C2,$D8,$EA,$32,$D6,$D1,
$57,$84,$F5,$71,$89,$DE,$C8,$2C,$92,$A5,$76,$3B,$7B,$8B,$6D,$3F,$30,$03,$5C,$BA,
$4C,$AA,$57,$E7,$4A,$C0,$FD,$AB,$30,$A2,$57,$2F,$52,$C4,$A1,$5E,$DA,$77,$FC,$32,
$EC,$9A,$18,$5A,$76,$47,$06,$A8,$3C,$F7,$B0,$18,$06,$31,$F0,$84,$7D,$AB,$1A,$90,
$C5,$D3,$18,$2C,$3D,$BD,$99,$75,$AD,$03,$C0,$16,$F8,$8D,$5B,$BA,$AE,$18,$ED,$73,
$80,$BD,$A6,$1E,$48,$90,$36,$15,$33,$4F,$CF,$80,$8B,$C9,$7B,$0B,$3E,$15,$CD,$02,
$4C,$15,$BF,$44,$F7,$05,$02,$A6,$F6,$42,$20,$BF,$6C,$1E,$1D,$30,$0C,$6C,$24,$85,
$76,$20,$EA,$55,$54,$65,$F0,$D6,$D3,$A0,$46,$52,$F7,$6F,$1B,$2A,$92,$E2,$B5,$E6,
$6F,$7B,$75,$A1,$3F,$FE,$FD,$31,$77,$0A,$B7,$03,$37,$4B,$AD,$6B,$8C,$5E,$B5,$6A,
$A8,$23,$8D,$B3,$A5,$04,$0C,$88,$10,$98,$CD,$F2,$52,$A7,$01,$D0,$B4,$4C,$E9,$FA,
$5E,$FD,$A5,$73,$53,$4C,$93,$ED,$D1,$72,$B8,$AB,$02,$9B,$60,$CC,$8A,$2B,$86,$51,
$C6,$54,$B6,$00,$7D,$DD,$C8,$A5,$09,$73,$88,$25,$D8,$58,$2C,$40,$58,$36,$1A,$D5,
$17,$70,$E5,$10,$AE,$CB,$65,$53,$3E,$BE,$78,$52,$CC,$6C,$50,$38,$B4,$9D,$A2,$3A,
$FF,$1C,$26,$96,$45,$06,$EB,$9B,$9E,$40,$4B,$78,$1E,$43,$88,$12,$81,$B0,$61,$A2,
$72,$2A,$12,$B3,$05,$14,$60,$99,$24,$6D,$43,$50,$7D,$41,$98,$34,$AC,$B3,$C4,$5E,
$D7,$E1,$2C,$3E,$55,$D4,$15,$5D,$90,$53,$05,$98,$4D,$A8,$58,$36,$15,$9D,$24,$E1,
$5B,$DD,$0A,$10,$34,$27,$1B,$4C,$1B,$7F,$48,$6B,$74,$24,$82,$41,$C5,$50,$BF,$62,
$74,$44,$B2,$0F,$E1,$73,$68,$6F,$28,$A9,$6E,$28,$78,$46,$06,$A0,$74,$75,$A2,$CB,
$7B,$44,$B7,$33,$57,$D7,$FB,$E9,$A2,$F4,$9D,$00,$F9,$37,$F0,$23,$E9,$19,$19,$AB,
$8C,$89,$CB,$A5,$BB,$02,$05,$8B,$57,$9E,$F8,$87,$81,$BA,$A4,$CF,$48,$CF,$E7,$9B,
$48,$F3,$90,$AC,$BF,$7F,$5A,$A0,$45,$A0,$4C,$CC,$F9,$C4,$ED,$A4,$9D,$91,$ED,$5E,
$F0,$8B,$68,$5B,$D4,$65,$BB,$E4,$8B,$FD,$5B,$90,$67,$04,$C0,$86,$BF,$2B,$12,$A7,
$3E,$F4,$87,$95,$76,$55,$8A,$D2,$4D,$B8,$9D,$BE,$12,$C5,$05,$0C,$46,$3C,$48,$B8,
$38,$3A,$03,$6A,$EA,$B6,$F4,$F0,$8C,$98,$90,$A0,$FE,$EA,$50,$78,$A4,$1D,$BA,$29,
$4B,$04,$10,$DA,$5D,$E2,$4B,$D3,$A3,$FB,$30,$5A,$DC,$A8,$19,$D6,$8C,$99,$DF,$17,
$E8,$F0,$C9,$97,$4B,$2B,$D7,$8A,$D4,$15,$2B,$92,$D1,$53,$E6,$18,$05,$13,$7D,$B1,
$C9,$9C,$70,$C5,$76,$6C,$A4,$2B,$E3,$0C,$E4,$FD,$75,$21,$24,$A4,$51,$F6,$1E,$D9,
$87,$F6,$B1,$EF,$88,$C7,$EC,$12,$AE,$CE,$D0,$2D,$C1,$30,$D8,$0F,$35,$4B,$72,$55,
$0B,$DE,$C4,$F2,$8D,$C1,$92,$61,$34,$6A,$C5,$9F,$95,$36,$B8,$B0,$05,$E2,$05,$90,
$FC,$E1,$27,$40,$97,$B4,$29,$54,$F1,$DB,$AE,$DF,$17,$13,$DC,$6C,$DA,$12,$C4,$A7,
$EC,$B6,$73,$FA,$68,$06,$C7,$5D,$17,$F7,$D7,$60,$B7,$C3,$58,$BF,$6F,$76,$B2,$1E,
$76,$4F,$35,$65,$7C,$38,$A5,$AF,$A6,$BF,$58,$BE,$69,$8D,$D8,$5D,$35,$F1,$A6,$5A,
$65,$20,$1D,$CB,$7D,$11,$9B,$4E,$FD,$8A,$00,$71,$37,$7E,$6D,$5F,$B5,$61,$1A,$85,
$3F,$2A,$AF,$43,$9C,$83,$AC,$EF,$B7,$8C,$4A,$BE,$CB,$51,$28,$F2,$ED,$3F,$0C,$64,
$25,$54,$42,$98,$67,$49,$5C,$DF,$42,$F8,$EA,$0A,$B1,$CE,$7A,$AD,$16,$3E,$C0,$FB,
$26,$5F,$B7,$BB,$BB,$72,$39,$10,$05,$E0,$C5,$E2,$95,$A9,$A9,$E4,$BF,$A6,$6D,$D1,
$48,$7E,$51,$C9,$AC,$6D,$74,$5F,$85,$C1,$6A,$7E,$CB,$BD,$E0,$C3,$BD,$E6,$2F,$C5,
$CC,$EB,$69,$5B,$22,$1B,$DC,$AC,$BC,$87,$89,$FD,$97,$C9,$5C,$BC,$8D,$91,$F3,$F7,
$41,$95,$D6,$DE,$17,$5C,$6F,$31,$03,$1D,$43,$41,$49,$03,$77,$F9,$8C,$BD,$FD,$CE,
$8D,$E5,$46,$77,$B8,$E0,$F7,$86,$01,$8B,$AB,$32,$3E,$97,$59,$AD,$5C,$1B,$76,$FD,
$64,$42,$8C,$D0,$58,$2D,$93,$B2,$4B,$5A,$D4,$17,$C6,$74,$AF,$E4,$41,$AA,$43,$BB,
$13,$06,$46,$AA,$C5,$81,$5D,$97,$30,$79,$97,$FE,$0B,$A7,$6F,$02,$AD,$50,$3F,$41,
$C9,$D4,$15,$F5,$D5,$6C,$0B,$26,$FA,$69,$F7,$DF,$F2,$3B,$4E,$9F,$F2,$15,$36,$3C,
$EB,$B8,$EF,$4B,$89,$92,$1F,$57,$F1,$E3,$AB,$8E,$FA,$3A,$9C,$FD,$B3,$1C,$ED,$0A,
$D2,$DB,$67,$32,$98,$71,$8E,$CC,$A7,$98,$C3,$B7,$2A,$D0,$A7,$8D,$EC,$E5,$CC,$11,
$69,$EB,$2A,$37,$76,$FF,$D4,$5C,$1A,$1A,$2D,$47,$DC,$DD,$44,$B9,$68,$72,$F8,$F8,
$86,$D8,$A2,$02,$A8,$9C,$96,$8C,$6E,$6E,$79,$31,$83,$98,$37,$9B,$7F,$27,$29,$C2,
$CF,$8A,$C0,$59,$B9,$BB,$A1,$65,$25,$61,$55,$50,$2A,$82,$99,$D1,$98,$B4,$D6,$3D,
$11,$85,$77,$D7,$A9,$52,$04,$F4,$52,$04,$CF,$28,$4E,$36,$43,$15,$54,$B1,$DE,$37,
$7D,$62,$8A,$A5,$5E,$B0,$8C,$4A,$08,$E9,$0F,$AC,$7D,$A7,$7C,$AE,$02,$5C,$38,$0E,
$6B,$73,$A7,$B0,$2E,$A8,$D5,$67,$FD,$2F,$BE,$F2,$3F,$99,$78,$AE,$EA,$5D,$A6,$84,
$BF,$CB,$FA,$3F,$75,$8B,$FE,$CE,$A5,$30,$F8,$B9,$9E,$97,$42,$92,$5E,$BE,$CE,$C5,
$C9,$BA,$91,$09,$CE,$E2,$D7,$0C,$2B,$DF,$BC,$08,$9E,$17,$55,$AF,$91,$C2,$F6,$E8,
$CA,$31,$62,$C8,$52,$B1,$73,$81,$B0,$ED,$E9,$95,$5C,$DF,$45,$70,$D3,$8C,$30,$E1,
$7F,$B3,$CF,$89,$61,$88,$B8,$B6,$8E,$F4,$06,$CB,$C7,$03,$9F,$97,$EE,$20,$1D,$78,
$43,$4C,$04,$94,$A6,$18,$44,$AA,$6F,$63,$EF,$26,$B6,$79,$68,$68,$8B,$AB,$E2,$2C,
$BE,$5D,$C2,$F0,$FE,$5A,$9C,$42,$FF,$F4,$A9,$18,$CD,$29,$D0,$5E,$0A,$C1,$46,$8F,
$92,$AB,$12,$3F,$AB,$9B,$19,$64,$62,$51,$0A,$52,$22,$A5,$2E,$30,$08,$A5,$2D,$39,
$60,$BA,$F5,$67,$18,$28,$83,$58,$D3,$34,$28,$38,$38,$C2,$AD,$41,$71,$0F,$B3,$F5,
$C5,$98,$15,$BD,$E5,$A8,$E9,$75,$C0,$2B,$56,$A7,$AF,$3B,$08,$53,$75,$AC,$9E,$92,
$20,$4B,$04,$4F,$CD,$42,$E1,$96,$A5,$20,$68,$FA,$56,$C1,$1B,$F4,$DA,$21,$B3,$C0,
$B2,$35,$0F,$4D,$C7,$BE,$46,$A9,$C8,$0A,$43,$88,$07,$95,$EE,$4B,$74,$39,$F9,$5D,
$38,$8D,$E0,$6E,$A2,$AE,$CE,$9F,$0D,$8D,$FA,$BE,$43,$9F,$26,$24,$7B,$D2,$98,$8A,
$F8,$DC,$BA,$01,$2A,$C8,$92,$F6,$CC,$EA,$47,$EA,$15,$64,$89,$78,$27,$69,$9D,$7E,
$5E,$CE,$AC,$EA,$72,$A0,$AE,$3E,$33,$76,$FB,$15,$F2,$3D,$40,$EF,$E7,$9D,$80,$73,
$80,$E5,$45,$6B,$5F,$B5,$B2,$41,$E2,$CA,$5D,$2C,$71,$B4,$1F,$BB,$6F,$97,$C9,$6B,
$B1,$41,$50,$C3,$34,$10,$73,$1D,$4E,$E3,$EC,$50,$7F,$C8,$0D,$3A,$4D,$0C,$0F,$C8,
$ED,$FE,$D5,$3A,$A5,$08,$0A,$84,$B1,$DD,$1A,$69,$F5,$0C,$17,$E2,$01,$07,$1D,$F5,
$D7,$32,$8F,$82,$AB,$F3,$76,$29,$0D,$14,$08,$5B,$1B,$BF,$46,$B1,$F7,$33,$05,$73,
$45,$D4,$5D,$33,$40,$7B,$20,$2D,$81,$2A,$30,$95,$6A,$67,$96,$B1,$CA,$A5,$AE,$4B,
$D7,$8B,$E7,$A0,$D9,$78,$5F,$09,$5D,$4B,$5D,$97,$6D,$D6,$85,$AA,$0D,$34,$01,$B5,
$3C,$CE,$22,$E4,$57,$90,$B8,$DB,$E2,$D9,$F0,$49,$57,$E5,$07,$DF,$DA,$E8,$2B,$73,
$09,$2B,$6E,$4E,$78,$B5,$01,$64,$90,$1E,$EC,$0C,$47,$0F,$AF,$F8,$F8,$B1,$BB,$EB,
$E3,$B8,$AD,$63,$7F,$A1,$6F,$DD,$5B,$AD,$FC,$49,$AA,$C0,$E8,$85,$CA,$C3,$C0,$50,
$04,$57,$22,$C9,$8B,$D2,$8D,$4C,$3D,$5D,$ED,$C0,$7E,$70,$BE,$DD,$57,$65,$DD,$99,
$11,$2E,$AD,$DE,$8F,$F3,$89,$D1,$88,$E1,$EC,$85,$FB,$85,$FE,$EB,$36,$9F,$AE,$90,
$D6,$A7,$1B,$50,$60,$2D,$58,$0E,$D2,$CF,$AB,$A1,$44,$55,$C8,$3A,$09,$85,$3B,$69,
$7B,$5E,$CF,$24,$FB,$0C,$A8,$65,$80,$AD,$E9,$A3,$B6,$EE,$1D,$62,$B8,$40,$0F,$03,
$D0,$3F,$7F,$15,$0A,$6A,$16,$6B,$3D,$4A,$26,$63,$3E,$11,$EB,$6B,$A8,$88,$AF,$DD,
$7B,$86,$43,$16,$10,$DE,$D6,$93,$62,$B0,$F5,$38,$CA,$E5,$85,$ED,$D8,$EF,$A2,$D4,
$24,$60,$C1,$95,$D2,$0C,$A8,$4F,$D1,$BB,$26,$57,$04,$96,$C4,$11,$EA,$E7,$BA,$A2,
$CF,$3D,$F2,$6A,$FF,$41,$C1,$6D,$CD,$9C,$F7,$F2,$D1,$BF,$16,$ED,$A9,$60,$76,$E3,
$2C,$20,$E3,$50,$2C,$4D,$04,$78,$D5,$CA,$A8,$91,$22,$84,$29,$9A,$00,$AF,$88,$D2,
$4E,$7E,$4B,$92,$7C,$06,$1B,$EA,$C2,$88,$B2,$70,$5E,$3B,$AB,$16,$0E,$12,$12,$4A,
$AF,$8D,$63,$B5,$5B,$39,$39,$B6,$92,$42,$30,$00,$97,$52,$CF,$65,$50,$E2,$66,$5C,
$D9,$6F,$70,$99,$05,$92,$24,$49,$8A,$83,$9C,$85,$BA,$2F,$DC,$3F,$2B,$88,$62,$55,
$B9,$13,$B1,$B9,$BF,$E8,$C0,$82,$0C,$54,$C4,$6D,$50,$73,$FF,$AD,$C0,$4B,$42,$00,
$65,$0B,$E9,$C8,$AB,$67,$25,$0B,$09,$14,$BD,$F6,$C3,$37,$20,$0B,$B4,$2C,$6C,$17,
$E8,$54,$2C,$44,$AC,$89,$F3,$71,$D3,$86,$08,$FA,$29,$A0,$BA,$9F,$0A,$F5,$68,$20,
$03,$35,$19,$48,$A2,$1B,$3B,$BA,$63,$93,$15,$83,$F5,$88,$34,$91,$9D,$59,$D5,$20,
$C6,$2F,$C3,$C6,$35,$61,$B1,$30,$2E,$1D,$1E,$2F,$CA,$9E,$B0,$DF,$14,$15,$DD,$78,
$BE,$C8,$9B,$78,$87,$A2,$8A,$73,$B2,$3E,$11,$AD,$6C,$3A,$5F,$19,$E2,$72,$07,$88,
$69,$54,$6B,$56,$45,$2A,$97,$02,$00,$83,$10,$9D,$99,$11,$00,$D9,$B2,$42,$F5,$91,
$06,$FE,$CB,$2E,$F0,$D5,$D3,$EF,$E5,$BF,$49,$AC,$AC,$99,$BA,$CF,$D4,$D4,$E6,$A6,
$56,$3D,$07,$DC,$B0,$93,$9F,$B2,$07,$A4,$84,$05,$56,$82,$F9,$23,$6C,$61,$5E,$B7,
$F7,$45,$7A,$1C,$1D,$D1,$7E,$2F,$EB,$69,$57,$B8,$70,$92,$88,$15,$D8,$3B,$0C,$DD,
$16,$ED,$32,$7E,$1D,$D9,$A1,$FF,$EA,$5D,$31,$16,$AE,$5D,$DF,$69,$5B,$69,$4B,$4A,
$5C,$9F,$5F,$8D,$C3,$46,$0B,$FB,$AB,$08,$5A,$F6,$57,$D1,$D2,$16,$56,$F8,$31,$59,
$11,$E2,$C5,$E9,$D6,$4E,$9E,$EA,$AD,$E6,$79,$89,$9C,$31,$F5,$C5,$F6,$B7,$82,$13,
$00,$EA,$15,$E1,$B0,$D7,$B7,$2F,$6C,$9D,$16,$DD,$9F,$DF,$6B,$B7,$FE,$99,$B6,$62,
$B8,$39,$49,$B4,$57,$A8,$55,$B2,$18,$91,$EB,$DA,$E8,$6E,$AD,$E0,$ED,$FC,$9D,$89,
$5D,$05,$13,$DC,$04,$18,$1E,$C0,$9C,$B0,$3C,$13,$2A,$B3,$92,$A8,$12,$BC,$EB,$2F,
$18,$80,$A2,$E6,$1C,$B4,$FE,$CA,$2C,$78,$2F,$CD,$DE,$F5,$C1,$EC,$3F,$BB,$CE,$97,
$B1,$23,$9E,$94,$BB,$4E,$5F,$F6,$45,$11,$6C,$BE,$AB,$B0,$9A,$B8,$27,$A7,$3D,$C6,
$83,$CF,$EF,$2E,$3C,$69,$5C,$CA,$2C,$A2,$1E,$C8,$33,$10,$D9,$AB,$3A,$24,$E0,$D4,
$E0,$5D,$01,$27,$AA,$D7,$13,$B7,$FB,$BF,$53,$45,$50,$92,$46,$6D,$67,$2D,$B1,$BA,
$7B,$E0,$B3,$DC,$B7,$F7,$25,$0E,$56,$CE,$7C,$55,$E0,$C8,$FC,$BA,$E1,$B8,$A3,$F2,
$8F,$92,$BC,$38,$48,$C8,$56,$31,$8D,$88,$A9,$20,$FA,$AF,$0D,$6E,$2B,$54,$0D,$AB,
$F6,$CE,$D4,$85,$55,$C6,$53,$9B,$07,$19,$A5,$00,$2F,$FC,$66,$DF,$F4,$6F,$C9,$DA,
$EE,$C1,$8D,$C1,$4B,$8D,$98,$C7,$0A,$78,$0A,$EB,$33,$64,$A9,$68,$24,$D0,$2A,$91,
$14,$C4,$68,$4D,$89,$BA,$43,$93,$90,$51,$3B,$74,$31,$ED,$01,$11,$E4,$0A,$EB,$E4,
$76,$A2,$CA,$0F,$1A,$D3,$9E,$0B,$1A,$64,$E2,$E1,$AF,$32,$5F,$61,$AB,$8E,$F3,$CD,
$0B,$07,$25,$D8,$75,$CD,$8B,$FA,$84,$FB,$9E,$29,$CF,$5D,$BA,$23,$9F,$D5,$D1,$F3,
$57,$A3,$95,$35,$C8,$2B,$85,$29,$15,$8C,$D9,$91,$42,$8D,$BB,$A1,$53,$5C,$A1,$54,
$31,$C3,$1F,$57,$CD,$F8,$90,$82,$A4,$CA,$E4,$92,$46,$52,$70,$78,$DF,$19,$A5,$20,
$42,$DA,$55,$82,$90,$C4,$52,$11,$F0,$A4,$84,$E9,$40,$5F,$E5,$20,$76,$47,$17,$8F,
$4F,$76,$E0,$53,$1F,$C1,$52,$58,$65,$01,$28,$DC,$07,$BD,$17,$6D,$93,$28,$BC,$7F,
$75,$C8,$4D,$73,$CF,$AE,$4B,$04,$61,$69,$31,$92,$44,$05,$62,$86,$3E,$A8,$62,$7F,
$AA,$A0,$47,$AB,$58,$0C,$DE,$3E,$D6,$35,$13,$2B,$DE,$F6,$D0,$F8,$C1,$AC,$E6,$54,
$97,$DE,$CC,$E1,$07,$E6,$0D,$51,$E4,$3E,$1F,$77,$02,$89,$5F,$64,$0D,$D5,$3E,$19,
$DC,$50,$3B,$8C,$92,$12,$70,$FB,$A2,$DF,$BF,$02,$25,$4C,$D8,$2F,$C5,$57,$63,$74,
$52,$97,$34,$E6,$D2,$48,$BB,$3A,$BD,$6E,$0F,$2C,$1F,$5E,$5D,$3B,$DA,$A7,$1C,$58,
$57,$07,$F9,$BC,$3A,$B5,$38,$36,$A9,$02,$07,$6B,$0D,$87,$E1,$8C,$D7,$20,$60,$8F,
$F6,$2C,$7D,$E1,$CA,$A2,$D9,$1A,$1A,$77,$01,$0E,$0E,$4C,$87,$FC,$57,$78,$A6,$92,
$D2,$CB,$A0,$4E,$C0,$77,$7A,$4E,$04,$80,$54,$34,$E2,$C1,$1A,$98,$DB,$F9,$EB,$DE,
$5D,$2C,$40,$06,$A7,$87,$74,$68,$B2,$AC,$2F,$7D,$A3,$C3,$07,$56,$46,$56,$C0,$DB,
$C4,$33,$B1,$56,$F6,$16,$33,$D1,$86,$BF,$30,$F5,$DE,$2B,$8C,$25,$6B,$95,$2E,$38,
$60,$2B,$45,$02,$1D,$C4,$2A,$05,$EA,$37,$2A,$D7,$07,$95,$5B,$80,$7A,$47,$04,$5A,
$7F,$20,$7C,$A8,$C1,$5D,$7E,$FE,$53,$EC,$7A,$F7,$EF,$20,$4B,$CC,$ED,$AB,$1E,$34,
$3B,$B5,$78,$9F,$B3,$CC,$1A,$7F,$63,$08,$A6,$95,$3C,$4F,$F7,$95,$C2,$00,$37,$42,
$95,$B1,$9D,$C7,$AA,$85,$FC,$28,$40,$66,$D5,$64,$FD,$AF,$1D,$9A,$E8,$33,$74,$9A,
$9D,$95,$59,$3E,$16,$43,$BF,$F6,$65,$5B,$69,$24,$71,$F7,$95,$B1,$9B,$F0,$2D,$DE,
$89,$40,$1D,$29,$78,$70,$87,$F7,$BB,$34,$20,$F0,$26,$36,$08,$D9,$FE,$24,$71,$A7,
$45,$23,$C1,$81,$02,$2D,$44,$12,$3E,$47,$65,$2F,$68,$48,$3F,$12,$05,$97,$18,$DD,
$58,$43,$FC,$46,$EB,$08,$8E,$4B,$1A,$03,$04,$B4,$E0,$D5,$97,$A2,$65,$D9,$46,$5B,
$78,$55,$85,$62,$6C,$E8,$75,$C3,$3A,$7F,$89,$03,$09,$CB,$98,$75,$C3,$A1,$DC,$BD,
$E7,$1C,$69,$36,$25,$54,$5D,$04,$A8,$82,$52,$8D,$1B,$5A,$85,$1A,$0B,$8D,$E1,$C9,
$61,$5D,$7F,$D9,$FE,$DE,$F2,$D7,$A2,$24,$EF,$4B,$CB,$75,$86,$2D,$C5,$38,$8A,$C5,
$FF,$58,$20,$09,$45,$E9,$CC,$B7,$EF,$60,$AA,$9F,$22,$C5,$B2,$62,$39,$AD,$26,$82,
$80,$20,$ED,$2F,$C5,$C9,$55,$58,$77,$82,$B9,$7F,$22,$31,$BF,$34,$A5,$52,$11,$11,
$54,$D6,$E2,$9A,$B9,$EA,$72,$53,$16,$49,$8A,$94,$AA,$57,$EA,$06,$18,$DF,$06,$BE,
$08,$05,$93,$C4,$80,$04,$75,$99,$71,$7C,$42,$D5,$D6,$D1,$A0,$F9,$97,$24,$75,$F9,
$6B,$95,$C0,$A8,$99,$67,$65,$BE,$C6,$99,$CD,$7E,$2D,$7F,$20,$44,$42,$71,$63,$47,
$2D,$82,$0D,$0B,$BB,$CA,$9B,$22,$40,$42,$F7,$EC,$7D,$49,$8B,$56,$89,$DC,$C7,$3C,
$BB,$A5,$5C,$B0,$7D,$B2,$F1,$9B,$80,$7D,$1D,$DD,$FD,$EB,$72,$D1,$A2,$47,$BB,$F4,
$40,$E4,$C2,$14,$E3,$57,$95,$C3,$1B,$2F,$8D,$73,$0D,$BD,$B6,$75,$D5,$F4,$9F,$F4,
$FC,$7A,$89,$FE,$F5,$BB,$36,$E4,$FA,$4E,$FB,$6C,$39,$21,$90,$49,$AF,$12,$B9,$68,
$A5,$E1,$F0,$BA,$CD,$90,$91,$25,$C9,$B3,$34,$32,$91,$14,$01,$CB,$88,$3B,$41,$4E,
$D3,$57,$00,$28,$F4,$B0,$3D,$FB,$BF,$3C,$DB,$4C,$29,$0B,$C1,$4D,$A7,$72,$0F,$54,
$47,$20,$AF,$BF,$3D,$86,$A2,$1F,$6E,$61,$9F,$63,$0D,$41,$4F,$B2,$5F,$54,$69,$BA,
$A6,$77,$F1,$F7,$3F,$1B,$AA,$1A,$21,$38,$1A,$04,$54,$84,$79,$65,$17,$C6,$31,$9B,
$84,$60,$A8,$C5,$CA,$3F,$05,$AE,$05,$46,$F8,$FC,$6D,$73,$A9,$3B,$26,$5A,$55,$94,
$27,$55,$05,$5B,$C1,$BC,$07,$11,$2B,$06,$19,$3A,$AC,$A6,$7F,$BC,$60,$90,$3F,$65,
$4F,$57,$2A,$A6,$14,$A5,$42,$02,$1A,$0B,$18,$C0,$17,$60,$C7,$6D,$D6,$AF,$68,$E7,
$2B,$48,$E8,$0D,$79,$62,$2D,$3B,$77,$6E,$36,$44,$55,$09,$C2,$0F,$2F,$7B,$EA,$91,
$17,$FC,$73,$B7,$37,$B7,$23,$BE,$52,$E1,$6C,$FD,$73,$03,$A8,$20,$B0,$B1,$3C,$0F,
$8C,$B5,$77,$81,$7F,$63,$C6,$24,$A3,$E0,$4A,$EA,$6F,$C4,$AB,$DE,$55,$D0,$2A,$A3,
$B4,$E0,$DF,$F4,$E6,$54,$A4,$69,$5D,$A9,$81,$EA,$F2,$B7,$68,$DE,$D5,$11,$75,$B4,
$30,$7A,$75,$98,$83,$74,$67,$0A,$23,$4C,$AE,$5D,$51,$95,$8C,$8C,$C4,$06,$A7,$08,
$6D,$31,$00,$66,$16,$E5,$70,$F8,$6E,$D4,$8F,$56,$09,$32,$C4,$A3,$64,$78,$A3,$62,
$27,$43,$EA,$83,$E3,$4E,$71,$90,$DB,$16,$1D,$13,$EF,$2E,$1F,$54,$8F,$42,$F5,$80,
$2E,$EF,$D0,$EB,$BA,$D7,$CE,$67,$12,$70,$83,$57,$E3,$B5,$18,$C2,$0E,$22,$B0,$E4,
$AC,$EA,$EE,$EC,$5F,$37,$C8,$AF,$84,$B4,$8F,$D9,$04,$54,$CC,$0A,$CF,$D7,$86,$B5,
$42,$EB,$53,$9E,$E2,$FC,$20,$C8,$AC,$82,$83,$21,$52,$91,$B1,$FC,$D5,$7C,$78,$89,
$D8,$9D,$6D,$2E,$1D,$54,$5D,$0E,$62,$55,$DC,$F8,$16,$40,$B4,$E4,$90,$CC,$8B,$E9,
$88,$2B,$90,$F1,$0B,$E6,$66,$15,$A4,$FE,$1B,$3A,$E9,$2B,$D3,$47,$9E,$93,$82,$73,
$02,$86,$63,$BB,$33,$4A,$3D,$C8,$DE,$82,$D5,$89,$98,$80,$98,$E3,$E8,$67,$C2,$61,
$D2,$80,$B2,$29,$F6,$54,$20,$C5,$72,$E5,$20,$CC,$93,$9E,$AE,$8E,$09,$B3,$75,$08,
$A3,$AE,$27,$CF,$96,$87,$26,$26,$FD,$15,$A1,$EC,$EC,$1A,$F5,$D7,$A4,$85,$10,$EB,
$55,$E7,$3F,$54,$D5,$96,$2E,$11,$79,$2B,$7C,$9F,$18,$72,$55,$45,$91,$7B,$B1,$AF,
$9E,$64,$4F,$1E,$BE,$2C,$AF,$F7,$DD,$58,$22,$06,$FA,$7A,$9D,$7A,$EC,$66,$EA,$46,
$C5,$9E,$8D,$AF,$1E,$78,$07,$FF,$8F,$71,$87,$27,$61,$3B,$4A,$03,$18,$F1,$2A,$E4,
$55,$1C,$DF,$83,$87,$50,$F9,$CA,$A8,$49,$2C,$B0,$9B,$AA,$23,$F1,$AA,$BA,$45,$AD,
$B8,$4B,$83,$70,$82,$B9,$EC,$3E,$8D,$05,$97,$E1,$EC,$BF,$00,$05,$5D,$63,$84,$5D,
$08,$9C,$D5,$BF,$00,$20,$0D,$CD,$4A,$1B,$3D,$F4,$41,$2A,$C7,$8A,$A5,$9B,$0F,$FE,
$31,$18,$37,$36,$AA,$D8,$F0,$15,$33,$E5,$AF,$A4,$D1,$D7,$70,$EC,$9E,$DF,$01,$22,
$FB,$CE,$28,$F8,$4B,$F5,$71,$93,$A9,$B1,$9E,$AE,$7E,$B4,$5B,$54,$27,$D8,$B2,$74,
$5D,$44,$D9,$BF,$5E,$AA,$ED,$FA,$E2,$1D,$2F,$C8,$60,$55,$95,$8A,$06,$EE,$8C,$A2,
$EE,$C6,$BC,$D4,$C6,$B2,$A6,$40,$B7,$D4,$DD,$B6,$3A,$98,$60,$49,$B4,$3C,$F6,$49,
$18,$48,$DD,$AB,$EF,$41,$16,$19,$E8,$FC,$02,$91,$19,$1E,$5C,$27,$42,$9E,$E2,$7E,
$E9,$B0,$18,$24,$48,$FA,$AC,$B5,$95,$1F,$E5,$66,$0C,$44,$45,$F7,$38,$66,$9A,$B1,
$C7,$69,$2A,$F1,$EA,$0F,$B0,$30,$6F,$7B,$AD,$54,$73,$48,$48,$BC,$73,$ED,$0E,$79,
$1F,$88,$F9,$6E,$EE,$C0,$C9,$B2,$C9,$BF,$28,$39,$B9,$47,$F0,$DD,$5D,$0D,$97,$09,
$06,$D1,$DE,$FA,$FD,$04,$05,$8A,$1A,$BD,$7E,$68,$2B,$16,$0A,$35,$BA,$8E,$69,$68,
$74,$75,$60,$1C,$C6,$61,$06,$9E,$94,$A1,$6D,$73,$96,$BE,$00,$1D,$5D,$97,$A8,$8F,
$1D,$EE,$38,$52,$DA,$C2,$FF,$0E,$52,$AB,$12,$D7,$E5,$CD,$BA,$AE,$C2,$B6,$28,$D0,
$20,$4D,$9D,$E8,$DD,$BA,$F4,$DA,$B7,$CB,$F9,$75,$28,$C5,$E5,$96,$3A,$AC,$C1,$22,
$E5,$29,$CE,$2A,$6E,$36,$28,$28,$BB,$D6,$F4,$42,$B2,$D6,$94,$AE,$46,$EF,$E3,$40,
$45,$A5,$8C,$EA,$E4,$1D,$45,$54,$15,$31,$B5,$69,$E0,$E5,$2E,$95,$1B,$14,$56,$0B,
$41,$81,$12,$73,$9C,$6C,$E5,$F8,$B6,$92,$72,$C5,$77,$43,$A3,$85,$80,$B8,$39,$52,
$E1,$5F,$46,$03,$75,$CF,$4C,$C5,$2F,$1B,$25,$87,$B3,$52,$4C,$AC,$E7,$41,$19,$4B,
$4A,$B4,$2D,$26,$AE,$6C,$00,$43,$76,$79,$BB,$09,$B8,$0A,$E6,$22,$BE,$B7,$4A,$32,
$45,$EA,$14,$17,$15,$EE,$75,$97,$F6,$64,$57,$65,$87,$79,$4D,$D5,$01,$61,$4D,$98,
$63,$3D,$18,$9E,$5B,$30,$00,$64,$31,$BC,$FD,$BF,$A0,$11,$82,$79,$43,$54,$0C,$64,
$81,$43,$41,$3B,$01,$8C,$EC,$F0,$81,$FC,$58,$3E,$5E,$20,$79,$EC,$40,$50,$51,$5F,
$6B,$FD,$6A,$90,$FF,$E3,$D7,$9D,$E2,$17,$AD,$80,$A6,$AB,$2E,$7A,$EE,$83,$A1,$16,
$91,$82,$BA,$DA,$1E,$6E,$38,$AF,$88,$1D,$E3,$58,$78,$88,$89,$A2,$60,$B4,$76,$50,
$E7,$BC,$B5,$EA,$BB,$7B,$01,$8B,$78,$DC,$85,$DA,$B5,$E2,$74,$38,$82,$21,$46,$70,
$54,$66,$58,$E7,$6B,$FC,$9F,$84,$B2,$51,$89,$72,$7D,$F1,$32,$AC,$F2,$CB,$23,$07,
$18,$7D,$15,$2D,$03,$2B,$EB,$25,$06,$5F,$D2,$67,$A9,$40,$8F,$6C,$F1,$46,$17,$9E,
$91,$33,$55,$AE,$D8,$A0,$99,$C8,$57,$97,$7B,$09,$B0,$68,$54,$92,$AD,$24,$3A,$80,
$99,$56,$42,$B6,$6A,$5B,$81,$B6,$30,$40,$47,$55,$BA,$1E,$FF,$B3,$AE,$AD,$2E,$DC,
$2F,$2F,$B1,$D0,$75,$8A,$35,$2F,$FE,$F5,$E4,$6A,$A9,$F6,$4A,$36,$C5,$2E,$E7,$BB,
$09,$55,$6E,$A0,$FB,$88,$9F,$04,$7F,$61,$C4,$EA,$FB,$EB,$C6,$E0,$8B,$9B,$AB,$D2,
$45,$4B,$D5,$E8,$01,$F4,$5A,$56,$9A,$B7,$42,$63,$21,$7C,$54,$6A,$D5,$74,$1C,$AB,
$01,$FA,$E4,$C5,$D5,$89,$C6,$CF,$9F,$08,$54,$F5,$16,$D2,$FA,$0B,$B0,$BA,$ED,$58,
$C3,$E0,$3F,$0B,$FD,$C5,$05,$C3,$55,$85,$AF,$8A,$50,$06,$FF,$89,$A7,$D5,$EA,$6A,
$F3,$BB,$FB,$85,$4C,$75,$22,$8D,$D4,$7D,$F3,$2A,$2B,$BA,$DF,$5B,$5F,$00,$36,$50,
$6D,$D3,$2B,$19,$10,$7A,$FA,$57,$63,$7F,$A2,$FE,$08,$5C,$27,$66,$D7,$E7,$8D,$77,
$22,$AA,$EB,$0F,$0F,$DF,$DC,$DE,$83,$85,$63,$5B,$5C,$3A,$EE,$4A,$05,$6B,$2B,$DE,
$72,$6F,$D5,$1F,$B1,$68,$A9,$6A,$66,$CA,$49,$CA,$06,$65,$77,$CF,$D0,$EC,$06,$16,
$51,$FC,$EB,$CE,$DA,$4A,$CE,$12,$A3,$35,$D7,$FE,$16,$E8,$67,$F5,$65,$5B,$DA,$9A,
$03,$C4,$AE,$A2,$E0,$6B,$85,$7B,$D2,$C8,$C3,$BB,$69,$2B,$A4,$B1,$EA,$C0,$94,$BA,
$29,$DE,$B8,$A5,$BA,$7E,$DF,$A8,$CD,$00,$82,$26,$F7,$47,$14,$41,$15,$7B,$98,$CB,
$FE,$6B,$C9,$FB,$26,$26,$06,$CA,$E8,$62,$3C,$A4,$3C,$7D,$57,$97,$41,$55,$08,$9A,
$2E,$5B,$58,$21,$D0,$0A,$EC,$F7,$C0,$60,$99,$DA,$D5,$47,$BE,$AA,$D3,$85,$43,$99,
$EB,$5E,$FD,$DC,$99,$AE,$E3,$B5,$67,$CF,$77,$6F,$58,$CD,$C3,$2B,$30,$1B,$DA,$88,
$50,$BB,$AB,$6E,$DF,$87,$3F,$26,$7D,$0C,$76,$6F,$2A,$66,$66,$81,$E8,$5F,$2D,$62,
$BE,$B2,$60,$A4,$12,$89,$79,$57,$68,$77,$0C,$58,$2F,$EB,$79,$75,$09,$BB,$6A,$68,
$2C,$2A,$EF,$43,$AC,$AF,$8E,$A4,$7F,$4E,$37,$F7,$A3,$84,$AC,$76,$80,$04,$DF,$FE,
$79,$08,$6C,$6C,$91,$24,$3F,$50,$D8,$66,$D9,$B3,$E3,$68,$5F,$58,$2D,$F8,$77,$02,
$80,$7B,$C8,$8E,$DC,$5B,$E2,$D6,$54,$12,$DE,$D3,$2A,$1B,$FA,$F1,$92,$25,$2E,$11,
$A2,$AC,$63,$A3,$FE,$61,$54,$30,$83,$76,$02,$81,$AB,$EE,$89,$11,$D5,$85,$CF,$89,
$59,$5F,$28,$58,$DB,$6F,$2D,$72,$69,$32,$1B,$64,$E2,$C8,$15,$6C,$4C,$2E,$DF,$46,
$23,$84,$1A,$59,$E7,$B2,$2A,$22,$37,$3D,$81,$15,$45,$E6,$F3,$BF,$76,$6D,$C6,$5F,
$E9,$56,$B1,$BC,$0A,$C6,$F6,$95,$D0,$68,$FF,$B4,$2C,$9A,$D4,$1D,$B3,$AB,$71,$E2,
$5B,$A4,$5C,$91,$AB,$E4,$F8,$D0,$FE,$CB,$37,$44,$E7,$AD,$7D,$6A,$0F,$AA,$22,$97,
$CD,$5F,$0A,$24,$CF,$C2,$CB,$F7,$3A,$1E,$B1,$62,$4A,$D6,$14,$91,$D1,$9C,$60,$EE,
$DF,$8E,$E1,$6B,$C6,$4E,$8C,$38,$E8,$80,$7C,$80,$F4,$4C,$D8,$F1,$8A,$44,$CE,$54,
$54,$54,$35,$20,$5F,$D4,$10,$47,$14,$69,$A4,$57,$5B,$78,$58,$9E,$F9,$D5,$F8,$DD,
$CC,$A1,$80,$84,$12,$12,$40,$B0,$16,$2A,$F1,$00,$30,$45,$51,$F9,$A1,$CE,$A8,$82,
$BF,$CB,$B8,$F6,$37,$08,$A3,$10,$03,$48,$B0,$CC,$AA,$96,$E2,$DE,$72,$42,$46,$B5,
$13,$A3,$7F,$2C,$E0,$59,$C4,$AC,$04,$D3,$75,$71,$F9,$46,$57,$C4,$46,$B5,$A7,$D6,
$5F,$9B,$85,$ED,$DE,$18,$BE,$CC,$0E,$3E,$E8,$ED,$57,$31,$24,$46,$AE,$E2,$C0,$EA,
$CD,$16,$69,$C9,$5A,$60,$50,$70,$BA,$14,$65,$F7,$29,$2F,$40,$35,$2F,$6B,$50,$33,
$91,$1B,$1B,$18,$77,$15,$C2,$D2,$37,$25,$2A,$71,$23,$10,$DB,$72,$EB,$E6,$03,$B1,
$E9,$B9,$E0,$14,$AF,$2B,$8B,$9A,$B8,$E4,$A3,$C9,$AE,$D8,$5A,$6F,$89,$AB,$7C,$D8,
$5F,$D5,$D8,$9F,$D4,$FC,$58,$70,$E8,$28,$8D,$DC,$89,$B9,$6A,$EA,$D3,$61,$E2,$64,
$7E,$65,$9D,$56,$CE,$15,$8A,$F4,$C4,$54,$2A,$D3,$B8,$EB,$99,$9F,$E2,$24,$45,$FF,
$02,$E7,$39,$CD,$61,$84,$B1,$55,$E3,$B4,$37,$D5,$34,$21,$B1,$C1,$E7,$96,$AD,$08,
$B1,$42,$F6,$E3,$AC,$C5,$DC,$75,$24,$8C,$05,$34,$A8,$21,$8C,$E0,$42,$5A,$AC,$6F,
$A7,$0F,$D1,$ED,$B6,$C6,$2F,$64,$BD,$3A,$3A,$A9,$F8,$81,$BA,$F9,$94,$F7,$BE,$3A,
$3E,$A9,$CD,$6E,$55,$09,$38,$07,$43,$4E,$FF,$35,$A6,$31,$30,$A5,$1C,$5C,$BA,$B3,
$C2,$ED,$C3,$C3,$E2,$54,$3D,$C1,$C1,$74,$95,$3D,$EB,$EC,$0B,$6C,$CC,$8F,$6A,$77,
$F6,$88,$BF,$D6,$BB,$22,$AD,$94,$BA,$E3,$F4,$17,$D5,$61,$A4,$44,$C4,$7B,$1D,$1A,
$32,$83,$73,$FE,$D2,$C1,$32,$94,$D2,$A9,$03,$03,$08,$D9,$3A,$76,$C2,$23,$6E,$57,
$15,$83,$D2,$79,$77,$E8,$D8,$28,$3F,$54,$B9,$D4,$DC,$37,$49,$9E,$AF,$5D,$9C,$E3,
$A8,$1C,$37,$E4,$55,$D9,$04,$31,$26,$4F,$FB,$82,$FB,$24,$FD,$C2,$C6,$B9,$57,$F8,
$9B,$CA,$35,$85,$4A,$B7,$FD,$35,$47,$9B,$B8,$5D,$85,$5B,$74,$20,$34,$A5,$40,$18,
$AC,$93,$9F,$4B,$A3,$03,$34,$8C,$DE,$B9,$BB,$80,$1B,$0B,$30,$23,$E2,$53,$0D,$EB,
$2F,$36,$38,$7B,$79,$53,$40,$D8,$A2,$81,$0B,$B0,$83,$1D,$FF,$89,$45,$56,$5D,$D7,
$D5,$FB,$5D,$19,$12,$87,$A5,$C5,$55,$86,$9C,$A8,$11,$88,$75,$ED,$05,$D7,$98,$1D,
$C8,$8B,$C3,$26,$42,$F0,$3F,$41,$49,$21,$F7,$EF,$8B,$61,$61,$47,$2B,$97,$EA,$24,
$E4,$ED,$C7,$66,$A7,$0C,$10,$9D,$8A,$9C,$9D,$23,$5A,$22,$08,$49,$2B,$FD,$0E,$C2,
$6F,$98,$74,$EE,$12,$C4,$48,$CD,$9B,$63,$6E,$CD,$31,$70,$3E,$DA,$28,$F9,$76,$78,
$CE,$F9,$2D,$23,$78,$6C,$AC,$0A,$A1,$13,$6A,$52,$5C,$ED,$82,$45,$D7,$39,$44,$81,
$D8,$19,$D4,$F8,$73,$83,$BE,$15,$4A,$76,$82,$A1,$68,$1F,$DA,$4D,$39,$36,$2B,$8D,
$F0,$25,$45,$8D,$33,$9E,$17,$E5,$FD,$CC,$A6,$90,$06,$46,$EA,$FB,$A6,$AF,$02,$D4,
$E0,$CD,$5D,$C1,$98,$BE,$B4,$88,$2D,$34,$49,$AB,$4E,$FC,$52,$6A,$44,$9E,$1A,$68,
$55,$B7,$21,$AA,$3C,$51,$D0,$04,$0F,$76,$A9,$1A,$8E,$E0,$98,$E8,$AF,$34,$44,$4D,
$B9,$68,$4D,$A6,$E1,$B8,$61,$FA,$7F,$E1,$8D,$AF,$06,$70,$24,$7B,$5A,$AA,$AD,$35,
$05,$16,$2D,$19,$61,$D7,$C9,$51,$18,$88,$CB,$E8,$ED,$DF,$3D,$F9,$F6,$A3,$49,$1B,
$3E,$3A,$68,$78,$8C,$2E,$0E,$FB,$56,$E5,$4B,$F3,$A2,$36,$98,$6C,$FD,$DF,$C8,$C1,
$64,$A5,$C6,$2E,$25,$F2,$A9,$F4,$DB,$E7,$7C,$B2,$70,$6B,$A2,$C6,$51,$31,$D7,$77,
$60,$0A,$AC,$82,$01,$14,$A8,$D2,$2F,$6E,$58,$41,$1E,$18,$EC,$ED,$AF,$B7,$54,$56,
$43,$78,$C8,$DA,$02,$EA,$EB,$A4,$9A,$46,$DF,$E3,$3C,$08,$C0,$9A,$BE,$03,$C1,$41,
$0D,$BB,$DD,$45,$22,$24,$77,$7C,$6B,$32,$8D,$39,$C8,$30,$99,$79,$39,$39,$23,$27,
$27,$EC,$63,$B0,$4F,$BE,$9B,$1F,$0C,$9D,$65,$1F,$14,$30,$3F,$B5,$42,$32,$FA,$7B,
$E3,$A6,$B7,$44,$33,$B0,$B9,$16,$C1,$4C,$B7,$4A,$F0,$F7,$CE,$B0,$95,$5D,$93,$E5,
$85,$6B,$3D,$0A,$6C,$8E,$C7,$D0,$86,$27,$16,$2A,$75,$5A,$29,$1E,$D2,$3A,$18,$0A,
$F5,$66,$B8,$8F,$74,$E5,$CA,$B1,$3C,$66,$CB,$9C,$E7,$BE,$25,$07,$27,$D3,$01,$15,
$F3,$4D,$29,$B3,$84,$A8,$15,$A4,$79,$54,$0D,$54,$9E,$C0,$0C,$3A,$BB,$C6,$A1,$00,
$A7,$34,$34,$9C,$E3,$A1,$7F,$2B,$60,$A3,$DB,$B6,$4C,$68,$A6,$42,$C2,$B8,$DF,$E5,
$9F,$2D,$EF,$22,$9A,$B2,$EB,$87,$EC,$B7,$C9,$B8,$32,$95,$F4,$7E,$AE,$DD,$B9,$CE,
$E2,$49,$CF,$C8,$A1,$D2,$E1,$F8,$79,$88,$8B,$89,$57,$85,$38,$4C,$0B,$87,$E6,$50,
$A9,$FB,$5C,$E9,$B5,$11,$58,$F0,$70,$D2,$FF,$85,$62,$05,$F1,$F7,$22,$2E,$56,$17,
$C1,$F4,$71,$9B,$EA,$CF,$FB,$A0,$8F,$DD,$05,$C8,$0A,$6C,$12,$84,$34,$59,$72,$6E,
$8C,$1E,$B9,$AB,$27,$5D,$23,$07,$49,$21,$60,$21,$8B,$8C,$12,$16,$15,$2D,$5E,$20,
$28,$23,$4A,$1D,$00,$C3,$7E,$49,$BF,$2B,$34,$58,$3E,$4A,$6F,$FC,$2C,$59,$B1,$44,
$03,$B3,$FA,$26,$F3,$84,$05,$CF,$B4,$60,$3D,$C4,$C7,$59,$15,$36,$D3,$9A,$21,$11,
$0D,$F0,$B2,$BE,$4C,$03,$C7,$67,$A1,$70,$88,$1A,$31,$FD,$7C,$91,$D7,$FD,$DB,$58,
$7D,$B2,$58,$50,$00,$74,$1E,$9F,$F1,$97,$8E,$1D,$D6,$50,$04,$6D,$D5,$F2,$CF,$8B,
$F0,$93,$2A,$14,$50,$BF,$0F,$94,$B0,$A1,$42,$32,$02,$1E,$8B,$B6,$8D,$29,$A0,$B2,
$A3,$9D,$92,$6D,$DA,$4F,$DD,$94,$AD,$98,$86,$92,$C6,$41,$8F,$86,$70,$F5,$25,$14,
$0D,$2B,$FC,$0E,$11,$FD,$44,$F5,$FB,$7B,$2D,$08,$1D,$5A,$97,$56,$0C,$54,$64,$DA,
$61,$53,$6C,$73,$80,$1C,$52,$C2,$4A,$FE,$55,$C4,$1A,$8D,$D0,$95,$F7,$DF,$C1,$8F,
$5F,$46,$22,$27,$3D,$FD,$62,$B6,$ED,$A3,$DA,$08,$91,$62,$5D,$95,$AF,$80,$8B,$6B,
$75,$ED,$92,$57,$D7,$39,$7A,$77,$87,$81,$99,$BA,$82,$9E,$E2,$E7,$8C,$12,$BD,$38,
$EE,$22,$7C,$5D,$AE,$5C,$D4,$F7,$51,$4C,$BE,$EB,$24,$46,$57,$FD,$5B,$A2,$33,$37,
$E8,$15,$9B,$17,$F7,$FC,$02,$DF,$2D,$42,$A2,$BA,$AE,$DB,$9C,$74,$17,$6C,$A8,$B7,
$D2,$4B,$FB,$8D,$30,$80,$31,$F7,$F2,$B8,$F8,$3E,$F9,$C5,$C1,$62,$8F,$80,$45,$16,
$BC,$9D,$24,$86,$61,$78,$CB,$32,$EA,$8C,$EC,$9C,$FC,$97,$46,$AF,$0B,$C1,$6E,$30,
$B1,$EA,$47,$BE,$F3,$2D,$D7,$7B,$9E,$A0,$AA,$A1,$DE,$B4,$6B,$CA,$64,$5A,$08,$9E,
$79,$AB,$3B,$A8,$9B,$6E,$5D,$35,$74,$03,$36,$55,$2E,$40,$4D,$91,$19,$5A,$AE,$56,
$A3,$69,$A1,$5A,$8F,$96,$16,$34,$20,$82,$AC,$45,$6B,$E9,$46,$32,$7C,$8F,$22,$79,
$8B,$44,$D7,$C4,$6F,$A8,$09,$95,$24,$5F,$52,$97,$18,$E4,$D0,$5D,$23,$16,$CF,$95,
$98,$BD,$BB,$A2,$F4,$36,$EC,$BF,$08,$A4,$71,$9B,$6D,$08,$6A,$B9,$AA,$A2,$08,$D4,
$3F,$77,$1D,$0D,$6C,$A7,$B4,$6C,$B0,$D5,$AD,$C4,$BC,$01,$DF,$1D,$2C,$52,$3F,$EA,
$E4,$E1,$CD,$A5,$66,$95,$3E,$54,$2F,$1E,$EC,$8A,$B5,$BE,$0C,$C2,$A1,$0A,$2D,$46,
$3C,$B4,$CD,$4E,$17,$79,$D2,$17,$F6,$3E,$B2,$40,$69,$34,$DE,$CA,$A1,$B2,$E1,$7B,
$63,$80,$10,$B8,$CD,$77,$E8,$28,$FB,$95,$A3,$45,$9F,$96,$55,$95,$15,$C4,$C4,$A1,
$67,$AF,$C6,$A0,$E7,$C3,$8B,$60,$47,$34,$03,$07,$DB,$F0,$00,$5C,$7F,$F1,$92,$6B,
$50,$8D,$38,$94,$00,$CE,$D5,$55,$F7,$18,$E4,$63,$10,$17,$2F,$ED,$61,$83,$84,$84,
$A9,$C6,$9D,$F4,$8D,$4B,$AD,$9D,$E1,$9A,$DA,$5B,$3A,$8B,$51,$D4,$B7,$3B,$DC,$F7,
$0F,$2D,$D5,$76,$12,$CD,$AD,$A9,$FC,$9D,$4A,$74,$0B,$74,$5F,$34,$6C,$8A,$A0,$EB,
$11,$F8,$3A,$CD,$50,$63,$19,$53,$54,$C5,$1E,$AE,$F5,$6E,$79,$9F,$6F,$DA,$57,$54,
$B7,$11,$1C,$91,$E8,$6B,$CE,$CA,$54,$E3,$22,$1E,$0A,$F5,$CF,$29,$86,$7C,$C2,$01,
$35,$4F,$CE,$EC,$AC,$F2,$A1,$DA,$62,$37,$42,$03,$A9,$7B,$F7,$8A,$53,$C9,$58,$59,
$CB,$02,$2B,$92,$62,$51,$AB,$F1,$91,$41,$BA,$34,$A9,$F6,$91,$2F,$C2,$92,$00,$C1,
$00,$31,$F9,$85,$30,$31,$46,$8E,$5F,$55,$E0,$49,$12,$98,$55,$6D,$5A,$B6,$1C,$3C,
$A5,$6D,$2C,$98,$C0,$C1,$7B,$60,$AB,$7F,$CB,$A7,$4C,$BE,$9C,$24,$81,$00,$6B,$D9,
$0E,$B9,$A3,$F7,$2F,$F5,$AE,$84,$DE,$E3,$1A,$19,$48,$DF,$4F,$BE,$76,$95,$EB,$1D,
$F4,$0A,$E9,$92,$94,$96,$78,$64,$4E,$5D,$A7,$44,$2C,$1B,$82,$BB,$8A,$4A,$C2,$53,
$25,$0E,$B2,$61,$26,$0E,$4A,$6C,$AB,$E0,$A8,$B2,$C4,$A7,$80,$C3,$79,$32,$0B,$34,
$33,$0A,$8C,$B1,$45,$E8,$D2,$4E,$08,$A6,$F9,$95,$33,$2E,$37,$5A,$20,$F5,$6D,$9E,
$E1,$75,$E5,$6F,$02,$46,$81,$10,$E0,$B5,$55,$5E,$F0,$FE,$70,$81,$DD,$51,$A7,$8D,
$E9,$F4,$54,$57,$0A,$A0,$4C,$82,$5D,$48,$92,$EE,$D4,$C4,$AC,$56,$FB,$0E,$AF,$4D,
$7B,$ED,$C0,$BE,$2E,$5E,$76,$6C,$14,$95,$C6,$31,$DF,$D0,$D7,$26,$4C,$E0,$E9,$C3,
$EA,$83,$8D,$D5,$D2,$6C,$EC,$F7,$30,$DF,$72,$51,$EA,$D8,$06,$EF,$EE,$68,$52,$67,
$9D,$F9,$46,$44,$62,$68,$61,$75,$B9,$FE,$57,$E8,$E2,$1A,$93,$4E,$23,$A6,$E8,$80,
$6A,$5D,$17,$2D,$63,$7F,$A0,$2E,$C9,$DA,$19,$47,$BE,$26,$EC,$23,$B3,$09,$5E,$C7,
$99,$7E,$6A,$52,$C1,$3E,$56,$A1,$08,$CD,$7C,$4E,$67,$99,$72,$77,$C9,$04,$C6,$6D,
$AD,$3B,$E4,$41,$58,$69,$A1,$B6,$0E,$9D,$82,$6D,$8C,$FA,$E0,$DB,$18,$D2,$92,$C6,
$17,$95,$88,$46,$2A,$CA,$7F,$3B,$7F,$2B,$7E,$24,$60,$A8,$36,$6E,$67,$5A,$A4,$D5,
$3F,$7E,$E0,$B1,$BD,$E4,$56,$6C,$B8,$08,$AC,$3B,$72,$63,$AE,$CA,$40,$91,$D8,$6F,
$F7,$01,$05,$7F,$C6,$4F,$A4,$D9,$50,$BC,$5F,$51,$82,$43,$48,$86,$D5,$74,$BA,$B0,
$FB,$74,$CA,$A4,$EF,$03,$3D,$F6,$1D,$70,$2A,$64,$40,$87,$2C,$CD,$50,$7A,$EE,$81,
$C5,$85,$5D,$EC,$2B,$AE,$8E,$E1,$BB,$B6,$2C,$15,$51,$EC,$A5,$55,$2A,$00,$E8,$0A,
$9A,$40,$06,$C1,$39,$AB,$AE,$7F,$2B,$28,$2B,$4E,$5B,$47,$2D,$01,$71,$99,$7D,$F5,
$23,$4E,$F8,$6B,$C5,$45,$5E,$0B,$50,$A8,$DA,$98,$77,$F5,$25,$78,$9B,$CE,$57,$D0,
$32,$47,$A5,$BA,$47,$B3,$57,$81,$08,$2C,$85,$22,$5E,$35,$95,$55,$83,$18,$2B,$66,
$D6,$01,$62,$2D,$41,$D3,$84,$21,$17,$4C,$1F,$F9,$25,$5D,$91,$90,$E4,$15,$CC,$F7,
$5A,$A1,$5C,$AC,$14,$DC,$F7,$93,$4F,$61,$35,$42,$16,$5E,$E2,$8C,$E3,$1A,$33,$70,
$2E,$D4,$E0,$C5,$59,$7D,$80,$7C,$89,$C3,$F4,$22,$FE,$4A,$40,$D9,$55,$53,$7C,$D3,
$9F,$C0,$73,$53,$26,$B6,$17,$CC,$F5,$CD,$AF,$E3,$59,$8A,$41,$3E,$F6,$EB,$60,$90,
$8C,$5E,$D7,$C1,$34,$40,$45,$74,$4B,$78,$1D,$95,$FB,$83,$12,$D7,$01,$B1,$A0,$93,
$C0,$C4,$30,$6B,$F6,$05,$AD,$0B,$1E,$61,$0A,$D2,$C8,$F0,$29,$AA,$97,$27,$9A,$9E,
$2A,$7D,$89,$24,$13,$22,$DA,$27,$60,$9E,$57,$D4,$2A,$1B,$38,$13,$C0,$1D,$8B,$E6,
$ED,$3E,$41,$4B,$33,$3F,$17,$42,$74,$B6,$C1,$4F,$00,$53,$4F,$BB,$22,$3A,$EF,$6C,
$18,$75,$5D,$E0,$28,$58,$46,$4C,$34,$7F,$B2,$5D,$15,$61,$21,$B8,$1D,$4B,$D8,$3C,
$E1,$6F,$00,$6D,$AA,$69,$A0,$92,$9E,$FF,$4E,$9B,$75,$1C,$A9,$93,$A8,$64,$90,$30,
$B1,$62,$A7,$24,$49,$6A,$C8,$AB,$AD,$91,$92,$3C,$E9,$0A,$90,$11,$89,$3C,$6D,$5E,
$96,$D7,$AE,$5D,$79,$05,$EF,$0C,$7E,$54,$2E,$5E,$62,$B5,$DC,$14,$9E,$35,$B2,$C0,
$89,$46,$35,$16,$EC,$E4,$77,$29,$EB,$88,$BC,$55,$5D,$56,$77,$22,$7D,$A6,$83,$0F,
$0F,$E4,$BB,$DF,$B6,$21,$6D,$C8,$8D,$ED,$45,$56,$B0,$3E,$4B,$76,$34,$7A,$52,$68,
$3D,$FE,$F5,$1F,$FA,$42,$9A,$0D,$0F,$D2,$A3,$1B,$11,$FA,$81,$DA,$14,$83,$BB,$2E,
$94,$1E,$B0,$F4,$68,$15,$67,$92,$3E,$54,$01,$C0,$E1,$EF,$5F,$66,$2C,$36,$71,$F8,
$15,$A9,$17,$C9,$11,$57,$1E,$D1,$DA,$39,$C7,$77,$1F,$2A,$DA,$F7,$31,$C3,$07,$88,
$FD,$65,$9F,$91,$0B,$C0,$FE,$BB,$8F,$C4,$B5,$07,$29,$39,$DF,$55,$D7,$5A,$73,$F0,
$5B,$BB,$0F,$28,$87,$06,$98,$C9,$91,$62,$4A,$1D,$22,$2F,$58,$AD,$B8,$2E,$67,$82,
$60,$C4,$E0,$F5,$9D,$C6,$6B,$40,$C4,$A7,$34,$C1,$AA,$D4,$93,$30,$D1,$95,$13,$5C,
$6D,$B5,$AE,$8A,$DA,$0A,$1A,$C3,$39,$50,$27,$34,$1B,$28,$5E,$77,$EB,$E1,$BC,$ED,
$6E,$48,$8A,$DE,$A4,$01,$F6,$F8,$3D,$7A,$06,$43,$16,$55,$ED,$52,$FA,$3A,$6E,$A0,
$76,$4C,$2E,$64,$BB,$E9,$39,$83,$66,$96,$6D,$30,$FB,$91,$71,$AE,$AF,$E6,$BB,$F9,
$1C,$30,$D0,$C7,$71,$6E,$22,$B6,$AA,$64,$A9,$2B,$E6,$9E,$30,$B2,$AC,$11,$25,$95,
$7F,$4B,$30,$6E,$DB,$F1,$11,$88,$7E,$A4,$44,$03,$98,$9A,$24,$18,$3D,$98,$C8,$05,
$8E,$84,$32,$B8,$64,$31,$FF,$3D,$71,$5C,$EE,$1E,$8C,$79,$EE,$AA,$C0,$AB,$E9,$C2,
$B8,$EA,$85,$F9,$E0,$B6,$4F,$DB,$17,$87,$27,$26,$22,$2E,$51,$6F,$B7,$44,$F5,$8D,
$DD,$AB,$DA,$A8,$E9,$CC,$E7,$C1,$D2,$CC,$30,$C1,$1B,$04,$77,$F8,$F7,$03,$4B,$23,
$14,$9A,$F5,$95,$9B,$A1,$6B,$00,$A4,$3F,$58,$7F,$23,$14,$96,$5F,$93,$65,$28,$30,
$60,$B0,$65,$1E,$45,$81,$52,$A9,$D8,$A4,$BD,$A9,$27,$4D,$08,$05,$66,$05,$83,$37,
$61,$F1,$ED,$A6,$FB,$B8,$0B,$2E,$DE,$8F,$49,$65,$5C,$5D,$38,$54,$6B,$2A,$2B,$E1,
$6D,$DB,$09,$AB,$24,$C3,$F8,$A8,$EF,$0E,$B8,$CA,$14,$79,$E0,$D1,$DA,$D5,$51,$39,
$FC,$27,$38,$94,$A2,$20,$0F,$02,$90,$B9,$65,$3F,$F9,$D1,$5F,$5F,$AF,$0A,$F2,$4E,
$C8,$C7,$65,$EE,$FD,$5A,$1D,$29,$0D,$DB,$D5,$87,$52,$15,$98,$A2,$F0,$16,$F7,$EA,
$B8,$75,$DF,$3A,$A0,$E6,$E5,$D5,$EF,$52,$95,$B9,$8C,$C7,$69,$0E,$3E,$56,$95,$D1,
$AF,$55,$FF,$4A,$3C,$38,$13,$B8,$BF,$20,$BC,$21,$23,$A7,$3A,$45,$7C,$9E,$05,$D6,
$84,$66,$2E,$E1,$6E,$68,$CD,$F9,$23,$31,$CF,$89,$05,$2D,$8A,$94,$B1,$7C,$13,$93,
$35,$9F,$7E,$B8,$2E,$39,$C9,$B4,$27,$10,$87,$6A,$67,$BD,$BA,$0B,$8F,$DA,$F7,$6C,
$C4,$C8,$FF,$2A,$96,$47,$9D,$DA,$17,$2C,$F7,$E3,$F2,$4B,$92,$E5,$3E,$52,$EF,$7C,
$FB,$E6,$46,$04,$9C,$D6,$9A,$03,$8F,$02,$5D,$82,$FC,$AD,$07,$03,$52,$74,$71,$3C,
$8C,$A1,$B8,$9B,$67,$39,$1D,$78,$27,$FD,$2D,$28,$6D,$AF,$01,$DE,$12,$08,$23,$16,
$EE,$42,$3F,$6D,$8B,$20,$1C,$4C,$58,$45,$BF,$49,$50,$E6,$FB,$A2,$12,$C5,$8E,$69,
$70,$14,$55,$1F,$05,$33,$B3,$7E,$F7,$C4,$64,$E4,$3D,$95,$BC,$B5,$69,$36,$D0,$6C,
$57,$04,$D7,$44,$AA,$7E,$63,$14,$FE,$52,$2E,$9F,$FF,$B7,$04,$DF,$51,$92,$53,$93,
$1E,$BC,$11,$13,$DF,$77,$CD,$4E,$95,$7C,$ED,$D4,$51,$FF,$8E,$69,$93,$4E,$DE,$3D,
$ED,$5A,$4F,$C1,$C2,$B7,$F5,$8C,$C2,$33,$47,$E1,$3E,$90,$D1,$4F,$A1,$91,$9E,$6B,
$93,$A2,$C8,$FB,$A2,$BA,$68,$35,$61,$3B,$5C,$02,$E4,$10,$4A,$69,$26,$48,$C3,$1C,
$28,$8E,$CD,$C8,$56,$FA,$61,$D8,$9D,$68,$37,$49,$BB,$EB,$15,$E0,$3C,$B4,$C2,$7D,
$F1,$D5,$0A,$5A,$02,$52,$A8,$97,$F5,$BD,$3E,$BA,$C9,$8C,$1E,$B1,$E9,$96,$FB,$B7,
$37,$1C,$8E,$86,$51,$2B,$E4,$5D,$19,$75,$22,$D8,$AB,$B2,$63,$AA,$B4,$AC,$80,$99,
$9F,$33,$0E,$95,$28,$B6,$49,$7B,$54,$62,$80,$01,$28,$B0,$1A,$13,$6F,$B3,$6B,$28,
$D3,$90,$4E,$E5,$87,$7F,$B3,$EE,$AA,$C1,$1E,$4C,$14,$61,$E8,$1C,$BC,$E0,$6A,$10,
$D4,$07,$EA,$C0,$D9,$B9,$5E,$10,$A6,$36,$CF,$82,$15,$C5,$EA,$C3,$71,$45,$89,$85,
$CE,$62,$A2,$EB,$71,$87,$31,$E9,$F5,$6D,$8B,$52,$00,$7B,$8E,$72,$97,$C9,$58,$17,
$57,$28,$03,$90,$BD,$98,$C3,$40,$08,$48,$47,$1C,$4E,$30,$C0,$02,$14,$FB,$CF,$BF,
$30,$29,$5E,$B5,$98,$47,$4C,$8A,$A3,$71,$39,$2A,$8D,$AE,$13,$14,$10,$BE,$9E,$6D,
$62,$AD,$D0,$2E,$2A,$7F,$66,$47,$D2,$3F,$A3,$07,$75,$85,$3F,$48,$FE,$CC,$93,$C3,
$32,$DA,$6B,$E5,$35,$42,$8D,$CA,$EF,$8D,$B4,$0C,$87,$9D,$72,$EC,$6E,$2D,$64,$B7,
$03,$9B,$C8,$0C,$AC,$54,$7A,$DF,$09,$75,$0A,$46,$B8,$16,$A7,$C0,$51,$98,$A2,$4F,
$88,$36,$61,$0A,$CA,$56,$F6,$27,$B3,$C6,$28,$77,$CA,$22,$A1,$EA,$4C,$B9,$1D,$5E,
$B3,$8F,$BA,$B1,$44,$47,$B6,$92,$D2,$72,$03,$47,$0A,$4B,$6C,$01,$7B,$E4,$D5,$1D,
$B1,$AC,$48,$76,$EC,$B8,$36,$13,$21,$CF,$7F,$0D,$51,$1D,$94,$34,$C3,$48,$C0,$66,
$C5,$DA,$95,$FD,$10,$14,$F5,$6D,$E1,$97,$D5,$A3,$91,$EE,$E2,$53,$DC,$CB,$36,$90,
$7E,$37,$ED,$5F,$62,$42,$A8,$A1,$2A,$C5,$BB,$2E,$A3,$29,$86,$82,$CF,$77,$E9,$DA,
$FB,$3E,$11,$9F,$A1,$0F,$BE,$30,$D6,$0E,$82,$DA,$93,$FC,$9A,$87,$55,$E6,$5D,$A4,
$31,$F4,$8A,$65,$EE,$E3,$90,$DB,$2E,$A3,$62,$3A,$AC,$19,$D3,$0B,$82,$78,$15,$A5,
$58,$FE,$0E,$57,$68,$F4,$14,$5D,$48,$99,$C0,$9D,$75,$E9,$44,$5B,$09,$25,$10,$E3,
$3C,$04,$4F,$29,$A0,$19,$9F,$E6,$39,$2F,$BE,$5C,$5A,$97,$2B,$E4,$6C,$FF,$7A,$47,
$74,$1D,$1B,$BD,$AA,$B4,$35,$5E,$BF,$72,$98,$55,$7E,$56,$A0,$56,$37,$77,$4C,$43,
$46,$EC,$70,$8C,$F7,$EB,$BA,$0B,$35,$AC,$E0,$83,$21,$77,$23,$28,$0B,$8B,$8C,$A3,
$A4,$0A,$00,$50,$44,$E5,$A2,$AF,$1C,$50,$10,$90,$91,$A3,$E1,$56,$3D,$DC,$1D,$11,
$B8,$49,$D4,$B8,$0A,$F7,$22,$98,$55,$40,$ED,$EA,$70,$60,$18,$56,$2B,$39,$B6,$62,
$39,$4C,$FF,$4B,$0A,$70,$09,$7F,$42,$F6,$53,$82,$68,$DA,$39,$A8,$1C,$A9,$0A,$B8,
$CF,$81,$7B,$B4,$C9,$95,$A3,$D2,$3F,$29,$F0,$82,$8A,$A0,$FA,$77,$59,$3D,$49,$34,
$40,$58,$27,$5E,$ED,$A5,$DD,$93,$E9,$08,$A9,$18,$9D,$E6,$14,$4B,$A1,$4B,$19,$70,
$70,$DA,$87,$BD,$C7,$32,$4E,$20,$35,$DB,$77,$91,$1F,$B9,$E2,$B6,$1D,$B0,$95,$BD,
$29,$2B,$79,$18,$20,$3B,$A1,$CA,$92,$30,$C0,$A0,$45,$0D,$5C,$1E,$97,$AC,$B2,$E4,
$4F,$57,$F6,$78,$92,$C0,$C6,$72,$BE,$71,$75,$FF,$8C,$57,$0E,$58,$55,$73,$7D,$07,
$62,$BC,$A7,$6C,$D6,$65,$92,$1C,$4E,$18,$94,$50,$61,$1E,$97,$30,$AB,$73,$D1,$31,
$C8,$1B,$D6,$92,$C0,$3E,$DE,$32,$D4,$C2,$BC,$19,$0F,$BE,$34,$91,$20,$EB,$7E,$4B,
$4B,$3B,$5F,$B0,$64,$06,$EB,$81,$FA,$5E,$A2,$10,$5F,$7C,$F1,$57,$2B,$56,$A8,$39,
$DC,$53,$66,$55,$D3,$A7,$95,$9B,$C4,$01,$05,$A7,$61,$A0,$E6,$06,$9B,$94,$96,$84,
$17,$F7,$EC,$85,$C4,$E9,$69,$6C,$31,$49,$AB,$3E,$55,$60,$BB,$DA,$2C,$69,$51,$EE,
$46,$6E,$EF,$BE,$DC,$E0,$C6,$5A,$F0,$22,$74,$4B,$B7,$6A,$2A,$5C,$11,$73,$BC,$51,
$88,$5A,$42,$82,$CA,$CD,$9B,$8B,$74,$68,$3A,$6A,$1C,$9E,$04,$55,$E7,$1E,$5B,$DA,
$A4,$40,$65,$82,$6B,$AA,$D6,$C1,$86,$35,$FB,$95,$29,$03,$58,$06,$9A,$32,$84,$B0,
$1B,$A0,$EC,$8C,$23,$E2,$36,$A9,$C5,$C0,$29,$0A,$37,$03,$0B,$E9,$3E,$79,$29,$38,
$B5,$06,$33,$A1,$89,$59,$05,$53,$44,$12,$01,$E2,$80,$4E,$10,$DB,$BD,$F2,$4D,$8A,
$EC,$A1,$FF,$F6,$D1,$36,$EA,$0B,$FA,$AA,$38,$42,$99,$C4,$92,$45,$E5,$A9,$08,$C6,
$EA,$2C,$B1,$06,$B7,$A0,$22,$62,$F6,$16,$9D,$1C,$12,$1C,$53,$84,$3F,$78,$97,$C9,
$4A,$B1,$A8,$AE,$86,$32,$5D,$06,$34,$27,$54,$89,$7A,$44,$C9,$2E,$6A,$BD,$30,$51,
$C9,$A2,$08,$AC,$4D,$EE,$2E,$88,$56,$93,$A2,$52,$41,$51,$DD,$0D,$A8,$01,$64,$D9,
$43,$1B,$40,$11,$3F,$B1,$A2,$33,$B9,$BD,$E1,$57,$1C,$B6,$16,$A7,$38,$34,$6E,$25,
$3E,$5D,$27,$6A,$A9,$4F,$6A,$8A,$90,$1F,$95,$0B,$63,$A8,$AB,$46,$BF,$12,$45,$E6,
$DF,$B2,$AB,$C8,$67,$7F,$4E,$A4,$FF,$4A,$05,$65,$14,$0D,$0E,$D1,$A8,$F1,$CC,$0A,
$0C,$17,$64,$26,$34,$4C,$5D,$44,$84,$D5,$E8,$03,$C1,$C4,$7C,$C1,$3E,$ED,$57,$70,
$49,$DD,$03,$EC,$D5,$0D,$F6,$53,$15,$B3,$B8,$B1,$95,$FC,$7B,$45,$C0,$EC,$A7,$8A,
$E5,$CD,$1D,$C9,$95,$DA,$88,$5D,$C1,$6E,$22,$16,$84,$EB,$B7,$76,$C1,$C2,$AB,$E3,
$F8,$D3,$11,$B2,$5E,$21,$B8,$A7,$3E,$BE,$F7,$98,$52,$07,$00,$53,$94,$12,$00,$4F,
$B7,$74,$2E,$4E,$49,$98,$C1,$7D,$F7,$83,$59,$C6,$EE,$B5,$A3,$1D,$D8,$1F,$16,$CA,
$28,$81,$7D,$BE,$26,$16,$31,$38,$7D,$7E,$FF,$9D,$FD,$7C,$16,$40,$FD,$6A,$9A,$0E,
$EA,$2F,$E2,$15,$2E,$48,$2C,$0F,$FD,$06,$6D,$CE,$16,$F1,$9A,$BF,$A0,$CA,$6C,$7B,
$0D,$D0,$06,$2C,$6D,$89,$C8,$E7,$EA,$EF,$82,$59,$C5,$53,$99,$EB,$C3,$17,$2E,$9C,
$8C,$CE,$A3,$16,$2D,$BD,$F9,$DC,$EF,$5B,$49,$4E,$73,$59,$40,$F5,$AF,$CA,$30,$CC,
$74,$D9,$51,$FD,$C1,$30,$8D,$21,$35,$7C,$D0,$7D,$AE,$B7,$F7,$25,$1A,$2E,$6E,$94,
$02,$21,$A6,$AA,$34,$07,$95,$D1,$81,$12,$AB,$71,$AD,$76,$24,$C1,$32,$8E,$F1,$33,
$60,$F0,$87,$7A,$C7,$B5,$51,$3D,$78,$40,$0A,$46,$1F,$5F,$58,$97,$AF,$AD,$5D,$BB,
$D0,$48,$A9,$0B,$FC,$46,$12,$BC,$D1,$09,$F7,$89,$3C,$08,$86,$62,$5D,$B3,$31,$1D,
$C5,$F7,$CE,$57,$92,$5A,$CA,$4B,$94,$DF,$C5,$C8,$D5,$69,$CD,$61,$21,$01,$4F,$3D,
$76,$25,$70,$37,$33,$BA,$2E,$31,$AD,$4A,$30,$64,$08,$C7,$F1,$A3,$46,$11,$29,$E1,
$FA,$77,$8A,$B3,$94,$BB,$B5,$19,$18,$8F,$2C,$92,$1E,$2E,$14,$05,$9B,$34,$1E,$92,
$24,$F2,$51,$81,$FA,$E3,$15,$09,$68,$38,$75,$53,$10,$02,$80,$37,$F3,$F1,$B2,$CC,
$5F,$61,$A8,$DA,$AF,$DB,$4D,$39,$57,$53,$2C,$2F,$6B,$BA,$37,$C1,$62,$35,$F6,$A6,
$9B,$69,$94,$C6,$B5,$55,$5C,$6B,$F7,$E7,$DD,$BD,$2A,$CB,$8C,$1A,$B5,$83,$5E,$1D,
$89,$12,$67,$F9,$4C,$7F,$B7,$19,$A9,$FE,$2B,$19,$A0,$D8,$64,$8F,$73,$2D,$13,$39,
$94,$85,$54,$8A,$95,$F1,$1C,$1F,$1C,$F3,$D7,$FE,$D6,$68,$87,$6F,$28,$0D,$43,$0E,
$C3,$8A,$B8,$83,$6B,$1F,$5D,$E2,$5C,$3B,$11,$38,$B8,$73,$A8,$B1,$49,$21,$D8,$38,
$2D,$AA,$90,$24,$24,$09,$28,$CD,$13,$C0,$9D,$14,$00,$31,$0C,$3F,$D0,$57,$73,$5C,
$D5,$3C,$40,$78,$56,$31,$2E,$08,$DA,$E2,$32,$6E,$7F,$00,$92,$24,$C7,$9B,$14,$97,
$9E,$8E,$3A,$86,$72,$30,$3F,$DF,$C8,$DB,$06,$AA,$36,$AE,$43,$2B,$5F,$85,$6E,$07,
$84,$A7,$32,$DC,$53,$76,$52,$F1,$D4,$71,$2E,$17,$46,$4F,$D8,$D4,$19,$11,$A7,$C5,
$9F,$9B,$FC,$24,$A4,$0A,$29,$67,$65,$48,$30,$91,$B4,$2B,$8A,$19,$D7,$E5,$60,$7F,
$1B,$BF,$F9,$72,$D4,$32,$A8,$03,$0B,$C8,$FC,$99,$4C,$2A,$74,$63,$E0,$F7,$00,$C4,
$87,$21,$77,$A4,$D0,$79,$BD,$D0,$8A,$C9,$3D,$4F,$6C,$C5,$C1,$DD,$95,$0C,$0E,$AE,
$A4,$96,$A1,$6F,$58,$50,$6D,$54,$DC,$B8,$68,$C8,$7D,$C5,$51,$F7,$3C,$5D,$D1,$B6,
$45,$51,$F3,$97,$02,$BB,$72,$4F,$0D,$00,$6B,$CE,$37,$7B,$6C,$C3,$75,$E9,$D5,$65,
$6F,$11,$0C,$5C,$CE,$2C,$A2,$6B,$6E,$64,$E0,$03,$A8,$78,$5E,$50,$4A,$E5,$94,$DE,
$30,$A6,$B2,$3A,$D0,$86,$21,$33,$75,$60,$A6,$C4,$B6,$21,$C5,$EB,$DC,$97,$95,$07,
$F6,$26,$22,$1E,$A5,$C0,$CD,$94,$56,$8E,$69,$B5,$86,$C7,$57,$35,$6A,$9F,$AB,$56,
$86,$84,$C8,$7E,$03,$C7,$30,$57,$A9,$71,$58,$F8,$39,$1B,$E0,$85,$3A,$62,$9B,$EC,
$A5,$7B,$87,$41,$56,$5E,$12,$0C,$5D,$16,$D0,$15,$B3,$FF,$45,$70,$D9,$B6,$75,$1F,
$33,$E7,$14,$58,$FA,$1E,$2A,$E4,$E0,$DF,$85,$49,$73,$1B,$3D,$3B,$3E,$18,$E3,$92,
$A4,$04,$5C,$F5,$E2,$FB,$8B,$ED,$89,$4B,$F4,$6A,$CE,$8A,$33,$F6,$40,$C6,$6A,$89,
$6F,$71,$24,$29,$C7,$5D,$A0,$31,$03,$14,$19,$04,$E6,$2F,$2D,$26,$63,$90,$64,$58,
$0E,$EC,$2A,$6F,$52,$61,$33,$40,$0B,$3D,$BA,$46,$F0,$64,$51,$44,$F1,$4C,$0E,$0C,
$B3,$54,$45,$12,$90,$B3,$D4,$C4,$80,$76,$BE,$A9,$19,$84,$E8,$3D,$88,$CD,$BA,$A3,
$0D,$1E,$53,$68,$DF,$FB,$D4,$55,$16,$75,$1F,$F4,$31,$9B,$6E,$3E,$6A,$05,$06,$E7,
$44,$85,$83,$AA,$00,$8D,$72,$95,$58,$EC,$89,$62,$AD,$8C,$6E,$C1,$F0,$4B,$76,$C7,
$91,$53,$39,$9A,$DF,$28,$AC,$D3,$96,$60,$42,$E0,$60,$DC,$0B,$A1,$B1,$8E,$F9,$BF,
$63,$22,$CD,$CB,$62,$35,$EC,$EE,$D5,$25,$23,$BB,$27,$E2,$34,$B6,$3A,$AF,$CC,$23,
$D8,$24,$EF,$2A,$2D,$1F,$3E,$DD,$4F,$C4,$B0,$DE,$6B,$67,$1F,$9B,$F4,$7D,$AB,$A0,
$0B,$57,$68,$B0,$D7,$0F,$BE,$42,$02,$48,$0E,$58,$96,$16,$A6,$22,$A9,$B8,$FD,$60,
$D5,$65,$B6,$00,$7D,$5E,$DD,$04,$73,$89,$F4,$4B,$38,$1E,$4A,$5E,$DD,$46,$FC,$4D,
$25,$F7,$8A,$D2,$57,$99,$75,$A0,$46,$8B,$7C,$75,$16,$EF,$3D,$13,$EE,$BA,$AC,$CC,
$98,$D6,$63,$D0,$A1,$D9,$D1,$4C,$34,$1E,$88,$F7,$08,$F0,$92,$04,$CF,$A4,$61,$03,
$81,$11,$88,$81,$A4,$11,$E8,$0A,$10,$8B,$D4,$AB,$40,$E5,$2A,$7D,$AF,$D5,$2C,$0B,
$2C,$00,$E9,$3A,$2C,$4A,$9F,$69,$A2,$AA,$27,$67,$39,$4F,$79,$18,$AC,$5F,$BD,$C3,
$4C,$20,$35,$90,$B8,$6F,$52,$32,$6B,$4B,$D2,$32,$E4,$AB,$4C,$53,$27,$05,$7B,$B5,
$A3,$33,$59,$1A,$E9,$D5,$1A,$6A,$A6,$D2,$4F,$80,$5C,$10,$9D,$D8,$65,$44,$11,$BD,
$29,$77,$FD,$89,$9E,$B2,$A5,$EE,$57,$02,$90,$1E,$89,$56,$AB,$7F,$A9,$79,$F1,$33,
$54,$8B,$B9,$16,$4B,$55,$E8,$96,$E0,$FB,$DD,$0A,$DD,$61,$06,$89,$30,$F9,$CB,$D6,
$B9,$51,$E7,$7F,$EB,$BF,$6A,$7E,$0D,$93,$AF,$A9,$CF,$FB,$82,$DD,$CF,$29,$DB,$1F,
$2D,$95,$FE,$8B,$D7,$CA,$24,$49,$5F,$64,$D0,$A6,$C3,$49,$7E,$6B,$15,$05,$9B,$88,
$96,$60,$58,$EE,$C2,$60,$E2,$70,$E0,$6C,$01,$57,$90,$B6,$40,$B2,$50,$8E,$BF,$6C,
$1F,$9F,$19,$82,$DF,$32,$0B,$B0,$EE,$BE,$3B,$66,$2F,$0A,$D8,$EE,$A3,$58,$14,$ED,
$46,$61,$B5,$31,$CB,$07,$59,$17,$B0,$F9,$80,$FD,$AF,$0E,$32,$34,$A2,$05,$57,$5E,
$8E,$59,$D3,$92,$ED,$11,$03,$95,$D9,$69,$56,$0C,$54,$76,$C7,$40,$CA,$62,$E5,$75,
$58,$23,$96,$C3,$11,$64,$A1,$11,$AC,$A4,$E9,$CE,$A9,$9C,$BA,$9D,$A6,$3D,$1E,$CF,
$62,$0D,$8A,$41,$AA,$81,$A7,$DF,$48,$0B,$E5,$1D,$E2,$2C,$27,$86,$2F,$BB,$2B,$59,
$D4,$19,$42,$9D,$A5,$5A,$F8,$7E,$0C,$56,$03,$EB,$BA,$04,$DE,$F7,$F4,$0E,$D6,$88,
$F6,$0B,$B0,$5F,$B0,$2A,$64,$09,$76,$E4,$CD,$32,$28,$30,$B1,$5A,$58,$D9,$76,$70,
$FE,$B0,$80,$F9,$37,$FC,$C2,$50,$40,$37,$66,$A8,$7F,$43,$18,$1D,$76,$11,$4E,$CC,
$B3,$A4,$FF,$C2,$FA,$63,$40,$6A,$2C,$5B,$0B,$A8,$C1,$EA,$64,$D1,$67,$83,$34,$02,
$D0,$1A,$C8,$94,$02,$DE,$E6,$EB,$62,$F0,$FE,$20,$81,$61,$CA,$D3,$F0,$14,$67,$86,
$C9,$60,$98,$29,$83,$B6,$D8,$1C,$E1,$61,$FD,$50,$CB,$57,$BF,$6C,$FF,$00,$95,$55,
$18,$3C,$4F,$87,$A1,$16,$CA,$F2,$CF,$BE,$80,$B6,$BC,$B8,$EC,$7A,$BC,$CD,$4F,$E9,
$9C,$88,$09,$0D,$93,$41,$21,$53,$2F,$C4,$D7,$90,$DA,$FB,$E6,$81,$A4,$BF,$45,$62,
$9E,$8B,$CA,$3E,$16,$1C,$46,$7A,$0F,$53,$FD,$F6,$B1,$94,$FC,$4C,$19,$FE,$28,$D2,
$52,$24,$EC,$D8,$35,$EE,$B8,$72,$B3,$24,$14,$89,$20,$03,$4A,$05,$59,$20,$52,$1E,
$8B,$C0,$FD,$ED,$94,$83,$FD,$0A,$FC,$5A,$62,$C4,$28,$FC,$E2,$99,$57,$2A,$EE,$AC,
$26,$56,$54,$89,$95,$AB,$FF,$25,$FC,$D8,$E0,$EA,$86,$16,$02,$7D,$0E,$5C,$BC,$9F,
$AB,$62,$63,$69,$71,$40,$9B,$13,$EF,$FB,$EC,$BC,$F6,$2C,$75,$A7,$CF,$A6,$BB,$67,
$81,$B4,$BF,$AB,$F2,$30,$B3,$C0,$03,$F4,$DD,$2D,$4D,$C5,$58,$76,$5F,$F9,$88,$F9,
$C0,$5D,$E9,$42,$62,$51,$30,$26,$99,$56,$97,$AD,$16,$77,$5B,$F0,$0D,$D8,$33,$06,
$A7,$5F,$15,$97,$20,$D0,$7F,$C3,$28,$C6,$95,$F2,$52,$C5,$36,$14,$35,$68,$88,$06,
$6F,$A9,$40,$21,$52,$06,$69,$19,$39,$06,$73,$DC,$AE,$8E,$C0,$6D,$30,$26,$F9,$8D,
$DE,$02,$19,$58,$22,$3A,$7B,$0D,$FF,$09,$3F,$44,$31,$D8,$6D,$F9,$82,$BE,$F9,$24,
$11,$77,$32,$51,$11,$98,$FB,$FE,$0A,$1D,$46,$C6,$3D,$5A,$01,$F9,$1A,$46,$F9,$EF,
$04,$0E,$5F,$AD,$69,$83,$07,$E8,$0D,$38,$55,$F9,$69,$2E,$54,$77,$EA,$0D,$AC,$2C,
$D1,$AF,$65,$A8,$40,$F4,$7C,$EC,$4A,$AA,$D4,$17,$1C,$D0,$09,$CF,$C2,$D8,$AA,$0E,
$CA,$92,$C0,$D9,$8A,$25,$5B,$9E,$7A,$C3,$2D,$CA,$60,$4C,$A3,$B7,$0C,$1D,$F7,$E9,
$51,$A0,$66,$5D,$27,$24,$83,$41,$4C,$FE,$2F,$B3,$56,$14,$B9,$55,$8B,$DD,$F7,$1E,
$19,$86,$2F,$80,$7B,$A1,$06,$3F,$02,$EB,$94,$94,$57,$68,$82,$5C,$C2,$3E,$3B,$CF,
$D4,$74,$DF,$25,$A1,$08,$16,$E9,$74,$14,$43,$C3,$E1,$7B,$79,$17,$48,$3E,$54,$B0,
$30,$61,$15,$3C,$C3,$3C,$97,$F0,$5D,$B8,$A0,$2B,$65,$27,$71,$48,$E0,$77,$75,$86,
$0A,$4D,$91,$A8,$E2,$46,$63,$11,$82,$A3,$D1,$0A,$89,$19,$34,$04,$F0,$54,$82,$B9,
$7F,$FF,$C2,$22,$E2,$40,$25,$C9,$57,$A5,$F4,$34,$77,$B0,$A4,$57,$A8,$90,$05,$08,
$E0,$05,$FA,$60,$CE,$83,$5E,$8D,$88,$D4,$D6,$17,$C2,$20,$BF,$35,$71,$46,$18,$EB,
$BB,$4F,$FD,$2F,$64,$5B,$E0,$31,$1A,$2C,$71,$8B,$73,$D3,$86,$07,$12,$16,$7A,$63,
$D5,$BA,$8E,$8A,$B0,$5B,$96,$10,$AF,$30,$9C,$2F,$03,$60,$CB,$90,$F5,$F1,$C7,$4B,
$3B,$9A,$F4,$AB,$71,$AE,$E0,$1A,$0C,$5B,$8A,$83,$E4,$05,$E7,$3D,$22,$FA,$B7,$3E,
$EF,$40,$06,$EA,$46,$87,$6C,$3A,$AF,$03,$57,$FD,$3C,$C3,$DD,$44,$28,$C6,$13,$17,
$42,$69,$FF,$58,$B7,$B2,$D7,$D9,$C1,$10,$A4,$BA,$B4,$29,$38,$D9,$48,$7F,$45,$64,
$78,$81,$1D,$4B,$B9,$A4,$AA,$91,$D4,$14,$41,$20,$D5,$69,$90,$64,$18,$48,$90,$D9,
$8C,$5B,$D8,$AB,$31,$C4,$C8,$84,$01,$CA,$74,$F4,$B9,$90,$02,$E5,$D6,$66,$8D,$A5,
$C2,$BD,$6E,$6B,$75,$23,$76,$54,$38,$F9,$D7,$86,$C8,$32,$C0,$FE,$6F,$3D,$E0,$1B,
$CB,$54,$3A,$30,$F1,$4D,$54,$8C,$ED,$D8,$C3,$AE,$00,$31,$AF,$A7,$AC,$6B,$41,$81,
$8C,$64,$91,$7D,$F5,$F1,$76,$6D,$ED,$5B,$17,$9C,$2B,$03,$62,$78,$01,$83,$E0,$61,
$AA,$FD,$2D,$93,$E4,$31,$FC,$FE,$17,$41,$47,$10,$A4,$5B,$55,$7B,$86,$60,$7B,$43,
$1B,$0D,$CA,$AF,$BE,$45,$1F,$A1,$5B,$CF,$9C,$4F,$A4,$FB,$C0,$80,$CF,$28,$A8,$72,
$EE,$B5,$BA,$AA,$A1,$98,$D4,$A4,$BF,$F1,$51,$2C,$E7,$48,$D0,$AA,$28,$54,$45,$6A,
$B0,$A4,$5E,$0F,$D5,$11,$02,$E1,$4E,$DE,$30,$07,$69,$63,$9F,$74,$05,$92,$B7,$3B,
$CD,$57,$8E,$CC,$04,$40,$38,$54,$F7,$4D,$4E,$76,$0B,$81,$CF,$EF,$D6,$DD,$B4,$2E,
$3F,$06,$88,$34,$2A,$68,$03,$67,$AB,$DC,$E8,$DB,$F4,$DD,$93,$C2,$C5,$63,$61,$A5,
$97,$BB,$31,$D0,$C4,$2A,$86,$49,$BB,$56,$83,$2B,$F6,$EE,$96,$15,$A4,$CA,$CF,$B9,
$44,$53,$C3,$BF,$A7,$8D,$8D,$CD,$68,$4A,$CC,$62,$51,$02,$B9,$7B,$AF,$4F,$39,$73,
$D6,$14,$95,$98,$73,$0C,$67,$DD,$88,$0F,$BF,$D2,$63,$A1,$81,$9E,$AF,$AE,$54,$76,
$DC,$56,$0A,$77,$E3,$34,$E3,$80,$DD,$64,$66,$ED,$62,$3C,$2C,$06,$DA,$35,$A0,$78,
$30,$62,$54,$51,$65,$20,$0F,$4D,$56,$41,$89,$6D,$F4,$BE,$A3,$94,$31,$E5,$A8,$C0,
$80,$7C,$A3,$78,$55,$A2,$5E,$1F,$BD,$4F,$C4,$96,$DD,$69,$E8,$18,$F9,$B4,$A6,$38,
$0A,$8F,$C3,$30,$5D,$D8,$B8,$E8,$28,$98,$60,$C4,$7D,$6F,$5B,$67,$E2,$99,$87,$C6,
$80,$D2,$90,$11,$73,$B3,$06,$13,$52,$90,$5D,$04,$1F,$8D,$00,$D4,$C0,$4C,$39,$2E,
$0B,$B2,$21,$18,$22,$C1,$98,$05,$40,$04,$26,$60,$29,$BC,$F0,$31,$16,$47,$DF,$EF,
$1C,$1B,$A0,$B7,$00,$2D,$46,$96,$22,$3B,$E4,$E8,$1E,$99,$D1,$35,$20,$8F,$47,$23,
$0C,$E1,$57,$15,$43,$03,$97,$A1,$FC,$3C,$A6,$64,$21,$0E,$58,$CA,$82,$1B,$A4,$BB,
$88,$9A,$BE,$D3,$49,$3C,$1A,$5C,$B7,$8E,$1A,$5E,$1D,$52,$74,$B1,$B8,$61,$77,$2A,
$EB,$FE,$49,$14,$D6,$52,$34,$D1,$A9,$61,$1F,$68,$13,$D8,$D1,$32,$68,$89,$00,$B0,
$07,$A2,$53,$FC,$2D,$7F,$3A,$01,$C4,$93,$8D,$90,$2A,$17,$6B,$0D,$26,$3E,$56,$AD,
$9A,$91,$85,$18,$FC,$46,$B0,$06,$42,$4D,$19,$21,$86,$83,$4D,$65,$02,$A5,$97,$05,
$DB,$34,$54,$5F,$06,$90,$FB,$79,$D9,$72,$16,$E5,$84,$C3,$8B,$8F,$1B,$66,$9E,$99,
$31,$B4,$EC,$25,$1F,$F5,$80,$43,$4A,$C7,$AF,$EC,$50,$A1,$98,$60,$6F,$98,$2E,$04,
$7B,$26,$DF,$86,$EB,$CD,$A2,$04,$C1,$A9,$B4,$85,$98,$99,$D8,$A6,$CD,$E6,$27,$87,
$F2,$54,$F4,$F2,$38,$C9,$FA,$1D,$55,$A0,$F4,$1D,$A0,$48,$21,$77,$69,$D5,$9C,$B9,
$5F,$E0,$31,$CC,$9D,$52,$05,$BF,$10,$FC,$29,$F0,$55,$81,$02,$D5,$C1,$1D,$A5,$C0,
$A6,$4A,$EE,$EE,$FB,$1A,$DE,$AA,$73,$6E,$42,$66,$63,$28,$E2,$A9,$48,$5C,$90,$87,
$43,$D5,$10,$FB,$0C,$80,$9D,$39,$82,$D1,$61,$DC,$02,$07,$04,$98,$2A,$73,$AC,$2A,
$2C,$B4,$62,$83,$CA,$98,$03,$C1,$E9,$10,$A0,$5B,$CF,$4C,$22,$0D,$F8,$4E,$30,$B5,
$B5,$86,$05,$95,$50,$EB,$60,$2A,$31,$5E,$10,$0B,$43,$81,$E7,$36,$37,$61,$2B,$23,
$D5,$9C,$FE,$AE,$50,$05,$B3,$E5,$24,$A8,$B8,$32,$68,$19,$97,$8F,$14,$5F,$8C,$79,
$4A,$D4,$BA,$43,$AB,$1D,$11,$E3,$9D,$DC,$16,$B7,$25,$C4,$BB,$79,$DE,$E5,$C7,$ED,
$1A,$81,$85,$73,$B7,$83,$18,$77,$0D,$38,$BD,$CD,$87,$64,$2C,$CE,$5C,$F2,$3C,$21,
$6E,$21,$DB,$58,$3A,$3C,$60,$9E,$BF,$B3,$91,$73,$28,$CC,$3C,$DC,$BA,$2D,$E3,$48,
$E7,$CA,$30,$06,$A7,$19,$2D,$C7,$F0,$69,$74,$71,$3A,$B9,$41,$86,$31,$88,$16,$C4,
$A9,$B0,$F3,$0A,$12,$55,$C8,$10,$E2,$44,$A4,$9C,$CD,$CC,$80,$F3,$EB,$0F,$75,$BD,
$6A,$10,$E6,$8B,$C3,$CA,$04,$A2,$56,$97,$BE,$CB,$BF,$97,$52,$BB,$53,$07,$A1,$C2,
$06,$78,$43,$8F,$F5,$6C,$B8,$32,$98,$49,$F6,$42,$51,$CA,$1C,$52,$E2,$D3,$D0,$29,
$6B,$86,$78,$AA,$94,$B3,$EC,$D8,$50,$9D,$33,$C6,$35,$5D,$46,$6A,$36,$9A,$BF,$F4,
$94,$6F,$FF,$17,$0C,$4D,$E2,$F1,$5C,$A9,$FE,$7A,$E9,$7B,$C2,$14,$6D,$C3,$3B,$C1,
$88,$F8,$78,$7D,$FB,$53,$6E,$16,$3D,$FB,$6D,$1C,$35,$1D,$1F,$00,$E8,$D9,$C4,$70,
$0F,$4B,$8A,$01,$40,$2D,$46,$E7,$CC,$A1,$94,$8E,$52,$15,$23,$C5,$5E,$D7,$D8,$8A,
$70,$D8,$51,$8C,$C4,$0D,$D6,$70,$59,$AE,$B0,$85,$30,$40,$D2,$25,$29,$DE,$34,$F1,
$69,$38,$A0,$8E,$30,$99,$23,$87,$99,$C4,$3A,$79,$1C,$7D,$49,$FB,$13,$9D,$DF,$F2,
$97,$78,$AF,$32,$C2,$59,$15,$23,$0C,$00,$A0,$07,$66,$FD,$BE,$9F,$7E,$44,$A5,$F6,
$68,$56,$76,$10,$0E,$36,$83,$02,$47,$3F,$EC,$6C,$40,$6C,$65,$18,$64,$AA,$C3,$37,
$EC,$D3,$86,$7A,$49,$16,$B1,$AF,$F8,$4B,$F4,$BB,$8B,$E1,$57,$B4,$B8,$36,$BE,$F7,
$26,$2D,$F9,$E1,$E7,$F4,$E8,$B5,$AE,$DA,$89,$94,$7B,$7A,$95,$7E,$BA,$49,$D2,$3A,
$07,$FD,$66,$73,$02,$EA,$C1,$C8,$F9,$70,$EE,$6F,$93,$20,$19,$18,$E5,$0D,$D3,$55,
$54,$9D,$DB,$50,$E2,$40,$18,$C0,$E7,$C5,$58,$43,$4F,$EE,$6F,$37,$35,$6D,$27,$12,
$66,$7E,$E4,$A3,$7F,$59,$5D,$11,$27,$F0,$21,$5D,$1E,$A1,$2A,$E9,$11,$51,$DB,$5A,
$62,$FD,$AA,$49,$9E,$2A,$64,$DD,$65,$AD,$BA,$88,$DE,$BE,$2A,$E8,$AC,$E8,$7D,$0C,
$62,$86,$46,$02,$92,$07,$1B,$E9,$46,$97,$47,$74,$4D,$5A,$34,$74,$5E,$C4,$AE,$52,
$62,$5D,$8B,$FD,$6F,$1B,$7A,$77,$E1,$56,$7D,$84,$C3,$C0,$B3,$85,$B6,$30,$1E,$21,
$1C,$E6,$05,$3C,$A3,$F1,$07,$42,$7C,$9A,$47,$27,$F9,$CF,$BF,$E5,$D0,$7D,$6B,$40,
$1E,$0F,$8D,$C8,$21,$98,$36,$C5,$57,$BA,$D7,$81,$21,$77,$B8,$82,$30,$B3,$D8,$27,
$9B,$6C,$FF,$00,$89,$84,$98,$DB,$DF,$A9,$E8,$36,$30,$64,$F3,$F8,$26,$24,$EB,$A1,
$AE,$A1,$63,$4B,$77,$88,$C7,$62,$71,$33,$45,$C0,$B0,$1D,$F3,$17,$1B,$A8,$22,$75,
$B5,$54,$88,$60,$10,$77,$B0,$A2,$58,$F2,$25,$B6,$98,$17,$70,$27,$57,$C1,$7B,$03,
$C7,$E8,$F3,$F4,$57,$47,$47,$6C,$15,$CA,$DF,$D8,$6F,$CA,$39,$D0,$AB,$D6,$EE,$5D,
$BE,$20,$A6,$6F,$40,$A2,$A4,$9E,$61,$22,$2C,$D8,$5B,$52,$92,$D6,$04,$C7,$57,$1C,
$BF,$6C,$8A,$51,$C2,$78,$74,$F5,$7C,$A3,$AC,$7D,$6B,$DD,$E5,$6C,$E7,$03,$2F,$9A,
$8E,$70,$CB,$4C,$E2,$AA,$F4,$CC,$87,$56,$CD,$4C,$4E,$C9,$AC,$35,$65,$78,$14,$C7,
$53,$CA,$20,$14,$98,$54,$EB,$DF,$21,$CB,$F1,$32,$07,$C0,$1F,$0A,$06,$40,$C4,$00,
$6F,$60,$EE,$89,$E5,$42,$9A,$F4,$5A,$8F,$F2,$79,$57,$2B,$88,$81,$D1,$C7,$09,$DB,
$BF,$AE,$66,$65,$D5,$CA,$BC,$AD,$AA,$8B,$DA,$AB,$30,$79,$B6,$D5,$45,$69,$C1,$37,
$FB,$D2,$43,$A4,$69,$D2,$80,$AF,$F7,$19,$43,$A0,$C2,$D3,$34,$4D,$80,$C4,$30,$0B,
$88,$03,$23,$71,$8E,$A0,$89,$D9,$C6,$18,$C9,$20,$83,$0E,$17,$6A,$7D,$44,$22,$4D,
$0E,$58,$2A,$67,$72,$7D,$C8,$91,$48,$A4,$89,$7F,$D8,$86,$74,$60,$4D,$AC,$4C,$49,
$B2,$63,$D3,$34,$16,$3C,$36,$69,$9A,$1C,$30,$50,$DB,$EC,$83,$E0,$6C,$22,$4D,$A4,
$DD,$25,$FB,$C4,$32,$2F,$30,$A7,$9E,$26,$17,$FB,$39,$48,$24,$07,$8C,$0E,$84,$D0,
$17,$CD,$1C,$CA,$86,$0F,$56,$98,$D1,$8E,$92,$73,$77,$65,$8B,$44,$7B,$9C,$06,$A1,
$F7,$78,$01,$03,$A9,$53,$55,$1E,$2E,$9F,$B4,$A7,$9C,$AD,$16,$87,$28,$01,$D8,$97,
$BD,$DA,$4E,$F8,$59,$BF,$B2,$A8,$F0,$A5,$CF,$71,$69,$40,$77,$22,$81,$93,$EA,$C6,
$91,$41,$5A,$74,$7E,$44,$B8,$3C,$1A,$AC,$25,$BB,$FB,$C7,$B1,$33,$18,$0D,$51,$2F,
$78,$BF,$74,$9B,$B9,$74,$9F,$CF,$A3,$5F,$33,$96,$0C,$4C,$6B,$E5,$61,$52,$70,$2B,
$5E,$57,$9D,$04,$A2,$BB,$DC,$8B,$84,$91,$81,$72,$32,$A2,$2D,$33,$19,$70,$99,$11,
$8B,$F0,$F8,$B5,$8D,$77,$73,$B2,$E6,$DF,$2F,$FA,$42,$17,$E1,$9B,$75,$E6,$07,$E1,
$54,$6D,$F6,$31,$DE,$A6,$EE,$4F,$B8,$E6,$80,$8E,$CE,$89,$3D,$56,$CC,$C9,$0A,$7A,
$32,$20,$CF,$4E,$FD,$43,$3A,$BF,$B2,$EE,$5E,$51,$C7,$2F,$A8,$9F,$07,$EC,$87,$AC,
$77,$0F,$25,$AB,$8F,$42,$6C,$32,$30,$64,$38,$9B,$1D,$B8,$D3,$4D,$D0,$58,$1C,$99,
$C2,$25,$52,$56,$30,$A6,$44,$AE,$95,$F7,$D2,$A1,$96,$45,$47,$EC,$3C,$15,$EA,$10,
$3F,$44,$92,$D5,$6F,$6F,$53,$9F,$43,$CB,$15,$BE,$2B,$54,$0C,$75,$19,$08,$5D,$BD,
$3E,$56,$C0,$F2,$C3,$F0,$A0,$50,$A2,$04,$A7,$C4,$CC,$7D,$71,$42,$28,$4B,$F1,$B7,
$7D,$03,$15,$99,$A0,$35,$5B,$36,$D8,$FA,$CF,$D1,$6E,$41,$C1,$0C,$70,$E3,$BD,$34,
$5E,$2B,$8A,$4F,$D9,$B1,$5A,$2C,$71,$E4,$D5,$B5,$F6,$3B,$C6,$E2,$A7,$11,$74,$BB,
$B8,$43,$B6,$53,$91,$04,$FD,$BF,$D7,$93,$D2,$18,$7E,$1C,$96,$98,$2C,$51,$72,$51,
$4F,$97,$70,$A2,$66,$E2,$AF,$EA,$87,$15,$89,$EF,$8E,$2A,$F1,$FF,$4D,$7B,$B5,$54,
$07,$5C,$5F,$44,$26,$DE,$65,$1E,$F8,$D2,$C7,$55,$D4,$EE,$AD,$2C,$46,$07,$B9,$41,
$95,$E5,$9B,$1F,$F1,$41,$01,$05,$BF,$BB,$2B,$03,$EC,$63,$12,$86,$81,$90,$F6,$50,
$8A,$87,$46,$3D,$52,$33,$D3,$8B,$BB,$78,$CE,$15,$D0,$03,$3B,$40,$06,$4E,$47,$02,
$C4,$12,$3B,$34,$74,$BE,$0F,$A7,$03,$53,$AC,$19,$6A,$78,$D3,$AE,$8C,$70,$3E,$AC,
$E1,$FD,$CB,$B5,$0A,$C0,$9D,$A6,$89,$30,$62,$7E,$2E,$D6,$08,$68,$72,$46,$E0,$68,
$8E,$29,$10,$73,$1F,$47,$91,$1D,$2C,$A2,$1D,$4F,$EC,$B6,$D9,$24,$01,$49,$A4,$B9,
$57,$43,$2E,$C9,$CE,$8C,$94,$E9,$0F,$66,$DF,$AE,$56,$1B,$6D,$59,$5D,$4E,$F0,$82,
$E3,$9E,$E8,$8A,$4E,$B2,$C6,$C1,$31,$63,$53,$63,$A6,$8E,$85,$4F,$13,$82,$37,$7F,
$C0,$01,$57,$58,$F5,$9A,$E8,$ED,$A1,$BE,$02,$EE,$9A,$80,$B1,$9C,$A1,$B6,$6A,$4D,
$EE,$82,$25,$BB,$7C,$C6,$30,$8E,$80,$4C,$46,$33,$F0,$B3,$E5,$CE,$B6,$65,$63,$E7,
$45,$C0,$81,$01,$22,$1D,$1A,$AF,$23,$21,$1B,$41,$77,$DF,$58,$10,$E6,$2D,$4D,$09,
$77,$16,$2A,$04,$49,$E8,$CE,$05,$0E,$D4,$58,$7D,$CD,$D6,$17,$F3,$0E,$30,$4E,$BB,
$ED,$5F,$11,$D1,$E3,$5C,$2C,$48,$5C,$F4,$A2,$3E,$BF,$20,$41,$14,$57,$A0,$C1,$6A,
$D1,$2F,$74,$51,$EB,$57,$CA,$88,$21,$0F,$26,$61,$8F,$A9,$54,$00,$0F,$47,$14,$1C,
$4B,$3C,$2F,$38,$3F,$93,$37,$74,$27,$CE,$FD,$FB,$BA,$5A,$86,$77,$41,$56,$BA,$2F,
$9B,$65,$6E,$38,$B0,$B5,$1B,$FF,$8E,$C4,$E1,$C5,$E5,$3A,$01,$1B,$38,$43,$7D,$8C,
$DE,$81,$B6,$76,$5D,$09,$03,$8E,$EC,$89,$65,$67,$5E,$D6,$E1,$A9,$AF,$89,$F0,$C7,
$0A,$2A,$A6,$8A,$D9,$30,$09,$71,$3E,$6D,$53,$75,$6D,$5D,$C1,$FD,$35,$B8,$FE,$3F,
$C8,$AC,$DA,$82,$06,$19,$38,$9A,$30,$32,$9E,$40,$58,$7F,$16,$BE,$20,$E2,$60,$C6,
$20,$35,$80,$DE,$BA,$E0,$74,$8C,$10,$DA,$64,$ED,$9A,$F3,$4F,$D0,$BC,$4D,$41,$45,
$D7,$CA,$BB,$4A,$DB,$90,$A1,$B8,$71,$3D,$5E,$47,$3F,$04,$D3,$EA,$75,$28,$3A,$29,
$59,$9D,$B9,$9E,$11,$BB,$5C,$21,$84,$61,$27,$B5,$6E,$2E,$88,$59,$B5,$FD,$44,$0D,
$06,$48,$1F,$B3,$88,$F8,$E0,$0A,$FC,$85,$D8,$74,$63,$68,$30,$5B,$91,$29,$9C,$3A,
$30,$70,$A7,$01,$8E,$89,$F1,$24,$99,$77,$17,$6A,$09,$76,$38,$77,$6A,$4B,$5A,$3E,
$C6,$D9,$16,$AF,$31,$A5,$65,$C0,$C6,$AF,$FA,$7F,$03,$25,$0A,$00,$05,$A4,$D8,$CE,
$40,$15,$EE,$93,$06,$83,$03,$4A,$A7,$E5,$11,$C3,$0C,$A5,$3E,$2A,$AC,$77,$DB,$EF,
$60,$C4,$36,$56,$8C,$0D,$89,$88,$C1,$88,$0B,$82,$70,$82,$A1,$99,$AB,$17,$F0,$97,
$61,$81,$4E,$31,$CF,$17,$FD,$93,$CF,$D8,$8C,$B8,$C6,$ED,$19,$20,$D3,$B8,$13,$2B,
$A4,$F2,$3F,$C0,$8E,$29,$1F,$EE,$73,$BC,$F2,$BE,$79,$9B,$D6,$0F,$CB,$92,$62,$E7,
$97,$8A,$BE,$60,$FE,$9C,$29,$D4,$40,$01,$9D,$4B,$73,$F0,$4D,$99,$F9,$7D,$EB,$F2,
$7E,$ED,$52,$7F,$E1,$BF,$A0,$4E,$FF,$CF,$1F,$C1,$AE,$C3,$5A,$3B,$C9,$CE,$81,$DB,
$22,$02,$23,$2A,$09,$7C,$4E,$F6,$83,$CA,$23,$04,$73,$CC,$9C,$F3,$8B,$D2,$77,$41,
$22,$02,$F7,$84,$E2,$EB,$9E,$BC,$38,$44,$89,$B3,$26,$08,$AC,$88,$9D,$A7,$37,$EA,
$D6,$8D,$EE,$A8,$CF,$9E,$8B,$24,$F6,$90,$5F,$ED,$95,$FD,$57,$07,$E6,$C0,$34,$23,
$59,$25,$BF,$BC,$94,$CF,$75,$07,$5C,$94,$36,$5C,$BD,$B4,$7C,$B2,$63,$F0,$60,$0A,
$B4,$59,$55,$09,$C7,$10,$98,$72,$89,$30,$9B,$1C,$95,$D5,$17,$B9,$34,$BF,$53,$76,
$F2,$96,$77,$D3,$39,$53,$29,$4C,$4F,$BC,$D1,$8C,$94,$EC,$82,$79,$E8,$2C,$11,$08,
$0C,$91,$8C,$D4,$4D,$A1,$59,$2B,$51,$7C,$87,$37,$A9,$49,$43,$57,$0E,$0D,$4B,$74,
$55,$43,$A3,$47,$A6,$78,$D5,$82,$DF,$AC,$70,$02,$B0,$B7,$E8,$C3,$B6,$4D,$30,$3E,
$24,$F1,$E4,$1A,$77,$63,$4F,$A8,$D4,$11,$0A,$7C,$1C,$7F,$96,$75,$18,$88,$6C,$71,
$01,$00,$60,$91,$83,$90,$10,$D2,$79,$C7,$F8,$83,$D4,$7E,$B4,$F3,$CD,$B0,$9C,$EB,
$35,$56,$1E,$8F,$7A,$88,$E5,$C7,$BE,$96,$D6,$20,$E1,$50,$86,$77,$05,$94,$BF,$BC,
$1E,$33,$AE,$13,$CD,$CA,$61,$5F,$0D,$31,$D1,$D8,$48,$D5,$B3,$6F,$EF,$D9,$71,$3A,
$9A,$52,$B2,$B8,$6E,$0F,$B3,$FB,$44,$36,$30,$A6,$B5,$89,$D7,$89,$78,$E3,$D3,$BD,
$4A,$4A,$C0,$A4,$B0,$0E,$75,$01,$88,$88,$9D,$2B,$0B,$19,$D9,$77,$F0,$40,$9C,$7A,
$F7,$74,$B0,$63,$61,$22,$72,$AE,$6D,$9D,$56,$28,$8A,$9E,$95,$A8,$69,$41,$C1,$53,
$51,$8D,$6D,$9A,$16,$47,$22,$45,$65,$D3,$9A,$A5,$D2,$DF,$53,$C5,$61,$0F,$0A,$57,
$63,$C1,$53,$C2,$40,$40,$95,$9B,$51,$35,$5D,$9C,$AA,$0D,$79,$B3,$F9,$DA,$83,$B8,
$80,$32,$EC,$6A,$F1,$11,$9A,$E8,$5B,$96,$52,$15,$B9,$0F,$D3,$9C,$66,$F9,$EF,$18,
$BA,$40,$11,$D2,$F2,$76,$61,$0A,$0E,$02,$25,$6B,$81,$88,$20,$25,$49,$80,$84,$60,
$62,$10,$2C,$67,$32,$4C,$08,$E7,$DC,$1F,$03,$45,$93,$27,$41,$D4,$8B,$33,$42,$D5,
$29,$59,$DE,$D5,$5C,$A9,$CA,$9A,$F6,$D5,$48,$C9,$03,$5D,$E3,$A8,$FA,$EC,$FB,$82,
$C3,$22,$DA,$57,$60,$0E,$2A,$7B,$B3,$50,$7B,$5A,$C7,$B2,$3F,$30,$5B,$3C,$CD,$01,
$E5,$2A,$D7,$1E,$E1,$D4,$64,$21,$5A,$C5,$F0,$20,$33,$71,$41,$B0,$C5,$CB,$90,$61,
$C4,$13,$15,$75,$28,$1E,$33,$EA,$F7,$27,$86,$C2,$1C,$D0,$6C,$CE,$ED,$12,$75,$25,
$B1,$76,$45,$5E,$01,$50,$FE,$40,$ED,$57,$4B,$55,$66,$AE,$21,$6B,$3C,$F6,$DD,$4E,
$50,$B3,$65,$90,$59,$7D,$4B,$03,$0B,$4D,$46,$4B,$8C,$CB,$34,$F0,$37,$85,$57,$09,
$4A,$A0,$88,$B9,$62,$1D,$E2,$63,$9C,$AD,$44,$60,$91,$E9,$41,$4F,$1F,$D6,$29,$E6,
$10,$03,$D8,$CC,$B4,$3D,$ED,$37,$57,$10,$0D,$A6,$77,$13,$D5,$73,$31,$0F,$DE,$1A,
$1A,$0C,$12,$A3,$31,$15,$E3,$96,$06,$E5,$60,$44,$F7,$07,$5C,$20,$D5,$02,$26,$39,
$62,$D5,$CE,$41,$07,$5C,$A4,$7E,$B8,$C0,$4A,$FA,$2A,$CB,$58,$D8,$45,$D5,$81,$77,
$C6,$26,$B8,$22,$F5,$85,$3F,$ED,$D0,$86,$9F,$15,$D0,$DA,$99,$F9,$15,$6C,$A3,$85,
$0C,$32,$5E,$46,$08,$45,$91,$F4,$7D,$4E,$6F,$C3,$4F,$5F,$1A,$57,$1B,$A3,$4C,$98,
$95,$E6,$5F,$61,$06,$DD,$68,$40,$47,$89,$7D,$E3,$A6,$E4,$B6,$04,$01,$45,$89,$A8,
$F5,$37,$76,$8C,$5B,$B3,$8C,$52,$A0,$01,$01,$0F,$4B,$0B,$8B,$A9,$2E,$A3,$79,$14,
$24,$81,$E3,$FD,$9E,$4D,$77,$5E,$4E,$60,$A9,$EE,$A0,$59,$29,$52,$A8,$EE,$01,$A5,
$17,$32,$AC,$C1,$3B,$CA,$0E,$0C,$C3,$56,$D0,$C4,$8C,$1A,$17,$4E,$31,$C8,$D5,$0B,
$A1,$ED,$CB,$BA,$F3,$27,$FD,$C2,$E5,$58,$7B,$6D,$D1,$84,$64,$B9,$93,$E8,$A1,$B2,
$70,$6C,$5F,$33,$C8,$3D,$4B,$93,$71,$E1,$36,$52,$D0,$21,$C5,$1E,$03,$87,$E5,$72,
$B0,$FE,$0E,$51,$DC,$4A,$B5,$4E,$79,$99,$6D,$55,$1A,$FA,$29,$FF,$3E,$B1,$1F,$18,
$21,$CB,$60,$55,$DB,$74,$64,$65,$A1,$42,$3A,$56,$77,$7A,$26,$C2,$00,$28,$1C,$A5,
$AF,$FB,$31,$83,$A2,$27,$3D,$00,$FE,$76,$BC,$43,$3C,$5C,$2D,$80,$60,$30,$20,$00,
$94,$D7,$F9,$FF,$C6,$00,$60,$17,$50,$2C,$4B,$0B,$B7,$54,$C7,$EB,$13,$42,$97,$D0,
$D2,$9D,$25,$D8,$0F,$0A,$C4,$16,$7E,$50,$22,$1F,$AC,$CA,$0B,$98,$23,$28,$59,$2D,
$9D,$7F,$AC,$A4,$21,$2A,$38,$A4,$D8,$E3,$4E,$7B,$75,$44,$E3,$02,$C3,$F4,$A1,$80,
$0D,$65,$84,$18,$7F,$BD,$54,$3C,$A6,$0D,$33,$F0,$5C,$6A,$52,$EC,$DD,$85,$A8,$84,
$0C,$0E,$B7,$67,$63,$6D,$0C,$35,$CA,$FB,$55,$6E,$44,$05,$EE,$4A,$34,$98,$20,$76,
$3A,$8F,$94,$E1,$AD,$08,$1C,$A3,$D0,$E2,$06,$B6,$0A,$53,$11,$AB,$99,$FB,$42,$9A,
$FB,$CE,$83,$09,$88,$F3,$02,$FB,$84,$82,$45,$1A,$F1,$46,$6F,$AB,$26,$33,$FF,$40,
$FA,$B4,$47,$F2,$E0,$EA,$68,$C2,$88,$3C,$BF,$D5,$6C,$90,$5E,$D6,$54,$66,$D0,$18,
$0E,$CF,$C6,$04,$11,$32,$BD,$4B,$6D,$7F,$05,$97,$C5,$34,$7D,$4A,$04,$64,$4C,$5B,
$41,$77,$8B,$A2,$3A,$6C,$9C,$95,$11,$72,$1D,$A3,$D3,$98,$AC,$47,$07,$53,$6C,$F1,
$CC,$91,$C1,$CC,$95,$9C,$64,$C0,$00,$22,$59,$44,$ED,$28,$6F,$12,$2D,$71,$1F,$E1,
$28,$01,$6B,$49,$43,$76,$96,$2A,$B2,$C1,$D6,$E9,$03,$23,$33,$F6,$4C,$13,$76,$47,
$C8,$20,$74,$1C,$D0,$60,$18,$0E,$F1,$B5,$E0,$16,$16,$9F,$28,$AD,$19,$23,$EC,$36,
$8C,$25,$39,$2F,$E9,$F2,$64,$61,$F8,$2F,$F8,$FB,$D1,$84,$EB,$EE,$28,$1C,$FF,$46,
$4C,$D9,$27,$53,$72,$4E,$E7,$7B,$66,$16,$A8,$65,$BE,$C3,$A1,$E8,$50,$19,$91,$3F,
$24,$C9,$F6,$C7,$E8,$4F,$B2,$FE,$08,$8A,$E0,$D8,$83,$A8,$98,$F9,$2E,$19,$74,$75,
$85,$1C,$22,$37,$61,$10,$54,$63,$12,$35,$C4,$57,$6E,$1B,$DB,$DD,$B0,$35,$0F,$D0,
$6C,$76,$7F,$35,$7A,$C6,$75,$79,$76,$D7,$85,$C1,$E2,$12,$13,$8B,$1C,$11,$38,$22,
$5E,$2C,$5C,$65,$BB,$1B,$44,$44,$7C,$46,$50,$F8,$5B,$B6,$51,$A8,$C6,$0B,$32,$D9,
$4F,$26,$EC,$EA,$AA,$49,$40,$06,$54,$87,$95,$FE,$57,$4F,$36,$28,$B1,$2B,$14,$F9,
$4F,$BB,$E6,$66,$75,$A2,$B1,$5D,$14,$F4,$35,$30,$27,$14,$BB,$BD,$B2,$0B,$D8,$07,
$50,$75,$1E,$F9,$87,$EE,$BA,$85,$D3,$63,$D5,$4D,$F0,$3A,$62,$E6,$50,$5A,$96,$37,
$DE,$66,$BA,$40,$BD,$99,$F5,$69,$47,$F7,$20,$47,$85,$9E,$36,$4B,$49,$FD,$46,$FB,
$DC,$3F,$75,$3D,$93,$BB,$2C,$6D,$EB,$5E,$CF,$FF,$9A,$EC,$71,$06,$4C,$2C,$83,$7D,
$B4,$D6,$34,$4D,$93,$0D,$D4,$09,$0C,$13,$00,$DD,$2A,$D3,$E6,$DE,$29,$CC,$00,$DC,
$05,$8A,$6D,$83,$C2,$1D,$94,$6E,$14,$40,$B4,$57,$EB,$06,$6D,$62,$55,$15,$E9,$8A,
$78,$16,$37,$D0,$F1,$93,$59,$E8,$76,$6B,$D5,$CC,$EA,$94,$BA,$BC,$FD,$2F,$40,$3D,
$04,$73,$2C,$21,$12,$BF,$EF,$4E,$3B,$62,$5B,$57,$08,$D3,$A2,$9D,$22,$F7,$BE,$A0,
$66,$F9,$5B,$A5,$F7,$D9,$F9,$0E,$02,$06,$50,$1E,$B8,$BA,$E1,$76,$F1,$40,$06,$EC,
$19,$F5,$A6,$A2,$E4,$61,$A0,$69,$4D,$DB,$11,$62,$42,$62,$15,$83,$48,$DD,$AE,$2C,
$AC,$D9,$15,$05,$D2,$49,$2E,$B4,$A2,$3B,$45,$B0,$EB,$54,$17,$46,$CE,$B3,$61,$86,
$42,$FE,$2A,$8B,$CC,$7C,$0C,$1A,$C2,$B4,$6B,$C9,$58,$2D,$93,$4A,$2C,$5D,$B4,$F3,
$79,$EE,$2E,$22,$DB,$BE,$CD,$BA,$42,$40,$96,$34,$19,$A0,$AE,$C8,$71,$32,$A9,$AD,
$5A,$A7,$C0,$DB,$43,$AA,$0E,$D9,$46,$2F,$7B,$18,$A7,$3F,$38,$13,$DB,$30,$1B,$6A,
$E0,$53,$10,$A1,$A9,$06,$21,$7E,$29,$27,$8B,$4A,$A6,$3D,$4B,$C5,$87,$D4,$16,$92,
$AE,$E3,$50,$46,$84,$CD,$5E,$CC,$09,$CD,$3A,$FE,$78,$38,$71,$0A,$12,$D0,$7A,$72,
$D2,$0F,$86,$34,$78,$90,$C5,$39,$9C,$CB,$9F,$6A,$CA,$06,$51,$D4,$96,$D5,$A4,$F8,
$1A,$09,$E1,$A6,$30,$30,$A8,$CA,$1D,$C8,$46,$55,$BB,$00,$C5,$2E,$50,$BD,$B6,$88,
$2C,$A3,$0B,$4E,$C6,$CF,$86,$E2,$55,$D4,$7C,$36,$A3,$A0,$E6,$3A,$80,$C2,$59,$94,
$5C,$BD,$3A,$E4,$F3,$E3,$7F,$68,$4F,$6D,$0B,$31,$AE,$1E,$71,$28,$0B,$AC,$55,$4C,
$74,$F1,$98,$B7,$96,$15,$8F,$37,$01,$6C,$F9,$09,$6A,$37,$AD,$2A,$A6,$F2,$60,$21,
$00,$95,$1C,$09,$E4,$36,$52,$50,$E5,$25,$C9,$6A,$43,$9E,$98,$B3,$2F,$EA,$BE,$4D,
$36,$36,$BE,$26,$CF,$CB,$E7,$4C,$8F,$1E,$B5,$FF,$E8,$AD,$61,$40,$B2,$74,$B0,$A3,
$EC,$D1,$DC,$27,$E0,$EA,$40,$68,$94,$A9,$A8,$AE,$EE,$2B,$90,$E0,$E0,$FC,$B4,$CC,
$6A,$89,$63,$19,$53,$20,$F7,$88,$8F,$F0,$55,$11,$56,$55,$8C,$1F,$91,$73,$A1,$7B,
$BB,$7B,$25,$4A,$C0,$FC,$9E,$D9,$87,$44,$CD,$14,$36,$F9,$FF,$5A,$EA,$D5,$F6,$7E,
$16,$D4,$9F,$57,$20,$DB,$0B,$F0,$79,$45,$50,$D7,$C9,$0C,$EE,$FD,$88,$4F,$6F,$3B,
$65,$64,$97,$8D,$B0,$5C,$D7,$83,$F2,$CA,$A7,$61,$4E,$EC,$EE,$93,$ED,$BE,$91,$D8,
$EC,$E3,$F5,$CC,$F3,$F3,$CE,$60,$81,$FE,$6E,$4A,$92,$24,$C3,$49,$65,$7A,$46,$4E,
$D5,$0F,$E3,$04,$81,$98,$A5,$AB,$42,$71,$0A,$7D,$15,$42,$6F,$92,$C9,$92,$1B,$7D,
$35,$F2,$FF,$B3,$81,$67,$79,$F0,$88,$67,$A0,$C8,$4C,$B5,$07,$4F,$AF,$7B,$84,$3B,
$41,$51,$A1,$39,$88,$96,$86,$B1,$73,$69,$9E,$ED,$DE,$36,$D5,$92,$40,$50,$74,$93,
$EF,$50,$85,$C5,$86,$8D,$D4,$74,$25,$55,$F9,$F8,$00,$71,$55,$05,$07,$A4,$3D,$BD,
$EE,$7C,$FA,$45,$7D,$7E,$F2,$13,$27,$60,$36,$B6,$52,$C4,$79,$D8,$75,$BF,$B6,$1B,
$B7,$BB,$22,$07,$FF,$D1,$82,$8B,$BE,$DF,$5F,$DC,$06,$90,$45,$27,$7C,$4A,$DF,$CF,
$08,$C2,$05,$5D,$EA,$1E,$00,$F7,$00,$DD,$38,$7A,$38,$F2,$A5,$2D,$C9,$A0,$A8,$DD,
$3B,$F0,$65,$77,$B5,$D4,$B5,$2F,$DE,$6F,$B3,$8C,$4D,$FF,$47,$EF,$94,$D2,$62,$B5,
$DA,$B1,$1F,$06,$67,$C6,$01,$D7,$8C,$CE,$85,$F2,$BD,$2A,$19,$8A,$37,$FB,$07,$72,
$53,$AC,$83,$77,$E5,$62,$A4,$B1,$61,$10,$7D,$20,$FA,$F2,$AC,$1E,$27,$E9,$15,$C7,
$62,$A8,$5B,$7B,$BF,$A3,$0A,$47,$2B,$7B,$D4,$44,$91,$A1,$D2,$93,$4D,$1D,$EB,$8D,
$FE,$2B,$5C,$41,$6C,$75,$B5,$53,$AE,$2B,$81,$9F,$25,$4C,$B7,$58,$78,$C9,$54,$C7,
$71,$C6,$70,$C8,$27,$63,$70,$F6,$94,$0D,$C2,$0D,$B7,$DE,$7F,$2E,$B8,$1D,$82,$01,
$12,$32,$C8,$E9,$D9,$A9,$39,$70,$62,$C2,$7D,$AB,$E3,$20,$21,$21,$1A,$D2,$85,$85,
$CE,$6C,$1B,$20,$99,$6F,$BC,$6D,$EB,$93,$FF,$F4,$C3,$DB,$0A,$B9,$DC,$22,$42,$AD,
$DF,$56,$81,$60,$BE,$FE,$93,$84,$07,$A7,$57,$D5,$97,$B0,$69,$C2,$2C,$00,$27,$96,
$BB,$63,$A4,$3C,$9D,$B0,$EA,$07,$BE,$C6,$71,$5F,$66,$2C,$8B,$44,$EE,$52,$3C,$8D,
$DE,$03,$5A,$35,$00,$C8,$C4,$C4,$AB,$B7,$8F,$94,$7C,$37,$8E,$9C,$CE,$29,$86,$BA,
$B9,$67,$63,$BC,$C9,$11,$85,$A5,$BB,$36,$7F,$15,$B0,$19,$40,$47,$23,$FE,$84,$11,
$00,$C8,$A9,$CC,$B0,$25,$4D,$E9,$54,$48,$52,$E9,$5E,$3E,$39,$4C,$F8,$1C,$EC,$A1,
$BE,$72,$CC,$F7,$55,$AE,$4D,$A3,$4C,$47,$D5,$07,$DD,$BB,$C7,$51,$B2,$B5,$9E,$A4,
$E3,$93,$95,$5A,$E5,$74,$97,$D6,$69,$6C,$AB,$9D,$A2,$8F,$82,$FF,$54,$8B,$D3,$17,
$81,$41,$76,$D4,$FE,$74,$44,$2A,$0F,$AE,$4A,$C8,$74,$27,$74,$F4,$E1,$22,$49,$0C,
$60,$07,$3B,$2E,$42,$DC,$FA,$8F,$5A,$98,$69,$8E,$1B,$4A,$CA,$7F,$D5,$4C,$2F,$C4,
$2F,$C1,$B3,$4A,$17,$5E,$11,$C2,$57,$A5,$75,$42,$36,$0F,$19,$75,$47,$14,$70,$3C,
$B1,$A8,$04,$61,$7D,$7A,$71,$56,$C8,$A0,$78,$5C,$62,$58,$C9,$5D,$A0,$20,$C0,$3A,
$E3,$3F,$D9,$47,$FE,$75,$78,$E4,$F0,$F7,$5C,$FF,$0E,$79,$B8,$34,$74,$D0,$92,$E7,
$A0,$43,$FF,$25,$0D,$1F,$D4,$78,$42,$09,$84,$02,$EF,$D2,$65,$99,$E4,$D3,$9B,$E5,
$E3,$60,$22,$58,$5A,$DB,$9C,$07,$36,$D1,$DB,$A1,$6B,$04,$42,$A6,$0A,$18,$E9,$26,
$ED,$44,$86,$FA,$25,$45,$C7,$AF,$05,$94,$50,$1D,$3A,$02,$3F,$33,$0D,$2E,$99,$05,
$D2,$EC,$84,$5B,$F3,$2E,$DA,$D4,$C1,$0F,$16,$25,$C5,$40,$1C,$16,$D2,$0C,$9B,$98,
$BB,$13,$7A,$CA,$A0,$A9,$7A,$D5,$A5,$21,$8E,$82,$F5,$BF,$B5,$4E,$80,$9C,$A9,$2F,
$A5,$B8,$95,$AB,$80,$A9,$99,$B7,$A4,$51,$DD,$71,$C2,$B7,$B1,$77,$0A,$C1,$F9,$6A,
$B9,$0D,$F6,$D4,$53,$DD,$75,$62,$8B,$2C,$2E,$C1,$25,$0D,$62,$5C,$70,$AC,$68,$B9,
$02,$EF,$CE,$89,$C0,$98,$90,$38,$10,$86,$B0,$4D,$4C,$D9,$39,$A5,$A6,$89,$81,$D5,
$0C,$EB,$0F,$50,$9D,$D5,$91,$31,$B4,$F3,$64,$97,$90,$1F,$25,$AE,$F5,$8F,$C2,$BA,
$19,$05,$AA,$EF,$89,$AC,$76,$11,$56,$61,$B0,$EF,$3E,$62,$65,$15,$C5,$5F,$29,$68,
$9C,$FB,$E6,$50,$00,$41,$F4,$61,$B2,$FB,$4F,$4D,$64,$EE,$3F,$61,$1E,$21,$27,$F5,
$7D,$B2,$96,$E6,$BC,$ED,$86,$EB,$ED,$2E,$EF,$D7,$1C,$BF,$82,$78,$D6,$B2,$22,$1E,
$7F,$B4,$10,$0A,$83,$D0,$67,$52,$9F,$19,$29,$18,$16,$AE,$38,$63,$BF,$A4,$F7,$E1,
$05,$11,$64,$08,$B5,$FE,$B5,$2F,$3C,$44,$56,$B9,$D3,$DE,$3F,$68,$3C,$C9,$B5,$F4,
$F7,$FE,$0D,$CB,$CF,$7B,$A8,$23,$15,$4E,$79,$0D,$23,$AA,$0C,$EC,$D6,$E0,$7F,$F8,
$32,$E7,$AA,$ED,$FD,$13,$67,$66,$6D,$1F,$F8,$A0,$F6,$4B,$EB,$04,$E1,$AB,$12,$07,
$9A,$A9,$2C,$40,$C2,$46,$3B,$13,$D3,$60,$8E,$2D,$99,$BE,$CB,$94,$D3,$F3,$5F,$A9,
$B6,$57,$94,$B6,$44,$C7,$DA,$9B,$CD,$0C,$B1,$91,$75,$ED,$CE,$40,$BA,$8F,$40,$92,
$1C,$0B,$80,$AE,$C2,$84,$DB,$F9,$C0,$DE,$FB,$5D,$24,$28,$BA,$19,$3D,$18,$69,$73,
$A2,$5A,$E0,$6A,$12,$5C,$F6,$3B,$54,$D1,$FE,$00,$C4,$75,$8C,$19,$E1,$FF,$FC,$09,
$AD,$1B,$35,$D7,$DD,$5C,$37,$3C,$A2,$42,$7F,$10,$50,$81,$B6,$84,$F3,$20,$6F,$EA,
$CE,$28,$8A,$60,$CB,$90,$96,$C0,$78,$8A,$A2,$48,$B1,$BC,$83,$80,$82,$59,$03,$84,
$D2,$96,$0C,$B0,$96,$54,$97,$01,$EB,$AA,$E2,$97,$FE,$B8,$95,$08,$33,$EB,$66,$40,
$D3,$FC,$E3,$91,$E2,$03,$02,$B0,$75,$05,$D4,$72,$5A,$F2,$82,$4B,$C1,$11,$9C,$40,
$1C,$C3,$55,$D9,$99,$4E,$1F,$5B,$E6,$02,$3F,$12,$3C,$89,$61,$B3,$58,$15,$1F,$55,
$30,$80,$31,$1A,$07,$50,$80,$CC,$DD,$03,$C0,$D5,$C6,$30,$C3,$E4,$FE,$3F,$D9,$BF,
$53,$8F,$B9,$04,$FF,$D8,$11,$CE,$C0,$9A,$C7,$BD,$C7,$19,$39,$F7,$BE,$3A,$98,$88,
$C7,$9D,$03,$4F,$79,$C9,$A7,$74,$FA,$F3,$57,$9C,$CA,$2B,$57,$45,$A1,$03,$46,$83,
$80,$F9,$87,$74,$7E,$67,$9C,$62,$9B,$44,$F5,$37,$BF,$0B,$B8,$FC,$EB,$11,$18,$A7,
$23,$23,$7A,$4F,$27,$46,$F5,$F6,$F3,$5D,$15,$5B,$58,$C2,$D9,$AC,$82,$3E,$46,$F5,
$E0,$D2,$31,$82,$C4,$5A,$D9,$B0,$9A,$B0,$EB,$CF,$BF,$2B,$17,$BB,$7B,$95,$07,$70,
$BD,$63,$B8,$5F,$65,$CB,$A5,$37,$D6,$70,$AF,$FF,$BF,$49,$C6,$1D,$46,$F8,$FA,$83,
$47,$08,$E0,$4A,$58,$5D,$CB,$BF,$02,$84,$D3,$0F,$38,$56,$C5,$0A,$5A,$36,$7E,$F2,
$28,$0A,$F6,$B3,$94,$F0,$53,$53,$77,$54,$3F,$F0,$D8,$FE,$00,$3C,$22,$0F,$24,$08,
$3A,$F4,$55,$68,$2D,$62,$CF,$0A,$14,$DF,$60,$B1,$F8,$4C,$63,$EE,$12,$F4,$EC,$F4,
$55,$E8,$D8,$2B,$0A,$91,$B6,$5E,$13,$4F,$D5,$FA,$57,$99,$72,$AE,$EC,$BE,$7F,$50,
$FB,$0A,$C0,$F0,$55,$56,$3C,$21,$06,$38,$E0,$B5,$97,$75,$A7,$36,$D3,$7A,$CF,$AC,
$EB,$D7,$05,$59,$69,$62,$A8,$C3,$24,$6D,$CC,$A5,$FE,$D4,$1A,$A6,$C0,$CC,$DD,$52,
$C1,$B4,$C1,$55,$B5,$D7,$B4,$17,$0A,$C1,$40,$CE,$CF,$2D,$EB,$D2,$B0,$27,$25,$5E,
$AD,$53,$E7,$00,$F8,$B5,$8C,$BB,$82,$FB,$63,$61,$9F,$A4,$60,$77,$42,$F9,$60,$67,
$CD,$FF,$DE,$B8,$87,$D8,$07,$6E,$FD,$D0,$00,$8C,$4D,$80,$AF,$BE,$CC,$75,$C0,$82,
$21,$C4,$BB,$17,$AA,$2A,$19,$DB,$E4,$B2,$0B,$77,$08,$90,$88,$22,$4B,$E3,$5D,$90,
$AB,$63,$12,$F5,$D5,$E5,$1E,$77,$99,$E0,$3C,$2C,$12,$96,$80,$01,$45,$32,$41,$52,
$D8,$10,$13,$24,$64,$84,$C4,$9E,$C8,$4C,$0C,$81,$49,$89,$0E,$ED,$0D,$88,$99,$21,
$D4,$E4,$EE,$FC,$BB,$19,$A2,$43,$CC,$8F,$58,$C8,$BC,$96,$61,$21,$66,$09,$B6,$AD,
$A7,$D0,$F0,$EC,$74,$55,$41,$A6,$8F,$D5,$D2,$B3,$E5,$3C,$11,$0A,$82,$6D,$61,$88,
$00,$6E,$AB,$F8,$8A,$FF,$A4,$20,$97,$A7,$52,$BC,$3C,$E6,$00,$B1,$85,$68,$11,$F1,
$6A,$36,$83,$B0,$E5,$AB,$6C,$93,$62,$0A,$21,$50,$B1,$9B,$8A,$90,$37,$1C,$D6,$E6,
$71,$FE,$17,$94,$B6,$A9,$88,$29,$AC,$A8,$41,$EC,$B2,$07,$71,$A7,$66,$2E,$7C,$6C,
$16,$B3,$65,$85,$16,$0E,$1B,$0B,$53,$2E,$D1,$2E,$8F,$D4,$1F,$C4,$50,$0E,$86,$EE,
$E1,$E2,$0A,$F8,$EE,$48,$EE,$C5,$90,$84,$ED,$84,$C3,$91,$F5,$0E,$13,$BD,$4B,$B1,
$55,$27,$5C,$99,$1D,$EA,$35,$43,$F7,$20,$87,$E6,$61,$26,$71,$29,$6B,$91,$D5,$EE,
$02,$F8,$B3,$CD,$FF,$E7,$00,$D7,$1A,$9B,$FE,$C5,$05,$14,$92,$01,$5C,$38,$52,$0E,
$F0,$98,$FB,$62,$53,$6E,$4D,$AF,$AD,$F6,$42,$62,$55,$A1,$F5,$4B,$2D,$6A,$55,$C0,
$C6,$BB,$B2,$75,$62,$91,$B0,$5A,$03,$10,$FB,$2A,$DF,$FF,$8F,$C6,$C8,$B3,$F3,$BB,
$A2,$F3,$EE,$72,$D5,$E0,$E6,$BC,$B0,$6E,$C2,$CC,$86,$61,$A2,$F0,$1C,$EA,$6A,$6F,
$B8,$11,$BB,$63,$1E,$EC,$EB,$53,$33,$70,$20,$CA,$76,$B2,$65,$F7,$AA,$40,$A0,$81,
$46,$E0,$F5,$FE,$2F,$D4,$2A,$32,$CF,$F7,$C0,$16,$A4,$3C,$21,$AC,$A1,$22,$E2,$F6,
$E7,$E5,$57,$D5,$43,$28,$55,$11,$7B,$81,$7E,$CD,$AE,$2B,$20,$F2,$47,$C8,$AB,$68,
$81,$FE,$7D,$D0,$51,$0B,$61,$35,$FB,$7F,$B1,$41,$DF,$92,$79,$46,$2E,$11,$AF,$1E,
$E1,$D0,$14,$E3,$C2,$BE,$56,$45,$4E,$BE,$CB,$2B,$5C,$B1,$49,$2F,$7E,$37,$3D,$D8,
$F4,$81,$53,$F5,$17,$01,$8D,$33,$F0,$FF,$F5,$D5,$6B,$7F,$BE,$58,$1E,$5C,$38,$2F,
$18,$FA,$22,$20,$1A,$9C,$77,$76,$0F,$60,$A0,$1B,$A5,$9D,$A7,$9B,$5E,$98,$FB,$44,
$F3,$AE,$58,$A3,$B1,$2A,$ED,$71,$A9,$A9,$EB,$75,$9B,$AB,$48,$6B,$DF,$EB,$C6,$F3,
$AB,$AE,$F6,$B3,$CA,$BF,$CE,$DF,$17,$EF,$1F,$B3,$D8,$E8,$14,$08,$65,$A0,$0C,$52,
$6E,$95,$F3,$58,$91,$7E,$83,$D8,$6E,$BC,$DD,$5D,$5B,$77,$53,$56,$5D,$E4,$87,$B4,
$A5,$40,$9A,$57,$43,$17,$0C,$7D,$E5,$46,$4B,$34,$52,$30,$34,$C2,$F3,$C9,$3E,$A6,
$23,$19,$5E,$EE,$0B,$94,$FA,$12,$EA,$8F,$BA,$1F,$87,$90,$A3,$F7,$4F,$5E,$ED,$6E,
$C7,$EC,$3A,$B1,$E8,$4F,$B6,$17,$AE,$EE,$62,$F0,$5D,$85,$87,$8C,$0C,$C9,$C3,$EC,
$AF,$92,$A5,$AB,$87,$E2,$FB,$78,$42,$B3,$C6,$99,$31,$7D,$B9,$58,$97,$DA,$57,$48,
$77,$77,$A8,$6B,$AA,$28,$C1,$DB,$7D,$16,$11,$DF,$D2,$14,$28,$0C,$9B,$8E,$A0,$16,
$85,$EE,$C6,$D6,$AB,$78,$38,$0D,$22,$5C,$C1,$31,$BE,$28,$20,$41,$A3,$DE,$96,$F2,
$3B,$16,$91,$38,$F5,$BD,$4D,$99,$C4,$67,$EA,$6A,$44,$85,$62,$0E,$B7,$AB,$98,$2E,
$A8,$A7,$0A,$B9,$60,$91,$5C,$10,$F3,$EC,$D8,$FA,$68,$83,$CB,$A7,$43,$48,$B2,$63,
$85,$2D,$6B,$BA,$0A,$B3,$E0,$A8,$F2,$5D,$B2,$B5,$1C,$18,$CC,$28,$3A,$21,$D2,$04,
$B8,$FF,$37,$0C,$C4,$B6,$63,$CD,$29,$71,$CE,$B2,$FC,$7D,$A8,$C7,$C8,$55,$15,$95,
$4D,$7F,$50,$F1,$04,$DE,$87,$7D,$AC,$02,$4B,$33,$00,$35,$3A,$A0,$7B,$A2,$36,$4C,
$00,$60,$B2,$91,$C1,$32,$EF,$3A,$28,$39,$69,$56,$55,$98,$C1,$05,$18,$00,$19,$2C,
$47,$13,$E5,$B0,$7E,$70,$FF,$06,$E0,$18,$5C,$69,$7C,$43,$40,$BC,$C8,$92,$B0,$31,
$06,$F9,$60,$60,$7D,$61,$50,$E0,$18,$42,$58,$C7,$F9,$1D,$03,$DB,$CF,$F4,$51,$1E,
$DD,$54,$50,$FF,$29,$B3,$28,$C2,$AB,$EB,$AC,$98,$C5,$41,$1D,$24,$0C,$66,$FD,$A7,
$39,$A0,$BE,$02,$32,$55,$73,$9D,$DB,$61,$C3,$6B,$F9,$7D,$43,$85,$76,$C6,$DA,$9F,
$80,$2F,$EE,$CA,$83,$CF,$A0,$C9,$15,$85,$F5,$1C,$CE,$A5,$0B,$08,$14,$D2,$A5,$44,
$45,$96,$94,$9E,$AF,$EA,$E5,$B9,$A6,$CB,$ED,$AA,$16,$D6,$B8,$19,$56,$D2,$A0,$78,
$6B,$53,$AA,$2E,$0C,$A5,$6E,$43,$5D,$08,$B1,$7A,$8D,$9A,$CB,$88,$6B,$0A,$0F,$20,
$D0,$F2,$1F,$B0,$A6,$D5,$29,$27,$59,$0B,$FB,$17,$96,$72,$EC,$0B,$F5,$1D,$B2,$DA,
$C4,$1F,$3F,$05,$7A,$30,$16,$ED,$39,$59,$24,$42,$5D,$B0,$90,$4C,$B1,$26,$19,$59,
$58,$59,$2B,$29,$B5,$75,$17,$64,$AB,$FF,$15,$09,$43,$65,$90,$0F,$FC,$6D,$C7,$6C,
$16,$DF,$E3,$CD,$01,$75,$C3,$D4,$2A,$77,$58,$83,$78,$FA,$FB,$41,$C9,$5E,$21,$03,
$F6,$4A,$AE,$FD,$08,$8D,$FE,$8E,$1A,$6B,$B5,$BE,$ED,$F7,$95,$F0,$3B,$63,$DF,$B4,
$E3,$9F,$B5,$5B,$CC,$89,$0B,$E7,$F4,$57,$23,$C4,$FA,$37,$5F,$42,$89,$50,$B0,$02,
$F8,$67,$A0,$BC,$EE,$95,$F7,$F1,$D4,$E8,$BA,$06,$77,$40,$07,$E4,$DE,$09,$B5,$29,
$AE,$96,$34,$74,$1D,$E9,$5A,$73,$05,$03,$54,$0A,$BC,$E2,$09,$AE,$82,$3B,$D5,$08,
$1E,$27,$22,$BD,$56,$0A,$38,$EC,$65,$DD,$36,$D5,$DD,$1F,$C8,$95,$9D,$AE,$FC,$C0,
$60,$4A,$DD,$2D,$40,$9C,$4B,$B6,$CA,$E2,$7F,$A3,$88,$47,$4E,$4D,$0D,$5A,$1D,$C4,
$77,$7D,$42,$B7,$30,$E9,$82,$7B,$EE,$FE,$AA,$0E,$A0,$B6,$A3,$F6,$75,$7E,$7A,$F7,
$D4,$1A,$D8,$E8,$55,$82,$90,$2C,$F7,$54,$F1,$BF,$D6,$B4,$20,$76,$25,$AE,$B4,$2F,
$84,$72,$C3,$83,$53,$4C,$AB,$DD,$BA,$65,$74,$5E,$F9,$75,$56,$65,$8A,$CE,$45,$47,
$12,$AB,$21,$E7,$88,$59,$1D,$98,$84,$D1,$EE,$41,$F3,$08,$09,$4B,$D0,$7C,$46,$5C,
$56,$BF,$6F,$B9,$1E,$03,$0F,$5A,$F9,$FA,$C5,$37,$7F,$DC,$2F,$7C,$55,$8A,$B6,$3F,
$0F,$63,$B8,$FC,$90,$F0,$24,$7F,$4D,$87,$22,$00,$9B,$CE,$3F,$15,$39,$1A,$EF,$07,
$EC,$C1,$A4,$B2,$FF,$14,$B1,$9E,$E4,$CD,$A6,$6F,$40,$4F,$21,$D1,$5F,$B0,$92,$2E,
$C3,$74,$F7,$D4,$98,$CD,$8E,$55,$00,$63,$28,$32,$F3,$DF,$0B,$EB,$DB,$BF,$5A,$D8,
$7F,$09,$FC,$FF,$EF,$87,$75,$E5,$36,$48,$0C,$FC,$BE,$D0,$F9,$4F,$95,$91,$CF,$85,
$15,$8B,$38,$61,$02,$5D,$9E,$43,$76,$29,$41,$75,$43,$72,$D8,$5A,$5D,$62,$06,$CE,
$CD,$56,$9D,$EB,$64,$54,$BF,$98,$DB,$AB,$8C,$36,$4E,$6B,$AA,$B0,$BC,$E4,$FD,$05,
$B1,$EE,$EA,$C5,$55,$D9,$D9,$67,$D9,$1C,$AF,$3A,$CF,$E0,$C0,$E2,$30,$16,$9E,$3C,
$18,$73,$14,$A2,$A4,$91,$53,$58,$44,$E7,$50,$22,$E4,$5C,$20,$F1,$22,$56,$96,$F4,
$A7,$6A,$0C,$12,$5A,$0B,$84,$06,$D6,$01,$87,$51,$68,$C9,$32,$4F,$51,$D8,$23,$37,
$B9,$01,$BE,$CB,$0E,$8C,$EB,$4E,$3D,$46,$EA,$AB,$9A,$D1,$88,$9E,$55,$EE,$91,$84,
$72,$88,$59,$3D,$C0,$BF,$DE,$95,$44,$84,$33,$C5,$7F,$BC,$CD,$8D,$32,$B0,$8A,$F4,
$75,$55,$DD,$83,$5C,$0A,$C4,$EA,$92,$0F,$3C,$C4,$B0,$D9,$A8,$2B,$02,$DA,$7F,$D0,
$1F,$E2,$DF,$F6,$53,$E6,$AA,$CB,$8D,$3B,$E6,$D9,$11,$A4,$0F,$FE,$A2,$DA,$D5,$6F,
$CE,$8B,$F3,$55,$92,$2E,$C2,$32,$6F,$F6,$37,$78,$49,$29,$2E,$31,$30,$A0,$43,$0D,
$6C,$07,$23,$18,$E8,$67,$3E,$40,$AE,$82,$6B,$EE,$0E,$04,$E7,$EF,$B7,$55,$CB,$DB,
$99,$4F,$23,$AD,$7C,$0D,$E6,$BB,$5B,$14,$85,$7A,$DC,$17,$42,$AE,$49,$ED,$6E,$AB,
$81,$5D,$F4,$7B,$34,$5B,$92,$86,$33,$E0,$12,$3C,$87,$BA,$C7,$EE,$8A,$C8,$7D,$79,
$5D,$00,$3E,$FC,$7F,$E1,$D7,$F9,$14,$44,$EE,$CA,$91,$EE,$74,$66,$AE,$BE,$2B,$BF,
$F7,$04,$9C,$09,$81,$3D,$32,$6B,$F6,$68,$33,$9B,$DB,$AF,$68,$98,$0A,$85,$B2,$15,
$C1,$81,$5D,$C0,$EC,$BB,$C4,$6B,$F7,$09,$5A,$9D,$7D,$D0,$B1,$77,$10,$C8,$D5,$2A,
$A6,$DA,$17,$11,$4A,$95,$1F,$28,$79,$01,$56,$D7,$F4,$18,$32,$68,$65,$F5,$52,$FE,
$E3,$7B,$3D,$55,$E3,$E0,$E8,$79,$C3,$33,$3A,$51,$B7,$6C,$38,$70,$96,$7D,$1A,$9A,
$BC,$89,$EE,$26,$F2,$92,$F3,$92,$60,$54,$5F,$2D,$E7,$1C,$1B,$CC,$01,$0A,$90,$8C,
$BF,$42,$BA,$0B,$E7,$5F,$A6,$7B,$50,$1B,$C6,$89,$68,$4F,$39,$F8,$23,$96,$AD,$77,
$FB,$63,$71,$4F,$53,$D7,$A6,$22,$6E,$C1,$8F,$E5,$AB,$B2,$94,$06,$0E,$EB,$05,$94,
$96,$F4,$7E,$92,$D3,$81,$B8,$9F,$AE,$D5,$3F,$04,$DF,$88,$87,$AC,$4F,$2D,$34,$78,
$8C,$BE,$BC,$FD,$BA,$98,$F6,$81,$07,$C8,$17,$C8,$EF,$E9,$C5,$AE,$EB,$A6,$76,$BD,
$5D,$87,$3E,$31,$74,$09,$3F,$57,$F8,$68,$49,$D1,$CC,$D4,$8F,$E4,$56,$13,$77,$9C,
$D6,$A3,$ED,$5D,$85,$17,$76,$50,$AE,$D2,$33,$D2,$37,$7B,$2A,$09,$71,$05,$98,$5B,
$42,$F1,$2A,$36,$98,$EC,$59,$72,$45,$59,$94,$D6,$8F,$50,$45,$D5,$58,$FA,$7A,$15,
$09,$78,$55,$F0,$BA,$70,$0F,$89,$B1,$71,$F7,$98,$5D,$46,$F3,$25,$16,$CE,$52,$3C,
$B4,$5B,$CF,$EB,$DE,$55,$23,$5A,$FB,$25,$53,$EE,$20,$0D,$62,$25,$0C,$01,$09,$CC,
$A0,$00,$89,$99,$AF,$77,$94,$9C,$0D,$93,$98,$FD,$DC,$7B,$AF,$6F,$03,$63,$4A,$40,
$31,$5B,$22,$96,$58,$61,$6E,$C6,$00,$9C,$74,$DD,$C0,$82,$80,$02,$71,$12,$79,$06,
$E3,$85,$25,$5A,$4E,$09,$1A,$33,$1A,$B8,$44,$50,$F9,$A3,$BD,$75,$9D,$81,$C4,$B1,
$D9,$2E,$43,$60,$65,$5A,$E0,$AE,$36,$D9,$A3,$B0,$1D,$04,$90,$81,$69,$5E,$1D,$58,
$91,$8B,$ED,$E2,$91,$F1,$8E,$72,$00,$58,$DD,$E0,$8D,$78,$E2,$AC,$EA,$3D,$FA,$BF,
$AD,$DB,$5A,$A2,$D8,$BA,$EA,$1A,$76,$D1,$32,$47,$DF,$73,$EB,$55,$06,$86,$45,$80,
$97,$AA,$0A,$98,$DE,$55,$84,$46,$C3,$2F,$7D,$A5,$18,$05,$86,$77,$3D,$34,$BC,$AB,
$9D,$14,$65,$B5,$6A,$38,$7F,$BA,$AA,$43,$0A,$E5,$71,$37,$F8,$E5,$EB,$2A,$06,$DA,
$AD,$43,$A4,$48,$74,$0A,$8F,$99,$2D,$85,$2B,$F6,$64,$0F,$32,$09,$49,$9C,$A6,$60,
$7A,$3E,$61,$9B,$3C,$F1,$6A,$75,$55,$5A,$8B,$E4,$5D,$35,$BC,$65,$C5,$34,$F9,$31,
$A9,$55,$78,$4B,$1A,$5B,$01,$6F,$5D,$98,$53,$E7,$AA,$EE,$FB,$6B,$26,$7D,$67,$5D,
$05,$2C,$FB,$FA,$34,$35,$1C,$6D,$EB,$AA,$29,$2D,$19,$01,$E1,$69,$82,$37,$7D,$61,
$7A,$B1,$AE,$9E,$E7,$A7,$AA,$92,$C2,$1E,$CD,$E4,$44,$13,$52,$50,$2A,$57,$F9,$EB,
$FA,$21,$A4,$A8,$38,$EB,$20,$6F,$29,$28,$2A,$BB,$0E,$01,$E9,$89,$D5,$B4,$12,$39,
$EB,$AA,$2B,$DC,$F1,$B1,$42,$16,$56,$C4,$F2,$98,$CC,$BA,$2A,$3F,$14,$EC,$1D,$7B,
$24,$2C,$18,$57,$4C,$44,$4B,$FD,$BE,$79,$9C,$3E,$6B,$A9,$FE,$21,$BD,$60,$64,$30,
$5A,$9F,$A9,$9D,$85,$E5,$5F,$17,$7E,$A6,$63,$67,$5D,$15,$28,$C8,$70,$EA,$2A,$AF,
$80,$92,$3A,$49,$AD,$92,$0E,$70,$DD,$D4,$55,$31,$73,$1B,$8E,$1A,$53,$9E,$5A,$67,
$A2,$30,$78,$05,$F3,$0C,$62,$DE,$5C,$19,$1D,$58,$72,$9F,$47,$20,$4A,$5D,$97,$B8,
$2C,$2B,$02,$E3,$55,$09,$C6,$0D,$44,$7D,$49,$7B,$CD,$54,$45,$2D,$63,$AB,$34,$2D,
$A9,$42,$C8,$00,$CA,$79,$1F,$47,$8E,$DB,$78,$D4,$55,$D0,$8E,$82,$D7,$04,$7B,$21,
$19,$0C,$19,$E5,$DA,$E9,$F1,$F5,$39,$EA,$C0,$32,$C1,$55,$16,$CB,$8D,$BA,$4A,$2F,
$26,$55,$AC,$71,$F9,$AA,$64,$9D,$9A,$FC,$86,$A6,$ED,$F8,$F0,$AE,$2F,$CF,$57,$9D,
$D9,$64,$E9,$24,$10,$3E,$06,$1C,$B9,$4D,$32,$57,$45,$09,$AF,$2A,$5E,$B9,$E7,$AB,
$86,$E0,$C8,$20,$83,$D6,$1D,$69,$09,$B8,$20,$1C,$62,$04,$3B,$01,$F3,$0B,$48,$C8,
$86,$84,$75,$25,$6F,$88,$11,$F6,$2F,$4C,$B3,$17,$7C,$55,$92,$D1,$AC,$43,$48,$12,
$0E,$98,$DB,$D2,$71,$BF,$4C,$67,$93,$58,$09,$4B,$C0,$D6,$F0,$AB,$4E,$19,$F1,$1A,
$61,$FA,$B1,$C0,$E2,$E2,$AB,$3D,$D0,$04,$6C,$76,$22,$2E,$13,$B6,$CD,$50,$60,$3A,
$57,$95,$3C,$B0,$5E,$DA,$AE,$7E,$C7,$AB,$24,$E5,$CD,$27,$B0,$7E,$D5,$67,$A8,$8A,
$87,$3A,$37,$2F,$E8,$39,$94,$0F,$F7,$F0,$50,$55,$9B,$1B,$BF,$2A,$B7,$5F,$A0,$50,
$AC,$0A,$92,$CE,$BC,$91,$20,$24,$74,$7E,$55,$CB,$35,$E4,$10,$B4,$25,$5A,$0F,$CA,
$77,$03,$5D,$F9,$DF,$BB,$04,$7A,$7E,$55,$A1,$E2,$53,$31,$D9,$EB,$DF,$B9,$E6,$AB,
$52,$7C,$95,$2A,$92,$FA,$C4,$C1,$84,$39,$5F,$D5,$E3,$91,$7E,$55,$4C,$90,$5A,$D0,
$64,$1F,$99,$9D,$FA,$55,$17,$A4,$EA,$90,$44,$4C,$57,$6C,$A2,$AB,$6A,$90,$A6,$06,
$05,$62,$62,$22,$A9,$62,$E2,$26,$2C,$45,$7F,$85,$8A,$91,$9A,$0D,$4E,$C6,$BE,$4F,
$C4,$E6,$5F,$25,$2A,$2E,$FD,$5A,$89,$B3,$F3,$45,$6D,$9C,$AF,$5D,$95,$82,$88,$26,
$31,$BE,$2A,$4D,$9F,$A0,$C9,$8E,$1F,$F4,$F0,$1E,$F2,$83,$FC,$0C,$76,$BE,$AA,$50,
$9E,$39,$D8,$0A,$79,$A7,$60,$24,$62,$B7,$03,$BA,$70,$91,$88,$A4,$06,$35,$A9,$A0,
$94,$48,$A4,$DA,$84,$25,$66,$23,$99,$7D,$53,$C0,$AF,$15,$46,$CC,$7F,$43,$4B,$51,
$A1,$05,$32,$B7,$05,$B7,$9E,$78,$54,$F7,$90,$E2,$AB,$F5,$CA,$9C,$FF,$0E,$0A,$A2,
$3A,$53,$5D,$4A,$21,$54,$35,$5C,$99,$7B,$FE,$7D,$FA,$CF,$64,$79,$12,$7C,$4E,$FB,
$3F,$02,$E3,$F8,$5F,$6F,$F6,$91,$B8,$36,$3E,$42,$C8,$F7,$4D,$EA,$5F,$89,$FF,$D2,
$E2,$1A,$63,$43,$FF,$DA,$D2,$EE,$97,$A5,$CC,$8F,$95,$EA,$EC,$D6,$D5,$93,$67,$A2,
$B7,$EC,$8A,$D1,$61,$00,$18,$75,$43,$A9,$EE,$EF,$38,$76,$D6,$B6,$2E,$FA,$1B,$9B,
$DF,$28,$7D,$3F,$30,$51,$2A,$10,$A0,$10,$DC,$97,$36,$DF,$D5,$4C,$5D,$5E,$CC,$FE,
$DC,$E4,$11,$44,$4B,$E6,$EE,$B0,$01,$4A,$D3,$CB,$F1,$FE,$65,$AB,$22,$1D,$D6,$31,
$55,$8A,$8B,$44,$B9,$20,$7F,$55,$A0,$6E,$0B,$F6,$66,$01,$FB,$CA,$36,$8B,$5E,$CD,
$AE,$8E,$4E,$9D,$4C,$5B,$DC,$BE,$53,$BA,$94,$7F,$A2,$C4,$AE,$AA,$5B,$E5,$EF,$13,
$DC,$57,$A1,$C4,$A8,$E5,$98,$4F,$7D,$8A,$0C,$11,$7D,$16,$96,$60,$46,$AE,$73,$AD,
$D8,$AB,$AD,$7E,$57,$C7,$FD,$2E,$58,$09,$CA,$76,$13,$74,$49,$60,$44,$92,$60,$09,
$1A,$C5,$F4,$76,$47,$AE,$D9,$58,$91,$A1,$16,$C1,$4C,$53,$B5,$E0,$4B,$CC,$C2,$85,
$5A,$37,$21,$57,$89,$FB,$A8,$AC,$68,$1C,$EA,$86,$14,$57,$22,$94,$41,$E1,$50,$0A,
$08,$FE,$CE,$53,$55,$DE,$AB,$03,$10,$F6,$55,$92,$BE,$22,$8B,$88,$A8,$33,$DE,$2D,
$B7,$4C,$DC,$71,$9A,$69,$89,$58,$64,$D1,$58,$5B,$2E,$C4,$EA,$7E,$78,$E2,$F3,$EF,
$47,$A1,$8F,$57,$29,$44,$9F,$0B,$17,$03,$81,$FA,$FE,$A8,$F0,$7C,$D9,$02,$A2,$A8,
$14,$A3,$37,$DC,$75,$21,$93,$83,$F3,$8D,$BA,$8B,$2E,$47,$DA,$C4,$8C,$12,$3C,$57,
$34,$11,$9C,$55,$21,$3A,$48,$27,$C3,$22,$40,$B1,$A7,$22,$58,$52,$23,$F6,$6D,$BC,
$C8,$08,$C2,$B5,$B9,$34,$01,$B9,$98,$24,$EA,$A4,$04,$28,$6C,$62,$FD,$7F,$33,$5C,
$C9,$44,$B1,$DA,$00,$49,$48,$77,$5E,$AC,$91,$A5,$86,$BA,$5F,$D3,$CF,$EE,$02,$B5,
$F6,$70,$93,$DB,$AF,$3B,$66,$14,$7D,$27,$A1,$9B,$B3,$95,$FB,$8A,$3B,$C1,$E9,$87,
$BD,$DF,$97,$23,$24,$DD,$17,$99,$D5,$63,$84,$A0,$D4,$EA,$33,$CF,$B6,$AF,$14,$91,
$BE,$F0,$61,$25,$6A,$F5,$A7,$5D,$A4,$EA,$47,$47,$06,$86,$FD,$82,$A9,$AB,$32,$9D,
$5E,$01,$2D,$0C,$AA,$8A,$C8,$FF,$F7,$70,$55,$D9,$C0,$E2,$07,$59,$4B,$BB,$8A,$D3,
$EA,$CA,$FF,$A1,$8F,$B8,$ED,$D3,$8E,$C1,$28,$C6,$62,$0F,$56,$00,$1D,$26,$39,$B7,
$D9,$D9,$D5,$96,$B8,$0A,$33,$C3,$1E,$BF,$3F,$41,$21,$95,$F0,$DF,$09,$2F,$51,$BD,
$BA,$40,$34,$C8,$7F,$A7,$25,$5B,$04,$5D,$EF,$DC,$BF,$E4,$BB,$84,$B8,$D3,$8D,$5D,
$BB,$4A,$E3,$01,$8E,$99,$3A,$7F,$0D,$C7,$F0,$85,$F8,$D8,$09,$73,$A0,$C8,$32,$52,
$50,$B4,$44,$43,$50,$79,$17,$A3,$68,$79,$77,$05,$74,$A0,$E8,$D4,$DF,$A9,$EE,$C0,
$FD,$15,$76,$5B,$8A,$E8,$96,$09,$9D,$7A,$B3,$F3,$F0,$F7,$EF,$1A,$FE,$A2,$22,$31,
$95,$86,$D4,$9D,$31,$91,$B4,$35,$E1,$BA,$23,$AC,$94,$BF,$AE,$D0,$11,$30,$49,$83,
$B1,$F4,$9F,$4B,$81,$69,$F8,$30,$34,$C7,$A8,$52,$BD,$51,$17,$E3,$DB,$28,$D4,$05,
$05,$61,$9C,$37,$84,$2D,$E3,$91,$05,$49,$91,$D9,$6F,$D6,$D7,$77,$91,$05,$49,$6D,
$D9,$D5,$2B,$5F,$6A,$14,$78,$5A,$73,$77,$29,$59,$80,$14,$F5,$EE,$22,$3D,$B0,$70,
$6A,$5F,$5A,$5F,$D6,$18,$29,$5F,$60,$15,$65,$63,$A8,$E5,$DE,$8B,$7D,$05,$88,$51,
$FE,$57,$8B,$03,$18,$CA,$DA,$F7,$BE,$81,$1C,$18,$71,$62,$7D,$9C,$9C,$BD,$F9,$BA,
$1C,$47,$B6,$F9,$3A,$D5,$9B,$B0,$A3,$8D,$36,$40,$7F,$1B,$F8,$5D,$DA,$7E,$F6,$F8,
$D4,$B0,$1E,$29,$E2,$C0,$A0,$D1,$4E,$DF,$55,$1C,$82,$7F,$B0,$C2,$DE,$75,$63,$BB,
$4B,$E1,$D8,$BD,$B5,$C4,$E5,$29,$3B,$07,$08,$CE,$B1,$80,$EB,$0B,$43,$F3,$33,$50,
$7E,$D9,$3A,$97,$E7,$7F,$F8,$7A,$16,$86,$FD,$15,$E1,$F1,$C5,$85,$B3,$D4,$5B,$24,
$2C,$14,$87,$29,$34,$35,$BF,$29,$F0,$8A,$C2,$C2,$00,$0E,$12,$A0,$DC,$1B,$00,$2E,
$14,$50,$A8,$AA,$0B,$20,$60,$58,$E0,$0A,$73,$51,$92,$10,$24,$AD,$73,$D5,$71,$0F,
$BA,$AD,$3B,$DF,$78,$8D,$BD,$9E,$7F,$65,$80,$71,$66,$21,$9F,$A7,$15,$AF,$00,$E4,
$4C,$A7,$B5,$E5,$85,$9A,$AD,$F8,$D6,$7F,$32,$B3,$8A,$C7,$01,$59,$50,$FB,$8E,$D6,
$FD,$02,$A3,$0E,$0B,$85,$C0,$DB,$08,$CB,$AE,$2B,$AC,$F6,$56,$D7,$FC,$77,$B9,$58,
$9F,$91,$80,$1A,$0B,$B6,$90,$1A,$DE,$57,$95,$C8,$53,$6F,$4D,$43,$F7,$E9,$69,$62,
$92,$EC,$BB,$42,$AE,$C7,$67,$30,$30,$69,$08,$B8,$CA,$CC,$76,$F4,$7D,$57,$D8,$AE,
$4B,$48,$5C,$1D,$14,$9B,$89,$60,$08,$28,$BA,$60,$C1,$43,$F3,$25,$C1,$21,$22,$C2,
$44,$30,$DE,$57,$08,$05,$C3,$A2,$DF,$29,$AF,$9F,$5B,$9B,$A1,$35,$76,$0F,$41,$0C,
$5A,$A3,$F8,$F1,$54,$44,$53,$77,$9D,$88,$D4,$E6,$FE,$E8,$AB,$85,$B0,$2F,$FD,$27,
$9E,$F7,$BE,$42,$4E,$89,$C2,$57,$95,$6A,$F0,$47,$55,$97,$E1,$FB,$55,$95,$80,$F5,
$E0,$A1,$3A,$4B,$13,$4F,$76,$78,$14,$2E,$46,$FA,$ED,$AD,$BA,$7F,$70,$64,$65,$C6,
$99,$55,$91,$A8,$D2,$97,$8B,$6B,$64,$1F,$D7,$9F,$18,$24,$01,$FF,$2D,$69,$F4,$16,
$BB,$93,$66,$28,$78,$96,$8E,$44,$1E,$28,$B8,$A5,$B2,$AE,$3B,$D6,$D8,$E4,$62,$B0,
$64,$4C,$4F,$B2,$6A,$BB,$F7,$15,$22,$DD,$F2,$D2,$A3,$31,$D8,$57,$9F,$5F,$18,$E0,
$15,$C8,$42,$64,$35,$7E,$32,$82,$91,$34,$CE,$5C,$39,$30,$6E,$2A,$1C,$EB,$EF,$7D,
$85,$90,$A5,$BF,$F4,$22,$60,$0E,$F9,$5F,$1E,$1E,$EA,$0E,$64,$50,$23,$20,$66,$1B,
$90,$28,$C4,$05,$A0,$4C,$5A,$4E,$7E,$28,$35,$41,$49,$57,$49,$BA,$D2,$EC,$11,$73,
$C2,$BB,$F8,$5E,$2A,$4C,$10,$AD,$01,$10,$71,$E0,$69,$92,$12,$54,$A1,$1F,$90,$7D,
$55,$81,$10,$2A,$E4,$ED,$F5,$22,$8B,$15,$C3,$03,$86,$F1,$CD,$FF,$0D,$4F,$C0,$F9,
$5F,$15,$96,$C2,$34,$24,$C1,$B4,$F0,$FD,$44,$23,$59,$55,$76,$48,$CC,$05,$3A,$C7,
$6B,$30,$AA,$15,$74,$7F,$B7,$EF,$E5,$F3,$C2,$48,$42,$1A,$02,$05,$87,$69,$0E,$DB,
$06,$90,$9C,$25,$20,$21,$1B,$7C,$50,$2F,$24,$27,$24,$1C,$12,$D5,$8B,$46,$18,$05,
$17,$03,$19,$4B,$AB,$0A,$D8,$13,$20,$D5,$3D,$2C,$9C,$8C,$EA,$23,$65,$CE,$29,$BB,
$D2,$51,$02,$5E,$48,$F1,$92,$D5,$15,$38,$7F,$0E,$FA,$5F,$D5,$9E,$E4,$F1,$4B,$C6,
$B8,$DC,$DD,$9D,$49,$EE,$5C,$90,$CB,$5B,$86,$D6,$9C,$28,$55,$5E,$31,$01,$1F,$88,
$78,$00,$0A,$96,$B7,$5D,$87,$67,$61,$21,$D8,$D6,$E5,$EC,$69,$26,$78,$3B,$1F,$06,
$14,$A9,$54,$B7,$62,$34,$AB,$41,$51,$4E,$55,$F1,$07,$B5,$80,$EA,$82,$AA,$2B,$44,
$BA,$E7,$22,$16,$81,$E3,$D8,$D1,$8F,$89,$BE,$C1,$A5,$D0,$95,$B6,$33,$60,$6B,$F0,
$E0,$E2,$E2,$EE,$C8,$C2,$9C,$E6,$FA,$CA,$11,$DF,$02,$2D,$99,$60,$99,$21,$60,$7D,
$1D,$8C,$95,$B5,$68,$0E,$50,$A4,$A5,$33,$EC,$9B,$0F,$7B,$08,$C4,$39,$26,$16,$29,
$7B,$FA,$94,$F1,$0C,$35,$BF,$CE,$95,$C8,$DA,$11,$00,$43,$56,$66,$E8,$87,$ED,$E6,
$42,$8E,$D3,$C3,$53,$1D,$A0,$99,$1D,$3D,$90,$97,$C1,$80,$38,$38,$3D,$27,$3E,$50,
$D7,$B0,$18,$C5,$87,$57,$30,$C3,$BD,$98,$50,$94,$A6,$C1,$47,$A4,$32,$4A,$A8,$C8,
$6C,$B8,$93,$05,$D5,$1F,$F1,$55,$09,$EF,$AE,$65,$4E,$FA,$2B,$D1,$A8,$64,$F8,$33,
$DE,$F9,$DE,$9C,$18,$B7,$A4,$AD,$6A,$5C,$45,$A6,$92,$CE,$A7,$6F,$5F,$2B,$70,$2D,
$52,$81,$B5,$F5,$A9,$82,$F5,$EC,$FB,$75,$13,$F7,$4C,$6B,$B4,$E2,$90,$91,$47,$BA,
$94,$FA,$1A,$A4,$20,$A9,$BA,$0A,$38,$02,$48,$02,$8A,$6F,$68,$72,$E4,$78,$96,$F2,
$EF,$48,$C5,$DB,$B3,$D8,$A4,$5A,$30,$8A,$62,$D2,$B5,$6D,$B1,$1C,$18,$DE,$DE,$82,
$A1,$40,$B5,$EA,$E8,$12,$5C,$FE,$C2,$8F,$7D,$E9,$05,$C5,$2E,$CD,$91,$49,$7E,$FB,
$22,$5C,$3E,$96,$27,$DC,$44,$35,$D3,$55,$21,$26,$7D,$D4,$E3,$BA,$E6,$AB,$BF,$24,
$77,$57,$6C,$00,$56,$B3,$FA,$D2,$27,$69,$5F,$09,$6A,$C1,$68,$56,$0C,$D4,$DE,$99,
$58,$4C,$B2,$38,$C3,$61,$A1,$79,$BD,$18,$05,$5F,$29,$C7,$CC,$0A,$AB,$AB,$D7,$EA,
$A4,$8B,$B3,$07,$18,$5E,$F8,$8C,$2D,$8E,$47,$90,$75,$35,$31,$EB,$22,$1C,$29,$CE,
$19,$75,$D7,$F4,$A9,$12,$0E,$DB,$B6,$AF,$73,$BA,$0F,$C0,$5A,$D5,$E1,$5A,$A7,$E5,
$63,$64,$F4,$08,$DF,$8D,$9B,$CF,$6D,$46,$30,$76,$F2,$5A,$72,$91,$B0,$C0,$98,$44,
$D8,$4B,$6D,$0E,$4D,$6F,$C3,$C3,$59,$B8,$5A,$93,$7D,$17,$42,$5F,$05,$90,$F3,$7A,
$83,$70,$77,$95,$F4,$7D,$AF,$C1,$3B,$DD,$B8,$79,$EA,$3E,$31,$8A,$3B,$0A,$48,$E4,
$55,$2B,$C5,$09,$36,$76,$2C,$29,$37,$7F,$57,$84,$AE,$CA,$DF,$36,$DA,$EB,$33,$D1,
$78,$EA,$AB,$3B,$F2,$1E,$95,$C8,$DF,$33,$A6,$FA,$02,$02,$7E,$1B,$24,$E7,$5F,$4D,
$B4,$B7,$75,$D0,$F5,$23,$0F,$47,$A9,$C5,$A2,$2A,$B4,$B6,$63,$FC,$55,$C4,$BA,$E1,
$8E,$50,$75,$A6,$8D,$47,$AB,$65,$85,$83,$63,$AB,$A7,$CC,$2B,$4E,$79,$BE,$B5,$59,
$37,$06,$51,$C0,$9E,$84,$5F,$77,$FB,$03,$59,$7A,$EB,$C6,$50,$C0,$B0,$E4,$80,$23,
$94,$71,$CD,$50,$6C,$B1,$2E,$CE,$68,$AE,$B7,$AE,$9E,$AF,$D6,$FC,$1E,$4F,$AB,$20,
$D6,$01,$A5,$30,$05,$C0,$BA,$72,$B8,$36,$B4,$6B,$86,$39,$35,$FB,$00,$C1,$82,$83,
$FB,$EE,$99,$D0,$2F,$82,$D2,$56,$20,$36,$DE,$8F,$11,$70,$92,$CE,$4F,$43,$44,$0D,
$CF,$7B,$4F,$89,$F0,$8F,$45,$AA,$A7,$71,$07,$DD,$85,$A9,$81,$40,$32,$B3,$AF,$38,
$5C,$00,$45,$C9,$64,$52,$EA,$46,$63,$D3,$B3,$FA,$44,$23,$71,$54,$CE,$7A,$7F,$62,
$0E,$5C,$46,$5C,$3C,$5B,$CA,$0D,$D4,$BD,$83,$E1,$B6,$C9,$69,$77,$AC,$BB,$70,$59,
$5D,$3D,$8C,$54,$2C,$73,$74,$E8,$75,$D9,$7A,$00,$AD,$7A,$75,$05,$13,$42,$2C,$DA,
$C1,$70,$00,$F7,$41,$87,$A7,$22,$81,$18,$25,$9B,$4A,$78,$6C,$19,$B6,$52,$B8,$31,
$98,$E1,$6A,$CD,$BA,$52,$86,$90,$11,$E9,$C3,$84,$85,$14,$3D,$EE,$E8,$97,$AF,$3A,
$C7,$42,$42,$FD,$FA,$9B,$EE,$EE,$37,$54,$3B,$01,$4B,$21,$FE,$57,$35,$40,$15,$BF,
$72,$68,$56,$5D,$FC,$F4,$BD,$EB,$7B,$5E,$75,$50,$F1,$19,$66,$B1,$02,$ED,$7F,$14,
$3D,$33,$7C,$25,$C0,$AA,$45,$17,$48,$E7,$89,$BA,$B3,$57,$35,$40,$62,$D9,$61,$F0,
$63,$37,$F6,$FF,$C9,$1D,$0C,$82,$97,$EF,$E9,$CC,$62,$75,$6B,$B4,$25,$62,$F5,$B7,
$C4,$E3,$1F,$1F,$54,$99,$54,$81,$1D,$82,$89,$8F,$FF,$4B,$4E,$FA,$84,$C7,$10,$81,
$37,$3D,$2A,$38,$6F,$ED,$CE,$7D,$15,$67,$C9,$E3,$1C,$F9,$61,$86,$84,$4D,$55,$05,
$45,$8C,$85,$0C,$1F,$80,$1B,$CE,$10,$62,$C3,$76,$4F,$A7,$68,$19,$C3,$1E,$A6,$D9,
$EF,$A6,$A6,$38,$7F,$5C,$C8,$8E,$BF,$2E,$CC,$2E,$06,$DF,$BF,$89,$52,$83,$A4,$08,
$0C,$22,$39,$59,$BC,$0A,$31,$15,$44,$E5,$C2,$FB,$37,$5B,$3B,$C8,$39,$2F,$29,$FA,
$25,$3A,$AE,$D3,$A4,$38,$06,$E4,$23,$D5,$D6,$57,$34,$7F,$13,$42,$F4,$1A,$8D,$CD,
$EB,$05,$C1,$01,$C7,$E6,$55,$71,$61,$81,$83,$4F,$04,$E7,$FE,$9A,$3B,$E2,$CD,$E8,
$9B,$5B,$E9,$DA,$E2,$3B,$52,$F5,$FE,$8A,$9E,$DC,$12,$C5,$17,$ED,$F7,$1D,$70,$57,
$80,$82,$0F,$F7,$77,$D4,$32,$2C,$36,$6B,$FA,$8F,$68,$59,$65,$AE,$D9,$AD,$76,$4B,
$0C,$93,$19,$D3,$68,$C1,$84,$BA,$88,$29,$B0,$12,$DC,$5D,$31,$8E,$0A,$BA,$0D,$D6,
$C1,$E7,$7F,$83,$CA,$F9,$B2,$7A,$91,$9E,$B0,$FB,$EA,$D2,$A7,$0A,$3B,$01,$D3,$37,
$33,$68,$2B,$A0,$C5,$8E,$8B,$8B,$7A,$11,$DE,$95,$92,$10,$B5,$AD,$C3,$C2,$C0,$29,
$54,$33,$35,$A7,$84,$FC,$61,$FF,$41,$EC,$EE,$01,$B7,$BF,$0A,$AB,$AE,$96,$0B,$40,
$0C,$9A,$5E,$1E,$E6,$09,$18,$92,$0E,$0E,$15,$E9,$B6,$B8,$11,$47,$61,$BF,$61,$87,
$98,$48,$0D,$C7,$2D,$9B,$80,$25,$90,$08,$96,$D3,$2E,$CD,$87,$86,$FC,$42,$30,$28,
$FF,$37,$51,$B7,$2D,$76,$EE,$16,$45,$7D,$76,$7E,$A6,$D6,$FE,$E4,$76,$45,$E5,$53,
$B0,$EC,$86,$40,$FE,$D5,$86,$65,$CB,$C0,$76,$0E,$A7,$AE,$03,$77,$D1,$3B,$55,$68,
$A0,$C1,$10,$A8,$C2,$01,$56,$27,$85,$FF,$E7,$0D,$FA,$BF,$3D,$6E,$5E,$71,$B0,$D5,
$11,$97,$FB,$2D,$87,$7F,$91,$7D,$A4,$E4,$57,$D2,$9E,$2D,$A8,$3B,$22,$59,$1A,$DA,
$CA,$30,$00,$3B,$2C,$E9,$32,$F9,$A7,$EE,$E4,$BC,$EF,$A4,$35,$20,$2B,$C9,$D5,$B4,
$AE,$94,$C3,$E4,$6B,$31,$13,$CB,$72,$77,$EA,$5B,$AE,$0E,$6C,$04,$EA,$FA,$9D,$20,
$B7,$04,$96,$32,$B9,$81,$97,$A9,$52,$88,$BF,$CA,$8E,$15,$B5,$6D,$39,$4F,$AE,$60,
$E6,$52,$1D,$F9,$F6,$B7,$BB,$BA,$C0,$88,$89,$AD,$C2,$D9,$87,$62,$23,$CD,$F1,$3A,
$F8,$59,$E2,$E3,$AB,$84,$8B,$89,$93,$1D,$5A,$29,$E0,$77,$91,$D8,$77,$1C,$59,$C9,
$DC,$AA,$39,$42,$47,$3E,$3F,$45,$FF,$E7,$E7,$D5,$AC,$28,$BF,$94,$6C,$07,$88,$D3,
$1E,$8F,$79,$89,$F0,$93,$A6,$D5,$DD,$4F,$78,$28,$00,$38,$D7,$76,$86,$39,$5C,$3E,
$4C,$7C,$BE,$C0,$62,$24,$EC,$5A,$8A,$B6,$62,$58,$A5,$AA,$CB,$C5,$C7,$02,$DF,$1A,
$14,$07,$EF,$C3,$1E,$7F,$E6,$BA,$C2,$4D,$FD,$BC,$EC,$08,$00,$55,$84,$DC,$79,$B3,
$A8,$72,$AD,$E3,$B7,$AE,$4A,$7A,$DD,$C9,$9B,$E9,$18,$31,$27,$38,$DE,$DB,$95,$6A,
$6C,$98,$76,$BA,$32,$2E,$17,$2D,$50,$41,$00,$F4,$0D,$7E,$4B,$FD,$DE,$CE,$3F,$4E,
$12,$5E,$A1,$A0,$DB,$99,$7B,$9B,$76,$E9,$5F,$47,$A8,$1F,$21,$06,$F7,$2C,$42,$6A,
$E9,$3F,$7F,$C5,$76,$E5,$90,$8D,$C7,$40,$D4,$60,$D5,$1D,$E5,$D2,$19,$A6,$AA,$8B,
$20,$DE,$DA,$47,$72,$BF,$A3,$46,$4F,$A8,$4D,$16,$55,$30,$2A,$88,$EE,$A3,$07,$77,
$36,$0C,$46,$F6,$42,$DF,$F1,$A5,$60,$D5,$FF,$52,$C1,$46,$44,$13,$4C,$E8,$5A,$20,
$23,$51,$C3,$84,$34,$ED,$1A,$4F,$EA,$DA,$EB,$B0,$8A,$A9,$41,$43,$33,$C8,$78,$D3,
$4B,$E7,$D7,$2A,$AE,$1D,$F6,$BF,$AE,$0C,$69,$1B,$0E,$EF,$AA,$72,$FA,$3A,$ED,$4E,
$77,$B1,$31,$13,$DB,$DC,$8C,$17,$EB,$E8,$FF,$20,$28,$43,$64,$6D,$89,$EB,$FF,$19,
$C4,$AF,$F7,$09,$AD,$93,$A9,$C1,$00,$4D,$18,$E4,$77,$15,$F1,$AA,$DB,$31,$1B,$3D,
$41,$58,$D8,$FE,$25,$1F,$80,$26,$0C,$F4,$22,$0F,$E8,$DF,$5E,$39,$DA,$53,$A8,$D0,
$5E,$BF,$C1,$A1,$6A,$30,$F6,$23,$0F,$8B,$CA,$3C,$36,$08,$20,$D4,$89,$98,$A8,$0F,
$C8,$2D,$CB,$A5,$B1,$58,$55,$B8,$13,$D3,$FF,$D2,$BB,$54,$A5,$04,$AC,$02,$55,$4F,
$19,$27,$C5,$5F,$B8,$85,$08,$AC,$FC,$D3,$AD,$29,$E6,$14,$E8,$77,$90,$F5,$83,$13,
$C8,$84,$6C,$90,$05,$BE,$08,$0C,$E6,$82,$13,$70,$82,$EA,$59,$F2,$5D,$C1,$DD,$88,
$B4,$A9,$61,$8F,$FE,$55,$30,$89,$DA,$6C,$D5,$89,$46,$DD,$18,$CB,$47,$EA,$06,$35,
$F8,$5B,$5D,$E4,$1A,$40,$80,$2C,$6A,$71,$EB,$D3,$60,$8B,$0F,$34,$D0,$06,$F2,$5D,
$D8,$B4,$10,$4B,$EC,$95,$0B,$CC,$2A,$6E,$69,$19,$0B,$9F,$EF,$74,$E9,$A3,$0A,$2A,
$51,$72,$5E,$29,$D2,$76,$D3,$9E,$F7,$08,$38,$CD,$1F,$71,$39,$55,$81,$43,$19,$BF,
$AE,$06,$89,$7A,$A6,$EA,$40,$62,$F9,$7F,$E1,$D5,$3A,$D0,$54,$14,$10,$7C,$BB,$C0,
$BF,$8A,$2A,$29,$CA,$EC,$5A,$CA,$55,$AB,$B2,$8A,$E9,$54,$75,$04,$AF,$C4,$3C,$52,
$18,$4B,$B3,$C5,$C9,$84,$82,$E7,$FD,$DE,$B5,$48,$3B,$70,$15,$4D,$46,$6B,$66,$9B,
$6D,$45,$99,$EA,$38,$4A,$7B,$14,$7A,$A5,$40,$00,$A5,$77,$F9,$27,$4E,$42,$2A,$7A,
$79,$97,$2B,$05,$73,$38,$20,$AD,$5B,$0F,$A4,$76,$F1,$FD,$1E,$D5,$C0,$D7,$28,$FF,
$1D,$82,$EE,$FA,$F2,$E6,$6C,$AE,$0B,$CD,$EA,$0A,$0A,$D5,$16,$76,$59,$C2,$91,$D8,
$0D,$1A,$4C,$CB,$6E,$32,$B2,$79,$C3,$74,$A1,$A7,$15,$39,$69,$89,$7B,$B9,$C1,$59,
$50,$7D,$C1,$1D,$5D,$31,$67,$E1,$A9,$AF,$CF,$34,$4D,$D5,$1F,$2D,$F2,$39,$72,$EB,
$3E,$90,$9F,$3A,$C2,$3A,$DF,$D6,$0F,$BB,$0F,$A8,$41,$0D,$ED,$E7,$D7,$D7,$83,$07,
$6E,$83,$36,$01,$49,$3F,$58,$FA,$E1,$FE,$FD,$12,$90,$04,$24,$F2,$F9,$C6,$C5,$24,
$01,$49,$40,$CA,$F1,$EE,$ED,$E2,$40,$12,$90,$04,$E9,$96,$95,$9A,$04,$24,$01,$49,
$81,$9E,$9D,$92,$99,$BB,$4A,$12,$90,$A6,$A5,$AA,$2A,$DD,$27,$03,$CD,$53,$75,$F8,
$57,$90,$84,$35,$56,$B3,$7C,$03,$2F,$FE,$0F,$7C,$9D,$00,$77,$47,$A2,$EE,$A3,$0A,
$86,$76,$8B,$E5,$D2,$57,$56,$6E,$9B,$0F,$F2,$74,$E9,$93,$65,$19,$32,$2C,$B1,$24,
$DA,$88,$B3,$B9,$36,$42,$6D,$B9,$89,$68,$1B,$F3,$E6,$0A,$6C,$A1,$C8,$66,$D8,$8E,
$0E,$D0,$3C,$00,$6E,$DD,$05,$98,$B8,$0E,$2D,$72,$10,$AC,$1F,$B7,$10,$88,$5C,$1C,
$A1,$A1,$1B,$63,$91,$59,$3F,$6D,$67,$99,$33,$9A,$19,$22,$12,$CD,$03,$1D,$11,$22,
$22,$0D,$48,$EE,$65,$69,$22,$32,$0D,$48,$96,$4D,$41,$22,$42,$0D,$48,$BE,$75,$79,
$22,$52,$0D,$48,$86,$7D,$71,$11,$83,$94,$49,$8E,$3F,$85,$89,$B9,$86,$07,$26,$76,
$6E,$B5,$65,$34,$45,$13,$90,$81,$36,$85,$8E,$A3,$68,$B1,$46,$90,$A4,$59,$CA,$AE,
$20,$36,$0B,$A8,$C2,$42,$D1,$83,$41,$DE,$E4,$E0,$4F,$54,$7D,$D0,$92,$4C,$AC,$BB,
$91,$24,$6B,$7A,$3E,$56,$43,$E5,$56,$44,$51,$89,$DF,$49,$55,$4A,$53,$5D,$62,$D5,
$FA,$F5,$3F,$23,$57,$23,$B2,$1B,$7E,$A8,$73,$40,$C4,$75,$6A,$C3,$DE,$D1,$7F,$F0,
$FB,$0A,$C8,$EC,$90,$BC,$C0,$12,$C2,$30,$B7,$35,$3B,$BE,$6C,$90,$E3,$96,$3F,$F8,
$68,$0E,$90,$95,$0C,$EB,$D3,$8E,$0D,$D2,$CE,$E5,$69,$0B,$B4,$28,$AA,$C1,$34,$64,
$CF,$C3,$B8,$0F,$13,$EC,$AE,$45,$CD,$68,$C0,$24,$23,$21,$39,$06,$A6,$9D,$64,$F7,
$26,$2E,$14,$09,$AC,$BF,$7D,$E3,$C2,$18,$51,$0A,$E6,$47,$C5,$FC,$30,$CB,$72,$A5,
$1F,$02,$48,$08,$52,$18,$1E,$D6,$A9,$2B,$0B,$B5,$60,$E6,$23,$5D,$C9,$87,$A1,$1D,
$3A,$52,$8B,$72,$29,$0C,$DB,$CF,$AA,$E4,$55,$48,$83,$1A,$DC,$E9,$1E,$E6,$FF,$E7,
$86,$29,$E4,$E6,$8C,$4E,$85,$41,$9E,$0C,$BB,$EC,$2F,$2B,$C4,$38,$42,$B0,$FA,$32,
$AD,$31,$BC,$96,$85,$60,$EE,$77,$26,$A3,$83,$A9,$C2,$30,$4F,$0D,$07,$E0,$2B,$D4,
$16,$98,$63,$90,$84,$20,$E1,$A0,$DE,$DC,$67,$D3,$9A,$DF,$6A,$72,$87,$51,$1C,$66,
$A5,$EA,$2B,$28,$30,$70,$C8,$C6,$13,$8A,$E1,$8B,$BC,$07,$81,$4C,$A3,$1E,$F0,$7A,
$7E,$A9,$13,$34,$30,$08,$48,$AB,$EE,$30,$F1,$84,$AC,$4E,$DB,$8E,$C0,$91,$A6,$8D,
$98,$70,$83,$BE,$5B,$AA,$AA,$EA,$B5,$95,$62,$DD,$A7,$88,$A7,$8A,$15,$2D,$04,$23,
$9F,$AA,$37,$71,$34,$82,$A3,$E6,$D8,$03,$48,$92,$3E,$C6,$57,$40,$DF,$D3,$02,$A0,
$66,$ED,$B8,$BD,$EF,$F2,$32,$53,$F0,$12,$98,$E7,$B2,$52,$CB,$B7,$F3,$0B,$56,$13,
$1B,$51,$DA,$F7,$37,$A5,$B5,$B0,$B1,$4C,$38,$84,$86,$23,$83,$5A,$19,$05,$13,$00,
$D9,$74,$27,$2E,$55,$E1,$EE,$0B,$CA,$16,$39,$D6,$A9,$AB,$50,$62,$A6,$2A,$CC,$36,
$B1,$2F,$B0,$F1,$5F,$26,$0A,$FF,$6B,$CA,$3B,$F0,$23,$26,$33,$40,$13,$66,$AF,$68,
$C2,$68,$FE,$C2,$9F,$41,$FD,$EB,$7E,$B6,$91,$05,$B5,$E0,$FC,$6D,$5D,$8F,$B0,$90,
$71,$DD,$28,$D8,$C8,$01,$9B,$07,$D0,$5A,$08,$38,$0C,$35,$76,$8A,$B8,$0C,$14,$18,
$68,$44,$56,$BE,$02,$5F,$18,$22,$45,$BB,$56,$E5,$4F,$CC,$07,$48,$48,$48,$9C,$DE,
$D8,$F6,$51,$B2,$7B,$E7,$DE,$24,$94,$86,$EB,$C9,$EB,$17,$E1,$41,$2C,$B6,$2F,$E0,
$02,$FB,$95,$8E,$7D,$E2,$58,$09,$3A,$1A,$18,$4C,$30,$33,$C6,$14,$F9,$7E,$45,$8B,
$5C,$12,$ED,$9F,$6A,$61,$34,$5C,$2D,$63,$F7,$A5,$80,$10,$0B,$57,$D2,$80,$81,$49,
$2D,$59,$C7,$C4,$53,$92,$5C,$C0,$DE,$ED,$C1,$2E,$D1,$C6,$55,$FA,$04,$BF,$11,$78,
$3A,$0B,$65,$B2,$60,$40,$66,$2E,$2F,$14,$4F,$4C,$40,$23,$0B,$CE,$88,$95,$03,$22,
$48,$A8,$2F,$21,$03,$F9,$13,$02,$92,$0E,$F4,$C1,$CB,$12,$02,$92,$08,$E5,$C3,$E9,
$C1,$80,$80,$08,$D2,$F5,$0A,$41,$06,$01,$A9,$05,$C7,$F7,$F7,$32,$08,$88,$44,$6D,
$69,$AA,$E3,$DB,$22,$0C,$0C,$76,$47,$0C,$6F,$54,$11,$61,$F0,$65,$2F,$20,$42,$16,
$44,$33,$17,$A1,$60,$DC,$30,$A7,$20,$67,$8C,$69,$A1,$1C,$60,$CB,$D0,$D9,$80,$84,
$DD,$36,$A4,$44,$D5,$80,$C4,$3A,$B0,$06,$0E,$C3,$8B,$81,$0B,$06,$0A,$D4,$24,$82,
$1C,$F1,$04,$8A,$02,$DC,$4C,$6A,$8C,$CC,$F3,$5E,$A9,$75,$72,$BA,$61,$C6,$B9,$08,
$96,$A4,$1B,$31,$13,$30,$13,$4F,$89,$84,$84,$89,$AD,$8B,$F2,$08,$59,$10,$45,$6A,
$FA,$D8,$95,$56,$C8,$82,$80,$C6,$46,$8C,$B8,$F0,$1E,$B4,$A2,$70,$69,$4B,$01,$5C,
$55,$C7,$B8,$D9,$E0,$1A,$13,$0E,$AE,$26,$B8,$6A,$7A,$D3,$06,$37,$C1,$8B,$41,$0C,
$08,$77,$2D,$41,$40,$08,$79,$FB,$5D,$E1,$DE,$22,$17,$05,$11,$64,$2F,$24,$6F,$84,
$4B,$88,$7E,$20,$9F,$0D,$9B,$BF,$C4,$1F,$90,$41,$92,$C2,$00,$14,$41,$06,$19,$64,
$68,$6C,$70,$06,$19,$64,$90,$44,$78,$7C,$19,$64,$90,$41,$60,$74,$88,$8C,$44,$DC,
$7D,$06,$90,$1C,$38,$F7,$79,$7A,$E0,$22,$EA,$D4,$0E,$AB,$8B,$97,$A6,$30,$23,$47,
$61,$69,$62,$81,$95,$1F,$07,$2E,$72,$09,$16,$BB,$49,$B3,$B6,$02,$B1,$89,$C8,$F0,
$2C,$C9,$BC,$D8,$FD,$B9,$1C,$FB,$26,$B4,$5D,$FE,$0E,$83,$97,$0D,$FC,$AA,$12,$19,
$24,$01,$89,$16,$34,$2A,$3E,$01,$19,$24,$01,$24,$22,$26,$54,$24,$01,$19,$24,$5A,
$6E,$44,$72,$19,$24,$01,$19,$76,$74,$4A,$5E,$45,$13,$24,$01,$64,$42,$42,$6D,$70,
$83,$34,$2C,$20,$C6,$B1,$95,$0B,$8D,$3F,$AB,$2B,$48,$0C,$F2,$58,$00,$E0,$0F,$64,
$8D,$13,$04,$B2,$B5,$38,$AB,$C2,$43,$1D,$F9,$A4,$0E,$63,$5F,$14,$F2,$00,$FB,$FE,
$08,$C6,$EA,$DD,$69,$69,$E8,$AA,$01,$F8,$C6,$70,$F6,$95,$04,$53,$D9,$1A,$6C,$33,
$56,$5A,$61,$68,$9D,$AB,$D0,$2B,$D9,$73,$18,$7C,$AC,$AA,$26,$AC,$B7,$7E,$D5,$20,
$25,$E0,$32,$2D,$32,$12,$B6,$7C,$61,$F6,$F5,$3E,$75,$6D,$D4,$28,$23,$09,$0B,$E4,
$1F,$9E,$DE,$D3,$37,$9B,$21,$D9,$1F,$63,$98,$C6,$B9,$6E,$40,$0E,$AE,$FD,$57,$1F,
$18,$B8,$04,$69,$CB,$34,$62,$87,$18,$A0,$B1,$EB,$BD,$38,$6D,$57,$1C,$47,$9D,$1D,
$E8,$23,$35,$20,$F4,$D4,$A1,$3A,$26,$55,$A2,$35,$69,$3C,$C3,$84,$A1,$8D,$80,$3A,
$D0,$1C,$E7,$D7,$E6,$B1,$66,$0A,$64,$CA,$D5,$80,$79,$F3,$91,$0F,$88,$66,$76,$E7,
$A4,$5A,$EB,$D4,$45,$51,$32,$74,$89,$E2,$BF,$03,$89,$C9,$49,$1C,$36,$19,$66,$4A,
$75,$7E,$C8,$EC,$13,$31,$1F,$68,$B7,$06,$88,$E9,$4A,$C3,$D6,$1F,$2C,$EC,$D0,$74,
$EC,$F2,$09,$1D,$7A,$20,$7C,$88,$47,$04,$97,$A4,$B0,$0C,$4D,$82,$62,$A5,$BB,$A0,
$C6,$B3,$22,$54,$A8,$4B,$04,$78,$0C,$41,$20,$79,$A1,$63,$93,$D8,$00,$BB,$43,$62,
$08,$E8,$55,$CD,$DF,$BF,$B5,$69,$6C,$D7,$13,$49,$CE,$E7,$FF,$0A,$0C,$AE,$70,$A9,
$E9,$58,$4B,$55,$7C,$72,$10,$C6,$2E,$E1,$4A,$B7,$BF,$95,$54,$3C,$7E,$C3,$91,$77,
$CA,$74,$81,$F6,$12,$12,$A0,$A0,$4C,$5E,$02,$95,$D7,$2A,$6E,$CB,$FF,$66,$DB,$51,
$47,$7D,$D6,$67,$65,$8B,$7F,$B3,$34,$26,$01,$A2,$98,$B5,$05,$6F,$12,$DE,$31,$58,
$CF,$88,$DE,$50,$27,$C0,$BA,$59,$96,$E8,$96,$E4,$9B,$FD,$68,$8D,$5F,$D4,$55,$C5,
$CA,$E5,$9B,$8D,$41,$0F,$16,$85,$A3,$44,$6C,$80,$03,$78,$AF,$0F,$1A,$53,$0A,$6B,
$FB,$B8,$9E,$7E,$CC,$31,$F5,$71,$80,$42,$1B,$B1,$9E,$03,$61,$6A,$DB,$3E,$64,$4A,
$DD,$7D,$EB,$9F,$FF,$A6,$6A,$2D,$6A,$4E,$2A,$86,$8E,$6D,$08,$8A,$8F,$AF,$4F,$B4,
$AD,$72,$C4,$BF,$14,$2D,$58,$1D,$80,$5A,$40,$5A,$3B,$37,$A3,$F6,$B8,$30,$B6,$30,
$08,$E7,$F9,$EF,$6B,$47,$4F,$72,$EE,$92,$D5,$BA,$F8,$93,$C2,$3F,$0C,$A2,$9F,$56,
$6C,$F5,$25,$2D,$FF,$23,$F7,$A6,$AE,$DE,$E2,$7F,$25,$4C,$FD,$CC,$51,$8C,$35,$EA,
$8F,$7A,$FC,$31,$B3,$82,$63,$DC,$0E,$7C,$75,$4B,$C5,$AE,$50,$0C,$9F,$3D,$40,$61,
$A7,$A9,$5A,$66,$FF,$9E,$AC,$05,$12,$8E,$F5,$65,$CA,$35,$37,$E4,$F1,$A1,$95,$35,
$EB,$AF,$43,$B8,$14,$41,$C8,$B8,$71,$F2,$6E,$3E,$2D,$78,$2F,$23,$3F,$04,$5B,$BF,
$78,$47,$6A,$5D,$AE,$AE,$F1,$77,$DF,$50,$40,$5F,$7A,$99,$10,$1E,$1A,$BF,$7F,$5D,
$9C,$76,$53,$35,$EF,$9A,$A9,$7F,$05,$E9,$28,$D7,$9F,$CD,$AE,$FB,$C6,$5B,$36,$71,
$CF,$A3,$F8,$E6,$5F,$55,$88,$0D,$48,$FC,$BD,$8A,$2E,$86,$67,$2B,$59,$8B,$C2,$01,
$5E,$BE,$D3,$93,$BB,$B7,$93,$01,$76,$FB,$4F,$07,$36,$E6,$55,$72,$26,$A7,$CF,$43,
$91,$C7,$56,$B5,$FF,$C3,$68,$4D,$B5,$AB,$1A,$56,$CE,$D4,$E2,$38,$06,$8A,$AE,$69,
$05,$46,$AA,$A1,$36,$A3,$A1,$44,$2A,$5F,$34,$B1,$CB,$C7,$9F,$D8,$1A,$48,$0E,$B3,
$24,$53,$71,$EE,$67,$5A,$38,$7F,$70,$8C,$73,$25,$81,$9B,$E5,$82,$DA,$86,$8C,$24,
$16,$1A,$A9,$53,$9C,$B4,$EB,$8F,$A5,$D4,$36,$ED,$2D,$32,$C0,$9E,$FD,$98,$3C,$77,
$73,$5C,$57,$81,$C4,$6D,$E1,$CF,$1C,$1E,$91,$92,$82,$BE,$2A,$41,$A6,$B4,$A5,$D0,
$ED,$9A,$60,$38,$33,$8D,$9D,$0E,$89,$28,$6F,$06,$DD,$F2,$47,$65,$DC,$4D,$F4,$8F,
$7C,$C5,$B1,$88,$62,$9C,$71,$BD,$C3,$C3,$59,$39,$75,$D7,$0E,$A6,$B2,$51,$CC,$60,
$3C,$C3,$7B,$30,$7E,$47,$2F,$8D,$C1,$38,$0E,$EB,$EF,$23,$28,$77,$84,$35,$A8,$DB,
$8C,$13,$8D,$11,$49,$3A,$5E,$BD,$08,$4B,$1C,$55,$D8,$D7,$02,$63,$BA,$FA,$88,$AE,
$EA,$49,$2A,$0E,$BE,$20,$D9,$7C,$07,$2B,$37,$52,$FA,$3D,$25,$77,$FE,$32,$3B,$55,
$A5,$66,$78,$06,$76,$0B,$8B,$12,$FD,$CD,$5E,$20,$27,$F8,$A4,$0B,$DE,$E3,$91,$13,
$06,$C5,$6C,$0F,$1F,$12,$5C,$EB,$7F,$C5,$28,$6F,$69,$D2,$4C,$2D,$08,$5C,$8B,$EC,
$2E,$62,$4B,$90,$E2,$24,$29,$78,$30,$88,$AA,$E3,$D0,$9D,$94,$E6,$A0,$A3,$69,$67,
$88,$32,$92,$3F,$90,$AB,$07,$85,$06,$D3,$17,$AB,$A3,$3E,$D0,$2E,$16,$D4,$E9,$B2,
$79,$5A,$E7,$29,$0C,$CE,$77,$3E,$CA,$EE,$55,$6A,$93,$7E,$4C,$DB,$FF,$A5,$E1,$6B,
$61,$01,$4D,$40,$FA,$11,$AE,$2A,$19,$12,$A9,$48,$42,$4E,$A4,$C7,$F8,$2F,$FE,$62,
$21,$42,$5C,$6A,$8B,$48,$2B,$B1,$FE,$05,$C9,$40,$61,$BE,$31,$5B,$0F,$EA,$AA,$02,
$44,$0E,$95,$A6,$79,$3D,$CF,$05,$FD,$DC,$00,$BA,$45,$EA,$95,$70,$6A,$74,$F5,$B6,
$72,$81,$ED,$C7,$FB,$B3,$2A,$31,$DE,$22,$2A,$35,$F3,$FB,$51,$CE,$83,$A3,$04,$B8,
$1E,$B2,$9A,$0B,$16,$86,$AA,$FC,$8B,$43,$2C,$DD,$EF,$81,$54,$76,$90,$78,$A8,$DA,
$49,$F3,$33,$33,$B1,$E6,$38,$83,$E1,$38,$D0,$84,$86,$68,$7D,$62,$C2,$1F,$21,$35,
$40,$1D,$2B,$B9,$1F,$30,$18,$8E,$37,$5C,$39,$6A,$CF,$7B,$44,$CF,$5F,$A6,$D2,$AE,
$93,$5C,$8A,$28,$26,$BE,$C0,$18,$22,$8A,$A4,$B6,$FF,$4C,$29,$F8,$57,$85,$D6,$A8,
$2A,$0D,$66,$CA,$92,$FA,$18,$5A,$29,$5D,$97,$38,$61,$54,$34,$6B,$AB,$E4,$04,$49,
$36,$44,$42,$4E,$50,$51,$30,$00,$45,$8D,$41,$20,$2A,$08,$41,$69,$4D,$95,$B6,$FE,
$2D,$83,$C7,$CE,$82,$65,$43,$95,$EE,$34,$3C,$C4,$2C,$7A,$AD,$1D,$C5,$22,$C4,$82,
$10,$54,$B8,$B0,$ED,$39,$E1,$83,$32,$0F,$12,$6E,$03,$0C,$4E,$FB,$85,$B7,$2E,$E7,
$F0,$CF,$6E,$12,$E7,$BA,$8D,$A8,$9B,$58,$96,$8D,$52,$8F,$BF,$B0,$2E,$15,$70,$6B,
$19,$8F,$95,$92,$42,$43,$07,$00,$30,$02,$12,$36,$1A,$A4,$6C,$3C,$5E,$AD,$44,$28,
$20,$36,$74,$ED,$DD,$DD,$D5,$15,$16,$21,$57,$8F,$C7,$12,$24,$18,$B8,$A5,$39,$32,
$D6,$F0,$FB,$F3,$1A,$FE,$BA,$60,$97,$01,$5D,$AC,$80,$35,$09,$CA,$08,$B8,$C8,$09,
$C6,$8C,$A4,$A9,$11,$E1,$35,$6C,$49,$E6,$31,$64,$A8,$D7,$9B,$EC,$6D,$F1,$66,$1D,
$20,$62,$05,$27,$7D,$75,$32,$7E,$E1,$71,$9F,$21,$2A,$6B,$72,$6E,$52,$FC,$7F,$11,
$A0,$33,$2E,$C6,$0C,$4D,$98,$A0,$C4,$41,$6A,$FC,$58,$F6,$78,$AB,$F2,$4C,$3E,$1A,
$88,$63,$01,$7E,$F3,$C1,$26,$0A,$E9,$04,$F7,$20,$CB,$68,$0B,$A8,$18,$AD,$94,$71,
$84,$F7,$65,$09,$9B,$82,$80,$0A,$1D,$EF,$D5,$77,$4A,$D0,$24,$B4,$16,$F5,$CA,$ED,
$87,$19,$67,$5F,$A9,$46,$B4,$EE,$37,$E5,$28,$0A,$42,$81,$51,$50,$97,$A8,$B6,$7C,
$83,$14,$76,$FA,$11,$CA,$E6,$72,$5E,$14,$40,$4B,$F1,$9E,$85,$94,$8C,$B1,$B2,$70,
$57,$01,$26,$36,$D3,$BC,$33,$F0,$B0,$3F,$3E,$B0,$AB,$0B,$5A,$F2,$25,$ED,$A2,$7C,
$76,$FE,$64,$AE,$4F,$3C,$D4,$B2,$84,$49,$EC,$0A,$DD,$63,$A4,$63,$2C,$46,$9B,$B2,
$EE,$E0,$01,$97,$FE,$BE,$F1,$B2,$09,$02,$FB,$75,$D0,$A6,$AA,$66,$16,$79,$3C,$0A,
$F8,$93,$F7,$B7,$37,$17,$96,$0D,$F3,$2B,$1B,$56,$9B,$A7,$80,$D6,$09,$E3,$D3,$4D,
$D9,$8F,$B3,$F1,$EA,$09,$96,$79,$FB,$E2,$69,$BD,$59,$92,$34,$F4,$69,$8D,$70,$74,
$70,$71,$0D,$F5,$53,$FB,$B3,$25,$86,$AF,$14,$DC,$5F,$95,$56,$46,$CA,$9F,$4E,$25,
$2F,$04,$2E,$70,$75,$0D,$5F,$5D,$D1,$E5,$9B,$41,$44,$35,$CD,$0D,$2D,$AD,$50,$61,
$C5,$67,$EB,$3A,$35,$17,$04,$ED,$EB,$29,$15,$79,$58,$01,$AC,$E9,$D7,$D9,$BC,$CC,
$59,$A4,$C2,$5C,$6B,$6F,$AB,$57,$5B,$DF,$9E,$5D,$34,$4C,$3D,$41,$12,$05,$49,$E5,
$84,$A5,$4C,$5F,$81,$C7,$9C,$8B,$FB,$44,$2C,$F0,$EC,$D7,$DD,$50,$B0,$CD,$CB,$6E,
$46,$7F,$C3,$85,$29,$99,$2A,$97,$52,$9C,$58,$9F,$E5,$A0,$40,$82,$A7,$59,$84,$08,
$ED,$89,$18,$84,$BA,$7D,$4B,$E2,$40,$D1,$FE,$DD,$3E,$81,$9E,$E6,$6B,$18,$3C,$6A,
$28,$E4,$15,$63,$FE,$1B,$4C,$BD,$DC,$27,$65,$05,$AE,$A6,$15,$7F,$45,$3D,$65,$BF,
$0C,$77,$62,$48,$5F,$2F,$80,$C3,$09,$F0,$2E,$F3,$55,$7B,$34,$D4,$10,$AE,$3F,$18,
$D5,$2C,$A0,$81,$E7,$CF,$D5,$73,$E3,$4B,$F6,$BC,$4E,$2F,$08,$E3,$0E,$0F,$C0,$3F,
$8A,$00,$8C,$FD,$42,$A2,$F0,$20,$76,$F5,$9B,$45,$22,$9E,$F3,$80,$F6,$9B,$A5,$FD,
$11,$BC,$CE,$34,$B9,$BB,$A2,$25,$DB,$DC,$8D,$1E,$55,$55,$89,$E4,$E6,$45,$4E,$3C,
$98,$86,$AE,$FE,$0F,$A4,$5E,$CA,$2B,$4D,$A3,$70,$BE,$81,$E1,$7A,$D8,$F1,$3C,$5D,
$AE,$4B,$51,$3E,$50,$2E,$70,$7A,$3E,$24,$AA,$4B,$89,$B3,$BF,$51,$DA,$72,$70,$B7,
$0D,$E3,$B3,$C1,$B2,$F3,$80,$2C,$1C,$06,$67,$68,$97,$EB,$88,$E3,$5B,$BD,$A4,$FC,
$36,$1A,$24,$35,$AD,$92,$6E,$B8,$FC,$90,$BC,$76,$1D,$A8,$70,$38,$EA,$8F,$F3,$F1,
$0B,$E3,$F2,$BC,$3A,$86,$4B,$DF,$D5,$A3,$DD,$29,$D8,$C1,$DE,$3C,$BF,$F8,$7E,$B9,
$AA,$40,$1C,$48,$FA,$0B,$DF,$9D,$62,$BB,$ED,$D5,$5D,$D6,$84,$2D,$43,$E4,$27,$17,
$EB,$42,$9C,$EF,$66,$78,$5D,$85,$EF,$0D,$E2,$D6,$07,$C3,$BB,$5F,$82,$F6,$BF,$C6,
$FD,$8E,$8F,$D5,$ED,$53,$D1,$70,$78,$D4,$09,$C4,$F3,$55,$55,$8A,$43,$DE,$5C,$7D,
$8C,$8A,$59,$3A,$6B,$2E,$07,$BF,$22,$13,$F6,$86,$48,$53,$35,$4E,$0E,$C2,$E3,$D5,
$35,$09,$1C,$5D,$06,$5F,$DD,$10,$32,$00,$D3,$00,$DA,$AD,$50,$62,$D0,$E2,$B7,$DC,
$77,$06,$C2,$B0,$EE,$4A,$D2,$F3,$80,$4A,$E1,$01,$28,$85,$E1,$A3,$0C,$DE,$6B,$81,
$63,$B4,$F5,$1D,$73,$60,$8B,$FB,$AA,$9A,$40,$53,$1D,$96,$55,$5E,$A3,$1D,$3A,$43,
$5B,$4F,$0D,$0A,$EB,$0E,$98,$11,$A6,$F8,$78,$1D,$3B,$51,$66,$DA,$9B,$38,$DA,$70,
$1D,$A9,$1D,$24,$2A,$11,$28,$31,$61,$38,$2B,$97,$63,$A3,$AC,$AB,$30,$24,$2C,$9F,
$75,$6A,$4D,$6D,$8A,$D4,$19,$A9,$E7,$30,$58,$12,$76,$F5,$17,$22,$E4,$ED,$E7,$FD,
$EE,$CD,$79,$0A,$1B,$56,$36,$31,$FE,$A3,$A3,$76,$A3,$B7,$4F,$C4,$6E,$99,$DB,$C7,
$57,$E1,$AC,$A7,$DE,$F4,$ED,$7D,$45,$18,$E2,$F3,$7D,$00,$48,$1A,$A2,$D8,$94,$91,
$D1,$D1,$E5,$B4,$B7,$F5,$9C,$1D,$F0,$FF,$6A,$26,$02,$BA,$7B,$9E,$F7,$79,$C7,$3C,
$F9,$70,$0B,$8C,$56,$5F,$9B,$7D,$15,$83,$AD,$70,$79,$42,$1C,$05,$F5,$1B,$51,$7C,
$98,$71,$54,$7C,$37,$37,$AF,$16,$19,$83,$FE,$26,$69,$3E,$5C,$7D,$91,$4B,$0F,$2C,
$0D,$9A,$4F,$30,$56,$D3,$88,$7D,$D0,$65,$EF,$C3,$BF,$3B,$09,$B9,$8F,$2D,$43,$30,
$00,$C4,$35,$17,$DB,$B5,$57,$32,$D6,$1A,$26,$26,$9C,$68,$05,$58,$F3,$71,$4A,$25,
$BF,$AE,$BF,$95,$22,$97,$BE,$AF,$30,$EB,$F5,$9C,$7D,$F8,$8C,$F5,$D7,$3A,$9D,$9D,
$BB,$44,$50,$FA,$CE,$2E,$30,$0A,$D5,$F4,$4A,$C1,$D4,$49,$A5,$C6,$31,$2A,$9A,$4E,
$6D,$BA,$C4,$5A,$91,$29,$7F,$4E,$C3,$47,$57,$13,$30,$B0,$73,$BB,$95,$32,$9A,$EC,
$3D,$6B,$8D,$93,$19,$A6,$23,$25,$7F,$27,$22,$84,$65,$FB,$31,$50,$C6,$84,$FE,$BE,
$A8,$ED,$7D,$77,$00,$EB,$02,$25,$C9,$60,$C9,$71,$C8,$7A,$2D,$F2,$00,$1C,$C5,$DF,
$E9,$CB,$6A,$3E,$34,$68,$FF,$69,$27,$2E,$47,$7E,$5B,$80,$14,$98,$2F,$00,$00,$A3,
$F1,$2A,$E5,$00,$CB,$77,$15,$EB,$63,$77,$A5,$4A,$29,$2A,$72,$2D,$85,$4F,$F6,$3A,
$49,$17,$57,$75,$F0,$1F,$A3,$F9,$A6,$DB,$13,$83,$49,$16,$6B,$CD,$5D,$6D,$0A,$C2,
$6F,$CB,$DC,$61,$14,$BD,$67,$22,$76,$ED,$BB,$B7,$AF,$4E,$A8,$BE,$69,$0B,$0E,$90,
$AA,$55,$0D,$94,$BB,$59,$56,$7C,$3C,$6C,$8C,$57,$05,$0C,$1A,$AF,$83,$92,$07,$EA,
$6A,$7E,$07,$6B,$70,$68,$46,$8A,$DF,$6E,$B1,$7C,$5D,$5F,$6E,$D3,$AF,$5B,$63,$31,
$D8,$26,$E6,$FE,$71,$EC,$23,$89,$E8,$AC,$6B,$DC,$0B,$F5,$73,$B1,$97,$7F,$15,$AE,
$25,$B9,$46,$5A,$C6,$FD,$D8,$BC,$F3,$B0,$27,$16,$3B,$16,$88,$5D,$F6,$37,$66,$84,
$B1,$42,$B5,$32,$AD,$29,$11,$AF,$C6,$B5,$61,$AD,$AE,$B4,$94,$EA,$DC,$61,$81,$D5,
$07,$EF,$D4,$0B,$92,$78,$3A,$7F,$D7,$37,$8D,$B1,$90,$93,$D2,$FC,$BB,$18,$9C,$4F,
$29,$F8,$49,$FD,$E4,$3A,$E8,$84,$F1,$09,$16,$76,$60,$14,$4C,$1B,$C7,$21,$42,$0E,
$1F,$8F,$A5,$55,$28,$1A,$B0,$A0,$18,$DE,$BA,$82,$B2,$07,$77,$89,$95,$6C,$B9,$EB,
$D2,$CF,$DA,$E3,$31,$E0,$28,$7E,$07,$24,$46,$FA,$C7,$1A,$6A,$90,$DD,$59,$5A,$78,
$A5,$2B,$52,$72,$2D,$C0,$BE,$CB,$02,$EC,$DB,$9A,$BB,$B9,$52,$F7,$E6,$2D,$10,$88,
$34,$54,$79,$7E,$9C,$88,$BB,$1A,$B0,$5E,$2F,$BD,$E2,$4A,$7B,$B9,$6C,$7E,$38,$B4,
$EA,$7F,$A1,$21,$76,$15,$C6,$F8,$2A,$30,$EB,$65,$F1,$CD,$55,$C6,$A4,$AF,$1B,$FE,
$27,$86,$7D,$95,$F9,$91,$58,$3D,$F2,$F7,$FA,$83,$58,$0D,$C9,$16,$43,$BD,$82,$BB,
$41,$08,$3F,$D5,$D1,$37,$00,$FB,$0A,$45,$5F,$B5,$E5,$F1,$AB,$E1,$AB,$3A,$FA,$57,
$D7,$EE,$40,$DA,$A0,$85,$80,$93,$56,$A2,$E2,$DC,$F3,$C9,$FA,$04,$71,$8C,$DD,$00,
$2D,$C8,$DA,$AF,$05,$F1,$04,$DE,$17,$39,$EB,$FF,$80,$ED,$F2,$55,$DA,$C7,$A6,$06,
$18,$64,$6F,$57,$23,$46,$99,$FE,$7E,$B4,$69,$5F,$85,$58,$2C,$29,$1F,$43,$09,$B7,
$70,$6C,$E4,$40,$93,$96,$A1,$39,$E9,$66,$30,$2C,$51,$25,$E4,$30,$CC,$64,$42,$46,
$50,$A4,$83,$6F,$5B,$5E,$78,$16,$13,$31,$5F,$69,$C0,$46,$6B,$34,$75,$17,$80,$03,
$4F,$8F,$28,$99,$1E,$F9,$EB,$D2,$3F,$E3,$1D,$7E,$0D,$06,$FF,$57,$04,$5F,$9F,$F4,
$2E,$18,$80,$78,$1D,$2F,$CA,$E1,$94,$E0,$2F,$90,$69,$FB,$AA,$B5,$2E,$06,$0A,$23,
$76,$E6,$82,$8F,$83,$50,$54,$1D,$3F,$7A,$2F,$BF,$69,$12,$E7,$22,$DD,$5F,$31,$26,
$8D,$54,$94,$2E,$CE,$0F,$C9,$42,$59,$4A,$DB,$2A,$E2,$E0,$A6,$38,$BE,$2C,$9C,$57,
$2A,$FE,$AA,$AA,$AE,$E2,$D8,$81,$FA,$35,$41,$84,$4D,$F5,$01,$9D,$1C,$A8,$52,$10,
$94,$3D,$E7,$CA,$0F,$96,$6B,$A1,$20,$54,$41,$11,$86,$BB,$4D,$E5,$63,$08,$AE,$0C,
$DE,$1F,$50,$07,$92,$95,$9F,$54,$25,$93,$9D,$36,$4A,$75,$3A,$A1,$0A,$88,$F1,$31,
$09,$58,$34,$20,$AC,$A9,$DD,$54,$F6,$A0,$A4,$D9,$21,$A1,$48,$A8,$2D,$54,$50,$E3,
$20,$7F,$65,$56,$5A,$4A,$9E,$7E,$AF,$0C,$E4,$EE,$CD,$79,$F5,$E7,$91,$E5,$C2,$DA,
$2F,$97,$16,$F7,$46,$AC,$42,$BE,$6F,$39,$59,$18,$26,$98,$4A,$94,$A2,$28,$60,$C1,
$A6,$E9,$31,$91,$55,$D0,$12,$6A,$93,$F1,$A4,$29,$51,$90,$6D,$71,$57,$36,$CA,$E1,
$6D,$ED,$F1,$36,$E9,$A5,$FF,$5D,$85,$36,$6B,$37,$E8,$4C,$6C,$60,$FB,$AC,$8F,$11,
$99,$EC,$22,$EC,$34,$9B,$50,$FE,$50,$54,$64,$62,$EE,$38,$2E,$C4,$5E,$E4,$FB,$18,
$54,$F6,$6B,$4D,$5D,$6D,$43,$91,$64,$20,$62,$DE,$1D,$26,$95,$3E,$13,$F9,$32,$AC,
$FA,$14,$81,$E6,$BA,$FE,$00,$1D,$32,$75,$F2,$52,$3A,$C8,$2B,$BB,$09,$93,$4B,$63,
$81,$59,$87,$33,$C4,$E2,$48,$91,$C2,$A7,$EC,$E2,$EE,$D3,$07,$61,$FD,$FE,$3D,$BF,
$9F,$79,$40,$41,$1A,$B3,$5D,$A5,$77,$A2,$F7,$01,$F0,$EE,$15,$A3,$0E,$66,$9B,$8C,
$6D,$18,$6D,$94,$B8,$A1,$A6,$49,$98,$6B,$47,$16,$68,$C3,$04,$C3,$8F,$32,$41,$8D,
$9D,$A7,$EA,$07,$47,$07,$0E,$DC,$71,$50,$2A,$48,$E9,$8B,$93,$1A,$03,$6F,$8E,$AF,
$4E,$25,$AB,$A7,$92,$A6,$6B,$5C,$0C,$EF,$96,$61,$D4,$58,$9B,$9B,$C3,$65,$A1,$99,
$77,$59,$92,$65,$BC,$3E,$8D,$EA,$D6,$D5,$37,$E9,$8E,$FB,$3B,$E1,$20,$95,$1F,$AB,
$96,$50,$5D,$17,$EA,$42,$BC,$3A,$02,$A8,$C7,$77,$67,$53,$B0,$CA,$6C,$7F,$CE,$10,
$F7,$D5,$AA,$31,$49,$16,$FF,$76,$A4,$D9,$53,$EC,$63,$88,$10,$22,$18,$48,$0B,$88,
$C2,$7E,$50,$E7,$CC,$BD,$08,$BF,$54,$25,$00,$C3,$0A,$E7,$E5,$5A,$43,$00,$24,$43,
$3C,$40,$B8,$A5,$75,$DB,$0E,$FD,$52,$2D,$8E,$D0,$F4,$EA,$2C,$90,$C7,$B2,$BA,$D4,
$1A,$D2,$5C,$00,$A9,$0C,$DC,$43,$08,$AE,$3B,$53,$9A,$E7,$C4,$AB,$E3,$BE,$AC,$FF,
$35,$15,$DF,$E0,$08,$1B,$64,$C9,$77,$B3,$6D,$C1,$EC,$18,$C7,$36,$18,$7B,$49,$63,
$92,$F9,$3D,$41,$BA,$65,$E2,$75,$A2,$57,$06,$7D,$E8,$54,$57,$52,$B8,$AB,$EC,$9C,
$5C,$A0,$B6,$FB,$7D,$D4,$57,$69,$C1,$BE,$5A,$23,$3A,$0B,$8D,$CC,$C0,$76,$02,$D0,
$5A,$0A,$AA,$FD,$34,$C6,$E9,$AB,$0E,$8B,$81,$FF,$8B,$A4,$16,$9F,$3B,$AA,$EA,$AF,
$99,$DF,$E9,$C7,$C5,$DD,$52,$9E,$87,$8D,$2F,$20,$C5,$2C,$1E,$21,$25,$59,$22,$28,
$E2,$A4,$1B,$8E,$61,$CE,$C1,$7F,$C6,$A6,$BF,$4A,$B3,$78,$B7,$E1,$EA,$42,$E1,$99,
$D4,$8E,$B8,$1C,$CF,$C0,$EA,$6A,$39,$53,$F1,$D8,$25,$AE,$48,$72,$EC,$35,$8A,$70,
$DB,$30,$2C,$68,$D7,$81,$EA,$1C,$44,$F4,$0B,$AA,$14,$63,$66,$39,$6B,$B1,$6C,$67,
$97,$45,$04,$4C,$6B,$E6,$05,$01,$E0,$FD,$E1,$B3,$72,$CB,$E8,$2F,$16,$27,$57,$59,
$EC,$46,$AE,$4C,$4B,$57,$22,$C3,$94,$6A,$81,$52,$E9,$A0,$43,$CD,$43,$1A,$01,$2C,
$09,$BF,$4B,$1A,$0A,$94,$2E,$3F,$0A,$AA,$6A,$8F,$01,$40,$46,$EA,$A3,$6E,$77,$AD,
$5B,$5C,$A8,$BE,$05,$64,$CD,$55,$AD,$8D,$2E,$BB,$C6,$76,$39,$93,$22,$F7,$27,$71,
$E5,$4A,$00,$39,$56,$BB,$B1,$92,$B2,$93,$7E,$15,$D7,$38,$BC,$12,$D1,$63,$36,$70,
$12,$9D,$BD,$65,$9B,$9C,$51,$D9,$43,$6A,$8D,$73,$23,$1F,$5A,$FF,$53,$5A,$3A,$5D,
$A6,$BA,$82,$A8,$9B,$75,$DB,$7D,$F2,$C6,$87,$8B,$7F,$5B,$A1,$AE,$EB,$11,$13,$87,
$D3,$85,$00,$B3,$60,$3D,$D4,$3A,$35,$4F,$B7,$BA,$3C,$06,$52,$C7,$B0,$D5,$F2,$D3,
$9C,$30,$FA,$5D,$13,$4F,$66,$7D,$64,$1C,$55,$CE,$A9,$9F,$96,$87,$07,$71,$E1,$AE,
$B8,$D6,$8B,$9C,$08,$57,$9C,$4E,$56,$BD,$AC,$57,$0B,$B7,$F8,$38,$79,$FC,$EB,$1A,
$EB,$CC,$EC,$AF,$C2,$F6,$77,$53,$E3,$8F,$8F,$20,$AD,$12,$8F,$92,$0D,$57,$2B,$9B,
$58,$49,$92,$12,$75,$B6,$33,$17,$15,$61,$FA,$6C,$48,$1F,$AF,$D4,$3C,$A9,$41,$1A,
$8C,$A8,$FC,$B5,$6B,$8C,$67,$91,$C7,$A2,$A7,$71,$2E,$E4,$5C,$C0,$4F,$05,$A3,$A6,
$A8,$1A,$BF,$1E,$33,$7C,$A9,$9E,$AF,$2A,$3E,$D2,$F2,$D8,$4C,$C1,$24,$79,$8C,$AE,
$00,$92,$0A,$C6,$3C,$CC,$78,$19,$88,$77,$52,$FC,$BF,$A8,$72,$C1,$75,$D3,$DD,$AD,
$E6,$05,$CB,$BA,$A7,$F9,$E0,$DA,$9C,$62,$71,$94,$25,$61,$1C,$B2,$CE,$00,$7A,$CC,
$BC,$93,$56,$D2,$72,$1D,$11,$E9,$A1,$0F,$17,$F5,$A8,$4E,$7B,$F4,$74,$AC,$29,$C6,
$60,$8F,$15,$C1,$0C,$8A,$BC,$FA,$2A,$67,$D0,$5F,$BD,$B5,$52,$95,$F7,$77,$DA,$75,
$42,$30,$22,$26,$A4,$DF,$E2,$6C,$CC,$A3,$B6,$E1,$FE,$19,$28,$21,$6A,$56,$DF,$78,
$E7,$15,$93,$3B,$AA,$72,$98,$48,$35,$08,$FF,$57,$93,$F1,$F8,$50,$59,$50,$C9,$6B,
$55,$C7,$38,$6E,$9D,$67,$E1,$58,$86,$36,$2D,$69,$A2,$1C,$16,$2F,$87,$B1,$B7,$08,
$FF,$3D,$C1,$81,$EC,$7C,$9E,$C0,$90,$35,$08,$28,$78,$D5,$FE,$78,$B3,$49,$AD,$67,
$4A,$47,$14,$96,$B8,$E5,$88,$21,$8B,$24,$A8,$0C,$55,$33,$75,$62,$58,$DD,$05,$44,
$F1,$23,$44,$85,$FE,$5D,$7D,$A0,$2B,$5A,$6A,$E3,$64,$64,$6F,$AA,$AA,$A7,$8D,$87,
$8A,$3A,$43,$14,$44,$5D,$14,$31,$3F,$54,$6D,$F7,$EE,$5E,$61,$DB,$50,$90,$15,$43,
$54,$22,$0C,$1D,$49,$42,$11,$ED,$6B,$5D,$1D,$6B,$77,$29,$5D,$D9,$33,$00,$C3,$6E,
$02,$7B,$FD,$CB,$D2,$93,$75,$F8,$F8,$ED,$68,$05,$40,$EC,$7E,$05,$92,$02,$65,$F3,
$80,$0C,$23,$2A,$21,$8A,$95,$84,$85,$9A,$EF,$00,$91,$15,$12,$5F,$8F,$81,$50,$67,
$EC,$5A,$E4,$83,$07,$46,$77,$8D,$37,$65,$5C,$F2,$85,$4C,$17,$7C,$CB,$08,$94,$0C,
$55,$9A,$3D,$47,$B4,$2E,$9A,$04,$E9,$69,$75,$93,$31,$72,$33,$58,$EC,$AB,$40,$56,
$0F,$64,$BB,$2A,$20,$BE,$56,$C4,$55,$27,$6A,$6F,$7C,$43,$A9,$69,$A0,$30,$2C,$9B,
$8B,$87,$A7,$D4,$BF,$44,$4B,$A9,$F0,$FD,$84,$D7,$30,$3C,$40,$49,$86,$F4,$73,$16,
$E9,$90,$F9,$48,$F3,$C2,$BB,$26,$7C,$91,$14,$E5,$FF,$D0,$14,$33,$FF,$E0,$5A,$5C,
$A4,$AB,$3A,$85,$C9,$6F,$75,$60,$08,$A0,$41,$C0,$18,$45,$83,$AD,$F4,$39,$5F,$85,
$25,$E6,$DC,$77,$39,$5E,$D3,$55,$02,$1E,$5A,$31,$57,$D5,$81,$9D,$7A,$E6,$84,$9E,
$FE,$FF,$E4,$18,$9B,$6D,$D1,$B7,$6C,$5D,$55,$D2,$7C,$2A,$2F,$37,$54,$CB,$6E,$AE,
$D6,$E4,$FC,$04,$B2,$36,$41,$47,$33,$1F,$EB,$5A,$F8,$AF,$7E,$15,$E7,$4C,$B6,$8A,
$42,$EE,$72,$A3,$76,$19,$2A,$7C,$6D,$BF,$EE,$73,$C2,$76,$F8,$CA,$B8,$E0,$7C,$AD,
$31,$32,$34,$53,$92,$3C,$E7,$0E,$52,$3C,$A0,$2A,$2C,$E5,$51,$AF,$94,$19,$86,$57,
$A2,$20,$B1,$2D,$58,$32,$9B,$41,$21,$39,$99,$08,$46,$51,$A0,$A6,$8F,$2A,$04,$C3,
$A2,$2A,$E9,$EB,$FC,$1A,$AF,$00,$FC,$A0,$E5,$C1,$84,$86,$8A,$34,$78,$34,$48,$E1,
$FE,$35,$3E,$FC,$FF,$6C,$A8,$87,$5F,$9F,$B5,$F9,$4D,$C6,$30,$1B,$6E,$F9,$DE,$F4,
$BB,$CA,$FF,$11,$4F,$95,$2D,$A5,$53,$0D,$BD,$33,$A7,$B1,$9E,$6D,$EC,$5D,$1C,$E0,
$D9,$06,$09,$19,$08,$40,$8D,$80,$12,$90,$26,$44,$9E,$0A,$48,$6D,$A9,$B2,$8F,$69,
$74,$5D,$61,$98,$90,$9B,$25,$C2,$8F,$04,$64,$F1,$22,$F8,$D1,$3D,$89,$36,$D4,$4A,
$6C,$E9,$6C,$3A,$BB,$BB,$E8,$0A,$33,$FB,$A3,$42,$37,$BC,$B6,$6C,$B4,$6D,$3E,$30,
$88,$FA,$E0,$65,$7E,$CC,$BA,$A0,$51,$15,$B6,$3A,$51,$DC,$A5,$EA,$36,$C0,$03,$2C,
$0C,$52,$B7,$6E,$94,$15,$4F,$39,$9D,$8A,$BC,$AB,$02,$13,$99,$41,$97,$86,$98,$C4,
$4B,$F0,$72,$7A,$0A,$CD,$53,$99,$16,$01,$69,$63,$02,$89,$07,$D3,$36,$E8,$06,$E0,
$DA,$0C,$9D,$0E,$51,$9B,$E7,$31,$D2,$5D,$90,$DD,$C2,$9A,$5A,$17,$86,$BE,$13,$0B,
$03,$B1,$D1,$8A,$84,$CD,$B0,$66,$54,$C7,$B9,$97,$46,$9C,$EF,$B8,$61,$9C,$A5,$A3,
$7E,$EE,$72,$B7,$A6,$1D,$8B,$6B,$64,$85,$AA,$A5,$C3,$1A,$56,$18,$34,$D4,$42,$99,
$85,$9D,$B1,$97,$94,$02,$2E,$0C,$C1,$8B,$4F,$8A,$88,$3B,$7F,$28,$05,$5E,$9E,$FA,
$6D,$95,$F6,$ED,$A4,$10,$B6,$99,$EB,$0B,$3B,$67,$11,$5E,$5C,$28,$8D,$9C,$BE,$C1,
$68,$C8,$D5,$D2,$F9,$84,$14,$B3,$2D,$E4,$04,$94,$B8,$02,$28,$96,$FF,$5F,$9F,$7B,
$55,$B4,$7D,$A2,$61,$AF,$BD,$94,$A1,$42,$3D,$A0,$77,$F2,$48,$A9,$E4,$69,$75,$18,
$58,$98,$0C,$96,$57,$D3,$26,$A4,$FD,$68,$93,$1E,$B7,$57,$69,$5C,$1F,$61,$87,$E6,
$BB,$EA,$97,$9E,$EA,$6F,$AE,$F6,$7E,$3E,$56,$00,$CD,$F6,$CA,$D8,$CB,$C3,$55,$97,
$9D,$06,$F2,$54,$2D,$FA,$D3,$8E,$09,$CE,$28,$F9,$14,$EC,$55,$9F,$A7,$01,$75,$0A,
$E1,$83,$C2,$8A,$3E,$FD,$55,$C8,$4C,$75,$C3,$FF,$42,$28,$43,$1A,$A5,$9B,$09,$7C,
$6A,$C5,$D6,$20,$ED,$8A,$67,$FF,$AB,$95,$48,$41,$84,$A3,$13,$88,$1F,$87,$81,$92,
$85,$63,$B0,$B0,$FC,$AE,$2A,$14,$82,$F8,$0A,$C1,$DE,$A3,$94,$9D,$57,$95,$24,$49,
$9E,$97,$90,$24,$49,$07,$52,$BB,$A4,$BD,$26,$EA,$AA,$92,$A6,$55,$92,$24,$E9,$A1,
$AA,$5B,$5C,$24,$7D,$42,$5D,$6F,$50,$6C,$BF,$AA,$92,$71,$92,$A4,$10,$6C,$7C,$75,
$46,$4F,$49,$92,$24,$49,$48,$41,$42,$43,$5C,$9E,$FC,$55,$25,$45,$FD,$4B,$21,$D8,
$48,$39,$9A,$EA,$AA,$61,$34,$A6,$01,$A2,$C9,$61,$2B,$6D,$12,$12,$D1,$86,$21,$3B,
$12,$02,$3B,$13,$3D,$27,$19,$99,$90,$6D,$16,$E8,$E2,$30,$28,$30,$6C,$BA,$69,$16,
$72,$13,$E0,$75,$29,$DD,$40,$BD,$CB,$F9,$AA,$3A,$C6,$0C,$38,$2D,$DF,$E1,$29,$A1,
$DC,$DD,$02,$7A,$60,$51,$58,$2D,$75,$A0,$ED,$8C,$EB,$AF,$DA,$C0,$10,$E5,$1F,$6B,
$6D,$40,$60,$40,$01,$79,$DF,$A0,$C3,$30,$B5,$63,$8A,$97,$DE,$2E,$41,$79,$8A,$F8,
$03,$4B,$09,$5C,$75,$2C,$4F,$39,$58,$10,$86,$27,$82,$32,$2B,$88,$20,$37,$21,$3B,
$16,$36,$28,$4C,$66,$B2,$60,$38,$3A,$AA,$04,$23,$7A,$C7,$E9,$96,$8E,$10,$4B,$C1,
$3D,$B8,$F6,$AA,$91,$EC,$0A,$AB,$E8,$AD,$44,$9F,$E2,$32,$E4,$05,$F3,$8B,$1D,$84,
$4E,$16,$62,$D2,$B0,$26,$9C,$E2,$38,$0C,$AC,$03,$DF,$DB,$FE,$C0,$96,$B1,$AE,$89,
$C3,$E2,$98,$4F,$B1,$06,$96,$12,$13,$E3,$CC,$90,$2C,$99,$1C,$C9,$63,$84,$31,$CB,
$01,$A4,$4C,$E1,$0C,$24,$5D,$7F,$74,$A6,$30,$C1,$18,$08,$A2,$89,$7B,$66,$A3,$59,
$02,$92,$73,$0E,$FD,$19,$4C,$51,$83,$F5,$F6,$BA,$0A,$A2,$67,$85,$DA,$C7,$AE,$5E,
$59,$20,$C4,$80,$64,$66,$7D,$9B,$B8,$60,$A2,$DE,$E5,$C7,$BB,$E8,$BA,$84,$25,$7E,
$30,$8D,$28,$8B,$B1,$4D,$E0,$48,$69,$C7,$36,$A6,$BE,$C9,$C4,$C3,$02,$70,$09,$54,
$19,$B6,$54,$76,$C4,$C4,$B5,$FF,$6B,$65,$68,$9A,$C9,$AC,$2A,$27,$60,$D0,$A8,$E3,
$14,$EC,$F4,$E2,$4A,$32,$0C,$06,$1B,$C4,$91,$40,$73,$0A,$96,$18,$06,$4A,$41,$F3,
$FD,$37,$98,$04,$6B,$ED,$22,$32,$C9,$24,$40,$18,$D0,$FF,$4C,$28,$D8,$28,$4B,$48,
$D5,$5B,$31,$1B,$68,$6A,$1E,$EB,$44,$77,$01,$96,$3E,$59,$0A,$FA,$1B,$16,$5E,$FB,
$2E,$7C,$25,$ED,$38,$A5,$64,$58,$8C,$90,$41,$E2,$CE,$81,$A4,$43,$6D,$B5,$16,$41,
$32,$45,$41,$2F,$D3,$7D,$8F,$B3,$79,$FC,$7C,$D8,$47,$AC,$83,$E9,$D5,$28,$9D,$23,
$BD,$17,$6C,$0D,$8B,$85,$49,$69,$18,$A1,$09,$42,$61,$A6,$83,$D5,$A2,$9C,$25,$C4,
$10,$3B,$21,$5C,$05,$B6,$39,$95,$88,$83,$F0,$94,$2D,$DC,$19,$5D,$05,$61,$E1,$D8,
$7C,$A5,$B4,$AA,$37,$D6,$93,$D4,$82,$13,$15,$AE,$DB,$C3,$6E,$B1,$BA,$51,$56,$05,
$76,$8C,$7F,$48,$83,$F0,$E0,$4A,$4C,$09,$9B,$12,$49,$3A,$C6,$A6,$17,$04,$2A,$D7,
$E1,$24,$28,$13,$FC,$FE,$B2,$56,$02,$EB,$C1,$ED,$9B,$4A,$F8,$3B,$AE,$89,$70,$A7,
$DC,$5F,$00,$78,$2A,$C5,$B6,$C0,$CD,$09,$49,$12,$D4,$E0,$E5,$46,$10,$92,$04,$14,
$9A,$19,$C0,$85,$58,$9E,$26,$49,$EE,$BB,$08,$79,$36,$75,$62,$4F,$B0,$B5,$9F,$F9,
$63,$D2,$33,$A8,$A5,$97,$12,$90,$F4,$8C,$40,$21,$F8,$40,$92,$24,$49,$B5,$26,$6B,
$D0,$B9,$92,$24,$24,$49,$60,$7D,$6A,$50,$55,$AF,$D0,$69,$42,$DE,$F4,$82,$57,$65,
$D4,$2C,$6A,$3F,$97,$1C,$AE,$A4,$65,$2C,$EE,$31,$36,$D4,$82,$A1,$D5,$09,$2D,$63,
$FA,$98,$16,$2D,$E1,$CF,$38,$50,$1B,$8F,$E2,$49,$42,$99,$2B,$44,$40,$A5,$B9,$09,
$CF,$09,$6C,$3C,$49,$0E,$0B,$C6,$02,$92,$84,$24,$CB,$74,$2E,$5F,$6E,$92,$24,$49,
$12,$A0,$91,$DE,$63,$14,$7F,$68,$49,$02,$CB,$C8,$32,$71,$B8,$05,$83,$80,$48,$DA,
$C6,$14,$B4,$0B,$0C,$E3,$22,$49,$08,$23,$ED,$EE,$BD,$35,$5B,$61,$66,$FA,$22,$55,
$38,$09,$A3,$9A,$4E,$88,$E5,$8B,$DD,$31,$D3,$D4,$D7,$37,$51,$C2,$F5,$57,$2F,$53,
$6A,$7F,$2A,$69,$36,$BE,$5E,$BD,$B8,$6B,$08,$86,$77,$6D,$A0,$E2,$68,$A0,$09,$C8,
$08,$5F,$49,$57,$84,$3A,$82,$27,$44,$D0,$B6,$45,$4D,$FE,$52,$3A,$2D,$E0,$FC,$12,
$7D,$CB,$FD,$34,$AB,$BC,$15,$C0,$97,$B8,$E2,$FE,$D2,$C2,$10,$72,$40,$0C,$3D,$C8,
$E1,$E4,$E1,$F7,$4F,$34,$0B,$82,$4C,$15,$03,$AB,$7E,$27,$23,$B7,$BD,$57,$BC,$0A,
$C6,$E7,$FA,$21,$02,$3B,$6C,$09,$33,$2A,$27,$03,$44,$4B,$01,$44,$0F,$56,$32,$16,
$12,$3A,$56,$25,$13,$3A,$98,$D9,$F7,$12,$EA,$AC,$52,$A4,$4E,$CC,$98,$15,$8E,$61,
$66,$AB,$F3,$08,$97,$7E,$33,$88,$C8,$13,$A3,$16,$43,$61,$A1,$A1,$5A,$77,$24,$FE,
$84,$85,$B8,$A0,$65,$D2,$98,$97,$47,$D0,$0B,$56,$CE,$30,$D2,$30,$4B,$3C,$3E,$56,
$80,$A0,$DC,$3E,$A3,$37,$CE,$11,$9F,$FE,$C0,$D2,$58,$A3,$40,$6A,$7F,$16,$38,$98,
$00,$2C,$D8,$70,$14,$1C,$94,$0E,$66,$4E,$DE,$9D,$95,$3A,$FF,$6A,$41,$8E,$BA,$F5,
$B4,$71,$39,$EC,$38,$0E,$1C,$CC,$CF,$29,$C3,$48,$1D,$95,$9C,$31,$00,$2C,$F7,$61,
$EA,$B4,$C0,$D5,$CF,$91,$A1,$52,$4F,$D7,$CF,$23,$D5,$DC,$48,$61,$0F,$71,$5A,$EF,
$6F,$24,$90,$0A,$C1,$92,$2F,$52,$70,$A4,$64,$A2,$A9,$0D,$29,$50,$93,$2A,$B2,$14,
$58,$20,$86,$08,$43,$0E,$F5,$45,$63,$FB,$20,$FC,$00,$3A,$91,$8E,$4D,$B5,$0E,$32,
$48,$02,$B8,$B9,$A1,$32,$48,$05,$69,$8E,$41,$58,$F8,$28,$4A,$88,$42,$B0,$D8,$51,
$81,$8C,$A7,$69,$80,$A3,$48,$12,$82,$54,$73,$79,$EA,$B1,$24,$BC,$54,$52,$7C,$81,
$85,$06,$50,$81,$85,$A4,$23,$45,$C6,$04,$D6,$91,$41,$D5,$7C,$10,$10,$10,$D0,$73,
$12,$11,$10,$3E,$38,$9A,$14,$2F,$9F,$62,$0A,$98,$20,$E1,$82,$A6,$7C,$DC,$5A,$0F,
$A6,$0B,$47,$9D,$4B,$EA,$71,$71,$49,$39,$EF,$D9,$10,$05,$59,$05,$A5,$AA,$BE,$A4,
$7F,$99,$B4,$8F,$A2,$94,$01,$F2,$48,$21,$D4,$7D,$DA,$6F,$52,$0D,$79,$B1,$90,$0C,
$88,$03,$91,$D0,$2B,$92,$A3,$E8,$0F,$38,$92,$48,$49,$42,$3D,$13,$10,$A1,$48,$95,
$60,$5F,$DE,$AA,$50,$BD,$90,$D1,$F7,$75,$2D,$95,$5C,$ED,$87,$A5,$72,$42,$93,$F4,
$60,$47,$82,$D7,$3B,$4B,$81,$26,$FE,$2E,$95,$8F,$44,$BD,$33,$E5,$F6,$C2,$A2,$08,
$5B,$97,$D5,$DE,$45,$B5,$7A,$15,$80,$83,$11,$D3,$2D,$91,$D3,$D4,$19,$DF,$F4,$EC,
$2B,$84,$57,$ED,$93,$BF,$66,$77,$15,$E9,$53,$83,$55,$86,$62,$57,$57,$0A,$5E,$96,
$AC,$BB,$54,$75,$28,$1F,$00,$94,$FD,$EC,$6D,$A4,$85,$65,$54,$5D,$35,$44,$9F,$23,
$25,$85,$F8,$55,$F8,$DC,$4F,$4D,$2B,$51,$4C,$20,$B1,$6A,$2E,$12,$E8,$94,$1C,$96,
$A6,$7A,$17,$BD,$7E,$62,$E6,$BF,$8A,$90,$67,$39,$D5,$DF,$69,$D6,$AB,$48,$84,$66,
$14,$87,$35,$F2,$FA,$AB,$38,$71,$04,$BF,$F4,$C1,$F4,$2F,$45,$BA,$80,$47,$23,$E4,
$A1,$FB,$06,$0C,$F7,$A6,$3B,$CA,$A5,$E7,$74,$8F,$18,$1C,$03,$52,$B3,$B2,$CB,$B6,
$9A,$9E,$DF,$D3,$47,$57,$A8,$82,$20,$3E,$C8,$27,$18,$B0,$B0,$3F,$32,$F2,$A3,$2A,
$12,$DD,$AE,$4C,$1D,$0C,$18,$7D,$27,$18,$76,$D9,$4A,$C3,$2D,$FD,$41,$C2,$2D,$22,
$80,$31,$9B,$44,$4C,$0E,$86,$07,$AB,$63,$85,$F5,$5F,$B3,$57,$2D,$59,$72,$37,$84,
$98,$E5,$7C,$72,$5F,$20,$06,$D6,$6A,$0F,$3B,$3A,$62,$0C,$8F,$60,$E4,$64,$C0,$AE,
$F0,$C6,$2A,$38,$15,$17,$03,$30,$56,$BF,$3D,$97,$A9,$56,$3D,$EB,$29,$3A,$5A,$A5,
$BD,$28,$70,$C6,$22,$B8,$5C,$6B,$68,$CC,$2B,$E1,$AF,$30,$03,$1E,$92,$2C,$BF,$1C,
$20,$63,$26,$E5,$8D,$DB,$D3,$96,$88,$01,$77,$BA,$C8,$3C,$BD,$C1,$8E,$17,$74,$E2,
$56,$8C,$B1,$78,$61,$5B,$12,$D0,$D7,$AC,$69,$D4,$EB,$49,$F6,$0D,$D0,$AF,$91,$6B,
$D5,$01,$00,$A9,$B1,$DD,$67,$9C,$D2,$0E,$DE,$6B,$B4,$26,$95,$80,$41,$DA,$B0,$DB,
$8B,$B5,$DF,$B7,$C3,$15,$DB,$F5,$8C,$E4,$85,$E5,$50,$47,$B1,$0C,$09,$76,$22,$BF,
$84,$58,$2C,$4B,$5A,$60,$EF,$42,$44,$7C,$50,$19,$18,$3E,$79,$2C,$1F,$C5,$F6,$83,
$EB,$A8,$6B,$04,$46,$40,$9A,$76,$7F,$15,$AC,$D8,$68,$D5,$89,$40,$3B,$86,$59,$9B,
$02,$A3,$77,$AC,$6E,$EE,$0D,$97,$5F,$15,$45,$C1,$1E,$A3,$AD,$C7,$2A,$41,$70,$A5,
$03,$7D,$13,$2D,$CF,$2E,$E4,$4D,$5F,$C6,$5A,$BC,$0A,$4B,$5C,$4D,$A0,$56,$13,$A7,
$FA,$2A,$2B,$03,$9B,$64,$48,$6E,$A6,$F7,$26,$E9,$57,$94,$B5,$5B,$76,$31,$2B,$A4,
$AA,$84,$57,$BB,$54,$55,$FE,$00,$67,$F2,$69,$3B,$76,$F5,$63,$0A,$F3,$28,$6F,$2E,
$5F,$05,$F1,$05,$EC,$5D,$D5,$65,$FD,$14,$1A,$D5,$59,$E8,$8F,$E2,$0A,$B8,$4F,$A7,
$04,$63,$63,$AF,$82,$1D,$10,$3B,$17,$62,$8D,$22,$26,$82,$5E,$AE,$58,$86,$7F,$82,
$E2,$B1,$63,$F2,$A4,$91,$84,$22,$D5,$C9,$CE,$48,$18,$2B,$57,$08,$F2,$CB,$B9,$F9,
$A6,$C6,$BC,$BE,$B2,$32,$0A,$3C,$EE,$32,$18,$D3,$A5,$AF,$CA,$10,$71,$1D,$FC,$57,
$59,$E4,$DA,$28,$72,$82,$38,$6A,$2D,$62,$99,$83,$0C,$A2,$33,$3B,$C8,$C9,$35,$E3,
$FD,$42,$1A,$6B,$6C,$6C,$0D,$B8,$B9,$7A,$3A,$C2,$D5,$32,$01,$07,$39,$76,$C3,$C6,
$13,$53,$BB,$52,$5E,$40,$76,$51,$2F,$59,$44,$EC,$4D,$BD,$40,$94,$46,$4C,$C7,$4A,
$51,$17,$43,$41,$60,$C7,$DF,$B8,$94,$CB,$CA,$F5,$6B,$97,$52,$AE,$B1,$66,$BE,$AB,
$B4,$E4,$2D,$78,$F6,$BA,$6A,$89,$B8,$1A,$31,$F5,$3F,$C2,$B7,$FC,$0F,$01,$6F,$75,
$0C,$49,$47,$AA,$81,$4D,$87,$65,$D9,$7E,$25,$1C,$3F,$7F,$AE,$53,$69,$BA,$C2,$9C,
$FF,$10,$F3,$DD,$42,$65,$2F,$ED,$0E,$63,$80,$CC,$EC,$2F,$44,$34,$3D,$76,$75,$92,
$61,$D7,$35,$D5,$2E,$ED,$2E,$A0,$2C,$A2,$46,$94,$5D,$13,$05,$03,$3E,$98,$AF,$70,
$94,$2A,$51,$5F,$8A,$08,$83,$21,$1D,$49,$51,$4F,$25,$C5,$A0,$41,$EC,$26,$5F,$00,
$5A,$00,$D1,$51,$C1,$71,$14,$0F,$88,$D0,$13,$0B,$9E,$DF,$D5,$C2,$95,$F2,$07,$16,
$B9,$1A,$88,$25,$C4,$62,$2A,$5D,$5D,$46,$17,$E6,$3F,$D7,$EF,$90,$AB,$17,$4B,$88,
$14,$E6,$0D,$00,$84,$C8,$07,$31,$E4,$6C,$FC,$41,$6E,$AF,$68,$31,$52,$4A,$36,$6A,
$C9,$B0,$A7,$1A,$43,$44,$AF,$5C,$E2,$C9,$EA,$03,$00,$C9,$A9,$3E,$69,$6B,$98,$93,
$E7,$AE,$1A,$CB,$B9,$8E,$A8,$4B,$34,$43,$01,$16,$B7,$4A,$FD,$97,$BA,$50,$32,$7F,
$7D,$49,$B8,$0D,$52,$F4,$AF,$14,$FA,$70,$82,$51,$98,$0B,$B0,$E1,$26,$39,$71,$EF,
$52,$B6,$8F,$6F,$95,$BE,$6D,$86,$BE,$2D,$F1,$21,$57,$1F,$68,$52,$1D,$20,$F3,$B8,
$44,$2A,$12,$FB,$97,$10,$37,$A5,$67,$C0,$67,$EE,$59,$C3,$C4,$3D,$40,$2F,$D5,$F5,
$1C,$01,$8F,$2E,$DE,$7F,$4D,$F9,$63,$89,$F7,$AA,$9E,$6E,$A8,$75,$1D,$9F,$24,$02,
$20,$41,$BA,$55,$09,$11,$D0,$91,$77,$12,$7B,$63,$79,$68,$EB,$6B,$25,$FF,$08,$F6,
$7D,$6C,$B5,$BE,$D2,$17,$1F,$AA,$80,$A2,$D0,$ED,$DD,$6B,$26,$94,$3B,$66,$AE,$03,
$36,$7B,$55,$82,$45,$22,$E1,$DD,$14,$E3,$07,$A7,$EB,$54,$58,$AE,$B0,$CE,$55,$1F,
$62,$24,$9C,$45,$0F,$AE,$B7,$B8,$02,$44,$2D,$C3,$9B,$59,$BD,$AA,$B6,$F5,$91,$5D,
$21,$82,$14,$C8,$DE,$E7,$39,$EA,$0E,$92,$64,$EA,$7E,$BA,$EC,$76,$FB,$AB,$2C,$E4,
$C6,$C2,$E4,$62,$11,$E3,$3C,$E2,$65,$82,$45,$06,$DE,$E7,$FE,$EA,$18,$59,$75,$E3,
$C4,$AB,$57,$C1,$83,$0F,$5C,$4E,$CA,$CF,$CE,$A9,$FB,$62,$13,$41,$88,$24,$4E,$D7,
$37,$4D,$85,$62,$83,$D9,$0D,$BF,$BE,$A5,$EA,$97,$80,$E5,$F8,$23,$11,$8E,$A8,$50,
$AF,$6D,$0A,$6E,$0B,$15,$DD,$BC,$98,$75,$EB,$D2,$22,$E4,$EF,$6B,$CF,$DC,$98,$26,
$D6,$BC,$39,$65,$67,$06,$36,$42,$D6,$A3,$D2,$BA,$7A,$E6,$AE,$13,$55,$C0,$BC,$CE,
$57,$AF,$31,$AC,$F5,$4C,$56,$54,$75,$10,$67,$80,$9B,$86,$86,$6C,$AE,$2D,$88,$5C,
$75,$F4,$97,$84,$21,$85,$62,$A0,$DB,$63,$C0,$C5,$40,$E8,$7B,$E2,$08,$40,$D7,$19,
$A6,$BF,$6B,$A3,$CC,$53,$FA,$13,$B3,$0B,$C9,$5D,$81,$6C,$53,$D9,$EC,$AA,$4B,$19,
$A7,$57,$A5,$3F,$E0,$A5,$BF,$27,$1D,$13,$E2,$A0,$C8,$71,$F8,$41,$C0,$00,$8C,$AB,
$6B,$CC,$18,$54,$D5,$91,$32,$12,$7D,$99,$54,$58,$59,$CC,$98,$6C,$F9,$BE,$B9,$68,
$F1,$B5,$26,$28,$AA,$A5,$CE,$5C,$F4,$8D,$06,$31,$79,$4D,$16,$8D,$0A,$0C,$58,$DB,
$30,$E6,$98,$22,$F1,$D5,$5C,$38,$94,$F8,$2A,$5D,$1A,$B6,$88,$BA,$06,$64,$FE,$F2,
$9E,$DE,$99,$D3,$2C,$61,$59,$A0,$AC,$2B,$0C,$60,$1B,$77,$2E,$2E,$4C,$26,$4F,$DF,
$80,$12,$00,$4C,$AD,$19,$78,$5D,$F0,$01,$AE,$08,$39,$92,$FB,$FA,$40,$00,$AA,$F3,
$00,$20,$F5,$B8,$48,$21,$B3,$DF,$29,$9D,$CD,$54,$AF,$98,$CB,$D9,$96,$BE,$88,$F5,
$57,$64,$A9,$73,$37,$61,$C5,$17,$98,$28,$50,$9C,$AA,$D6,$47,$4D,$46,$86,$81,$19,
$B7,$40,$01,$00,$B6,$ED,$09,$FB,$C3,$9A,$16,$D7,$54,$E4,$E0,$60,$76,$B3,$98,$20,
$0A,$56,$99,$21,$93,$5F,$7C,$0F,$8C,$C0,$29,$FD,$41,$31,$87,$44,$F7,$38,$2C,$D6,
$51,$27,$A9,$70,$C3,$8B,$9F,$22,$06,$22,$FB,$E0,$84,$82,$1F,$68,$9E,$15,$94,$40,
$1D,$E5,$84,$C8,$91,$D3,$5F,$9C,$D8,$AA,$82,$4C,$75,$C5,$25,$36,$4C,$4B,$4F,$5C,
$EC,$FA,$9E,$C2,$2A,$7F,$59,$B2,$2A,$67,$34,$75,$5D,$30,$2F,$80,$13,$1E,$1A,$4C,
$EA,$9B,$A6,$21,$AF,$3F,$FA,$E0,$D6,$16,$BF,$AF,$03,$3A,$CA,$10,$7A,$6C,$99,$FE,
$08,$91,$A2,$48,$B6,$B3,$83,$67,$5D,$6B,$D1,$73,$36,$2D,$84,$B1,$E3,$88,$4D,$43,
$2F,$96,$43,$5D,$69,$D7,$C4,$9E,$6C,$C4,$0E,$38,$8E,$31,$B3,$ED,$58,$1C,$E2,$C5,
$50,$61,$7D,$1D,$68,$59,$64,$7A,$50,$AC,$4A,$91,$B7,$7F,$26,$07,$A9,$89,$80,$C0,
$83,$0F,$1B,$89,$7F,$CF,$31,$25,$65,$56,$CE,$87,$FE,$7E,$25,$C3,$A9,$45,$30,$EA,
$DA,$7A,$FD,$D2,$C9,$94,$E1,$31,$B4,$0F,$A6,$85,$09,$1A,$26,$CE,$93,$3B,$2B,$6D,
$DF,$F3,$01,$67,$9B,$3C,$03,$C9,$FE,$C1,$6E,$FC,$4D,$A0,$07,$FE,$EB,$6F,$EF,$C1,
$9D,$58,$79,$A5,$30,$EC,$CA,$14,$0E,$2A,$2B,$42,$2C,$E8,$F0,$31,$DA,$E6,$AB,$F6,
$F2,$28,$79,$EA,$FA,$B6,$C3,$89,$10,$C9,$5C,$4C,$D1,$69,$15,$46,$56,$18,$8B,$20,
$86,$20,$35,$33,$0E,$82,$8F,$03,$AC,$5C,$C0,$19,$28,$3C,$9C,$8D,$E0,$6F,$6D,$16,
$03,$59,$61,$B1,$AB,$64,$DF,$B8,$0D,$72,$37,$6A,$0C,$93,$60,$29,$39,$72,$7C,$80,
$71,$A3,$10,$86,$87,$8F,$8C,$EE,$93,$61,$D0,$CC,$85,$08,$35,$8F,$D0,$6E,$07,$99,
$5C,$24,$83,$C1,$77,$1F,$EF,$BE,$10,$F1,$E4,$B6,$C0,$09,$02,$BC,$5D,$7F,$80,$FA,
$6C,$26,$03,$A6,$E8,$67,$8A,$B8,$24,$03,$CD,$EA,$5F,$0C,$77,$A7,$8E,$22,$38,$D6,
$85,$4C,$57,$07,$F3,$F2,$5F,$05,$DF,$0F,$F0,$E1,$7F,$67,$6C,$3F,$E1,$26,$FB,$95,
$77,$F8,$25,$5D,$D1,$F0,$57,$76,$D3,$35,$55,$BD,$C5,$55,$C2,$FF,$EE,$51,$C5,$B7,
$79,$BC,$89,$47,$BE,$6B,$86,$F6,$D5,$28,$8B,$0C,$AE,$34,$B1,$34,$4B,$9E,$49,$7B,
$F1,$2C,$B7,$E8,$BB,$81,$0F,$5A,$07,$72,$FE,$F1,$45,$4E,$5D,$CD,$5B,$BC,$4B,$CD,
$3A,$88,$09,$28,$07,$FA,$65,$C7,$68,$CF,$A6,$FE,$5D,$A8,$7D,$F3,$D0,$DE,$FB,$D6,
$51,$2B,$AB,$05,$DE,$23,$39,$32,$9F,$BF,$DD,$56,$41,$2F,$1C,$29,$73,$5D,$BC,$BA,
$04,$73,$D3,$2B,$C2,$A7,$C8,$5A,$70,$1A,$5C,$23,$E8,$0B,$C3,$88,$A4,$4C,$AC,$A6,
$0D,$D5,$1D,$9F,$9D,$E8,$C0,$A4,$F6,$1A,$EE,$FC,$BD,$68,$48,$D3,$94,$0C,$30,$8D,
$59,$6D,$77,$93,$2B,$C7,$0B,$A1,$BF,$F5,$61,$FE,$38,$A9,$C7,$2B,$03,$CE,$2F,$8C,
$B8,$17,$C5,$5D,$43,$58,$83,$2A,$2E,$53,$9C,$1A,$81,$71,$8B,$04,$D5,$57,$87,$EC,
$35,$FE,$8A,$39,$5D,$28,$E9,$25,$4B,$FC,$90,$4C,$DF,$F2,$5D,$C3,$59,$25,$FF,$9E,
$6C,$4C,$D6,$FF,$5E,$B1,$FE,$A2,$88,$C6,$26,$D8,$5B,$EE,$7D,$FB,$E5,$54,$7D,$2C,
$EF,$7D,$54,$B0,$F6,$75,$BD,$8B,$FE,$AE,$A4,$1F,$26,$DA,$53,$2D,$82,$15,$02,$E5,
$01,$55,$16,$01,$4D,$35,$01,$63,$77,$E4,$D0,$9E,$BF,$53,$21,$A6,$56,$28,$A2,$A0,
$BD,$4B,$30,$DE,$01,$B5,$81,$E8,$B6,$83,$07,$0A,$56,$2A,$ED,$CF,$57,$3E,$32,$FD,
$5F,$D6,$ED,$5A,$F7,$05,$7B,$D9,$EF,$4A,$D1,$9F,$C0,$B0,$7D,$49,$92,$51,$83,$DB,
$8A,$CF,$E2,$AF,$6A,$02,$52,$66,$61,$F1,$B8,$6B,$E5,$8C,$A3,$C9,$8C,$CC,$0F,$38,
$A9,$A7,$5B,$67,$84,$2C,$7D,$CD,$F6,$5D,$88,$36,$11,$F6,$97,$61,$ED,$A9,$9C,$B1,
$03,$94,$ED,$1E,$F4,$FE,$97,$BC,$3A,$F1,$30,$A1,$AF,$1E,$AA,$27,$40,$A5,$45,$96,
$31,$E8,$D3,$C9,$D5,$09,$41,$1E,$7F,$7C,$02,$5F,$C4,$95,$F7,$3F,$F5,$48,$A9,$DE,
$9A,$C8,$BC,$3D,$62,$71,$A7,$29,$2F,$72,$CA,$DD,$24,$C5,$BF,$30,$D2,$EA,$3F,$B4,
$CE,$C7,$7D,$59,$D5,$CC,$86,$73,$68,$8F,$E6,$CC,$B0,$C1,$A3,$DE,$CD,$C2,$CD,$F7,
$EA,$4B,$37,$59,$5C,$06,$5A,$FF,$27,$DD,$82,$EC,$FA,$F5,$62,$EA,$51,$5F,$9A,$B3,
$E8,$4F,$26,$9B,$30,$58,$F3,$9F,$00,$AD,$AD,$7D,$89,$7A,$D0,$01,$06,$65,$6C,$65,
$97,$F2,$58,$BA,$20,$F4,$AD,$C0,$14,$56,$6E,$B0,$18,$C6,$D5,$7C,$BF,$62,$39,$DF,
$BE,$12,$66,$24,$41,$E9,$0B,$F8,$52,$C5,$52,$E2,$AA,$60,$E4,$3D,$28,$61,$39,$B8,
$C8,$5A,$39,$60,$43,$34,$39,$24,$C7,$BE,$82,$42,$72,$1C,$7F,$D1,$5E,$8F,$91,$89,
$7D,$66,$64,$0A,$B9,$1F,$6A,$E4,$4C,$63,$BE,$BB,$51,$32,$D9,$55,$8B,$41,$AE,$5F,
$6F,$85,$34,$9D,$0C,$2D,$C7,$88,$F9,$B1,$8D,$BF,$DE,$42,$74,$87,$CD,$BA,$DD,$2D,
$79,$F5,$A0,$C5,$65,$F8,$D2,$5E,$03,$35,$DA,$9B,$F0,$24,$B9,$2F,$8D,$5B,$B5,$94,
$F4,$4A,$EC,$22,$D6,$EA,$77,$EE,$DB,$72,$B7,$6E,$F2,$EB,$12,$AD,$BA,$80,$FD,$CE,
$1B,$00,$B1,$15,$AC,$F6,$98,$C4,$A0,$ED,$6B,$E3,$AE,$83,$50,$4F,$AD,$59,$28,$85,
$5B,$04,$85,$4F,$20,$05,$DB,$62,$44,$50,$B4,$F2,$79,$95,$EC,$5D,$ED,$50,$58,$5E,
$AA,$1A,$D5,$97,$07,$F1,$82,$63,$5D,$B2,$ED,$84,$BB,$EF,$64,$1D,$59,$97,$3D,$4C,
$10,$40,$3B,$69,$03,$10,$14,$7F,$8E,$C8,$77,$C6,$05,$0D,$36,$BB,$AA,$59,$03,$2D,
$83,$09,$29,$C3,$0C,$76,$3D,$32,$1B,$B1,$F9,$AA,$29,$FB,$6D,$91,$71,$5D,$56,$01,
$A2,$E2,$EC,$F7,$18,$70,$55,$EB,$0A,$62,$49,$1D,$16,$1A,$3D,$FF,$C7,$F7,$0C,$CD,
$DB,$99,$AE,$AA,$D7,$34,$D0,$6F,$B0,$C8,$A3,$B8,$7C,$2F,$75,$55,$07,$2A,$E0,$4C,
$DC,$4D,$8D,$A3,$FB,$A0,$11,$53,$57,$3C,$F0,$32,$A6,$50,$EC,$F0,$47,$9E,$3A,$1A,
$A1,$55,$5C,$4B,$8A,$7D,$ED,$3B,$72,$DB,$D6,$B8,$20,$56,$66,$F8,$FD,$81,$87,$F6,
$F1,$FA,$C4,$42,$2C,$01,$54,$17,$A6,$DF,$AF,$2B,$87,$76,$5D,$01,$69,$02,$2C,$C9,
$7C,$50,$04,$C5,$2F,$79,$F3,$EB,$DD,$D9,$57,$5E,$36,$08,$BC,$ED,$3B,$ED,$5B,$C4,
$76,$1A,$38,$D7,$17,$63,$E7,$1A,$57,$B4,$B4,$20,$FA,$20,$17,$6C,$D0,$A1,$7D,$85,
$C5,$56,$4E,$BE,$0E,$EF,$82,$41,$A4,$B5,$A2,$4D,$D8,$56,$88,$F1,$55,$EE,$CD,$C9,
$39,$78,$4A,$6A,$A5,$15,$CE,$AF,$55,$48,$25,$13,$6E,$04,$31,$10,$A9,$A8,$D4,$AE,
$03,$37,$E1,$1C,$1C,$93,$58,$3D,$80,$65,$B2,$C5,$F8,$C3,$9C,$80,$DC,$76,$07,$DF,
$62,$7B,$17,$F9,$F5,$08,$07,$E8,$C9,$3C,$B5,$FD,$9D,$A1,$A0,$E6,$A0,$F9,$07,$E2,
$F1,$52,$D9,$F0,$F6,$08,$C7,$03,$19,$E6,$06,$36,$0E,$88,$E5,$83,$09,$9F,$BE,$A5,
$C4,$A4,$31,$5D,$75,$CF,$E3,$F4,$E7,$5D,$45,$97,$4A,$8C,$30,$D7,$25,$58,$AC,$2D,
$38,$C5,$BE,$14,$E0,$AE,$99,$04,$10,$1B,$EC,$0B,$1F,$22,$43,$8F,$77,$41,$5F,$46,
$6C,$95,$C5,$60,$98,$21,$D0,$20,$B9,$6A,$67,$5E,$10,$BA,$0E,$C3,$89,$F5,$C1,$B4,
$46,$F4,$3D,$23,$D0,$E4,$C4,$43,$F6,$F8,$2B,$66,$D0,$18,$5B,$E1,$57,$19,$B6,$8B,
$6A,$42,$D7,$A1,$B4,$45,$A9,$1D,$00,$1C,$F2,$61,$68,$E2,$1E,$8C,$35,$22,$24,$0B,
$8F,$B0,$30,$58,$5D,$C9,$53,$72,$A5,$4A,$6A,$F4,$7C,$10,$39,$7E,$A3,$DE,$6B,$3C,
$D6,$DD,$D1,$AC,$60,$BB,$20,$42,$C7,$0A,$19,$5F,$32,$87,$BE,$87,$5B,$AC,$E6,$EE,
$4A,$B2,$51,$72,$CC,$14,$47,$17,$BE,$C3,$95,$C2,$AC,$24,$28,$1B,$7D,$12,$C1,$44,
$83,$F1,$1A,$B8,$61,$65,$5A,$E3,$AA,$32,$B9,$B7,$7C,$7D,$F5,$F9,$7A,$95,$AC,$9C,
$E0,$D6,$85,$FF,$03,$A4,$DA,$56,$98,$01,$D1,$06,$29,$80,$36,$1F,$15,$44,$8D,$6F,
$4B,$90,$14,$A0,$C7,$AB,$BA,$19,$FF,$36,$41,$84,$A4,$F3,$94,$6C,$FF,$2F,$7E,$A9,
$13,$E6,$01,$AE,$0B,$A8,$A3,$8A,$39,$B8,$6C,$B7,$E5,$B8,$18,$95,$DB,$FE,$AF,$BE,
$97,$6F,$9C,$1C,$23,$B3,$7C,$87,$A2,$F2,$B4,$58,$C6,$A9,$38,$48,$CF,$8C,$EE,$3A,
$C0,$E3,$6B,$50,$73,$5D,$8B,$52,$97,$01,$5C,$FB,$C6,$E1,$F0,$BA,$8D,$D9,$A5,$D7,
$E5,$31,$E5,$17,$03,$C1,$38,$60,$18,$6D,$D0,$16,$7D,$59,$2D,$A6,$18,$9B,$82,$A4,
$EF,$54,$38,$58,$EE,$2F,$E2,$1A,$E3,$A5,$1E,$31,$82,$E9,$04,$AF,$8E,$C6,$7A,$A1,
$3A,$32,$BD,$3C,$59,$71,$5E,$7F,$F8,$96,$5C,$75,$BF,$A4,$75,$23,$93,$0B,$FD,$24,
$EF,$F4,$D3,$F9,$BC,$BE,$EC,$5D,$1E,$2B,$5F,$17,$DB,$87,$BB,$8A,$9E,$BE,$22,$06,
$09,$0B,$89,$44,$3E,$7D,$5D,$F8,$CF,$A8,$40,$3C,$74,$5C,$AA,$3D,$2C,$AA,$D6,$96,
$F4,$1B,$1A,$5D,$E0,$D7,$53,$0A,$0E,$6D,$D4,$CF,$FF,$13,$7F,$42,$FB,$00,$C1,$02,
$7D,$96,$BB,$87,$09,$05,$47,$0B,$8B,$A8,$82,$0A,$76,$70,$05,$68,$09,$94,$62,$72,
$9F,$2E,$10,$73,$8D,$E4,$A3,$68,$16,$4D,$2C,$25,$6E,$65,$F4,$7C,$45,$06,$A9,$AC,
$53,$CC,$B9,$4C,$8F,$D4,$91,$12,$29,$27,$0E,$48,$45,$D7,$FE,$7D,$37,$C8,$03,$78,
$A3,$0B,$A3,$25,$4F,$69,$BD,$44,$1D,$94,$16,$00,$C5,$25,$0B,$29,$F4,$E1,$8C,$A9,
$10,$3A,$5A,$4D,$A4,$F4,$11,$52,$A6,$96,$98,$C8,$29,$91,$C4,$1B,$F8,$AA,$12,$E5,
$06,$E0,$0D,$80,$49,$67,$76,$29,$16,$ED,$70,$5F,$41,$24,$89,$6F,$D2,$12,$14,$B3,
$8C,$F5,$D9,$E9,$EB,$88,$0B,$E2,$A7,$C7,$55,$82,$C8,$53,$E0,$9D,$B3,$FA,$BD,$91,
$81,$89,$1B,$CB,$AD,$F7,$F0,$22,$74,$97,$A1,$07,$87,$6B,$CA,$F2,$6C,$22,$03,$8E,
$A8,$BA,$C2,$D5,$D3,$BC,$91,$C7,$88,$EC,$68,$D3,$1A,$EB,$A7,$95,$79,$65,$E0,$6C,
$90,$D7,$8A,$D7,$8F,$45,$E6,$9F,$46,$1B,$D1,$C5,$4B,$84,$96,$BA,$0B,$28,$40,$20,
$40,$D1,$7D,$D5,$AC,$BE,$02,$AC,$F2,$3B,$FA,$BA,$DE,$70,$B9,$79,$57,$E9,$7C,$A1,
$AE,$40,$66,$4E,$40,$AA,$C0,$6A,$27,$4F,$1B,$81,$1C,$80,$8D,$D6,$5D,$09,$7A,$21,
$05,$32,$49,$72,$61,$3C,$FD,$AB,$43,$8E,$91,$43,$EF,$05,$B0,$FA,$63,$97,$ED,$FA,
$C6,$B4,$94,$00,$56,$E2,$32,$9B,$59,$9D,$B5,$8C,$9C,$F2,$1C,$AD,$C4,$05,$9C,$2D,
$5F,$0E,$CC,$A9,$03,$37,$13,$D3,$95,$A3,$13,$FC,$8B,$2F,$49,$18,$50,$F3,$F8,$25,
$A9,$EE,$81,$DE,$BC,$2E,$B2,$B7,$EE,$D3,$B5,$54,$D5,$B5,$67,$B7,$1A,$C6,$3C,$91,
$C6,$A3,$F3,$9C,$B8,$F0,$C6,$AA,$83,$9B,$2C,$5D,$0C,$3D,$BA,$5D,$C1,$BE,$4D,$AA,
$78,$F7,$15,$EB,$DE,$73,$3E,$54,$6A,$14,$CE,$2C,$BB,$9B,$A3,$A2,$40,$0C,$88,$DB,
$D3,$D0,$16,$E4,$B5,$9B,$5F,$5D,$11,$F7,$86,$A8,$54,$95,$C5,$89,$BA,$55,$3E,$54,
$C2,$8D,$55,$E4,$91,$EA,$7F,$29,$33,$A9,$FC,$55,$84,$CB,$5B,$75,$4D,$4D,$28,$45,
$23,$AB,$AA,$91,$57,$5D,$26,$38,$8D,$18,$A2,$02,$04,$4A,$29,$D5,$9D,$1B,$17,$8A,
$EB,$B1,$C6,$BB,$F2,$AE,$16,$B2,$65,$82,$EA,$E5,$62,$27,$C8,$09,$E5,$BA,$4F,$97,
$9B,$5C,$17,$49,$99,$18,$99,$5C,$38,$F6,$11,$59,$D1,$71,$C9,$75,$CB,$38,$B2,$E7,
$5F,$9D,$C7,$DF,$F9,$57,$E7,$8C,$70,$14,$45,$CF,$DF,$8C,$C3,$39,$86,$43,$C9,$37,
$17,$EE,$22,$A5,$EE,$78,$57,$7B,$0E,$DB,$63,$73,$B0,$E0,$D5,$A5,$48,$EC,$AB,$00,
$97,$4D,$9C,$A0,$A8,$7B,$43,$1C,$4C,$5E,$C7,$EB,$02,$71,$10,$8B,$4D,$11,$C4,$62,
$C8,$4E,$0D,$52,$BC,$0C,$44,$0F,$2F,$0C,$14,$BE,$58,$06,$B3,$57,$68,$16,$28,$92,
$6E,$39,$8E,$3E,$32,$FA,$D5,$D7,$55,$E9,$F6,$75,$42,$E5,$C2,$FA,$17,$60,$1C,$D9,
$D7,$B9,$90,$F8,$24,$95,$19,$44,$FE,$F2,$FE,$4B,$FA,$A3,$07,$5D,$05,$DD,$3A,$6C,
$3C,$E3,$43,$AF,$6B,$5D,$72,$C6,$F7,$C0,$40,$1E,$39,$62,$41,$52,$CA,$F3,$FB,$59,
$D3,$BF,$3E,$61,$D2,$35,$0E,$DE,$03,$B3,$99,$A2,$22,$F9,$EE,$68,$13,$65,$FB,$BA,
$65,$17,$65,$FF,$85,$0A,$29,$26,$4B,$57,$1F,$1C,$FC,$D5,$05,$C6,$05,$36,$9E,$00,
$EA,$F8,$AB,$D9,$C2,$61,$0F,$1A,$7B,$2A,$A8,$E3,$AF,$66,$C1,$FB,$73,$D4,$6E,$68,
$6E,$FD,$0D,$2D,$4A,$75,$DC,$0F,$B0,$74,$77,$AB,$BA,$D8,$DF,$D6,$0E,$D5,$5B,$7B,
$57,$09,$28,$EC,$5B,$1B,$8A,$8D,$F4,$0C,$39,$2E,$FD,$EA,$31,$BB,$92,$7E,$5D,$22,
$96,$2F,$FE,$89,$90,$FF,$4B,$9A,$85,$84,$9B,$5D,$D7,$87,$02,$00,$CA,$3A,$42,$F8,
$8B,$C6,$CF,$25,$6B,$1D,$32,$65,$C3,$ED,$E8,$7A,$3D,$7C,$98,$F4,$AB,$8B,$CC,$71,
$F0,$CD,$98,$EE,$74,$E1,$AA,$85,$F4,$75,$33,$E8,$57,$92,$98,$5A,$42,$1E,$DA,$61,
$08,$DA,$D1,$39,$48,$01,$A9,$C7,$96,$3B,$B7,$65,$57,$04,$94,$83,$A6,$A9,$38,$90,
$B0,$A8,$76,$90,$82,$83,$30,$2F,$AA,$69,$FD,$93,$75,$DA,$E7,$00,$06,$DC,$93,$89,
$58,$B3,$7D,$F5,$C3,$B2,$E6,$E6,$B5,$6F,$81,$0C,$E6,$A7,$BF,$FE,$68,$74,$99,$2E,
$84,$24,$A1,$4A,$6D,$3E,$79,$12,$02,$22,$69,$92,$68,$A5,$3E,$1F,$B9,$8A,$DB,$88,
$06,$05,$AF,$4A,$FD,$AA,$4F,$3E,$58,$7A,$E4,$32,$3F,$25,$FF,$58,$5D,$12,$18,$E5,
$BA,$C4,$46,$7D,$84,$BD,$35,$D3,$1D,$C2,$08,$6B,$48,$27,$B6,$C7,$E1,$7A,$92,$8C,
$1E,$CD,$9E,$A2,$90,$B0,$03,$01,$F8,$EB,$24,$3E,$02,$61,$94,$D0,$E7,$6E,$54,$6F,
$D4,$06,$84,$78,$5D,$52,$6C,$B8,$51,$5F,$CD,$8B,$E1,$6F,$9C,$66,$88,$A8,$94,$F8,
$94,$F8,$A3,$27,$ED,$42,$34,$6A,$24,$56,$A9,$2F,$7F,$D0,$30,$6F,$D6,$3D,$0C,$0E,
$89,$61,$3E,$8C,$5C,$B3,$D8,$FD,$9D,$BE,$BF,$86,$A1,$00,$54,$EC,$22,$14,$07,$A4,
$1A,$74,$85,$ED,$50,$E9,$28,$85,$EF,$CA,$9C,$96,$55,$37,$5A,$E0,$9D,$48,$7F,$12,
$1D,$3B,$88,$CE,$EB,$B0,$54,$76,$1E,$45,$F5,$05,$32,$F3,$62,$99,$6C,$16,$49,$47,
$5A,$7D,$10,$3A,$82,$A6,$3D,$C5,$2F,$18,$B1,$BE,$59,$6F,$40,$1D,$D6,$6C,$20,$00,
$6B,$21,$C3,$C0,$2F,$C2,$04,$A5,$A0,$D3,$AF,$5E,$9E,$BC,$21,$EE,$16,$C9,$86,$DF,
$E5,$FC,$FB,$0A,$A9,$29,$D3,$ED,$00,$7A,$FC,$75,$ED,$7E,$77,$68,$73,$2F,$E4,$59,
$93,$5F,$78,$D8,$6F,$30,$AB,$29,$56,$6F,$AA,$C1,$2B,$D3,$B8,$D6,$16,$98,$CC,$BA,
$E6,$AF,$E9,$28,$10,$E5,$8A,$EC,$7B,$DC,$E4,$B5,$27,$C9,$BD,$A4,$BA,$3B,$7F,$D6,
$F4,$51,$D8,$31,$27,$B9,$D5,$15,$4D,$29,$22,$08,$F4,$85,$34,$D6,$1B,$99,$96,$CA,
$72,$57,$75,$1B,$F3,$7A,$18,$16,$F5,$E2,$02,$89,$4A,$3E,$AC,$0F,$85,$91,$F9,$80,
$88,$8A,$F2,$D3,$6B,$02,$16,$83,$44,$EA,$72,$55,$5F,$F0,$66,$A1,$EB,$72,$09,$9F,
$C1,$D1,$14,$59,$0F,$ED,$95,$9E,$1F,$65,$1D,$C9,$F5,$AE,$1C,$31,$32,$D8,$5A,$20,
$CD,$B4,$66,$18,$AE,$AA,$06,$FF,$D5,$FA,$93,$07,$0E,$93,$1A,$A3,$51,$A7,$AA,$1E,
$AA,$9A,$A6,$9D,$2D,$A4,$86,$5C,$EB,$A4,$EB,$92,$73,$16,$80,$6E,$4F,$FD,$7F,$A8,
$B1,$F8,$F6,$1D,$B5,$AA,$03,$CE,$5F,$90,$82,$99,$0C,$20,$81,$75,$59,$FC,$4E,$AF,
$93,$75,$42,$7B,$BA,$24,$1A,$66,$40,$05,$0E,$EF,$88,$59,$D7,$0D,$BC,$D4,$37,$19,
$CA,$63,$FD,$BF,$CD,$11,$18,$21,$98,$0E,$9A,$C1,$E1,$E2,$89,$44,$53,$77,$E0,$1F,
$A9,$E5,$BA,$EF,$70,$BC,$FA,$A4,$3A,$56,$5E,$5C,$EF,$2F,$87,$69,$6A,$B3,$5C,$78,
$31,$DC,$F5,$3E,$AC,$98,$B6,$ED,$83,$B1,$78,$8A,$AB,$0E,$CA,$65,$0B,$B8,$48,$55,
$C4,$6C,$47,$CA,$FC,$F1,$BF,$93,$36,$D4,$8F,$25,$22,$6C,$EE,$F4,$46,$3E,$2F,$79,
$1D,$3F,$CA,$FF,$82,$B3,$04,$2C,$0D,$6E,$3F,$4E,$EA,$56,$89,$2A,$25,$6C,$06,$51,
$82,$D4,$BA,$16,$D7,$05,$0E,$2E,$8A,$46,$5F,$16,$6E,$7F,$47,$D4,$06,$D3,$14,$EF,
$70,$B4,$1D,$0B,$2F,$09,$AC,$6E,$38,$DD,$91,$25,$FE,$3E,$03,$E8,$31,$18,$78,$01,
$C9,$78,$5F,$8E,$F1,$33,$DF,$D3,$79,$D4,$55,$FE,$50,$A5,$95,$B8,$C0,$9D,$84,$3C,
$FF,$77,$70,$55,$1D,$A0,$05,$FB,$0D,$BC,$F0,$DC,$D5,$DB,$27,$D9,$A3,$F7,$15,$13,
$A0,$B5,$BF,$20,$81,$67,$90,$18,$5C,$8D,$B6,$2B,$BF,$64,$78,$02,$D8,$13,$74,$83,
$45,$B4,$79,$E3,$19,$6B,$BF,$D5,$38,$58,$2F,$4F,$E4,$E8,$09,$35,$44,$A4,$A8,$3E,
$28,$52,$31,$23,$58,$50,$23,$79,$17,$FC,$7F,$85,$A1,$55,$24,$73,$8C,$33,$CD,$A6,
$EE,$5B,$70,$B9,$FC,$7F,$3A,$7A,$F8,$CF,$10,$7F,$93,$85,$90,$AA,$F2,$FF,$0B,$84,
$7A,$E9,$5D,$1F,$A1,$FA,$77,$D2,$6C,$75,$A1,$35,$FF,$BF,$CD,$35,$CC,$7F,$4B,$E7,
$F6,$7F,$7C,$02,$48,$A7,$EA,$06,$FB,$1A,$AC,$3A,$A6,$51,$AC,$B6,$98,$99,$F2,$51,
$FB,$07,$62,$AC,$73,$55,$27,$D5,$F0,$8D,$54,$D5,$79,$C3,$A9,$05,$70,$85,$4A,$EB,
$3C,$CA,$B8,$BA,$A2,$C1,$E3,$72,$83,$94,$EF,$A7,$A6,$1C,$BE,$77,$B1,$A1,$AA,$4E,
$D6,$CF,$95,$58,$C8,$B0,$C8,$92,$9F,$71,$99,$AF,$E4,$99,$1A,$AB,$AD,$C5,$E1,$F2,
$FF,$95,$99,$3E,$AE,$3A,$97,$70,$CC,$A9,$30,$64,$D8,$FB,$07,$61,$F8,$F4,$52,$07,
$02,$12,$BA,$50,$8E,$D2,$77,$6A,$AD,$E0,$BF,$8A,$A1,$FF,$D3,$7A,$D7,$8D,$FE,$2B,
$18,$AB,$86,$E0,$FF,$D2,$9E,$88,$7A,$20,$F2,$D4,$1B,$E8,$DF,$EA,$97,$20,$BE,$BB,
$58,$FA,$C6,$A6,$23,$17,$61,$4B,$55,$F2,$FC,$5D,$46,$9D,$28,$91,$B3,$68,$97,$5D,
$17,$18,$52,$8D,$2A,$81,$DF,$E1,$2C,$56,$00,$55,$5F,$0D,$BA,$5B,$F2,$8F,$9E,$36,
$7B,$06,$11,$DC,$57,$87,$57,$8D,$D7,$19,$6D,$8A,$4A,$91,$61,$7D,$A3,$EB,$FC,$F7,
$A6,$7F,$FC,$57,$72,$BB,$8C,$42,$BF,$5B,$9B,$28,$83,$03,$94,$FF,$02,$B9,$BF,$12,
$A5,$1C,$E0,$E9,$AE,$6A,$AD,$D3,$85,$EB,$BC,$79,$EC,$BB,$0B,$6A,$B4,$02,$AE,$33,
$0E,$1A,$BB,$CD,$90,$12,$CE,$0F,$9D,$E1,$11,$F7,$3F,$7A,$55,$04,$C6,$C8,$31,$50,
$43,$01,$52,$5F,$06,$12,$83,$FC,$5C,$15,$BD,$FA,$1C,$3C,$C8,$2A,$E7,$BF,$15,$43,
$56,$A0,$99,$E0,$09,$E7,$B4,$96,$17,$13,$95,$6C,$06,$11,$2E,$0A,$C7,$9C,$D6,$B7,
$82,$BE,$BD,$D5,$10,$4D,$99,$BD,$BC,$9A,$F7,$55,$CB,$BD,$5F,$1D,$29,$76,$99,$FE,
$B3,$BE,$73,$8B,$E5,$20,$CD,$D9,$D5,$89,$37,$63,$E7,$3F,$EA,$EB,$B1,$04,$83,$2E,
$E0,$57,$05,$C9,$DF,$F9,$E3,$FB,$68,$5A,$9C,$54,$8E,$96,$A9,$15,$49,$1F,$76,$59,
$3D,$7C,$C4,$FD,$CB,$0C,$F5,$9B,$E2,$71,$F7,$40,$A2,$F4,$ED,$EE,$22,$77,$45,$F0,
$19,$92,$6B,$72,$7D,$37,$0C,$AD,$E3,$DA,$60,$1A,$B8,$EA,$49,$ED,$45,$C0,$D5,$A5,
$F8,$1D,$95,$C6,$4E,$2D,$18,$D5,$D3,$B1,$4A,$6B,$FA,$12,$C9,$86,$CE,$93,$44,$7A,
$ED,$B1,$C0,$BD,$EC,$94,$E1,$F5,$E9,$13,$17,$05,$AA,$2D,$D4,$65,$59,$94,$3D,$27,
$E9,$F9,$F6,$EA,$E9,$38,$B6,$37,$8A,$92,$41,$1B,$32,$93,$DE,$2E,$F8,$28,$72,$F1,
$32,$84,$42,$1F,$15,$E5,$61,$CF,$3D,$65,$AE,$CC,$FB,$8B,$C3,$7D,$9D,$E8,$84,$BB,
$5B,$A9,$76,$C2,$21,$8A,$6C,$AB,$F8,$4D,$97,$CA,$55,$72,$F2,$4D,$36,$AF,$FB,$AF,
$3C,$EC,$1F,$83,$E1,$C4,$80,$B9,$3A,$31,$53,$A0,$87,$EC,$2D,$A6,$EF,$6D,$74,$F3,
$54,$81,$B9,$08,$FE,$2A,$50,$67,$94,$B4,$1A,$5D,$DE,$F0,$8E,$AD,$6C,$21,$35,$65,
$57,$2D,$53,$34,$E7,$EA,$28,$FD,$3F,$BB,$2E,$C6,$F0,$C7,$83,$51,$ED,$EF,$44,$55,
$60,$69,$F0,$7E,$F7,$65,$BA,$BA,$23,$03,$AB,$4A,$CD,$C2,$7D,$29,$B1,$46,$DF,$18,
$5C,$A6,$CF,$15,$DB,$CC,$98,$6D,$F5,$1C,$C1,$02,$40,$EF,$96,$6E,$F7,$D5,$95,$F0,
$F8,$DB,$39,$27,$29,$F3,$C2,$3B,$98,$62,$80,$2B,$F5,$F6,$42,$73,$AB,$AE,$A0,$7A,
$D8,$9D,$ED,$65,$55,$2A,$FD,$E4,$2A,$4D,$8F,$FA,$15,$0D,$28,$B4,$47,$1C,$03,$9F,
$F4,$F2,$14,$04,$7F,$45,$06,$FE,$2A,$E0,$E9,$FA,$D2,$7F,$61,$98,$85,$68,$51,$F0,
$77,$84,$C2,$55,$56,$EB,$F1,$7B,$CB,$16,$B7,$60,$A0,$89,$C2,$8F,$60,$98,$D8,$BE,
$96,$C0,$BF,$2D,$2E,$F6,$8D,$4B,$FA,$0A,$82,$01,$B7,$C0,$85,$2D,$01,$93,$C2,$FC,
$6E,$61,$5D,$50,$35,$10,$FC,$9D,$57,$08,$1C,$A7,$8B,$50,$15,$06,$97,$DC,$88,$4E,
$6E,$08,$EA,$88,$66,$03,$40,$81,$8C,$82,$F0,$83,$29,$22,$A9,$94,$E9,$23,$9D,$4E,
$EF,$55,$6A,$DF,$4D,$EB,$1D,$5A,$82,$B5,$09,$68,$9C,$27,$62,$10,$91,$75,$8A,$3E,
$2B,$67,$2F,$E1,$1B,$2D,$8A,$CA,$52,$78,$DA,$35,$B8,$41,$6E,$CB,$5C,$60,$40,$DD,
$A5,$BE,$43,$F5,$86,$3B,$A5,$6E,$72,$F7,$9F,$70,$21,$DE,$34,$30,$57,$CA,$0C,$28,
$50,$16,$BD,$A1,$3D,$F5,$40,$8E,$7E,$00,$AC,$A6,$AF,$0F,$8D,$4A,$C6,$33,$EE,$6F,
$D0,$6A,$7D,$F5,$53,$11,$5C,$BA,$83,$32,$DC,$46,$03,$30,$CC,$60,$63,$01,$A7,$AE,
$E0,$70,$66,$45,$49,$E2,$A4,$AF,$B4,$39,$1F,$8B,$E4,$15,$B4,$CC,$BA,$4E,$70,$27,
$7E,$0A,$30,$96,$5B,$D3,$E3,$08,$F6,$94,$FC,$77,$71,$E0,$77,$A2,$8C,$4F,$23,$D9,
$96,$07,$52,$F4,$D1,$DD,$EF,$89,$4B,$D0,$C9,$8A,$EF,$1E,$7A,$62,$CB,$4C,$EF,$3A,
$DB,$69,$C6,$E7,$BE,$4E,$42,$81,$7D,$32,$96,$B0,$40,$A9,$AF,$82,$55,$76,$C1,$AA,
$B3,$1F,$4A,$38,$62,$D2,$09,$60,$FA,$ED,$6B,$E3,$EF,$70,$61,$68,$18,$5C,$84,$1D,
$03,$54,$9E,$49,$0D,$24,$63,$1B,$E3,$41,$D9,$B7,$93,$0E,$63,$B8,$EE,$48,$D3,$67,
$80,$FE,$4E,$6B,$6F,$9C,$67,$D7,$81,$F9,$7C,$46,$5C,$D6,$01,$C4,$3A,$79,$D3,$66,
$83,$EF,$3D,$0E,$66,$CE,$27,$4F,$18,$BD,$80,$E3,$B5,$42,$05,$FB,$1D,$D2,$93,$9F,
$AC,$DC,$9D,$20,$20,$9E,$9C,$F0,$CD,$1F,$C1,$BE,$F1,$7E,$C6,$7F,$6E,$50,$E3,$D8,
$91,$C0,$A8,$26,$36,$1C,$1B,$59,$20,$31,$8B,$A6,$25,$78,$A5,$50,$7E,$3C,$9D,$FB,
$A1,$BB,$C3,$A7,$3B,$DB,$52,$33,$06,$D8,$16,$F4,$17,$6F,$92,$B7,$C5,$94,$E3,$3C,
$50,$91,$5B,$92,$25,$FC,$28,$40,$C6,$F5,$51,$1D,$3E,$15,$AD,$5F,$30,$64,$7B,$E6,
$68,$AD,$1A,$C9,$FB,$AA,$62,$D8,$BE,$95,$C2,$17,$27,$C7,$F3,$03,$DC,$54,$24,$A2,
$42,$37,$08,$B6,$4D,$AB,$3E,$D6,$79,$57,$B8,$AA,$DF,$80,$A9,$17,$BC,$2B,$15,$73,
$BB,$D7,$26,$EB,$F7,$04,$8C,$29,$C1,$1E,$52,$1F,$40,$13,$94,$DE,$0A,$CE,$5C,$BF,
$4A,$1C,$BA,$48,$50,$EF,$9B,$B3,$B7,$26,$9E,$E8,$C1,$C3,$FE,$0A,$0A,$91,$61,$8E,
$07,$55,$5B,$4A,$F7,$09,$9B,$4A,$0F,$BA,$1F,$90,$DD,$4E,$CF,$75,$57,$61,$CF,$0B,
$16,$D9,$D7,$31,$63,$51,$31,$5B,$2C,$15,$37,$F2,$53,$A6,$EE,$34,$95,$01,$6D,$65,
$F5,$99,$54,$51,$D8,$57,$35,$C3,$94,$D5,$8F,$DB,$5D,$89,$43,$43,$C1,$D5,$E5,$68,
$8D,$FE,$18,$67,$8D,$6F,$F8,$C6,$5C,$55,$37,$B4,$41,$63,$5C,$37,$53,$AE,$78,$24,
$1F,$A4,$74,$86,$00,$A7,$C3,$62,$CE,$A8,$EA,$5D,$E9,$55,$7C,$54,$72,$55,$AE,$A5,
$F4,$C6,$79,$34,$1A,$AA,$A4,$09,$D9,$65,$AE,$32,$91,$0F,$3D,$6E,$BC,$41,$15,$5D,
$57,$F0,$D7,$D7,$6B,$57,$26,$4B,$F7,$80,$3A,$28,$02,$4C,$DD,$7C,$D5,$16,$AE,$01,
$25,$F9,$1E,$EF,$9F,$65,$16,$0A,$7B,$D2,$2B,$14,$C3,$5D,$F2,$36,$08,$9B,$0E,$26,
$61,$B8,$02,$FE,$0C,$10,$FB,$BF,$34,$8C,$A8,$51,$C8,$88,$0A,$B4,$2D,$C5,$EB,$82,
$EE,$DF,$C4,$9D,$EF,$EC,$EA,$7B,$D0,$FE,$F0,$54,$E8,$BC,$47,$F1,$C6,$09,$56,$41,
$7C,$D7,$7F,$DE,$25,$8E,$C1,$41,$B0,$FA,$69,$52,$E6,$2B,$75,$1B,$B3,$A9,$AF,$91,
$0E,$CA,$DB,$57,$08,$14,$DD,$7F,$CE,$30,$20,$C8,$70,$DB,$61,$DD,$DB,$B4,$01,$1F,
$6E,$DB,$F9,$63,$81,$C2,$89,$C1,$81,$ED,$E2,$72,$F8,$EB,$E6,$D4,$77,$4C,$D3,$AA,
$A8,$BA,$12,$08,$03,$B4,$B0,$B8,$AC,$3E,$63,$F9,$9D,$4D,$5A,$32,$2E,$C2,$74,$5A,
$B4,$FA,$2D,$6C,$58,$BC,$40,$6C,$95,$10,$17,$C2,$3A,$23,$7D,$12,$F0,$95,$49,$0E,
$25,$94,$AA,$62,$29,$91,$B0,$01,$35,$CA,$6D,$EB,$82,$44,$00,$94,$42,$7E,$37,$63,
$2C,$91,$77,$1A,$17,$95,$69,$22,$52,$3B,$A3,$5D,$1A,$F3,$03,$0C,$75,$E2,$79,$D7,
$8D,$70,$8D,$2F,$45,$7A,$89,$D4,$4E,$FF,$3F,$A0,$3A,$FF,$BB,$DC,$47,$17,$D4,$F2,
$93,$36,$AB,$AE,$51,$3D,$A4,$25,$F5,$E5,$2F,$90,$E8,$EF,$FF,$49,$A6,$35,$02,$95,
$54,$24,$6C,$61,$15,$20,$D9,$F9,$F3,$63,$68,$DA,$60,$DD,$91,$BC,$47,$60,$E5,$90,
$0A,$E0,$E1,$44,$08,$D5,$47,$BC,$57,$75,$B1,$BA,$34,$06,$8A,$54,$DA,$9D,$73,$B6,
$13,$FD,$9C,$9E,$66,$C8,$B5,$11,$38,$51,$7A,$33,$54,$B3,$AA,$CE,$63,$0C,$81,$9A,
$30,$AA,$1D,$5A,$B6,$3E,$58,$82,$76,$5F,$56,$25,$6A,$C2,$15,$E8,$47,$99,$4B,$D9,
$A8,$76,$89,$75,$59,$62,$77,$A2,$AA,$D9,$95,$BC,$7E,$03,$26,$A2,$3F,$BA,$71,$0B,
$E3,$4F,$BD,$6A,$72,$F0,$93,$EF,$5E,$15,$63,$60,$C1,$8A,$EF,$62,$A5,$52,$5F,$E0,
$2B,$AD,$64,$32,$9A,$24,$D3,$6E,$DF,$16,$71,$8D,$36,$7C,$0B,$DF,$63,$11,$67,$8B,
$B4,$4F,$13,$88,$1E,$BA,$D0,$A5,$2C,$2A,$CB,$61,$69,$FC,$97,$E0,$DD,$3E,$FF,$4F,
$64,$08,$53,$67,$A6,$C4,$D7,$AB,$5B,$98,$AE,$A6,$6F,$46,$B6,$1F,$AF,$2C,$1A,$2D,
$1F,$DD,$A1,$D1,$31,$98,$D9,$5C,$33,$F5,$1D,$80,$62,$DC,$8E,$AF,$D8,$25,$86,$64,
$AE,$3A,$30,$C1,$91,$79,$58,$AB,$5C,$32,$2A,$D1,$C4,$C6,$5A,$3C,$FC,$38,$52,$7B,
$37,$F7,$54,$F9,$E8,$AA,$98,$68,$D3,$8C,$FC,$35,$72,$5C,$58,$16,$25,$D0,$D8,$A7,
$18,$29,$74,$9A,$D1,$B1,$50,$AC,$EA,$32,$72,$F6,$04,$EE,$03,$6C,$A2,$9E,$F7,$D9,
$2D,$71,$44,$97,$6D,$34,$C5,$2E,$F0,$57,$55,$77,$5F,$C0,$B0,$43,$56,$68,$CE,$02,
$50,$03,$13,$3F,$36,$3C,$37,$93,$B8,$DF,$42,$D5,$41,$FC,$CA,$B9,$7E,$B6,$B9,$9B,
$C4,$AA,$34,$8A,$D4,$55,$93,$6F,$00,$0C,$CC,$9A,$AB,$2A,$8D,$E5,$51,$30,$50,$75,
$15,$47,$50,$6D,$F1,$0C,$56,$28,$E8,$6A,$0F,$84,$D1,$BA,$8B,$5C,$26,$48,$2C,$1F,
$45,$BE,$29,$6E,$FF,$AB,$87,$57,$5B,$CA,$43,$F9,$1D,$01,$70,$FA,$F7,$15,$FF,$96,
$3E,$BC,$AA,$E2,$DD,$D1,$87,$CA,$D0,$AB,$2B,$88,$92,$65,$3A,$57,$64,$0F,$0D,$85,
$31,$93,$18,$98,$B9,$BF,$50,$B6,$E1,$82,$C3,$3B,$AE,$6D,$F0,$18,$DC,$B7,$A0,$8B,
$8F,$C0,$6D,$98,$86,$73,$94,$68,$61,$82,$D2,$69,$60,$15,$10,$E1,$60,$E2,$B8,$07,
$1C,$27,$C0,$43,$7F,$B1,$60,$B1,$A8,$35,$9C,$77,$57,$21,$12,$BF,$84,$F9,$57,$AD,
$38,$E7,$00,$BF,$59,$8A,$2B,$82,$70,$B5,$D5,$3B,$59,$4D,$8E,$AE,$5E,$1E,$AD,$F9,
$C0,$A0,$75,$DB,$59,$2D,$4E,$A3,$63,$1E,$B0,$64,$7E,$55,$E2,$69,$C7,$DA,$9F,$74,
$98,$14,$23,$1B,$8B,$CA,$F5,$0D,$81,$85,$A2,$49,$02,$5E,$82,$C4,$26,$51,$FC,$8F,
$AC,$99,$67,$00,$E2,$A4,$DE,$B7,$F7,$9E,$41,$0B,$E6,$DF,$C8,$81,$57,$27,$D3,$74,
$A1,$01,$F2,$1C,$01,$25,$EA,$64,$CA,$BF,$DE,$FB,$F2,$09,$35,$56,$95,$14,$11,$8B,
$B7,$C4,$FE,$CC,$59,$6D,$C6,$45,$F1,$A0,$D2,$B1,$59,$21,$FA,$0B,$6A,$A3,$83,$A0,
$D5,$AE,$AC,$21,$86,$A4,$09,$9F,$DC,$D7,$AD,$D6,$EA,$47,$4E,$58,$66,$8A,$22,$56,
$B8,$58,$87,$89,$E5,$83,$0B,$37,$60,$09,$88,$4B,$55,$E7,$DB,$54,$BD,$EA,$A0,$09,
$DA,$D7,$A3,$91,$F9,$F5,$3A,$0B,$4B,$DE,$BE,$5D,$23,$55,$49,$77,$5A,$46,$0B,$F8,
$ED,$40,$ED,$E3,$E6,$71,$47,$9A,$AC,$9D,$A4,$37,$FD,$BA,$BD,$D7,$55,$D5,$DB,$93,
$20,$BF,$92,$1D,$D1,$F4,$FA,$3A,$C9,$25,$AA,$DB,$74,$1D,$02,$A0,$2C,$DE,$69,$17,
$80,$DC,$98,$0F,$D8,$AD,$AE,$85,$FA,$03,$70,$BB,$54,$61,$7D,$2F,$B1,$02,$4C,$4E,
$76,$AA,$82,$F9,$AA,$1B,$A6,$A2,$D3,$9E,$F3,$D5,$D2,$B8,$0F,$27,$06,$1F,$3D,$65,
$27,$E7,$20,$3E,$8B,$A2,$C0,$25,$9E,$3D,$11,$EF,$28,$A1,$AA,$80,$01,$63,$CF,$43,
$0C,$17,$3C,$EF,$12,$89,$C6,$52,$F4,$C9,$B0,$A1,$DC,$5F,$53,$54,$AE,$90,$1F,$46,
$39,$66,$C7,$D2,$E6,$32,$2D,$73,$0A,$2D,$77,$5A,$F7,$CA,$B2,$B1,$17,$13,$B6,$1F,
$B6,$F5,$58,$51,$8D,$B7,$BB,$40,$C7,$FF,$55,$69,$D9,$8F,$E1,$FF,$55,$91,$D9,$42,
$4E,$A0,$2F,$0E,$7F,$35,$38,$69,$EA,$E5,$3B,$01,$4B,$81,$52,$E5,$A5,$BE,$35,$75,
$55,$B9,$9C,$95,$AD,$B9,$9A,$FD,$88,$99,$60,$F3,$F8,$DD,$D4,$D6,$95,$FC,$77,$4D,
$AC,$47,$D4,$60,$8A,$32,$1A,$D6,$E2,$A2,$A1,$2D,$87,$DC,$6C,$95,$F5,$4E,$D0,$68,
$D9,$55,$DD,$5B,$5C,$18,$AC,$A6,$8E,$52,$22,$C9,$61,$77,$94,$68,$35,$0A,$15,$3B,
$DC,$77,$BE,$59,$D0,$FC,$FE,$57,$40,$52,$85,$FF,$00,$7E,$22,$02,$B3,$95,$5A,$F8,
$E9,$23,$45,$31,$18,$F8,$41,$CE,$F1,$F9,$BE,$EE,$63,$D2,$B3,$BE,$1D,$6F,$AE,$46,
$06,$C4,$08,$E7,$6A,$F3,$56,$88,$D5,$DE,$A8,$DA,$EF,$02,$5D,$CD,$0A,$D3,$FE,$F2,
$81,$C7,$0E,$A9,$EE,$02,$CF,$DF,$8C,$06,$A8,$39,$97,$EB,$B0,$35,$C6,$55,$1A,$57,
$94,$95,$94,$FB,$DD,$AB,$CA,$82,$61,$77,$40,$64,$A0,$CA,$A6,$C5,$B3,$C6,$C5,$6B,
$7F,$F3,$8D,$F8,$83,$40,$2F,$9C,$AF,$26,$E2,$45,$EE,$90,$80,$CF,$7F,$72,$70,$B5,
$0D,$D2,$3E,$02,$BC,$C8,$1E,$9C,$BE,$07,$7B,$FF,$02,$8C,$CF,$D9,$C7,$1C,$C2,$A3,
$0C,$76,$39,$2C,$5D,$15,$91,$99,$58,$C8,$3C,$45,$1B,$84,$65,$E3,$45,$5C,$55,$5B,
$A0,$8A,$9C,$6C,$AD,$46,$B9,$32,$51,$08,$26,$18,$19,$3B,$1D,$DB,$A8,$47,$FE,$65,
$0D,$5F,$49,$0D,$6B,$F5,$D4,$E7,$0C,$1C,$98,$20,$8B,$07,$B3,$55,$12,$48,$36,$76,
$6A,$B7,$BA,$14,$FA,$39,$02,$EB,$23,$56,$F4,$56,$71,$C5,$AD,$B2,$1F,$31,$89,$F3,
$C0,$13,$7F,$65,$27,$5B,$80,$C7,$FF,$2E,$92,$E0,$FC,$DE,$07,$76,$A8,$6D,$67,$FD,
$59,$44,$79,$9E,$41,$FF,$EB,$42,$CD,$7C,$55,$79,$B8,$30,$CD,$A9,$23,$EE,$6A,$8A,
$A8,$A1,$28,$08,$A3,$E4,$42,$87,$B5,$A8,$EC,$16,$02,$77,$86,$1E,$2C,$06,$4E,$61,
$50,$95,$14,$A5,$60,$A2,$D4,$F2,$52,$8B,$87,$18,$23,$0D,$03,$FE,$8B,$37,$55,$BC,
$7F,$A2,$5C,$4D,$3F,$75,$3F,$38,$4D,$58,$DF,$FE,$DE,$EA,$00,$DA,$31,$4B,$C2,$1F,
$ED,$2A,$78,$58,$2D,$75,$14,$5A,$EA,$32,$AA,$A2,$2E,$2A,$F1,$13,$DD,$45,$FF,$BB,
$89,$5E,$0E,$57,$83,$77,$51,$AE,$8D,$8F,$06,$65,$7C,$6C,$B3,$5F,$A5,$9B,$7E,$8C,
$6F,$6C,$C7,$22,$73,$C3,$61,$8C,$F1,$87,$BC,$DA,$3B,$16,$C4,$E0,$23,$D4,$8A,$4E,
$5A,$56,$0B,$C4,$5C,$01,$FF,$09,$00,$C9,$E7,$B1,$73,$45,$66,$08,$31,$84,$B8,$89,
$11,$7C,$C6,$35,$FB,$A7,$AF,$E5,$00,$77,$97,$96,$C1,$8B,$37,$63,$17,$9E,$CC,$2A,
$E2,$9B,$85,$29,$B3,$F2,$F8,$ED,$FB,$CC,$21,$2F,$7F,$B5,$65,$F4,$54,$4D,$9F,$AB,
$20,$37,$4C,$0A,$A6,$FF,$F3,$20,$39,$88,$61,$FB,$1F,$BF,$D4,$AC,$EA,$78,$E1,$E8,
$63,$6F,$AD,$30,$F7,$B3,$C8,$BA,$22,$A4,$C3,$C8,$7B,$1D,$5A,$75,$0E,$00,$A8,$A4,
$3D,$57,$A1,$BB,$82,$71,$4C,$AE,$0B,$51,$48,$AB,$0C,$51,$3E,$7F,$B6,$D9,$42,$95,
$B8,$0D,$DF,$A9,$56,$92,$7F,$60,$A1,$63,$53,$81,$57,$A1,$6F,$08,$AB,$AD,$BB,$C2,
$50,$2C,$AD,$E1,$A9,$F3,$D5,$2C,$0E,$70,$13,$98,$2E,$46,$77,$17,$E6,$36,$D4,$95,
$04,$70,$3F,$F6,$42,$FD,$04,$E1,$22,$6D,$C7,$A2,$E0,$0A,$E0,$15,$94,$C8,$7F,$1D,
$17,$62,$E5,$E5,$24,$B4,$AA,$E3,$55,$A6,$2E,$3A,$00,$CF,$E2,$18,$78,$5F,$25,$23,
$85,$61,$8D,$D2,$43,$96,$10,$3B,$9C,$62,$3D,$9A,$FF,$57,$63,$70,$FF,$D5,$58,$F1,
$D9,$8B,$5D,$07,$B7,$0F,$FB,$8E,$86,$95,$B6,$45,$26,$D4,$91,$B6,$E3,$D7,$E9,$9C,
$F2,$E5,$D6,$79,$9E,$DE,$57,$79,$42,$37,$22,$3A,$38,$CD,$A3,$96,$49,$E6,$B5,$18,
$AB,$2E,$72,$BE,$8B,$4B,$57,$F4,$AF,$4A,$82,$2B,$AF,$84,$3C,$CA,$DB,$E7,$CC,$1F,
$05,$70,$F4,$E6,$2D,$45,$2C,$0A,$B6,$C1,$03,$BD,$BA,$26,$03,$7B,$77,$68,$B0,$3A,
$EE,$4A,$E4,$D0,$91,$CA,$BB,$05,$63,$92,$80,$B1,$5A,$C6,$93,$4C,$31,$D8,$E4,$CC,
$9D,$18,$9A,$35,$2C,$BB,$2F,$4D,$51,$37,$21,$FE,$77,$5C,$B5,$78,$43,$27,$94,$48,
$FA,$6F,$CF,$2F,$38,$68,$66,$67,$16,$95,$F6,$EC,$5E,$CC,$48,$03,$A1,$30,$D8,$97,
$58,$1E,$1A,$90,$5D,$75,$33,$7D,$52,$A6,$BA,$30,$F9,$95,$02,$A9,$F9,$B1,$5D,$06,
$38,$D8,$7F,$5D,$E4,$7C,$91,$AD,$FE,$E1,$8A,$BB,$46,$47,$D1,$FC,$EC,$2A,$E3,$E0,
$5B,$0C,$99,$EA,$F2,$02,$E1,$F6,$17,$AC,$35,$81,$98,$C2,$ED,$82,$7D,$27,$C1,$AB,
$10,$59,$E0,$D0,$15,$52,$BF,$40,$F9,$0A,$82,$46,$F9,$AA,$5E,$C6,$F9,$0B,$2F,$37,
$AA,$0C,$BC,$DC,$61,$BA,$36,$4E,$3F,$7D,$DE,$A6,$22,$FB,$13,$B0,$A7,$5E,$AA,$BA,
$8A,$0A,$17,$A1,$6F,$5F,$07,$7C,$6F,$16,$73,$C3,$02,$68,$D7,$11,$09,$03,$F0,$AB,
$07,$78,$7A,$B7,$82,$78,$C2,$20,$6D,$E3,$72,$54,$96,$D4,$D2,$12,$D5,$4B,$3F,$D0,
$5D,$D8,$81,$83,$C0,$BC,$6A,$7F,$99,$BC,$8E,$70,$B8,$1E,$E8,$41,$23,$61,$A4,$AD,
$03,$D1,$1C,$8F,$5A,$7C,$35,$2F,$26,$EB,$82,$0A,$1C,$17,$DE,$DF,$23,$26,$E1,$BA,
$BE,$B8,$EB,$EB,$3A,$5D,$43,$50,$C3,$2F,$02,$3A,$52,$20,$66,$6C,$84,$76,$15,$0B,
$68,$1B,$18,$11,$D8,$80,$CC,$40,$30,$2A,$F5,$2C,$35,$74,$F2,$FC,$BF,$AB,$3A,$A8,
$F8,$C3,$84,$C7,$19,$12,$EE,$1C,$05,$57,$98,$34,$29,$20,$25,$2A,$E6,$A5,$E5,$AB,
$8A,$BB,$69,$6C,$A1,$63,$F8,$D7,$04,$C6,$F5,$D3,$D0,$9A,$EA,$DA,$5E,$57,$8D,$B5,
$09,$C9,$FB,$7D,$4A,$67,$1F,$7A,$DD,$0E,$0C,$A6,$AA,$31,$FE,$85,$AA,$46,$6C,$FF,
$89,$97,$83,$53,$CC,$08,$BA,$E2,$FC,$3F,$B2,$01,$16,$A7,$CB,$11,$2D,$FD,$0D,$69,
$FB,$83,$4F,$22,$EE,$76,$F7,$27,$7D,$93,$02,$F5,$33,$D0,$DF,$31,$99,$D6,$CC,$A8,
$B0,$F8,$BB,$B7,$61,$28,$D7,$D7,$D3,$B1,$5E,$61,$C4,$08,$82,$D2,$D8,$A9,$33,$E8,
$FD,$D5,$45,$0D,$1F,$39,$85,$24,$F7,$77,$B3,$57,$74,$E7,$BF,$2B,$8C,$6B,$3F,$76,
$90,$79,$EC,$FC,$F7,$19,$D0,$57,$3D,$31,$C3,$8B,$A1,$29,$67,$D5,$0C,$C9,$03,$4C,
$F4,$47,$58,$FB,$FD,$75,$26,$EC,$7E,$B0,$BB,$86,$68,$28,$75,$26,$58,$65,$B2,$E9,
$E8,$FA,$C5,$B4,$57,$77,$7E,$B5,$4A,$07,$97,$80,$BA,$A2,$75,$FF,$D8,$77,$F1,$11,
$6A,$EA,$23,$3F,$EA,$AD,$3C,$F8,$A5,$DB,$F1,$9F,$06,$C5,$6F,$15,$52,$61,$DF,$16,
$E6,$A9,$48,$71,$CB,$2F,$39,$FB,$53,$C7,$7E,$65,$B4,$AA,$8C,$AA,$FC,$2A,$25,$E5,
$BA,$FA,$CD,$4A,$AB,$0F,$80,$8A,$BE,$17,$15,$97,$67,$80,$A9,$D0,$1B,$67,$53,$D7,
$2C,$FE,$9E,$BA,$AF,$F8,$64,$F0,$27,$2E,$73,$35,$75,$75,$64,$8D,$3A,$20,$5D,$A7,
$E5,$A2,$14,$5F,$95,$12,$13,$F9,$43,$7D,$FF,$CD,$25,$3E,$0C,$91,$40,$3B,$C3,$5C,
$25,$77,$A3,$A7,$F5,$BA,$46,$C0,$E0,$7D,$B7,$89,$C3,$A1,$49,$C3,$9A,$D7,$B3,$0E,
$DD,$63,$CE,$AC,$AF,$11,$3B,$63,$04,$5F,$69,$D9,$A7,$F0,$23,$5F,$1D,$9D,$FB,$FA,
$59,$14,$E7,$81,$0F,$88,$2B,$16,$A3,$B4,$00,$4F,$77,$67,$7C,$7D,$74,$99,$DA,$2B,
$D0,$91,$0B,$66,$8D,$41,$B9,$D6,$7B,$FD,$03,$E3,$0A,$D3,$DE,$3D,$9D,$76,$1D,$D9,
$BA,$DC,$B7,$ED,$EA,$F1,$59,$CC,$B3,$69,$E0,$7E,$EC,$AE,$B5,$4C,$05,$14,$AC,$8F,
$9D,$44,$A6,$04,$13,$CA,$DC,$B5,$C5,$B8,$5C,$AF,$BB,$E4,$66,$BD,$F9,$19,$60,$BF,
$50,$2E,$3A,$56,$D7,$84,$74,$A7,$BE,$63,$4D,$75,$9A,$E0,$EE,$60,$0A,$7D,$77,$3C,
$F5,$7D,$A9,$AF,$9A,$E9,$B0,$8E,$56,$11,$D4,$58,$55,$AB,$D8,$CD,$DE,$0B,$D7,$72,
$43,$F1,$76,$C5,$2E,$2A,$B7,$4D,$4A,$F5,$6E,$D2,$EA,$7E,$D7,$A7,$F7,$DD,$76,$5F,
$B2,$3D,$48,$2F,$B5,$EF,$84,$A3,$EA,$17,$FE,$F5,$47,$FA,$CF,$5D,$7D,$E2,$C0,$61,
$B4,$C3,$68,$05,$59,$C2,$FD,$ED,$CF,$12,$E0,$2A,$41,$BB,$BE,$94,$A5,$3E,$D0,$3C,
$1C,$48,$F7,$EB,$E0,$A9,$13,$AB,$24,$99,$A5,$D1,$CB,$FC,$7A,$F7,$45,$65,$CB,$E6,
$1A,$72,$5F,$AF,$5D,$D8,$E0,$F7,$37,$82,$CD,$BB,$4B,$B4,$62,$C1,$4A,$CB,$C6,$11,
$62,$19,$C8,$A0,$23,$A4,$2B,$AF,$3C,$F3,$48,$BD,$FE,$56,$B2,$A4,$41,$77,$47,$E5,
$D3,$F7,$B7,$A5,$85,$00,$D8,$4A,$C5,$78,$64,$80,$55,$F1,$44,$98,$57,$22,$E4,$9C,
$B2,$6F,$66,$C8,$87,$75,$5E,$1F,$C3,$C6,$2F,$55,$70,$B9,$13,$C7,$61,$C8,$BE,$AA,
$45,$CA,$B7,$13,$A6,$3F,$CC,$05,$1B,$AE,$D9,$78,$E4,$AD,$55,$C7,$38,$89,$C5,$2C,
$D9,$21,$A3,$48,$C4,$31,$BF,$26,$C1,$FD,$90,$FD,$BD,$8F,$23,$A4,$EE,$10,$E0,$9E,
$47,$E1,$BA,$80,$92,$A6,$57,$A1,$83,$5E,$D7,$83,$E2,$F3,$5E,$DF,$E3,$78,$F4,$6B,
$B2,$FA,$38,$52,$0B,$E7,$CE,$6A,$69,$29,$A5,$8B,$69,$0D,$2A,$A5,$33,$4C,$AC,$51,
$B7,$95,$02,$7F,$88,$5D,$F9,$64,$DD,$05,$FE,$01,$B7,$BD,$0F,$4D,$3B,$F7,$D1,$9A,
$BD,$81,$4A,$AE,$52,$5D,$D2,$A1,$BB,$3E,$AA,$EB,$7D,$0F,$C2,$64,$EF,$3B,$91,$7C,
$85,$DF,$87,$8B,$9E,$56,$4E,$3F,$6C,$E3,$0F,$F3,$FD,$56,$63,$37,$F9,$D0,$5F,$CF,
$A5,$96,$50,$A2,$FE,$32,$66,$9C,$36,$59,$F1,$AC,$E8,$2F,$3A,$E5,$AE,$CF,$0D,$49,
$F6,$15,$A7,$69,$D7,$4A,$3C,$90,$8D,$7E,$E5,$BB,$EE,$C6,$46,$F9,$D4,$E2,$71,$84,
$96,$63,$F4,$76,$66,$DD,$47,$4B,$6B,$22,$FA,$BD,$52,$38,$2C,$BC,$33,$2B,$F7,$3F,
$08,$58,$9D,$2C,$F6,$3A,$77,$48,$16,$09,$E0,$4C,$E7,$86,$DF,$AB,$65,$57,$95,$18,
$79,$66,$22,$83,$F7,$1C,$B8,$4A,$75,$DB,$B7,$DF,$83,$31,$2A,$FF,$56,$5A,$9F,$E4,
$AA,$4A,$A5,$0A,$DB,$D1,$75,$AB,$5F,$26,$BC,$FA,$CE,$B8,$A1,$45,$4F,$76,$5F,$32,
$E5,$E2,$A2,$AE,$0A,$F7,$CA,$0A,$DF,$5F,$94,$E2,$EC,$9E,$AD,$15,$8C,$22,$EE,$30,
$44,$F4,$F9,$B8,$AE,$9A,$70,$51,$15,$93,$6C,$32,$60,$49,$30,$4A,$67,$80,$6E,$B5,
$E5,$AF,$AC,$15,$78,$B4,$58,$39,$77,$DF,$0D,$B1,$AC,$79,$E1,$BF,$EE,$98,$09,$45,
$63,$88,$C8,$52,$6E,$BF,$2D,$DA,$B9,$4E,$3D,$58,$A8,$2A,$32,$0A,$E8,$9F,$A3,$B6,
$51,$31,$CD,$2D,$AD,$01,$87,$E7,$5D,$29,$FD,$4E,$FD,$22,$EC,$59,$32,$33,$7B,$85,
$DC,$BE,$2B,$46,$38,$42,$21,$5B,$51,$65,$04,$C8,$BA,$23,$82,$69,$64,$F2,$F3,$18,
$CD,$83,$DB,$A1,$AE,$BB,$55,$00,$74,$EB,$D5,$67,$2B,$98,$F9,$17,$D1,$9A,$9A,$D1,
$97,$DC,$82,$65,$47,$5D,$D4,$19,$7A,$55,$A7,$EC,$16,$B4,$7D,$07,$D3,$30,$14,$CB,
$7D,$B7,$AE,$EC,$53,$55,$B8,$30,$44,$84,$E5,$BF,$37,$E9,$DB,$F0,$A4,$FA,$92,$17,
$36,$EA,$F0,$91,$38,$B5,$98,$AC,$C4,$D0,$74,$D7,$85,$12,$1D,$B2,$26,$4C,$37,$B3,
$8F,$86,$14,$14,$89,$FD,$0D,$28,$12,$13,$C2,$50,$F4,$40,$70,$61,$20,$70,$51,$3F,
$46,$66,$49,$40,$25,$63,$50,$5C,$51,$4A,$51,$55,$34,$5C,$09,$14,$83,$15,$61,$6E,
$06,$5F,$AC,$74,$41,$C6,$BC,$46,$79,$3C,$10,$AE,$CB,$60,$B6,$FA,$C2,$EB,$83,$26,
$3E,$A6,$A8,$29,$49,$65,$67,$50,$09,$DF,$A7,$65,$86,$32,$2C,$22,$8B,$5C,$41,$F2,
$E0,$12,$B0,$54,$5A,$E2,$7C,$D0,$08,$07,$FE,$7F,$1E,$07,$04,$39,$15,$F4,$FE,$27,
$78,$5F,$94,$EB,$BE,$67,$12,$B7,$EC,$BB,$B1,$E2,$0C,$1E,$D4,$DA,$6D,$62,$F7,$52,
$C0,$9E,$9A,$27,$D4,$97,$F5,$CB,$DC,$02,$2F,$0F,$44,$DF,$D1,$9A,$76,$BE,$AF,$1F,
$A4,$C1,$AA,$B3,$E5,$4D,$C6,$49,$5F,$7D,$7C,$B9,$89,$FE,$EF,$B1,$9B,$2A,$02,$66,
$B2,$C7,$1D,$CA,$6E,$DC,$80,$2E,$55,$20,$35,$B8,$CE,$F4,$24,$58,$69,$FB,$81,$15,
$27,$19,$00,$52,$E9,$2E,$D2,$7F,$04,$56,$6E,$02,$10,$C1,$50,$25,$53,$7D,$17,$51,
$AF,$80,$75,$28,$BC,$58,$AA,$C8,$97,$54,$AE,$88,$61,$0C,$00,$F7,$0F,$C9,$8E,$33,
$18,$77,$7D,$51,$37,$86,$BD,$FF,$42,$2F,$DA,$25,$D6,$45,$80,$FB,$F0,$81,$5F,$2E,
$56,$49,$94,$E3,$FE,$E2,$DC,$25,$36,$47,$44,$2D,$F9,$F4,$C0,$8C,$14,$87,$42,$F6,
$A8,$72,$6F,$C5,$AB,$92,$2E,$2B,$F4,$6A,$92,$0C,$6F,$EC,$D0,$D4,$5A,$57,$EC,$B9,
$B0,$3F,$37,$F1,$AD,$8B,$AB,$D4,$A1,$5F,$7E,$E2,$DE,$3D,$4E,$AD,$0A,$3B,$FD,$71,
$8B,$78,$9D,$FB,$D7,$36,$37,$0C,$7C,$3C,$FE,$BB,$87,$1B,$F6,$4E,$61,$81,$0B,$5B,
$68,$7D,$8F,$89,$CC,$D4,$59,$D6,$05,$A3,$38,$A1,$00,$65,$85,$D7,$50,$2B,$E8,$21,
$B9,$E0,$CF,$50,$7D,$80,$F7,$2A,$8F,$FC,$39,$B5,$D4,$B9,$D0,$ED,$1B,$16,$1B,$03,
$20,$09,$66,$D5,$B7,$4B,$22,$4D,$79,$62,$C1,$F3,$16,$99,$3C,$24,$9D,$E9,$08,$13,
$C7,$EA,$15,$77,$2A,$75,$7F,$0A,$9F,$CF,$04,$29,$65,$C1,$60,$DD,$EF,$12,$72,$E0,
$D4,$BF,$DD,$1C,$07,$C8,$5F,$11,$36,$43,$5F,$DD,$6D,$7A,$21,$7D,$BA,$35,$DA,$E7,
$0A,$E8,$BE,$02,$CD,$C5,$96,$50,$06,$A6,$27,$A7,$4F,$DD,$42,$1A,$5E,$9B,$0A,$DE,
$AC,$FB,$14,$B4,$52,$21,$0C,$B5,$5F,$3C,$F7,$CF,$7D,$E2,$29,$0A,$57,$C2,$83,$E3,
$62,$3E,$9F,$3E,$9A,$BE,$5C,$04,$23,$8A,$6A,$97,$1E,$3F,$5F,$05,$2A,$D3,$A4,$28,
$7F,$22,$5A,$54,$F1,$5B,$A2,$B2,$52,$2C,$83,$95,$C7,$55,$25,$26,$62,$55,$24,$12,
$14,$65,$02,$14,$60,$44,$C0,$C0,$AC,$96,$9C,$89,$A8,$0D,$19,$F5,$77,$CD,$46,$22,
$BE,$5D,$AD,$EC,$29,$27,$E6,$30,$1C,$2C,$61,$EE,$10,$EB,$A7,$7C,$92,$E0,$5E,$6D,
$6A,$F7,$6A,$74,$10,$35,$DE,$29,$83,$28,$E4,$28,$0C,$C3,$29,$8A,$40,$69,$6A,$C4,
$00,$99,$74,$15,$39,$AA,$6D,$A8,$E6,$A9,$52,$19,$D8,$53,$A6,$DF,$56,$ED,$C7,$63,
$01,$E5,$32,$A0,$63,$50,$A4,$B2,$DF,$6D,$1A,$67,$91,$03,$CB,$C9,$AE,$13,$55,$F6,
$EE,$C3,$5A,$6D,$C1,$4D,$6D,$AF,$52,$AA,$7B,$61,$DC,$2B,$A8,$4B,$D8,$AA,$20,$E4,
$80,$B9,$14,$57,$D3,$24,$0C,$4B,$FE,$9E,$4B,$25,$5A,$AC,$BF,$FC,$BE,$C2,$31,$28,
$3C,$8E,$EE,$77,$D8,$3E,$7D,$4D,$42,$56,$F7,$86,$2A,$0B,$B5,$14,$CC,$5A,$CA,$27,
$FA,$92,$E2,$CA,$9D,$8C,$5E,$A6,$72,$96,$A5,$15,$64,$F5,$6D,$C6,$2E,$08,$2F,$D2,
$A9,$17,$A7,$38,$34,$6D,$AD,$30,$8A,$B0,$71,$FC,$CC,$AA,$23,$E7,$E2,$20,$52,$69,
$29,$E2,$D6,$EF,$BA,$41,$10,$10,$A2,$EB,$A4,$31,$8A,$D1,$9A,$34,$F9,$06,$27,$D3,
$DD,$AD,$92,$61,$F9,$AA,$DF,$51,$19,$5E,$8D,$1C,$60,$10,$F6,$33,$9B,$BF,$88,$DC,
$FC,$1F,$9C,$A9,$F3,$27,$CD,$54,$DA,$52,$78,$3C,$0F,$05,$BB,$43,$2B,$82,$24,$0D,
$AB,$20,$A0,$99,$D3,$1D,$F4,$2A,$8A,$8B,$4C,$80,$18,$29,$E9,$83,$17,$D4,$22,$DF,
$7F,$91,$79,$B9,$3E,$01,$F4,$8A,$9C,$75,$CA,$90,$2A,$AD,$37,$AB,$AE,$30,$30,$C0,
$B0,$3B,$2F,$98,$11,$44,$10,$DF,$E9,$63,$44,$DF,$1C,$0E,$9C,$00,$FC,$C9,$5C,$F9,
$24,$F5,$52,$44,$F4,$B1,$8A,$11,$30,$30,$E0,$60,$F1,$F9,$7B,$08,$22,$88,$20,$83,
$B1,$6B,$49,$EB,$A3,$75,$88,$61,$7B,$92,$E8,$1D,$D9,$10,$AF,$07,$68,$72,$C1,$00,
$83,$76,$70,$24,$83,$CE,$F4,$CE,$3C,$81,$E2,$50,$B8,$72,$2F,$D4,$83,$C9,$C6,$BB,
$08,$EB,$54,$AB,$12,$54,$DB,$84,$9A,$CE,$2D,$4C,$D9,$2B,$91,$6E,$F4,$16,$A5,$5F,
$45,$07,$56,$BE,$CA,$FD,$9B,$C1,$04,$49,$B4,$3D,$3E,$28,$ED,$2D,$BC,$75,$B7,$FA,
$10,$AD,$6F,$22,$25,$ED,$8A,$82,$68,$89,$01,$B0,$F7,$D9,$1B,$56,$D6,$AE,$4D,$9F,
$E3,$D7,$C9,$04,$50,$57,$81,$10,$03,$7A,$21,$C3,$C2,$0D,$CC,$33,$E7,$66,$95,$43,
$1E,$1E,$06,$E9,$68,$38,$20,$CE,$99,$30,$0C,$62,$1A,$31,$B2,$CB,$4B,$A1,$7F,$F6,
$5A,$BB,$B7,$A4,$D1,$08,$2F,$19,$DA,$C4,$11,$62,$F0,$0E,$6E,$81,$C3,$10,$CA,$A4,
$4C,$15,$14,$97,$29,$77,$2A,$F1,$D5,$98,$DC,$54,$80,$CC,$51,$96,$CA,$B3,$D9,$86,
$84,$01,$0E,$DA,$14,$87,$43,$A1,$D9,$96,$0E,$CD,$9B,$FA,$DE,$AE,$BB,$1B,$B2,$D6,
$76,$83,$A1,$F0,$61,$0A,$C1,$BC,$3A,$06,$5F,$9D,$32,$06,$92,$11,$19,$24,$94,$26,
$BD,$BA,$DA,$C2,$D4,$BF,$8F,$0C,$98,$19,$1B,$3A,$06,$2A,$84,$29,$39,$23,$33,$57,
$D7,$2F,$53,$24,$05,$93,$45,$2D,$1C,$44,$21,$A5,$0C,$13,$B8,$BA,$0B,$48,$3E,$BA,
$C6,$3A,$47,$4A,$7E,$AE,$C2,$05,$24,$D9,$0F,$73,$9C,$A1,$82,$F2,$0C,$5E,$26,$D7,
$54,$AD,$CA,$58,$81,$03,$03,$E6,$0A,$2A,$DD,$D1,$58,$55,$D5,$F7,$4D,$03,$60,$A2,
$78,$01,$B1,$E0,$F5,$9A,$54,$AF,$C5,$B7,$F7,$F0,$C7,$5F,$EB,$EE,$86,$02,$FF,$EE,
$88,$E1,$84,$96,$4E,$BD,$06,$94,$8E,$78,$6E,$1B,$25,$D3,$15,$F2,$04,$44,$E9,$AA,
$50,$A4,$B5,$E1,$B3,$56,$85,$A1,$B1,$5A,$92,$D6,$EC,$7C,$31,$B8,$FC,$8A,$DC,$E6,
$BF,$F5,$15,$74,$B4,$84,$95,$1B,$90,$65,$E6,$5F,$9E,$97,$DD,$80,$E1,$7C,$92,$36,
$91,$2E,$75,$7F,$EC,$EE,$99,$9F,$91,$F5,$9D,$E8,$AC,$33,$61,$38,$4A,$89,$EB,$8B,
$FF,$97,$3F,$8E,$67,$13,$03,$90,$C3,$35,$64,$9C,$62,$54,$23,$43,$5F,$F1,$16,$7A,
$DC,$9D,$58,$98,$9F,$03,$03,$04,$9C,$D6,$A8,$1D,$71,$04,$11,$12,$0A,$BF,$EE,$3B,
$2B,$FE,$8F,$30,$4C,$49,$13,$41,$83,$09,$7C,$22,$5E,$0C,$80,$40,$8B,$1C,$63,$48,
$9F,$A2,$AC,$4B,$92,$A4,$04,$B9,$92,$83,$88,$28,$F1,$DE,$AD,$4A,$9C,$6E,$4C,$3D,
$44,$12,$A7,$05,$1B,$3D,$28,$54,$38,$16,$81,$6B,$AB,$9F,$3E,$AA,$4F,$B9,$D2,$DB,
$1C,$51,$09,$A6,$77,$9E,$9C,$E7,$1E,$1D,$41,$4C,$03,$1F,$8A,$0C,$32,$BC,$5C,$07,
$56,$30,$51,$C0,$C2,$43,$28,$88,$82,$D3,$44,$6B,$72,$19,$72,$88,$49,$5C,$42,$C9,
$A9,$65,$98,$2B,$25,$51,$EE,$FE,$EA,$A6,$D6,$20,$16,$1B,$AB,$13,$7D,$6A,$63,$A5,
$D2,$37,$97,$D4,$05,$60,$2F,$F8,$11,$B5,$AE,$98,$B3,$CF,$13,$AC,$85,$A0,$89,$A8,
$13,$23,$8D,$A4,$E8,$11,$2B,$C4,$34,$45,$62,$1E,$BE,$26,$3C,$0B,$D3,$13,$DD,$0A,
$D8,$71,$52,$29,$12,$E9,$3B,$19,$2E,$80,$64,$35,$BA,$E7,$AC,$8A,$8A,$CA,$CA,$90,
$3D,$5D,$55,$40,$06,$1A,$8A,$DA,$C4,$0A,$B8,$D4,$3D,$B0,$5D,$77,$A3,$85,$6D,$FA,
$02,$2F,$84,$56,$9B,$05,$1C,$F7,$2D,$D8,$95,$BC,$99,$8E,$66,$BD,$0B,$CD,$F5,$5F,
$0D,$3D,$36,$12,$D7,$6A,$AC,$76,$F0,$51,$68,$E5,$E8,$71,$56,$86,$C1,$31,$E4,$47,
$DD,$A3,$A8,$0C,$59,$FC,$FF,$48,$A8,$B7,$EC,$D4,$57,$61,$86,$D8,$3F,$03,$3A,$51,
$9F,$28,$75,$26,$8A,$91,$54,$A7,$50,$21,$76,$49,$11,$0B,$DC,$F8,$90,$FB,$E7,$49,
$BD,$FD,$2E,$50,$B2,$4D,$8C,$F5,$55,$DF,$5F,$25,$0D,$1C,$EF,$0B,$E4,$0F,$C4,$1A,
$97,$7C,$55,$85,$7C,$D5,$CC,$55,$12,$F4,$13,$2B,$0D,$76,$14,$43,$74,$D3,$1F,$FE,
$BF,$4F,$55,$28,$80,$AB,$CD,$CE,$86,$F6,$B5,$58,$24,$4D,$74,$5F,$B1,$F9,$50,$64,
$B1,$E8,$02,$F4,$74,$FF,$27,$BA,$5F,$89,$22,$FB,$5C,$01,$94,$DC,$07,$D0,$68,$61,
$29,$C5,$E7,$81,$EF,$83,$3F,$3D,$FA,$2F,$B8,$95,$C1,$6C,$DC,$15,$7B,$EF,$4E,$F7,
$87,$41,$94,$E2,$3F,$55,$D8,$FF,$4A,$6B,$0B,$61,$F4,$AC,$40,$51,$B6,$22,$0D,$D4,
$A8,$53,$27,$BA,$D5,$18,$AC,$ED,$DC,$A8,$C6,$8A,$4F,$0E,$C4,$53,$F8,$DC,$8D,$EB,
$7F,$7D,$CA,$83,$F8,$D2,$46,$88,$86,$14,$69,$98,$55,$53,$22,$00,$B3,$18,$BE,$19,
$D8,$29,$7D,$21,$61,$10,$64,$86,$9E,$44,$57,$51,$C2,$68,$9E,$03,$2C,$00,$B9,$C2,
$CD,$E4,$BE,$0B,$0C,$C9,$82,$87,$A9,$3F,$4A,$73,$29,$DC,$05,$65,$72,$5F,$23,$C8,
$2A,$CE,$5F,$F5,$B2,$58,$7A,$C0,$B3,$FA,$54,$E3,$89,$53,$17,$84,$F0,$0F,$3C,$C2,
$50,$DB,$B2,$7F,$7A,$D5,$8B,$5B,$A1,$78,$0A,$FA,$3A,$CB,$94,$B3,$66,$CE,$A0,$A8,
$BC,$B2,$1F,$75,$79,$57,$DC,$4C,$DF,$36,$DC,$A8,$88,$DF,$AE,$62,$7C,$90,$E4,$8C,
$89,$CA,$71,$C9,$19,$B3,$33,$08,$B2,$6F,$AF,$0B,$41,$AE,$F0,$11,$BF,$8A,$EC,$78,
$6D,$56,$F8,$81,$E6,$E3,$5E,$A0,$8E,$FE,$C6,$2C,$57,$1F,$3F,$7B,$52,$E4,$0C,$6F,
$19,$11,$EC,$20,$C6,$D3,$6C,$FC,$0F,$E7,$74,$86,$15,$17,$2D,$DF,$6B,$2C,$CE,$3E,
$06,$8A,$DE,$03,$B7,$A8,$BA,$F3,$01,$BB,$82,$96,$1B,$F9,$00,$41,$72,$47,$5C,$0B,
$09,$41,$0C,$8F,$B1,$0E,$8B,$85,$65,$AB,$DA,$EF,$2E,$AF,$51,$E3,$76,$5D,$11,$82,
$2F,$E0,$05,$2A,$0A,$00,$63,$47,$6F,$66,$E6,$D1,$84,$D6,$42,$1F,$6B,$1F,$85,$3B,
$A0,$41,$C9,$71,$7F,$31,$A5,$26,$FB,$09,$C3,$55,$72,$71,$D8,$71,$5C,$CB,$13,$60,
$88,$03,$E7,$18,$56,$64,$F0,$AA,$A2,$7C,$0C,$50,$61,$FF,$51,$6A,$7D,$07,$21,$5B,
$9A,$3E,$08,$55,$A5,$0E,$BF,$A9,$AF,$04,$89,$CC,$EC,$5B,$75,$73,$E9,$3B,$57,$CD,
$D6,$05,$3F,$13,$31,$31,$02,$BB,$21,$52,$BA,$DC,$06,$FA,$99,$73,$05,$0E,$F5,$FC,
$FC,$03,$C3,$C5,$26,$7A,$E6,$15,$FF,$54,$1D,$82,$FD,$95,$47,$DF,$52,$1D,$2E,$26,
$5D,$87,$72,$30,$0C,$09,$E5,$C6,$4D,$D7,$7F,$1F,$28,$41,$A3,$F8,$7F,$95,$AC,$91,
$14,$40,$A1,$75,$C6,$F9,$B7,$49,$2A,$2A,$D6,$01,$24,$4B,$DB,$7E,$9F,$75,$02,$3E,
$C3,$70,$93,$A2,$5B,$73,$49,$03,$90,$7D,$51,$05,$12,$7F,$A1,$EA,$97,$AE,$A3,$48,
$4C,$7F,$7A,$D1,$50,$96,$F6,$5D,$15,$63,$C9,$D2,$E2,$E2,$8F,$DA,$42,$55,$A5,$C0,
$02,$8A,$B7,$F3,$99,$E0,$A1,$A9,$4C,$D4,$4E,$29,$BC,$59,$0D,$06,$0E,$76,$4C,$35,
$10,$A9,$CB,$CA,$84,$D8,$76,$1D,$90,$C0,$0D,$18,$29,$67,$CC,$B4,$5E,$83,$A1,$CB,
$64,$F8,$99,$2F,$43,$BE,$9C,$65,$FF,$82,$74,$AF,$8E,$F5,$0D,$B3,$87,$8E,$8F,$A4,
$7A,$E1,$D7,$8D,$79,$DF,$62,$7A,$13,$8E,$FE,$7A,$1B,$66,$8E,$E3,$D6,$53,$86,$5E,
$5D,$91,$14,$11,$87,$C3,$1D,$CB,$E5,$CC,$28,$41,$7E,$97,$65,$7F,$52,$BC,$4C,$D7,
$49,$AE,$FD,$77,$8D,$E6,$16,$69,$7C,$03,$CC,$50,$2A,$1A,$13,$88,$5B,$F3,$55,$88,
$13,$D7,$C1,$54,$65,$31,$1F,$87,$D7,$52,$FA,$6B,$73,$6A,$7D,$63,$AC,$29,$D5,$62,
$1A,$27,$6A,$59,$7F,$11,$73,$BB,$5A,$D4,$27,$8E,$95,$FB,$6A,$89,$DF,$74,$3E,$5B,
$76,$6C,$72,$EE,$0A,$4A,$55,$1D,$E3,$DF,$D6,$B2,$6B,$91,$D2,$28,$FA,$CF,$F8,$7A,
$8F,$59,$4F,$AC,$36,$48,$1C,$BE,$BF,$09,$BE,$0B,$76,$7C,$58,$6F,$13,$D5,$3E,$0F,
$EC,$B8,$94,$77,$F2,$A7,$28,$FC,$AD,$A1,$CD,$50,$51,$7C,$5A,$B8,$57,$28,$B0,$A1,
$EB,$38,$90,$67,$6E,$EF,$9B,$00,$07,$54,$16,$72,$53,$F5,$79,$E1,$7C,$A9,$BF,$AE,
$14,$5D,$73,$DD,$BE,$8F,$EA,$E4,$50,$71,$AA,$10,$CC,$4A,$2C,$97,$62,$32,$F4,$3E,
$10,$C2,$E3,$13,$1B,$67,$1F,$CC,$3A,$00,$68,$45,$1D,$D9,$EE,$3D,$C4,$76,$31,$BD,
$77,$B5,$F3,$35,$8D,$FF,$30,$3F,$77,$E3,$7F,$74,$2C,$61,$F8,$CD,$B0,$CB,$98,$D7,
$0B,$F4,$18,$B0,$E9,$DC,$06,$5E,$39,$D1,$D1,$8D,$A2,$D3,$5B,$C9,$FB,$96,$60,$1F,
$AD,$D2,$1A,$31,$38,$62,$8B,$55,$85,$25,$7E,$29,$F4,$D1,$B1,$AD,$29,$54,$7B,$3E,
$E2,$8F,$2F,$A4,$34,$B3,$07,$36,$FF,$C2,$4A,$E3,$9B,$46,$AE,$FF,$F9,$7D,$03,$95,
$A9,$A0,$0A,$5C,$AB,$A1,$C7,$98,$7E,$9A,$D5,$49,$91,$66,$68,$7B,$5C,$7D,$FA,$F7,
$48,$F5,$52,$1A,$7C,$AF,$FB,$95,$F4,$7B,$E7,$EF,$8A,$21,$AD,$E9,$BA,$54,$34,$31,
$1B,$98,$66,$51,$36,$29,$4D,$17,$20,$A0,$4D,$49,$E0,$E2,$BC,$0A,$5B,$78,$D8,$68,
$27,$AB,$84,$EA,$0E,$04,$9F,$25,$52,$BE,$52,$EC,$6F,$55,$56,$77,$C5,$D8,$9E,$07,
$5D,$91,$4D,$4D,$8E,$93,$BB,$68,$7C,$AC,$D8,$6F,$AA,$32,$74,$A2,$F2,$0A,$19,$8C,
$D3,$CC,$07,$71,$1D,$1F,$F8,$AE,$A1,$17,$A9,$4B,$80,$7E,$6C,$75,$19,$5F,$1F,$EC,
$23,$1A,$07,$F4,$D3,$28,$AC,$28,$ED,$D7,$16,$AD,$28,$48,$CA,$60,$43,$BF,$C9,$C1,
$36,$F2,$63,$DD,$FA,$CA,$81,$1B,$32,$76,$90,$89,$00,$41,$EA,$2E,$E3,$CB,$EE,$C8,
$3E,$C0,$08,$75,$4A,$76,$1C,$5C,$7F,$D4,$2D,$9B,$29,$08,$51,$57,$04,$A4,$06,$80,
$D2,$0B,$C9,$85,$D3,$01,$68,$D4,$35,$47,$4C,$0B,$83,$88,$DA,$A4,$6E,$83,$70,$82,
$FC,$EA,$DA,$49,$5D,$CB,$5C,$CC,$C4,$49,$DC,$B2,$89,$58,$17,$BA,$70,$A7,$E6,$7D,
$D6,$DC,$BA,$C0,$AC,$58,$80,$7A,$48,$E9,$35,$D6,$BD,$96,$EF,$13,$D9,$7E,$FE,$80,
$BB,$5A,$E0,$23,$2E,$07,$DA,$3D,$F6,$F7,$82,$C6,$10,$A6,$62,$A1,$77,$45,$0B,$2B,
$C0,$F5,$84,$7E,$90,$1E,$C9,$7B,$37,$20,$CD,$55,$C6,$D9,$6F,$25,$31,$D8,$E5,$3C,
$30,$75,$D9,$5E,$D0,$AE,$65,$38,$06,$6C,$9E,$22,$E1,$FD,$0E,$8B,$7B,$BB,$C3,$15,
$37,$E6,$B2,$F3,$18,$E1,$C8,$53,$7D,$48,$86,$01,$6D,$8B,$02,$D7,$55,$E0,$B3,$0C,
$7C,$85,$B2,$CB,$D4,$15,$30,$7A,$AE,$CF,$D4,$82,$3D,$2C,$37,$5F,$DC,$F5,$9E,$8C,
$98,$B8,$FF,$1F,$26,$18,$C4,$17,$1B,$28,$0C,$A2,$06,$0A,$18,$C4,$42,$A7,$2E,$CC,
$4E,$82,$78,$CA,$32,$B6,$F1,$54,$23,$3F,$36,$61,$C2,$5F,$1E,$E1,$B7,$3B,$3A,$D2,
$3B,$B1,$28,$31,$C5,$95,$BF,$56,$71,$1F,$91,$79,$CD,$94,$00,$DC,$BD,$E1,$B2,$F8,
$F2,$CA,$DD,$08,$00,$AF,$D5,$0D,$F2,$49,$AC,$94,$F5,$02,$EC,$C4,$B2,$75,$10,$7F,
$A3,$CF,$0E,$4D,$B2,$3B,$4D,$A5,$0E,$73,$7E,$B0,$E6,$8B,$E1,$CF,$BC,$67,$DE,$17,
$DB,$89,$0E,$F7,$47,$A4,$07,$0E,$A7,$AB,$85,$12,$3B,$E9,$0D,$AB,$40,$64,$22,$B7,
$87,$E8,$F8,$C5,$0B,$53,$8B,$B2,$0F,$78,$EC,$B8,$C4,$24,$D0,$8A,$B2,$8E,$4F,$BA,
$FA,$C4,$DA,$57,$BD,$F8,$85,$62,$47,$AB,$4C,$A0,$E8,$04,$8B,$57,$4E,$98,$F7,$13,
$07,$16,$FD,$AA,$9E,$3F,$ED,$BF,$CB,$8A,$C4,$9B,$EC,$A6,$D7,$79,$61,$60,$4F,$AF,
$DF,$E7,$77,$6D,$42,$22,$33,$58,$31,$E0,$0C,$2A,$4F,$2C,$31,$3E,$61,$21,$BA,$7B,
$95,$1C,$46,$62,$38,$57,$FB,$62,$60,$38,$2E,$99,$AD,$0A,$07,$4C,$0E,$7D,$07,$81,
$C4,$44,$52,$06,$A8,$FA,$0B,$31,$4A,$7A,$81,$80,$88,$35,$FC,$EC,$D5,$F4,$9E,$C2,
$AA,$A2,$03,$9D,$FC,$66,$0D,$D6,$CA,$7B,$D0,$8C,$0D,$19,$46,$87,$54,$C4,$98,$9B,
$A0,$68,$33,$40,$1B,$73,$41,$A2,$27,$2A,$34,$87,$85,$E2,$34,$4B,$C4,$10,$CA,$AF,
$4A,$86,$80,$9A,$0D,$05,$9A,$17,$57,$E9,$4D,$0F,$62,$1D,$FC,$3B,$3C,$EF,$76,$8C,
$A9,$4E,$5F,$8E,$13,$4A,$14,$6F,$29,$DF,$85,$C2,$3F,$EF,$9D,$BE,$C4,$D8,$FA,$CE,
$92,$87,$6A,$4B,$2D,$BA,$C1,$57,$98,$1D,$DB,$7B,$A2,$FD,$1D,$0F,$BD,$EB,$98,$1F,
$C0,$47,$45,$AF,$22,$D9,$5E,$D8,$B7,$DF,$BC,$3C,$B3,$2E,$1F,$FA,$F0,$75,$11,$3B,
$29,$76,$A3,$1E,$8E,$FD,$30,$3A,$97,$50,$3D,$37,$AF,$4A,$99,$56,$65,$20,$75,$DF,
$25,$61,$22,$44,$A3,$17,$46,$A8,$E1,$17,$46,$B5,$04,$BF,$EF,$95,$23,$85,$46,$0B,
$C1,$A4,$A3,$3B,$FD,$3A,$C6,$3A,$A0,$C5,$72,$AB,$3A,$5A,$97,$A8,$BB,$10,$ED,$44,
$B1,$D8,$81,$41,$AB,$AF,$7D,$27,$BD,$7D,$D0,$4B,$61,$5E,$DC,$23,$A5,$DF,$93,$77,
$B9,$5F,$46,$7B,$34,$D4,$51,$52,$B5,$3C,$F9,$8E,$69,$C6,$FD,$EE,$8A,$8F,$9D,$53,
$D1,$5A,$9C,$57,$73,$E2,$EE,$2B,$85,$EE,$94,$46,$36,$56,$3D,$55,$DC,$D5,$CB,$B1,
$FF,$A6,$2D,$11,$B9,$3B,$01,$D1,$13,$5C,$03,$75,$0C,$8D,$DA,$56,$88,$96,$4C,$92,
$1F,$A5,$AC,$8B,$97,$ED,$F3,$37,$5B,$C0,$BF,$DE,$F8,$84,$EF,$43,$D9,$ED,$CC,$55,
$00,$D4,$5D,$EE,$05,$52,$4C,$EB,$FE,$E0,$F5,$E8,$8F,$BA,$AB,$65,$22,$C6,$42,$5D,
$15,$DC,$64,$C5,$5B,$2C,$0C,$69,$B9,$D1,$1A,$99,$E9,$D6,$FE,$FE,$98,$79,$CE,$D6,
$BA,$EB,$2A,$F1,$ED,$6C,$5F,$DD,$03,$DC,$E0,$AF,$A6,$EC,$C3,$FB,$9D,$FF,$F8,$BC,
$29,$0A,$C7,$54,$B9,$27,$2E,$F5,$7E,$28,$91,$BF,$6A,$0F,$8D,$97,$EF,$33,$F4,$08,
$97,$2C,$B8,$E8,$03,$4B,$57,$87,$1C,$54,$FB,$C4,$17,$8B,$39,$5C,$E2,$38,$F8,$1B,
$0C,$1B,$96,$B9,$69,$F9,$C0,$3A,$2B,$A1,$47,$29,$FA,$2A,$AC,$5C,$DE,$1F,$DA,$87,
$52,$8B,$7F,$49,$79,$FD,$C7,$13,$1B,$1F,$6A,$EB,$05,$EA,$A6,$ED,$7D,$E5,$3A,$C0,
$83,$59,$83,$09,$6C,$6D,$1E,$C9,$55,$87,$FC,$69,$5A,$74,$0B,$43,$93,$CB,$68,$AF,
$0F,$DD,$45,$69,$A0,$26,$0E,$5A,$55,$20,$44,$C0,$BB,$C4,$4C,$75,$4A,$35,$4E,$D7,
$D5,$E5,$1B,$C6,$2A,$AB,$4D,$1A,$BF,$69,$AF,$32,$AE,$13,$31,$3D,$24,$E9,$63,$62,
$10,$E2,$1A,$2C,$57,$DA,$27,$7B,$C2,$A2,$C0,$F7,$E0,$DA,$6C,$30,$75,$DB,$E8,$BB,
$4E,$C6,$75,$F3,$2E,$BC,$BE,$35,$0A,$3D,$3D,$9B,$86,$E0,$88,$D6,$77,$45,$D8,$DF,
$22,$C9,$0C,$2B,$D5,$09,$09,$7D,$D7,$DC,$5B,$FB,$BE,$88,$C7,$EF,$55,$37,$39,$EE,
$BD,$AE,$3C,$60,$95,$A0,$AB,$78,$84,$05,$98,$CC,$A8,$C6,$AF,$FF,$8E,$AC,$AF,$B3,
$D0,$B8,$56,$62,$86,$F0,$2C,$AE,$A0,$AA,$E5,$40,$FA,$97,$DA,$3F,$9F,$7E,$93,$40,
$B9,$41,$B0,$83,$AC,$7B,$36,$95,$B2,$9F,$FF,$DD,$3F,$F2,$1E,$2C,$E8,$4D,$FE,$01,
$5A,$08,$D5,$B9,$50,$50,$97,$39,$1F,$8A,$E9,$87,$E2,$75,$26,$08,$17,$AC,$73,$3C,
$89,$1D,$F6,$2B,$9A,$F7,$AF,$F2,$88,$11,$70,$5C,$61,$89,$52,$C0,$79,$76,$2F,$7A,
$A3,$7C,$05,$09,$F2,$AD,$2B,$07,$9D,$BB,$13,$B5,$35,$35,$8B,$B0,$C9,$F9,$16,$92,
$0C,$95,$2A,$56,$77,$5B,$9A,$40,$85,$22,$71,$23,$51,$32,$35,$18,$B6,$2F,$BE,$FD,
$30,$BC,$4F,$87,$FF,$09,$09,$57,$EC,$7F,$5A,$5A,$FD,$D7,$AF,$EF,$34,$E6,$A6,$26,
$47,$62,$9A,$79,$3B,$B0,$52,$DC,$D5,$0B,$82,$B6,$45,$B9,$BD,$71,$1A,$0E,$E4,$5A,
$75,$BF,$6D,$35,$E5,$AB,$EE,$FA,$F3,$56,$8C,$0C,$0A,$1A,$E6,$54,$C8,$09,$A4,$41,
$82,$1E,$4C,$27,$DA,$DA,$74,$43,$23,$AE,$53,$99,$AD,$18,$7A,$4A,$A1,$3E,$0C,$5F,
$FD,$45,$C2,$54,$02,$65,$44,$F6,$BB,$DB,$80,$82,$C9,$BA,$9A,$79,$4A,$77,$C2,$C1,
$0C,$54,$04,$DB,$0B,$22,$47,$C5,$9A,$0F,$AC,$52,$2F,$69,$8A,$9E,$B0,$A5,$F5,$67,
$A6,$0E,$A5,$2A,$3D,$76,$C4,$18,$53,$E3,$1B,$BF,$CA,$F7,$2B,$D5,$40,$57,$90,$08,
$5D,$B3,$91,$F7,$0E,$47,$70,$12,$A3,$C8,$33,$93,$F3,$93,$F2,$A4,$40,$0D,$F0,$53,
$FF,$DE,$81,$AF,$74,$FC,$15,$C9,$AD,$5B,$EE,$06,$81,$C6,$37,$31,$CC,$5D,$4C,$DD,
$17,$3C,$0C,$19,$5E,$08,$85,$FE,$67,$43,$0E,$20,$34,$0E,$7E,$4F,$CE,$62,$61,$CA,
$56,$E3,$71,$30,$57,$A7,$45,$10,$F6,$86,$4E,$7F,$49,$18,$D4,$1D,$FC,$A9,$50,$B8,
$AB,$46,$9F,$88,$7C,$15,$02,$76,$77,$54,$48,$82,$75,$43,$6D,$7D,$57,$EC,$33,$FE,
$06,$C6,$35,$6C,$FF,$45,$E0,$A9,$E6,$6C,$7D,$17,$B4,$70,$64,$FB,$5F,$72,$68,$7B,
$7F,$61,$C6,$EB,$DF,$E9,$07,$65,$86,$BF,$D4,$31,$5F,$FC,$FE,$EA,$8F,$41,$FD,$C8,
$C8,$87,$1D,$BD,$47,$AC,$AB,$E8,$56,$D6,$5A,$F5,$F8,$56,$ED,$82,$EB,$91,$EE,$0A,
$F1,$04,$1F,$9D,$FD,$93,$A5,$FF,$25,$82,$53,$F5,$D4,$28,$E9,$C1,$18,$1E,$04,$C1,
$46,$D9,$C9,$5D,$45,$C2,$35,$C4,$23,$2F,$D2,$23,$B8,$FF,$FA,$EC,$19,$0E,$98,$50,
$3B,$DE,$C2,$31,$09,$09,$F3,$57,$D9,$31,$87,$A3,$A0,$EB,$0F,$2C,$06,$A3,$FB,$02,
$CF,$C4,$45,$D0,$7D,$88,$98,$1E,$8E,$F3,$33,$B4,$EA,$92,$4F,$24,$55,$1C,$8C,$8D,
$B2,$45,$6C,$9A,$84,$A8,$A4,$A0,$AB,$34,$13,$0C,$84,$7A,$42,$BA,$B0,$E7,$51,$82,
$E5,$51,$1C,$76,$4A,$BB,$BE,$AF,$16,$68,$32,$AF,$FF,$EB,$C3,$AE,$9B,$10,$AA,$21,
$14,$A7,$79,$A6,$A2,$99,$FA,$02,$AF,$58,$1D,$47,$64,$8C,$BC,$30,$11,$19,$B4,$29,
$92,$32,$9F,$BB,$62,$18,$54,$64,$6D,$85,$5A,$85,$13,$5F,$60,$33,$A9,$3F,$D4,$B8,
$7B,$0D,$3C,$E5,$B7,$A4,$67,$7F,$D5,$49,$79,$97,$8B,$83,$E3,$BB,$21,$78,$1B,$53,
$E3,$D8,$82,$65,$F2,$BB,$B0,$04,$59,$14,$D1,$E2,$4D,$02,$96,$2A,$DE,$59,$C2,$C1,
$7A,$B0,$CC,$56,$F6,$E1,$8B,$4C,$12,$1E,$F3,$42,$2C,$0C,$1F,$43,$E3,$83,$93,$B0,
$4D,$BD,$F2,$C1,$51,$F8,$20,$4D,$F8,$20,$0B,$FD,$46,$13,$36,$C8,$3C,$BA,$EB,$7B,
$B8,$52,$05,$EC,$29,$D1,$79,$99,$13,$AD,$F6,$0B,$F0,$99,$E6,$97,$C9,$8E,$C6,$65,
$62,$4D,$F7,$D1,$A4,$6B,$28,$F4,$65,$BD,$6D,$56,$91,$4B,$B5,$C6,$29,$C5,$AC,$7F,
$00,$9B,$AB,$5F,$49,$72,$EB,$B8,$2B,$A5,$58,$B5,$32,$0A,$C2,$56,$FE,$98,$41,$EF,
$BC,$A2,$92,$58,$C6,$2E,$10,$08,$51,$A4,$AB,$43,$5E,$FA,$BC,$A5,$B7,$0C,$AA,$73,
$99,$35,$BE,$0B,$32,$3B,$8A,$B6,$76,$6E,$5B,$A4,$A2,$F3,$48,$A5,$01,$A7,$4A,$1D,
$B4,$4F,$E9,$CD,$75,$EE,$F7,$D5,$C4,$52,$ED,$BA,$54,$F8,$8D,$B8,$3B,$ED,$58,$A8,
$AE,$70,$18,$7F,$B7,$5C,$C1,$DF,$F5,$E7,$A4,$59,$00,$E6,$BF,$FC,$BD,$BA,$E7,$F6,
$69,$D7,$3D,$71,$FB,$80,$D0,$FB,$B4,$69,$7F,$3D,$8A,$6A,$5E,$B5,$6C,$FB,$69,$09,
$58,$4E,$11,$0E,$63,$BB,$17,$B2,$A6,$19,$18,$6B,$18,$22,$B7,$62,$F1,$68,$69,$64,
$EE,$AE,$2D,$C1,$55,$87,$DC,$49,$8A,$92,$30,$3C,$C9,$D7,$D6,$44,$5E,$D5,$2A,$55,
$37,$30,$31,$58,$8E,$A2,$8B,$A6,$6B,$D8,$03,$6C,$B9,$31,$A6,$A8,$30,$A9,$B5,$44,
$FE,$12,$C0,$AB,$6B,$53,$DD,$EB,$E8,$39,$B6,$AE,$A0,$87,$4A,$8D,$7C,$ED,$A5,$EF,
$8C,$5D,$CF,$B1,$AF,$BE,$39,$F6,$F2,$00,$5A,$0B,$89,$93,$B8,$4A,$F7,$A6,$54,$B9,
$B1,$09,$72,$DC,$A8,$65,$E9,$C1,$47,$52,$74,$96,$FA,$C2,$5C,$BB,$E5,$A8,$54,$08,
$15,$80,$5F,$05,$36,$55,$81,$D5,$69,$FF,$B1,$83,$46,$43,$A1,$9B,$D5,$24,$27,$76,
$A2,$1E,$EE,$75,$29,$41,$68,$57,$F7,$83,$32,$21,$47,$24,$86,$78,$53,$1B,$F5,$EF,
$76,$C5,$90,$76,$CF,$90,$D5,$44,$FF,$47,$06,$88,$F3,$C2,$04,$EC,$74,$F5,$32,$35,
$F5,$A2,$78,$76,$B5,$6C,$A5,$E4,$AE,$FB,$A6,$8B,$CA,$CC,$55,$AE,$60,$49,$77,$EE,
$46,$98,$9B,$C2,$4B,$A1,$F6,$69,$54,$FF,$54,$6D,$3C,$DA,$D5,$42,$AE,$02,$B3,$D6,
$72,$A3,$C5,$66,$14,$E4,$62,$A1,$C9,$68,$57,$F4,$77,$7C,$B5,$BB,$C8,$77,$7A,$5B,
$11,$D7,$74,$85,$44,$BD,$C8,$14,$71,$93,$3E,$83,$E6,$BB,$72,$6C,$90,$50,$C4,$7D,
$44,$F9,$92,$A5,$8D,$5D,$7D,$4E,$25,$56,$2C,$33,$5E,$8B,$C4,$FC,$A0,$42,$B6,$39,
$77,$68,$C9,$A2,$A3,$00,$1A,$23,$75,$2B,$9A,$3E,$A5,$F4,$4F,$69,$AF,$3A,$84,$ED,
$78,$34,$E8,$D4,$78,$2A,$E1,$35,$E0,$50,$68,$FE,$72,$2E,$4D,$D0,$88,$42,$CB,$87,
$49,$1D,$F8,$3D,$50,$6B,$08,$76,$0B,$35,$CE,$28,$48,$3C,$6D,$46,$70,$2C,$98,$F5,
$A5,$59,$8D,$C2,$7E,$D6,$D0,$BD,$F9,$6A,$81,$9F,$16,$84,$64,$07,$71,$E0,$7D,$42,
$B8,$C2,$20,$F5,$C6,$2C,$7E,$44,$95,$5D,$DF,$59,$1D,$31,$58,$ED,$25,$57,$A5,$74,
$FC,$17,$45,$E9,$EA,$7A,$12,$12,$83,$AE,$F1,$31,$EE,$F3,$D9,$BF,$03,$A5,$6B,$F5,
$DE,$F7,$0E,$AF,$C0,$7F,$A1,$7E,$DD,$1D,$61,$3A,$B9,$8C,$62,$EA,$48,$6F,$D7,$0F,
$AC,$8D,$A2,$AA,$0A,$88,$3E,$D9,$A0,$48,$29,$6D,$98,$0D,$00,$10,$3A,$7F,$43,$A4,
$83,$C0,$5C,$48,$CF,$11,$4B,$15,$A2,$28,$AC,$3E,$F9,$C5,$38,$35,$56,$D4,$60,$75,
$D2,$3D,$F1,$78,$01,$6B,$C1,$00,$3F,$C5,$E5,$22,$C2,$FB,$5F,$C7,$29,$BA,$AB,$24,
$2C,$74,$57,$7A,$F3,$18,$8A,$EE,$2B,$E8,$1B,$E6,$39,$BB,$2F,$AC,$14,$5F,$B7,$49,
$97,$5A,$7E,$D7,$BF,$08,$7D,$BA,$42,$22,$3A,$F9,$1B,$1C,$C3,$B1,$07,$5E,$21,$32,
$7B,$F7,$C2,$48,$32,$88,$30,$56,$6E,$2E,$EA,$BA,$22,$B1,$91,$0C,$EF,$81,$3A,$17,
$04,$7D,$71,$CE,$28,$CF,$F0,$55,$59,$9D,$FB,$02,$A5,$8D,$A9,$A1,$B4,$ED,$A2,$7B,
$C1,$B4,$EF,$19,$52,$DD,$60,$B9,$52,$F3,$59,$B5,$62,$63,$4C,$55,$8B,$14,$A8,$51,
$7F,$52,$F9,$BA,$1E,$4D,$4C,$AA,$55,$BE,$5F,$2D,$6C,$57,$6B,$66,$60,$57,$06,$2E,
$8A,$E7,$80,$BF,$91,$D5,$41,$30,$18,$39,$41,$81,$00,$71,$5D,$45,$A5,$52,$38,$64,
$11,$EF,$83,$0B,$55,$25,$65,$95,$E2,$FF,$1C,$EC,$DE,$FA,$D9,$E7,$FD,$F5,$CD,$C9,
$AF,$ED,$3E,$19,$7A,$60,$11,$C1,$11,$F9,$0E,$1A,$96,$2C,$12,$0E,$CA,$31,$BA,$42,
$00,$A2,$7D,$98,$69,$5F,$FF,$F6,$23,$A1,$2E,$30,$18,$A2,$D6,$E0,$0A,$F0,$5D,$6B,
$D6,$99,$FA,$34,$38,$82,$EB,$A1,$EC,$8E,$76,$25,$58,$87,$48,$34,$BE,$AB,$8E,$24,
$01,$C1,$66,$82,$C3,$AA,$FF,$02,$0B,$5D,$23,$74,$82,$9E,$13,$C7,$9E,$8C,$75,$D5,
$1E,$A9,$F4,$FF,$CB,$94,$BE,$47,$D5,$70,$9B,$18,$18,$AA,$6C,$44,$6F,$26,$F8,$2C,
$79,$25,$2C,$F8,$E6,$AA,$6A,$47,$76,$9F,$FF,$61,$8F,$D6,$23,$0A,$ED,$2B,$AF,$6B,
$51,$15,$79,$A1,$D3,$C1,$E1,$E3,$42,$59,$99,$2A,$DC,$53,$D5,$A9,$52,$A0,$54,$59,
$1D,$09,$58,$A1,$90,$65,$F9,$A8,$2A,$71,$63,$FA,$8E,$39,$36,$90,$E6,$B5,$AE,$D1,
$D0,$03,$D3,$FF,$BF,$14,$BA,$A7,$38,$AB,$36,$3B,$C6,$28,$04,$F3,$01,$6D,$99,$BC,
$CD,$7F,$09,$62,$B9,$48,$A8,$05,$07,$AE,$B4,$92,$C4,$94,$BB,$1E,$B7,$B6,$22,$86,
$EE,$6A,$95,$4A,$72,$99,$2A,$D2,$0C,$AC,$55,$91,$17,$AB,$A7,$4C,$BF,$18,$D6,$8D,
$7A,$36,$DD,$DB,$BD,$D9,$2F,$BF,$24,$92,$18,$AA,$C9,$11,$55,$DE,$A0,$01,$03,$82,
$36,$09,$31,$27,$0C,$0B,$BC,$D1,$3A,$49,$AD,$EB,$56,$6F,$4F,$93,$56,$E9,$6D,$A7,
$51,$77,$8D,$3D,$A6,$20,$0C,$AB,$42,$32,$25,$DC,$76,$7B,$27,$53,$88,$98,$B2,$6E,
$07,$12,$AC,$CB,$DF,$72,$2C,$32,$AF,$0F,$D5,$E8,$E5,$D1,$87,$3C,$F0,$AB,$8C,$BA,
$6B,$97,$1C,$00,$C5,$7F,$35,$F9,$B4,$E4,$9B,$D6,$6E,$12,$EA,$52,$58,$B8,$87,$CE,
$09,$09,$86,$0A,$C6,$1A,$64,$3F,$0D,$45,$60,$FA,$A7,$A6,$C6,$C9,$97,$77,$91,$14,
$DE,$C5,$CA,$36,$D8,$6E,$46,$A6,$39,$F5,$B8,$F6,$CF,$DE,$DF,$BD,$8E,$94,$E0,$B6,
$48,$B4,$BA,$8F,$70,$E4,$10,$4C,$50,$55,$6D,$EF,$FA,$B3,$8B,$05,$DA,$ED,$A6,$F5,
$B5,$B7,$EF,$D4,$15,$80,$09,$15,$F5,$3C,$1E,$EB,$AA,$44,$10,$BE,$B1,$89,$6E,$9C,
$DD,$8F,$88,$02,$B2,$9D,$8D,$E6,$6E,$BA,$BF,$0D,$75,$C8,$72,$0F,$DD,$09,$8E,$B9,
$73,$23,$AA,$32,$AE,$BF,$2B,$74,$20,$61,$A7,$2C,$68,$46,$A4,$B9,$AA,$67,$21,$11,
$68,$56,$25,$33,$5A,$A3,$D5,$27,$74,$F4,$F5,$80,$FE,$1C,$75,$45,$C3,$3D,$32,$77,
$C2,$2D,$59,$ED,$B2,$17,$09,$5D,$FD,$1D,$EC,$32,$4E,$FC,$DC,$CB,$B0,$E2,$AC,$5A,
$8B,$31,$F7,$33,$4C,$8B,$B6,$22,$52,$B0,$01,$3B,$F7,$30,$37,$BC,$12,$2D,$DE,$CD,
$BA,$AA,$88,$6B,$83,$21,$21,$60,$B2,$7B,$08,$A1,$49,$87,$F6,$30,$17,$BD,$EA,$86,
$2F,$93,$D8,$18,$59,$E6,$B1,$E6,$AB,$C4,$78,$D7,$DD,$54,$C3,$7A,$25,$25,$10,$8A,
$A1,$E7,$2B,$1B,$82,$1A,$A1,$20,$04,$27,$EB,$71,$E4,$63,$50,$7D,$8A,$30,$0D,$0A,
$42,$42,$FC,$3B,$95,$15,$3D,$40,$84,$18,$8D,$42,$C1,$3B,$56,$3B,$4E,$04,$85,$56,
$7A,$8A,$43,$CA,$A8,$E0,$D5,$17,$B0,$30,$B2,$34,$B9,$7F,$69,$97,$2A,$37,$A0,$05,
$EC,$55,$77,$C9,$7B,$7E,$B8,$AB,$4A,$9E,$93,$BF,$38,$AE,$F0,$89,$22,$15,$8D,$4C,
$04,$E6,$37,$89,$5A,$46,$07,$2B,$88,$86,$A4,$BC,$73,$87,$56,$37,$5C,$29,$E6,$AB,
$0D,$02,$DC,$27,$F0,$AA,$3D,$5C,$AC,$66,$10,$0D,$86,$8E,$E7,$BE,$4E,$24,$9D,$A7,
$6C,$D1,$A1,$93,$4F,$F1,$F9,$8C,$E9,$D9,$06,$FE,$3F,$B5,$02,$75,$11,$82,$60,$CB,
$91,$4C,$AE,$4C,$10,$5A,$77,$1D,$EC,$F5,$24,$FC,$12,$CD,$E6,$76,$D1,$D4,$3C,$95,
$EA,$0A,$22,$83,$4A,$B5,$FB,$08,$C2,$2E,$D7,$26,$2B,$41,$2F,$DC,$5D,$ED,$7F,$69,
$16,$C9,$9C,$2B,$77,$13,$83,$9F,$2E,$B1,$E9,$9A,$9A,$75,$C0,$B0,$0F,$73,$90,$0D,
$67,$CA,$FF,$5D,$7B,$BE,$70,$E8,$2A,$22,$FE,$D8,$9D,$20,$C8,$3F,$7C,$E0,$1F,$4B,
$26,$26,$1F,$0A,$44,$5D,$29,$18,$A8,$BA,$C8,$D1,$F9,$E4,$0A,$C2,$F3,$40,$70,$05,
$C0,$81,$79,$8B,$04,$96,$EE,$A3,$16,$DE,$A9,$BC,$21,$32,$52,$6C,$EC,$A7,$C6,$BB,
$27,$C2,$8E,$8C,$5D,$AB,$3E,$5B,$3A,$D8,$C7,$A3,$01,$D0,$95,$BA,$DF,$95,$A4,$7D,
$CA,$A1,$40,$7D,$9D,$45,$E3,$BA,$8B,$17,$B1,$0C,$25,$BB,$AA,$86,$3F,$E0,$0B,$EC,
$4D,$06,$56,$68,$14,$82,$8A,$C5,$F6,$2F,$AB,$96,$A4,$82,$65,$62,$77,$5F,$7D,$50,
$11,$46,$71,$64,$59,$13,$90,$24,$C4,$50,$2E,$23,$44,$7A,$10,$57,$7D,$3A,$D5,$76,
$21,$80,$D5,$88,$EB,$32,$46,$15,$9B,$57,$61,$DD,$D9,$8B,$21,$72,$63,$61,$70,$33,
$F1,$A1,$8A,$62,$B5,$0B,$D3,$FD,$BB,$D0,$D6,$BF,$A5,$FB,$7E,$A6,$AC,$89,$F3,$7D,
$FB,$AC,$D3,$08,$28,$A6,$A7,$7D,$47,$74,$14,$99,$ED,$A7,$F8,$6E,$CE,$62,$16,$F6,
$1C,$DF,$AF,$BA,$0E,$29,$82,$5A,$E3,$F7,$C0,$B4,$17,$83,$AA,$C1,$3D,$8F,$3A,$4E,
$95,$65,$25,$B0,$B9,$A3,$55,$77,$56,$55,$9C,$91,$CA,$E8,$52,$F2,$E6,$57,$C5,$CF,
$A2,$0F,$AD,$84,$61,$42,$FA,$AA,$48,$04,$F0,$2A,$9A,$A4,$EC,$AB,$BC,$4B,$4B,$A1,
$93,$1F,$9A,$18,$7E,$2C,$94,$18,$93,$C7,$04,$AF,$5D,$BA,$97,$62,$60,$1C,$DD,$A9,
$DB,$B2,$E8,$C6,$1A,$35,$16,$09,$4E,$18,$4D,$27,$70,$56,$EB,$27,$6A,$A9,$A0,$32,
$EE,$82,$22,$1E,$91,$4F,$D7,$CE,$5D,$DA,$9E,$A6,$1F,$18,$8A,$E3,$4B,$EA,$47,$5C,
$56,$26,$77,$27,$50,$54,$B8,$F6,$C1,$14,$79,$3C,$82,$B0,$20,$9D,$23,$E8,$4C,$34,
$CB,$AF,$67,$E4,$75,$4E,$FF,$AA,$77,$88,$E0,$E3,$57,$35,$78,$26,$AB,$AB,$A0,$CC,
$1D,$E1,$6A,$2F,$F9,$BE,$FC,$E8,$2B,$1C,$30,$38,$D5,$F7,$8D,$EB,$8B,$31,$0A,$D2,
$9B,$FF,$80,$4B,$74,$99,$A2,$BA,$58,$A2,$DF,$C0,$C8,$C5,$23,$AB,$26,$F1,$B1,$F2,
$91,$07,$B7,$48,$F5,$56,$55,$45,$81,$C9,$A0,$C0,$55,$95,$87,$4A,$DB,$0C,$F4,$18,
$91,$9C,$FD,$CF,$D4,$AF,$AB,$00,$94,$7C,$37,$91,$1A,$68,$60,$D1,$4E,$7D,$51,$0A,
$55,$DB,$FD,$AF,$D2,$FE,$2D,$50,$AF,$EA,$0A,$96,$01,$6B,$A8,$CE,$4C,$A2,$30,$14,
$BE,$DA,$F4,$CA,$C6,$8B,$B0,$9A,$FC,$79,$D3,$17,$23,$D7,$3F,$F3,$B0,$61,$C5,$76,
$FB,$5F,$C5,$19,$FC,$43,$F0,$DA,$18,$42,$2C,$7B,$32,$A2,$9B,$77,$76,$3E,$53,$14,
$67,$E8,$30,$76,$E3,$F7,$BB,$CC,$74,$8C,$25,$14,$8C,$EE,$07,$36,$D9,$F0,$5F,$25,
$FD,$B2,$88,$BE,$C1,$95,$D5,$54,$CC,$C3,$E3,$EA,$31,$C7,$5C,$E9,$9C,$68,$F2,$D5,
$EA,$7A,$3D,$CB,$5F,$4E,$E1,$00,$25,$46,$2B,$96,$AF,$CA,$1A,$B7,$B8,$E5,$2E,$10,
$2B,$11,$EC,$1A,$C2,$50,$21,$05,$BE,$64,$ED,$DA,$DC,$55,$A8,$A6,$1B,$3B,$CB,$9E,
$F5,$7A,$F5,$BB,$AB,$6D,$51,$8D,$D6,$06,$49,$B3,$60,$87,$0A,$15,$A1,$68,$8B,$27,
$57,$92,$AD,$49,$3F,$85,$BB,$13,$93,$72,$91,$03,$EF,$D5,$CA,$3B,$B0,$24,$AE,$1A,
$83,$AA,$02,$B5,$CE,$6B,$66,$21,$2A,$0A,$EA,$78,$1A,$A2,$99,$2F,$F2,$48,$C8,$57,
$0C,$A2,$CB,$CF,$F1,$3C,$00,$53,$BF,$08,$5D,$DA,$DD,$07,$9F,$12,$B1,$17,$C0,$24,
$27,$84,$E2,$01,$B3,$EF,$F6,$E1,$B7,$23,$5E,$FA,$8E,$61,$44,$2A,$05,$EB,$17,$E4,
$35,$E0,$48,$77,$10,$48,$03,$0C,$3E,$CC,$50,$8D,$EB,$26,$DC,$AD,$3D,$C2,$AA,$AE,
$08,$89,$CA,$47,$B9,$C6,$27,$D0,$F5,$35,$09,$FD,$23,$A0,$BF,$3C,$0B,$FB,$81,$38,
$BF,$12,$78,$DA,$CE,$50,$DF,$45,$E7,$5C,$2F,$4C,$58,$B7,$D4,$8F,$F9,$01,$46,$A1,
$5A,$6E,$F3,$D2,$02,$45,$21,$97,$EF,$0C,$A3,$75,$B3,$67,$83,$75,$79,$B8,$4B,$FE,
$DA,$05,$D1,$9E,$B5,$22,$92,$B1,$44,$03,$21,$4A,$EE,$EA,$82,$04,$27,$73,$50,$D5,
$55,$22,$17,$5C,$50,$44,$EA,$24,$4E,$CB,$78,$0D,$F8,$F5,$05,$15,$A4,$F9,$2B,$46,
$EB,$89,$46,$AE,$FC,$E9,$CC,$D0,$70,$37,$10,$2D,$50,$F2,$EF,$CA,$B2,$FB,$FD,$33,
$06,$B3,$CE,$81,$33,$54,$0C,$A4,$41,$A2,$6B,$F9,$17,$B5,$90,$24,$44,$C5,$95,$2B,
$A3,$20,$C9,$B8,$C5,$3A,$83,$CC,$90,$5D,$1B,$BD,$2B,$25,$63,$8F,$DA,$BB,$5F,$35,
$10,$DB,$B9,$A4,$4B,$27,$A9,$52,$9C,$CB,$6C,$D8,$57,$8B,$23,$E5,$BE,$1C,$B7,$E8,
$61,$8E,$19,$E9,$C2,$2E,$D5,$11,$BA,$E7,$55,$C4,$9F,$FF,$8E,$F9,$CC,$4E,$A3,$DF,
$76,$65,$C7,$69,$7B,$31,$06,$CB,$7D,$55,$6A,$72,$82,$11,$8D,$DD,$B6,$F7,$5A,$C5,
$A9,$C4,$77,$B5,$F1,$66,$7D,$B7,$7A,$5D,$1A,$BF,$C2,$9C,$F7,$FA,$5F,$E5,$E1,$10,
$71,$60,$51,$27,$3B,$41,$06,$19,$64,$CF,$DB,$AB,$CF,$E9,$8F,$90,$A7,$B7,$CC,$29,
$B3,$AF,$12,$A9,$F2,$66,$34,$89,$51,$BF,$DB,$96,$AB,$AE,$98,$C0,$94,$67,$53,$21,
$3A,$EC,$61,$75,$DB,$B0,$04,$3F,$EB,$75,$A4,$CA,$C7,$45,$B0,$9A,$5B,$E0,$C0,$BA,
$BA,$6A,$B1,$9A,$E6,$35,$7A,$1C,$4C,$86,$AC,$64,$08,$B2,$EA,$1C,$AA,$FB,$4C,$FC,
$C0,$77,$D5,$3B,$BC,$1D,$F0,$EA,$5A,$21,$82,$89,$62,$89,$89,$A6,$71,$75,$75,$98,
$6B,$C5,$7E,$75,$81,$07,$1B,$D0,$AA,$F3,$FF,$3E,$B8,$78,$F0,$7D,$25,$95,$98,$4C,
$B1,$43,$3B,$26,$13,$51,$FE,$AB,$57,$50,$30,$16,$20,$76,$03,$6A,$08,$52,$57,$F3,
$60,$47,$99,$84,$B7,$11,$4A,$06,$77,$63,$D0,$28,$17,$75,$15,$DF,$79,$37,$6F,$9A,
$CB,$FF,$1D,$2E,$E6,$39,$19,$71,$A3,$C4,$B0,$07,$F8,$49,$7D,$C4,$FC,$75,$2B,$6F,
$FC,$35,$DD,$1A,$3D,$BF,$27,$70,$17,$A7,$B3,$77,$BB,$4A,$E4,$52,$BD,$A7,$55,$21,
$A2,$DE,$59,$72,$60,$81,$18,$FD,$9C,$1C,$57,$E8,$F9,$20,$85,$3D,$F7,$E7,$99,$D0,
$44,$A1,$EB,$5A,$6C,$9D,$62,$ED,$BA,$4C,$21,$50,$62,$16,$F9,$A5,$EB,$DA,$92,$05,
$1F,$ED,$BD,$5F,$BE,$FB,$C2,$DE,$A7,$72,$E5,$5D,$F9,$EA,$96,$85,$1D,$83,$66,$30,
$55,$D8,$5C,$60,$00,$C9,$4E,$DF,$2D,$6F,$0A,$99,$F3,$FF,$30,$1E,$84,$8A,$51,$67,
$55,$0E,$C1,$5A,$0D,$13,$2B,$EE,$1A,$FF,$CD,$91,$E2,$31,$2B,$C2,$BA,$1B,$85,$49,
$89,$89,$85,$41,$4F,$70,$60,$89,$FB,$0D,$98,$9A,$EB,$12,$E1,$54,$EA,$67,$85,$15,
$12,$E0,$AB,$D2,$2D,$92,$11,$EB,$35,$9D,$73,$0D,$31,$43,$52,$B4,$85,$3A,$DB,$F5,
$98,$5A,$76,$87,$25,$82,$44,$A8,$67,$11,$53,$0D,$90,$AA,$C3,$9B,$D8,$30,$61,$AE,
$4F,$24,$AB,$A0,$A0,$AF,$3A,$60,$F2,$D7,$23,$F1,$AA,$52,$06,$F7,$D2,$EF,$7D,$68,
$DE,$77,$15,$F2,$AA,$9A,$F4,$76,$97,$B5,$95,$45,$94,$E7,$86,$FA,$10,$F3,$3E,$78,
$2D,$17,$AB,$06,$39,$1B,$77,$4A,$35,$3D,$2A,$8F,$50,$8F,$73,$FD,$BF,$82,$02,$30,
$00,$48,$A8,$DE,$29,$55,$D9,$0C,$56,$E8,$20,$01,$85,$59,$61,$67,$E0,$CF,$15,$94,
$D0,$D0,$22,$08,$23,$53,$D6,$E6,$E7,$73,$5D,$CC,$FB,$A2,$7E,$53,$26,$D8,$55,$46,
$5D,$5E,$D9,$D8,$57,$ED,$2E,$FD,$F8,$85,$EB,$87,$46,$2C,$43,$77,$B5,$76,$35,$AC,
$CE,$C8,$17,$BA,$35,$58,$19,$E5,$5C,$E7,$F9,$FD,$A3,$6B,$AF,$DE,$E3,$B1,$4D,$15,
$C8,$4B,$BC,$A1,$52,$5D,$17,$C5,$BD,$2E,$1E,$1E,$A8,$D4,$F0,$BE,$0A,$4D,$BD,$61,
$E0,$10,$5E,$B2,$3A,$87,$FA,$C1,$FF,$0B,$AB,$77,$F9,$AF,$C8,$B7,$65,$E7,$C8,$9B,
$56,$76,$54,$73,$37,$DD,$9F,$74,$62,$90,$06,$7F,$05,$7C,$84,$98,$7D,$0B,$20,$88,
$89,$9B,$AD,$31,$D2,$12,$B8,$F2,$64,$05,$01,$BF,$5E,$1B,$BB,$19,$81,$B6,$09,$C8,
$E0,$62,$E6,$57,$60,$A9,$26,$24,$39,$A1,$C2,$34,$7C,$87,$DA,$87,$6D,$C0,$3F,$0C,
$3A,$00,$80,$DD,$1E,$FD,$09,$93,$FA,$0A,$7D,$14,$3A,$B0,$87,$BB,$E3,$DE,$DC,$E6,
$AB,$F6,$5D,$92,$F5,$D1,$EC,$12,$2B,$F9,$14,$EE,$2C,$6A,$9D,$FF,$D8,$DE,$D7,$69,
$E7,$F8,$26,$67,$82,$83,$A5,$FB,$FC,$57,$25,$C5,$32,$28,$34,$FB,$BD,$A0,$6B,$CF,
$7F,$75,$84,$7B,$10,$A4,$B6,$B9,$EB,$7B,$37,$C3,$93,$FB,$F3,$EF,$F4,$5E,$20,$86,
$94,$63,$A0,$98,$63,$04,$2C,$17,$1B,$67,$24,$AB,$4B,$2B,$53,$1C,$00,$77,$BD,$35,
$54,$E6,$D9,$2E,$03,$7F,$52,$66,$6F,$50,$35,$49,$EA,$4A,$18,$21,$46,$7F,$F2,$F9,
$7B,$46,$4C,$0C,$F5,$64,$26,$B4,$D0,$13,$7C,$B0,$1D,$E0,$AB,$16,$66,$24,$6C,$FB,
$3E,$D2,$EF,$73,$E8,$9B,$53,$FC,$A5,$A5,$F7,$BF,$2F,$8A,$73,$3D,$93,$E1,$65,$65,
$95,$CB,$9E,$B3,$74,$44,$98,$72,$B3,$C7,$EB,$5F,$91,$97,$0C,$78,$A0,$23,$06,$97,
$DC,$25,$A3,$00,$31,$C6,$1E,$7E,$FD,$17,$D6,$6F,$23,$4F,$B0,$EC,$86,$A3,$81,$E2,
$B3,$BA,$04,$BE,$95,$B0,$D5,$38,$12,$92,$CE,$7F,$77,$65,$D7,$E1,$55,$15,$92,$24,
$A9,$02,$29,$6A,$D7,$60,$47,$69,$54,$49,$AD,$56,$2D,$55,$4D,$EA,$16,$45,$49,$52,
$05,$C6,$26,$30,$41,$62,$7F,$27,$95,$60,$20,$08,$D4,$30,$61,$54,$79,$0E,$B9,$EF,
$FB,$C6,$7F,$81,$28,$52,$2C,$D6,$39,$BD,$78,$7D,$06,$52,$B1,$48,$0C,$AC,$71,$0A,
$80,$AD,$02,$93,$7F,$10,$AE,$C0,$CF,$17,$4A,$95,$10,$F6,$B0,$93,$EE,$14,$0B,$57,
$CC,$C5,$46,$2A,$32,$68,$77,$4C,$E9,$00,$3A,$A7,$86,$FA,$CB,$F9,$EA,$A2,$25,$DF,
$9D,$AC,$A3,$F6,$BB,$CC,$CF,$96,$D3,$D4,$69,$29,$DA,$01,$05,$6F,$C4,$CD,$9D,$74,
$DC,$CE,$77,$1E,$F7,$18,$40,$DD,$C5,$52,$ED,$C2,$84,$58,$C6,$BA,$7F,$85,$97,$D3,
$ED,$C6,$02,$F4,$8F,$1D,$70,$D2,$75,$BB,$D8,$18,$B8,$51,$9E,$2C,$FA,$34,$2C,$A3,
$9B,$5A,$B6,$B5,$BD,$3E,$D6,$0A,$98,$2E,$01,$BD,$BD,$BA,$55,$A3,$2B,$C7,$D2,$3C,
$4A,$36,$93,$6E,$CB,$22,$25,$5D,$E0,$60,$D5,$55,$49,$41,$C7,$60,$D0,$AF,$03,$4D,
$D9,$53,$2B,$38,$97,$B1,$2B,$0F,$E5,$11,$50,$D4,$53,$F8,$99,$7E,$54,$17,$BB,$A6,
$92,$32,$6A,$24,$4F,$F3,$C8,$7E,$F7,$25,$40,$E9,$59,$C2,$93,$4F,$7D,$06,$C4,$B3,
$34,$3D,$2F,$26,$7A,$E9,$42,$4C,$80,$DD,$CE,$34,$31,$04,$82,$69,$90,$AF,$15,$BD,
$E3,$07,$B5,$B5,$EC,$EA,$6E,$D4,$00,$40,$DD,$26,$AD,$45,$93,$0B,$4A,$03,$87,$24,
$61,$07,$3D,$57,$B0,$7F,$35,$C1,$4F,$D2,$49,$46,$95,$7B,$A8,$84,$D3,$D2,$69,$96,
$B6,$2D,$F4,$A1,$67,$DA,$21,$FE,$32,$81,$23,$7D,$48,$0A,$B9,$22,$01,$34,$65,$39,
$7D,$51,$00,$9D,$30,$5D,$25,$40,$3C,$B5,$78,$B7,$BD,$42,$B5,$F6,$6D,$C3,$1C,$FC,
$AF,$22,$3A,$02,$93,$AB,$3E,$35,$24,$A7,$69,$64,$66,$1F,$89,$37,$FE,$4A,$04,$DD,
$D8,$5E,$F7,$3F,$AB,$28,$48,$55,$E4,$59,$D8,$71,$59,$E7,$17,$EE,$15,$E7,$88,$52,
$FB,$0C,$82,$CF,$88,$D9,$E9,$5F,$37,$C5,$9F,$FF,$D6,$77,$CB,$A8,$1A,$CC,$55,$F7,
$A5,$E6,$38,$B9,$7B,$0D,$F0,$74,$18,$33,$F9,$3A,$81,$D4,$B5,$6D,$AF,$FE,$EE,$80,
$BA,$30,$0B,$A9,$66,$FB,$07,$42,$75,$85,$A5,$4A,$F5,$0B,$4D,$25,$85,$BE,$04,$F1,
$10,$85,$9F,$2D,$6B,$A1,$40,$A0,$EB,$44,$88,$0C,$AB,$36,$54,$17,$89,$D9,$20,$86,
$12,$81,$D5,$3E,$AC,$B9,$14,$33,$F4,$34,$67,$5D,$EE,$64,$E2,$8E,$B5,$5F,$77,$40,
$B0,$53,$C2,$D5,$98,$7A,$E6,$9F,$7F,$72,$F5,$DF,$AE,$FE,$3A,$50,$F2,$B2,$21,$1E,
$77,$F4,$90,$15,$C1,$8F,$0F,$E3,$26,$61,$BC,$2F,$83,$A6,$68,$8A,$26,$82,$DA,$90,
$B4,$96,$FB,$15,$78,$22,$6B,$01,$91,$6D,$E6,$2D,$B8,$EB,$4F,$04,$64,$25,$46,$D4,
$EC,$46,$F1,$10,$4D,$07,$14,$74,$09,$F9,$10,$0D,$3A,$30,$1B,$AE,$D7,$2B,$5C,$07,
$4C,$08,$34,$1C,$EF,$E1,$46,$3D,$55,$C8,$FD,$30,$0A,$E7,$D7,$0D,$EA,$EB,$16,$23,
$69,$9C,$75,$DD,$43,$07,$3F,$9F,$A1,$4A,$B1,$40,$C9,$D7,$AE,$06,$C5,$8D,$76,$3D,
$19,$E4,$A2,$A7,$C7,$2D,$D9,$B9,$74,$1D,$3F,$EF,$B3,$7A,$BD,$54,$FC,$A6,$52,$C7,
$C0,$C6,$8E,$FF,$EA,$B7,$58,$EF,$D4,$CF,$BC,$38,$0F,$4F,$59,$8D,$64,$90,$41,$62,
$7A,$60,$78,$22,$4D,$06,$31,$5C,$43,$2C,$1D,$5B,$AE,$FE,$A6,$48,$1D,$4D,$42,$8D,
$DC,$5A,$2A,$65,$62,$B4,$C0,$FC,$73,$46,$5D,$F5,$D8,$CC,$C6,$D3,$6C,$FB,$4B,$73,
$8F,$E8,$B4,$9E,$0F,$EB,$5F,$68,$CE,$9D,$AB,$50,$EB,$42,$D7,$86,$09,$99,$0C,$E7,
$93,$F1,$1C,$C3,$CE,$A8,$41,$D6,$31,$35,$0F,$72,$DC,$AE,$53,$4F,$6E,$D8,$A4,$0D,
$48,$D7,$7F,$B6,$13,$43,$4E,$AA,$9B,$47,$EA,$21,$42,$F8,$83,$42,$17,$DE,$39,$D0,
$9C,$16,$BF,$7E,$17,$F5,$56,$F4,$57,$19,$3E,$3A,$B5,$AB,$60,$16,$27,$0F,$7D,$77,
$7A,$BB,$88,$81,$49,$58,$C2,$23,$05,$33,$D4,$AD,$2C,$AA,$4E,$55,$18,$40,$11,$8F,
$49,$FD,$EF,$42,$43,$7E,$86,$5D,$6D,$96,$FB,$3A,$CA,$77,$F6,$17,$8B,$E4,$DC,$92,
$95,$8A,$21,$E2,$55,$EF,$96,$BD,$2B,$28,$D9,$00,$C5,$22,$89,$D4,$F8,$00,$FC,$F7,
$06,$01,$9F,$35,$07,$DA,$C5,$B3,$98,$21,$0A,$61,$5F,$08,$CF,$55,$F7,$40,$49,$E0,
$47,$DF,$D3,$87,$0B,$36,$F9,$47,$B6,$C3,$41,$F5,$5D,$A1,$06,$AE,$9E,$3A,$FB,$B7,
$25,$26,$F2,$AE,$B9,$EE,$61,$2C,$5F,$C5,$A6,$0E,$0A,$E6,$96,$A0,$53,$33,$6B,$3C,
$13,$A3,$BB,$2F,$32,$3B,$9F,$78,$85,$A0,$F0,$AC,$4C,$52,$56,$C6,$1A,$7D,$84,$4D,
$E1,$1A,$57,$13,$81,$23,$8E,$28,$9A,$DA,$05,$1C,$88,$BC,$FA,$76,$CE,$8C,$48,$3E,
$FA,$50,$AE,$2E,$65,$FD,$1D,$E0,$BB,$65,$C4,$AF,$92,$0A,$69,$C3,$CB,$6B,$5D,$31,
$CF,$63,$49,$FE,$4D,$CE,$CB,$7E,$BE,$6A,$26,$EE,$83,$5A,$ED,$9F,$54,$A8,$65,$3E,
$0E,$46,$88,$B8,$24,$5C,$C2,$80,$74,$6D,$FB,$7E,$DD,$FC,$BB,$90,$D9,$61,$A6,$B1,
$8B,$21,$01,$D7,$3A,$F0,$BA,$36,$9D,$DD,$13,$F0,$BE,$35,$07,$73,$BE,$FD,$88,$41,
$D7,$55,$2B,$34,$5C,$30,$A5,$9F,$5D,$33,$73,$CA,$D7,$82,$FD,$6D,$4C,$BF,$AE,$D2,
$A7,$5D,$CF,$6D,$EE,$0F,$1D,$E9,$47,$CC,$B8,$E6,$68,$B9,$E3,$84,$1D,$E0,$AF,$80,
$35,$46,$D1,$77,$E2,$17,$CD,$DF,$2C,$F9,$12,$1A,$E5,$8C,$72,$86,$5F,$AD,$D7,$BE,
$82,$05,$F5,$A1,$BA,$F6,$E5,$14,$BB,$B0,$60,$1C,$27,$B1,$B5,$60,$CC,$E3,$93,$5D,
$40,$A5,$5F,$0C,$34,$63,$2F,$A2,$4D,$09,$CB,$63,$AA,$82,$7B,$28,$C7,$73,$57,$2D,
$6C,$C8,$FF,$FD,$C6,$D0,$D4,$66,$B3,$88,$3C,$30,$7D,$F9,$B8,$04,$B9,$F7,$DD,$89,
$0C,$64,$06,$44,$E5,$CC,$62,$49,$09,$9C,$23,$62,$06,$A7,$C4,$15,$30,$69,$5A,$12,
$C3,$03,$06,$89,$CF,$03,$00,$D2,$B1,$44,$F8,$ED,$06,$79,$30,$80,$B8,$F5,$F6,$62,
$96,$EF,$E0,$0E,$83,$22,$09,$E2,$26,$0C,$20,$B4,$B8,$92,$55,$15,$15,$5A,$B2,$65,
$F5,$B7,$7C,$42,$5D,$42,$9A,$9F,$F5,$62,$92,$82,$AD,$E5,$C2,$43,$EA,$55,$2F,$B1,
$B8,$B7,$C4,$45,$87,$79,$48,$8E,$01,$CC,$1A,$64,$E7,$75,$4D,$54,$AF,$AD,$FD,$A9,
$6C,$5D,$EF,$61,$FD,$55,$C5,$5A,$0F,$84,$B3,$BF,$44,$40,$77,$2E,$97,$EF,$FC,$5B,
$45,$86,$51,$99,$77,$EA,$E5,$D3,$82,$41,$A9,$61,$D2,$D1,$29,$D3,$3E,$12,$A5,$F0,
$0B,$91,$C1,$4F,$05,$93,$87,$2C,$D6,$9E,$EF,$58,$D4,$DD,$49,$DE,$75,$EE,$80,$FF,
$12,$D3,$6D,$0D,$DF,$69,$90,$6B,$E5,$C6,$78,$3D,$0C,$1A,$39,$4E,$14,$E1,$4E,$DF,
$FD,$5D,$12,$50,$15,$64,$70,$3E,$E2,$F0,$97,$E8,$B4,$B2,$AB,$C4,$1B,$24,$81,$D1,
$00,$C1,$73,$5C,$AF,$E8,$30,$DD,$E7,$90,$E8,$A3,$62,$22,$4B,$77,$DA,$30,$97,$E5,
$A9,$29,$53,$00,$19,$47,$58,$DC,$7F,$4F,$6E,$37,$A0,$55,$A9,$A5,$1E,$07,$BF,$07,
$76,$F0,$6E,$37,$4F,$EE,$6A,$A9,$01,$2B,$22,$0B,$DD,$B0,$28,$DC,$A8,$85,$B5,$88,
$BE,$3C,$F1,$C5,$B3,$6E,$85,$A9,$C2,$DA,$65,$D8,$D6,$EB,$08,$5A,$AE,$F9,$76,$FF,
$DC,$F9,$02,$E9,$0A,$40,$EF,$32,$E2,$A9,$E6,$39,$90,$75,$C1,$AD,$C8,$FF,$9F,$AF,
$B4,$3E,$05,$49,$4A,$7E,$79,$88,$20,$A7,$5F,$58,$F9,$5E,$A5,$EA,$44,$27,$8F,$28,
$DF,$21,$56,$D2,$73,$10,$0A,$1B,$26,$06,$35,$E0,$E2,$A1,$51,$E5,$60,$C3,$E6,$D7,
$8C,$73,$BC,$83,$2C,$A2,$F8,$A0,$9D,$BB,$BA,$68,$8A,$FA,$E2,$FE,$0A,$4C,$28,$6F,
$BB,$81,$01,$A1,$15,$E1,$28,$E2,$24,$85,$C5,$17,$CE,$45,$C3,$57,$F1,$33,$34,$6A,
$2E,$A1,$D6,$A5,$0F,$0A,$A8,$50,$A9,$6A,$31,$5F,$D7,$BF,$1C,$94,$05,$F1,$6D,$6E,
$49,$11,$BF,$26,$FF,$3A,$84,$05,$24,$B6,$CE,$5C,$3F,$D6,$BE,$F0,$DF,$72,$35,$89,
$41,$7E,$54,$0C,$53,$3B,$9D,$14,$11,$6F,$56,$AA,$A3,$A0,$F3,$C3,$F9,$02,$ED,$B8,
$C8,$85,$D9,$8D,$C8,$28,$94,$98,$E8,$97,$C8,$33,$3B,$85,$16,$9E,$EF,$89,$29,$D9,
$6E,$EB,$EE,$F6,$EB,$5F,$A2,$C3,$22,$BE,$41,$8D,$F2,$A7,$29,$99,$E1,$06,$D5,$23,
$39,$36,$44,$01,$8B,$EA,$83,$FA,$B3,$8E,$57,$D4,$0F,$8F,$0B,$73,$9A,$1B,$ED,$BC,
$23,$03,$61,$77,$9D,$C3,$57,$6C,$11,$96,$BA,$FF,$0D,$04,$F3,$DF,$FE,$FB,$90,$90,
$71,$66,$49,$B2,$AD,$E1,$D2,$B2,$02,$64,$D9,$D1,$21,$AD,$8E,$9D,$5C,$B7,$49,$C3,
$64,$8A,$00,$A5,$DC,$18,$B1,$44,$40,$65,$B1,$77,$6F,$04,$51,$8D,$79,$CB,$2E,$41,
$C1,$C6,$55,$FD,$F0,$F3,$97,$AB,$4A,$D9,$5F,$68,$77,$14,$E4,$57,$F5,$FB,$40,$D4,
$77,$BC,$AF,$DF,$61,$9F,$1D,$DA,$EB,$9E,$90,$C3,$31,$A5,$14,$9B,$F2,$A5,$9E,$C0,
$73,$9A,$85,$E3,$B1,$EB,$20,$30,$34,$57,$86,$05,$4E,$A6,$A4,$D4,$3C,$02,$57,$6B,
$E6,$5B,$CC,$AE,$03,$A9,$C2,$2A,$B0,$58,$8E,$9D,$E8,$1D,$EE,$92,$5E,$A0,$D7,$A3,
$52,$28,$22,$1E,$02,$68,$74,$EE,$0E,$6E,$8B,$D4,$4D,$0A,$7F,$25,$C2,$82,$E5,$3C,
$7C,$86,$80,$90,$6C,$92,$4D,$89,$9E,$08,$E4,$0D,$F5,$59,$D4,$BA,$51,$DC,$EA,$2B,
$86,$7B,$B9,$9E,$85,$7D,$ED,$D0,$88,$02,$DF,$10,$59,$C3,$A8,$76,$34,$16,$7A,$E3,
$90,$35,$13,$5D,$1D,$B1,$D8,$DB,$2C,$0C,$BA,$19,$64,$97,$52,$3D,$22,$CE,$05,$FC,
$15,$B9,$CA,$FD,$D4,$E6,$04,$31,$17,$F2,$E7,$94,$41,$7A,$9D,$23,$D8,$9A,$EC,$1E,
$24,$71,$20,$CE,$33,$05,$49,$73,$5D,$6C,$0D,$CB,$21,$D8,$6B,$44,$C7,$33,$C9,$28,
$BD,$2B,$EA,$4A,$7A,$D3,$6A,$1E,$AF,$93,$6E,$2A,$66,$A8,$89,$AA,$4D,$84,$C1,$8A,
$61,$DA,$8D,$50,$54,$30,$28,$39,$D7,$D4,$1C,$83,$03,$37,$84,$53,$DF,$FD,$27,$C9,
$30,$00,$76,$C0,$4D,$01,$33,$D4,$60,$DB,$54,$60,$DE,$F7,$79,$F3,$A7,$15,$01,$A6,
$ED,$BB,$29,$B3,$FA,$1F,$30,$58,$F5,$14,$55,$A3,$F8,$FF,$90,$92,$47,$DE,$EA,$02,
$26,$16,$07,$A8,$AC,$A1,$E1,$76,$9E,$BA,$3F,$FC,$F9,$AE,$17,$AF,$62,$0D,$B1,$6E,
$CD,$0D,$51,$15,$78,$B2,$96,$F5,$85,$E6,$C4,$A8,$AB,$A7,$01,$3F,$15,$CF,$5D,$2C,
$9C,$7C,$3A,$2C,$62,$F6,$D1,$E2,$68,$13,$8D,$F1,$57,$A3,$48,$13,$44,$53,$26,$7C,
$C3,$B7,$04,$DF,$37,$36,$9F,$76,$AB,$EB,$E0,$25,$00,$3D,$98,$31,$D0,$D2,$34,$41,
$2D,$08,$32,$D2,$ED,$7B,$03,$E3,$CA,$C0,$DC,$42,$0C,$F5,$BF,$CA,$4F,$22,$D6,$83,
$FF,$ED,$2B,$AE,$60,$D2,$2A,$EF,$DB,$AA,$85,$32,$75,$A8,$2C,$0B,$EC,$B8,$33,$54,
$2B,$BE,$8A,$31,$65,$26,$07,$E4,$A9,$87,$D7,$17,$12,$AE,$EE,$55,$95,$E5,$75,$B0,
$CA,$FA,$9E,$E7,$C1,$64,$7D,$69,$44,$9A,$7D,$61,$A8,$39,$35,$C2,$55,$1D,$F0,$63,
$6F,$D4,$FD,$E9,$8A,$41,$E6,$A2,$94,$9F,$D8,$D5,$BB,$DD,$23,$F6,$3E,$2F,$92,$4A,
$41,$44,$4E,$13,$D0,$48,$76,$E4,$B6,$FA,$01,$C4,$57,$F1,$55,$1A,$7B,$55,$2D,$E7,
$BE,$E5,$FA,$DA,$92,$01,$76,$70,$89,$84,$72,$54,$33,$5F,$1F,$77,$D6,$F8,$EA,$88,
$72,$1B,$1D,$46,$2B,$4F,$FD,$4B,$17,$5F,$77,$6D,$17,$67,$01,$69,$69,$D5,$DE,$1F,
$5F,$94,$67,$19,$F6,$DE,$25,$D0,$80,$52,$A8,$55,$68,$D4,$21,$57,$3E,$50,$D7,$07,
$2D,$42,$2D,$CD,$D1,$B6,$2F,$FD,$15,$5F,$CF,$E4,$45,$6F,$63,$B1,$00,$17,$EF,$FA,
$10,$FA,$34,$E3,$A8,$3B,$53,$51,$18,$A6,$1E,$BE,$FF,$F7,$82,$DB,$AB,$7F,$11,$5F,
$84,$61,$D6,$87,$ED,$A1,$EA,$77,$41,$F5,$4C,$06,$7D,$67,$C3,$FE,$89,$C2,$FF,$A3,
$CB,$1A,$7D,$41,$1B,$82,$E7,$9B,$36,$31,$30,$40,$8F,$5E,$C6,$3E,$B2,$AC,$5B,$2C,
$9A,$08,$90,$AC,$B6,$FE,$E6,$E1,$D5,$16,$E2,$EA,$AD,$08,$FA,$55,$8B,$3D,$0C,$BF,
$AB,$E5,$C1,$10,$E0,$4A,$B9,$F4,$4A,$82,$FE,$56,$65,$FD,$87,$74,$50,$82,$00,$4B,
$B8,$33,$C2,$7F,$F5,$C5,$47,$FD,$54,$D8,$32,$90,$5E,$1D,$C3,$86,$99,$AB,$66,$7C,
$CD,$75,$3D,$5E,$DF,$BC,$BB,$D4,$E2,$3C,$88,$DC,$2B,$FD,$3B,$D1,$97,$B3,$E7,$78,
$F8,$0B,$69,$06,$1E,$F7,$ED,$74,$5F,$05,$15,$77,$C4,$A4,$6F,$2B,$BD,$70,$2A,$F1,
$61,$94,$0C,$7F,$C1,$9B,$9B,$11,$2F,$66,$9E,$E2,$B3,$6A,$D1,$7A,$EA,$83,$A6,$D4,
$54,$89,$CF,$CE,$A7,$F0,$B7,$7C,$D9,$D7,$29,$DA,$A2,$D7,$45,$C4,$1F,$BB,$11,$02,
$FB,$7A,$91,$0D,$CB,$55,$BA,$0E,$C4,$7B,$5F,$18,$1B,$17,$8B,$91,$27,$3F,$9A,$F1,
$01,$18,$59,$D7,$CF,$43,$D9,$86,$BD,$01,$BE,$C2,$AC,$C0,$C8,$F5,$35,$C7,$9C,$D7,
$57,$5D,$77,$00,$8C,$28,$20,$96,$94,$91,$96,$50,$29,$17,$3C,$51,$8C,$82,$7B,$7F,
$F5,$0B,$F7,$79,$6E,$57,$D0,$88,$04,$57,$B8,$D4,$73,$0E,$55,$9F,$45,$7C,$3B,$A3,
$AE,$F0,$BB,$53,$A9,$19,$CB,$C9,$50,$7D,$55,$13,$7F,$EF,$90,$47,$7D,$FA,$F5,$52,
$E4,$DD,$65,$43,$B1,$F3,$C9,$EB,$E7,$86,$FD,$1D,$9D,$5A,$B1,$C0,$C9,$7B,$C4,$3B,
$9A,$90,$87,$85,$47,$41,$C3,$9D,$B1,$E8,$67,$32,$C1,$B8,$3C,$E2,$B5,$80,$FB,$F5,
$A4,$A9,$53,$D2,$B0,$13,$FE,$0A,$5C,$8A,$BB,$E3,$97,$4A,$9F,$FC,$CD,$32,$A1,$1B,
$EB,$1C,$DD,$95,$E4,$6D,$9E,$E3,$BE,$E4,$C7,$D7,$62,$C5,$FD,$19,$38,$A2,$D6,$E3,
$A5,$F5,$B5,$FD,$76,$62,$1F,$79,$02,$18,$EE,$F4,$F3,$FA,$B9,$FB,$C9,$FD,$63,$78,
$5E,$35,$1C,$FB,$27,$43,$4B,$DE,$92,$A1,$D0,$5A,$84,$60,$82,$99,$FF,$EC,$9F,$C6,
$16,$E3,$66,$94,$24,$C3,$40,$DE,$B0,$F5,$80,$C5,$4D,$64,$7A,$05,$43,$5B,$99,$FD,
$63,$93,$55,$F4,$5B,$C4,$12,$7A,$61,$15,$D3,$96,$4F,$BE,$5A,$35,$D5,$20,$9F,$7D,
$4A,$60,$6A,$90,$42,$55,$8D,$23,$15,$2E,$7B,$18,$B1,$FB,$27,$57,$77,$AD,$CC,$57,
$56,$FE,$73,$C0,$05,$D2,$BE,$F3,$4D,$00,$C1,$FC,$B7,$75,$83,$F0,$AA,$77,$2F,$95,
$2A,$22,$B7,$DC,$AE,$8D,$26,$6E,$BC,$FC,$9D,$F2,$62,$00,$9C,$29,$92,$41,$04,$31,
$CE,$3D,$E6,$B8,$D0,$EF,$5F,$6B,$5F,$42,$1E,$72,$CE,$8D,$17,$30,$E3,$EE,$EB,$D0,
$14,$36,$60,$C2,$89,$34,$A7,$EB,$2C,$AA,$AE,$A9,$FF,$88,$55,$FF,$67,$05,$5D,$64,
$D2,$38,$5F,$81,$2C,$12,$DD,$69,$81,$21,$D3,$9A,$1F,$6C,$2D,$EC,$77,$10,$07,$A3,
$6E,$44,$90,$5D,$90,$30,$98,$C1,$D8,$FD,$67,$1F,$91,$16,$A2,$CA,$60,$58,$6A,$C7,
$40,$A6,$9E,$39,$12,$9E,$C0,$C4,$7E,$2B,$E4,$41,$40,$1C,$6F,$92,$80,$29,$75,$31,
$04,$9B,$6D,$FC,$BF,$3A,$1B,$4F,$E4,$F0,$26,$82,$43,$53,$BC,$38,$02,$F0,$04,$26,
$3A,$0C,$81,$18,$02,$E2,$90,$65,$60,$0F,$1D,$A6,$F0,$B3,$71,$C0,$18,$D0,$5F,$5A,
$A8,$10,$87,$A1,$01,$A3,$1D,$01,$71,$94,$18,$10,$E6,$E1,$7B,$DB,$77,$0C,$D4,$83,
$6B,$C8,$FA,$B6,$13,$03,$C8,$87,$EC,$E7,$4D,$CE,$8E,$C8,$BC,$4F,$BA,$99,$17,$5C,
$C4,$49,$58,$21,$E0,$11,$CD,$A3,$F5,$C2,$83,$C9,$44,$6B,$3A,$D0,$E9,$6F,$D3,$22,
$20,$1A,$1B,$1E,$46,$16,$38,$20,$23,$B7,$B2,$1D,$90,$F1,$E0,$C3,$C6,$8E,$D0,$55,
$E3,$3D,$EE,$75,$B6,$19,$37,$B9,$2E,$68,$A4,$DA,$A0,$8E,$0B,$69,$EC,$56,$DB,$22,
$B8,$BD,$D3,$28,$04,$5A,$EE,$FA,$9D,$02,$10,$9C,$31,$D5,$5B,$91,$24,$D3,$CF,$20,
$19,$2D,$EE,$AA,$12,$84,$DE,$FD,$80,$71,$94,$EA,$DD,$2F,$91,$10,$44,$D2,$DE,$FB,
$D1,$63,$CA,$68,$CF,$DE,$9A,$A6,$89,$34,$61,$C4,$83,$E8,$D1,$CE,$C5,$3C,$B1,$69,
$29,$06,$AB,$C1,$72,$60,$64,$A4,$1F,$9A,$0C,$9A,$60,$49,$84,$66,$B9,$73,$62,$13,
$69,$E3,$7A,$04,$F0,$5F,$70,$A9,$8A,$69,$F4,$1D,$E7,$9A,$2F,$1B,$EF,$77,$50,$13,
$A2,$D6,$FD,$F4,$2F,$B7,$EF,$EA,$CB,$5D,$3B,$4B,$51,$1F,$B6,$BE,$88,$20,$DB,$08,
$4A,$E8,$31,$D3,$61,$1D,$1B,$A3,$12,$E1,$FE,$43,$0E,$84,$32,$2C,$27,$57,$F1,$C7,
$CD,$D4,$6D,$1F,$F5,$D0,$60,$80,$E4,$13,$D9,$1F,$D3,$19,$93,$F4,$21,$D9,$12,$1C,
$BF,$E3,$1C,$A7,$09,$51,$CC,$3E,$3E,$A9,$13,$99,$E0,$CB,$40,$0D,$74,$1A,$B7,$A0,
$97,$3F,$6C,$77,$1D,$7F,$37,$9A,$B9,$3F,$20,$7F,$42,$51,$9E,$86,$26,$7D,$90,$92,
$D3,$96,$AB,$28,$62,$BA,$AA,$50,$41,$75,$FA,$F4,$88,$6E,$43,$8F,$BF,$1B,$E9,$6D,
$0C,$00,$A5,$01,$8F,$7A,$00,$B0,$0E,$DE,$81,$7B,$86,$CB,$A2,$A5,$52,$53,$AC,$28,
$BA,$04,$FB,$7F,$62,$28,$32,$14,$49,$69,$7E,$9D,$82,$89,$BB,$FC,$5B,$4B,$D5,$D2,
$5E,$22,$74,$11,$15,$C8,$C0,$C2,$1E,$62,$4A,$7A,$44,$2B,$17,$33,$59,$1E,$FB,$F4,
$E4,$FF,$CD,$3C,$85,$DE,$FD,$1A,$65,$1C,$A8,$CA,$21,$17,$BA,$54,$F8,$7F,$A8,$BC,
$72,$D0,$DF,$FC,$B1,$79,$19,$EB,$9C,$11,$F5,$75,$B0,$86,$0F,$06,$A0,$97,$5D,$C8,
$C4,$F9,$20,$DC,$30,$9E,$31,$F0,$9B,$3D,$AE,$D8,$D7,$E2,$E6,$09,$A2,$8D,$51,$37,
$09,$EF,$AF,$E2,$95,$C6,$DC,$AE,$0C,$60,$C5,$DB,$D0,$75,$34,$1D,$A1,$E1,$B6,$6B,
$89,$26,$69,$58,$8D,$DA,$83,$74,$1D,$9B,$19,$E4,$9B,$CF,$41,$F4,$77,$F3,$AB,$1E,
$BA,$C4,$A6,$3A,$76,$24,$75,$9B,$63,$A4,$DC,$BC,$FA,$23,$58,$C0,$AE,$3F,$88,$15,
$46,$17,$2B,$1C,$84,$FF,$8B,$42,$87,$E2,$0E,$85,$45,$52,$DF,$CD,$22,$24,$0D,$B8,
$30,$E2,$24,$60,$92,$C2,$CE,$D2,$FB,$15,$D7,$DE,$E8,$BA,$FE,$02,$B6,$11,$F5,$EA,
$18,$22,$46,$87,$48,$7A,$E7,$23,$A6,$A2,$51,$C5,$F2,$F3,$02,$A5,$FD,$29,$EC,$D5,
$0F,$BA,$12,$A2,$F4,$1E,$AF,$6B,$95,$1E,$4C,$CA,$A1,$02,$02,$AD,$62,$C7,$FB,$19,
$63,$C8,$F6,$19,$3E,$D0,$88,$9D,$59,$67,$19,$09,$8C,$14,$BD,$3E,$B5,$D6,$FE,$98,
$60,$1B,$2F,$AD,$54,$B3,$FE,$EA,$48,$36,$62,$BB,$BA,$16,$49,$E2,$BA,$1A,$F8,$8F,
$DA,$76,$4D,$F8,$64,$B5,$BB,$BE,$F6,$D8,$0E,$CC,$CB,$A5,$A1,$E0,$20,$F1,$BA,$4D,
$B7,$3E,$30,$CD,$23,$EF,$ED,$28,$5C,$AE,$67,$6F,$1B,$6A,$00,$8F,$ED,$6B,$C1,$A3,
$8B,$74,$D6,$48,$FC,$BA,$A8,$BF,$3E,$55,$97,$8F,$9C,$D4,$6E,$CF,$CE,$1A,$5B,$48,
$4E,$54,$89,$5D,$FF,$9D,$AC,$4C,$50,$E3,$B9,$1C,$11,$E6,$BA,$3A,$71,$0A,$D7,$57,
$DC,$D4,$0B,$F8,$57,$01,$C0,$D9,$FF,$F8,$F9,$F7,$C0,$EC,$C5,$8B,$8F,$1C,$31,$95,
$CE,$9D,$31,$31,$7E,$50,$28,$0E,$00,$77,$76,$C7,$5D,$C3,$A6,$BB,$C8,$7F,$FD,$69,
$54,$FF,$93,$A1,$4F,$F2,$FA,$A1,$5A,$B5,$1E,$A2,$B3,$E0,$A8,$AF,$FA,$62,$25,$A6,
$A1,$97,$9E,$3D,$2A,$1B,$AA,$78,$CA,$86,$3E,$01,$85,$26,$D2,$D8,$14,$C6,$67,$D6,
$80,$D4,$89,$0A,$0E,$D3,$FC,$38,$46,$CD,$99,$D1,$8A,$31,$CF,$64,$76,$AA,$18,$14,
$DA,$5F,$E1,$E1,$23,$59,$DF,$34,$FC,$2F,$30,$D0,$3F,$D7,$66,$94,$1B,$CB,$95,$EF,
$91,$85,$C9,$24,$70,$8E,$12,$04,$A4,$59,$18,$0D,$55,$58,$ED,$BF,$33,$A1,$91,$49,
$99,$19,$83,$93,$63,$9D,$92,$55,$E5,$68,$55,$FD,$A6,$3A,$D9,$5B,$20,$73,$02,$CB,
$61,$CA,$16,$55,$86,$29,$4C,$B5,$05,$52,$53,$0D,$EC,$B0,$0A,$8E,$C5,$60,$1C,$8A,
$B3,$99,$F7,$5D,$2C,$22,$8D,$E0,$A7,$F5,$97,$65,$E7,$FF,$F9,$5F,$1A,$02,$D3,$7D,
$9A,$12,$1C,$E4,$5E,$35,$CB,$2A,$18,$4C,$59,$AC,$96,$00,$C2,$62,$B1,$24,$B9,$17,
$59,$A9,$AA,$ED,$0B,$C7,$FF,$EE,$FA,$D4,$4E,$02,$B6,$5E,$63,$ED,$83,$5D,$4F,$81,
$AA,$B0,$BF,$D2,$F6,$6C,$9D,$82,$45,$FD,$79,$D8,$32,$DA,$F1,$D3,$BE,$C3,$31,$D3,
$2B,$D1,$65,$75,$1A,$AE,$CB,$7B,$ED,$65,$AA,$12,$CA,$70,$64,$4E,$85,$E6,$BC,$31,
$55,$BE,$57,$83,$A0,$84,$D7,$8E,$AB,$FA,$38,$C1,$DC,$A6,$54,$84,$46,$78,$70,$98,
$4C,$BE,$62,$8D,$A2,$B5,$B2,$56,$43,$29,$8E,$BE,$A3,$19,$D5,$6B,$03,$87,$52,$B6,
$85,$02,$28,$9E,$62,$40,$64,$0F,$7F,$F9,$9D,$89,$EA,$4B,$D1,$0E,$51,$53,$B4,$8B,
$D7,$F9,$E0,$8C,$65,$3C,$69,$72,$0B,$25,$F1,$36,$9D,$AC,$FC,$EC,$02,$37,$90,$9A,
$83,$13,$26,$0B,$12,$9A,$B0,$B2,$A0,$00,$91,$80,$B8,$3D,$76,$B0,$40,$3B,$45,$4E,
$FF,$BB,$C1,$1A,$30,$4A,$F9,$2E,$D7,$DA,$F8,$E3,$5D,$7F,$E0,$3E,$FE,$1C,$6E,$5F,
$3E,$F6,$5F,$21,$53,$93,$35,$CF,$E9,$0A,$0B,$17,$55,$27,$70,$B5,$78,$6C,$E1,$5E,
$F7,$94,$EE,$44,$38,$AE,$D0,$92,$7F,$75,$9C,$AE,$7D,$BE,$00,$05,$EE,$85,$EB,$64,
$B5,$A0,$54,$FA,$1F,$88,$BD,$DB,$28,$38,$15,$8F,$DD,$DA,$77,$87,$86,$F2,$D6,$1A,
$DA,$AA,$24,$A3,$5C,$12,$0B,$86,$91,$1E,$DE,$3E,$5C,$8F,$1D,$C8,$CD,$30,$31,$03,
$A9,$FE,$ED,$A7,$64,$97,$E3,$33,$64,$8A,$C0,$CC,$9C,$BD,$EE,$C1,$D6,$92,$35,$71,
$86,$65,$0C,$04,$63,$66,$AD,$F7,$5F,$11,$A4,$80,$E1,$0A,$33,$D2,$5C,$74,$C2,$44,
$98,$09,$07,$03,$32,$0B,$8D,$9E,$11,$32,$D1,$0C,$B8,$83,$DA,$B1,$47,$C4,$8C,$8D,
$91,$0E,$7B,$68,$7C,$CB,$4E,$A7,$48,$4E,$47,$CE,$11,$38,$BA,$49,$BE,$4B,$25,$D5,
$97,$8D,$5D,$42,$3A,$49,$7A,$FA,$7F,$C5,$7C,$25,$8C,$15,$8B,$35,$23,$9A,$39,$F7,
$BF,$6F,$48,$7B,$23,$A4,$2D,$39,$1D,$C1,$4C,$4F,$56,$1E,$CC,$AE,$44,$1E,$52,$77,
$B2,$A3,$DA,$C9,$55,$75,$1C,$4C,$04,$9C,$B6,$E6,$A5,$FA,$5A,$57,$07,$EA,$2A,$CD,
$B0,$AB,$59,$4A,$C4,$A7,$E7,$4B,$2A,$A9,$87,$B1,$74,$05,$70,$E3,$4A,$C3,$E1,$BB,
$1A,$D7,$EB,$C2,$96,$51,$2A,$84,$15,$D9,$28,$AA,$EA,$D5,$9A,$6D,$D3,$71,$63,$B3,
$75,$66,$EA,$71,$A5,$FB,$75,$63,$DB,$BC,$30,$70,$BF,$05,$CA,$5F,$B5,$23,$CE,$16,
$EE,$5D,$23,$86,$1E,$EB,$CD,$69,$21,$F8,$F0,$B2,$31,$97,$22,$40,$CB,$39,$DA,$AB,
$5A,$85,$C1,$C4,$B2,$D3,$DD,$E4,$19,$E8,$D9,$57,$5E,$C9,$12,$BA,$C1,$82,$1D,$F3,
$0D,$D6,$2B,$17,$5F,$06,$09,$19,$04,$DD,$A5,$27,$48,$08,$41,$42,$B3,$21,$CA,$51,
$1B,$BF,$0C,$12,$32,$67,$75,$7D,$AA,$40,$3E,$EE,$34,$61,$9E,$65,$CF,$49,$AB,$67,
$EB,$67,$D7,$01,$A8,$09,$1D,$BB,$BC,$9E,$49,$A8,$E0,$D5,$81,$69,$5C,$7A,$98,$1F,
$42,$E9,$7B,$81,$FA,$83,$30,$E6,$95,$10,$53,$B1,$62,$4C,$2C,$39,$14,$03,$9E,$79,
$C4,$0E,$F9,$ED,$31,$A6,$21,$2B,$8C,$3C,$86,$BE,$A2,$D1,$C8,$52,$58,$A1,$62,$E7,
$04,$AD,$45,$F9,$9A,$E4,$D9,$41,$D8,$7D,$11,$C8,$41,$E3,$36,$94,$4B,$0C,$F6,$D1,
$79,$F3,$79,$ED,$CB,$50,$1B,$8C,$44,$F0,$F7,$C0,$1B,$C2,$18,$13,$FF,$15,$2F,$F0,
$61,$A9,$CC,$8C,$58,$1E,$B6,$E7,$76,$BB,$C7,$1B,$AD,$47,$00,$1F,$CA,$04,$61,$64,
$60,$70,$98,$D2,$C6,$76,$56,$8B,$E3,$4F,$05,$D2,$A1,$30,$A2,$B8,$A8,$FE,$CF,$6B,
$F9,$61,$41,$95,$BF,$2B,$EA,$26,$E3,$7D,$17,$F2,$9E,$B0,$F9,$46,$EA,$D5,$C5,$02,
$69,$E4,$E2,$EB,$EC,$BA,$D5,$27,$EE,$97,$DB,$28,$F7,$27,$3D,$B5,$96,$CA,$2E,$81,
$43,$29,$27,$AC,$89,$28,$07,$25,$EE,$AE,$56,$03,$A6,$B2,$24,$E3,$BA,$4B,$51,$6A,
$D8,$08,$1F,$95,$F9,$18,$72,$07,$87,$CE,$C5,$72,$A9,$12,$C6,$75,$A7,$F5,$1F,$72,
$76,$96,$25,$2D,$0E,$81,$DD,$49,$9C,$25,$74,$90,$95,$48,$01,$A0,$44,$13,$20,$92,
$4A,$D7,$58,$E0,$03,$52,$FD,$6A,$D3,$FC,$AB,$17,$A9,$F4,$30,$24,$76,$08,$56,$58,
$09,$99,$85,$88,$DF,$12,$52,$CF,$B0,$AF,$CE,$CD,$27,$6F,$3A,$F2,$B5,$B8,$62,$C9,
$76,$F6,$DB,$6B,$10,$33,$42,$2D,$31,$80,$6A,$41,$18,$2B,$CD,$BD,$B8,$EF,$EA,$92,
$07,$17,$32,$F1,$C2,$1E,$FA,$49,$21,$D8,$9A,$00,$E2,$5D,$F7,$AA,$CC,$2C,$67,$22,
$67,$3E,$04,$88,$B5,$1F,$5A,$93,$D7,$1D,$08,$33,$3F,$D3,$1C,$A1,$1F,$CE,$84,$F2,
$8D,$B5,$32,$25,$0C,$05,$14,$8C,$75,$32,$58,$14,$B1,$56,$6F,$B0,$12,$C6,$D8,$7E,
$43,$3E,$14,$DE,$50,$9D,$D0,$F3,$DD,$61,$D5,$5D,$D6,$DD,$31,$C2,$FF,$C2,$4F,$53,
$10,$09,$23,$84,$CB,$D6,$5C,$4E,$D3,$2F,$AA,$42,$2A,$CD,$D5,$8D,$09,$36,$8E,$61,
$DC,$C3,$7C,$5F,$90,$AA,$0A,$B9,$4F,$06,$AE,$3B,$5D,$19,$07,$15,$1D,$76,$55,$D4,
$DD,$5C,$F2,$B0,$D2,$52,$C5,$EE,$87,$54,$AD,$F3,$56,$75,$B9,$12,$9F,$BF,$0A,$86,
$EA,$DC,$FC,$EA,$E2,$F1,$80,$78,$35,$08,$62,$AE,$98,$EE,$AD,$DC,$D0,$45,$3B,$57,
$10,$A0,$7A,$58,$2E,$4C,$1D,$39,$14,$44,$41,$2B,$42,$6F,$CE,$01,$AA,$42,$6C,$36,
$D1,$A1,$DE,$AE,$E0,$D0,$AC,$29,$42,$10,$62,$F4,$E6,$45,$D6,$EA,$BD,$A0,$FD,$BC,
$AB,$09,$FB,$28,$D1,$D7,$F4,$2D,$0A,$5B,$FD,$EB,$8A,$A8,$3F,$4C,$BA,$10,$ED,$40,
$14,$5B,$76,$EE,$83,$C4,$B5,$FB,$DE,$BD,$08,$8D,$8F,$85,$3A,$43,$B8,$B5,$67,$5F,
$31,$D1,$BB,$50,$66,$F7,$65,$F7,$A1,$82,$DA,$F2,$CB,$F1,$8F,$FD,$ED,$A9,$FF,$57,
$E5,$A0,$D9,$99,$A6,$FB,$4C,$B5,$E0,$10,$8B,$86,$61,$E7,$51,$24,$64,$12,$47,$5B,
$07,$D5,$89,$24,$73,$9E,$2C,$82,$E9,$5F,$5D,$7F,$D2,$1B,$4F,$4F,$F8,$55,$4B,$97,
$58,$56,$67,$F8,$12,$A7,$3E,$AF,$FB,$CA,$43,$CC,$EA,$25,$D1,$37,$AE,$3A,$40,$9E,
$D6,$7F,$EA,$3F,$D2,$3D,$C8,$D8,$02,$CC,$AE,$A3,$2A,$03,$E8,$75,$AD,$98,$91,$13,
$FC,$C2,$71,$81,$66,$FF,$A6,$D2,$77,$7C,$15,$23,$9C,$19,$F6,$EE,$46,$4A,$5D,$A5,
$7F,$27,$68,$75,$1E,$36,$BE,$FA,$86,$39,$B4,$F8,$CE,$26,$77,$72,$C5,$75,$94,$AB,
$08,$43,$C5,$75,$A3,$B4,$D7,$B7,$8D,$EA,$EA,$FE,$90,$A4,$D9,$13,$DE,$D2,$EA,$87,
$A8,$13,$A9,$C6,$B2,$06,$5D,$71,$E3,$BA,$11,$5A,$34,$C3,$63,$4C,$D7,$7C,$15,$90,
$55,$55,$3E,$7A,$1E,$65,$DD,$57,$42,$77,$11,$67,$C6,$DC,$A7,$AA,$4B,$AB,$85,$73,
$5D,$43,$B4,$D5,$FF,$A3,$0F,$62,$C7,$84,$4B,$3B,$38,$76,$55,$07,$EF,$43,$BA,$1B,
$1F,$D7,$55,$67,$19,$75,$A3,$3B,$85,$23,$75,$74,$F7,$D0,$95,$48,$F7,$BA,$73,$7A,
$44,$74,$02,$B5,$96,$A5,$82,$F3,$DF,$19,$0C,$1F,$5C,$EA,$9F,$DA,$D6,$E8,$E7,$EA,
$AE,$0D,$CC,$87,$80,$D4,$E8,$25,$DA,$C9,$69,$75,$50,$E8,$CA,$BB,$E5,$8A,$30,$E3,
$F4,$A9,$1F,$AF,$09,$EF,$67,$B0,$ED,$17,$2E,$EF,$63,$88,$9B,$FF,$26,$B2,$15,$53,
$A5,$85,$EE,$46,$B5,$1E,$BA,$88,$FD,$35,$C6,$7D,$B3,$60,$22,$71,$51,$C3,$1F,$29,
$8B,$A7,$BE,$1F,$45,$88,$1C,$00,$86,$A9,$AA,$B2,$6C,$A8,$18,$28,$72,$BD,$E6,$30,
$28,$E3,$81,$87,$97,$75,$B4,$A6,$25,$66,$2F,$4D,$94,$02,$EE,$0E,$30,$25,$A4,$96,
$F5,$90,$E8,$AA,$7A,$15,$79,$C6,$F4,$C6,$4D,$CB,$35,$15,$A7,$14,$AC,$EE,$25,$7F,
$F5,$CF,$DF,$04,$68,$31,$B4,$48,$96,$7A,$4E,$F5,$88,$C2,$08,$06,$5A,$DD,$14,$CB,
$5D,$A3,$F6,$1D,$CB,$82,$2E,$90,$1E,$3D,$59,$FC,$0B,$DB,$BB,$11,$52,$B0,$A2,$FA,
$DC,$36,$1D,$98,$86,$EC,$D0,$05,$B3,$66,$A8,$40,$82,$DD,$4C,$06,$B6,$50,$9F,$E1,
$00,$00,$40,$78,$23,$E3,$E3,$12,$F5,$04,$AE,$5D,$8C,$54,$EC,$EF,$25,$71,$8A,$38,
$73,$51,$2E,$CA,$BC,$61,$69,$42,$62,$DD,$06,$83,$FD,$A6,$2F,$08,$C3,$C2,$CE,$43,
$2D,$68,$5C,$AD,$26,$33,$60,$6E,$C5,$C2,$1A,$2A,$31,$8E,$14,$C1,$75,$98,$79,$72,
$82,$BA,$05,$75,$34,$89,$1A,$00,$7A,$C9,$BB,$70,$80,$A0,$81,$BF,$85,$1E,$69,$0E,
$64,$60,$74,$77,$9A,$02,$C8,$84,$CC,$24,$43,$15,$28,$84,$B2,$DB,$68,$44,$86,$3F,
$AE,$CC,$39,$2A,$B2,$5C,$1D,$13,$A4,$D2,$C1,$29,$9B,$F8,$C6,$EB,$B4,$B0,$C0,$08,
$3D,$34,$24,$E2,$31,$E0,$D6,$98,$01,$A2,$C7,$FC,$1B,$65,$83,$F0,$FF,$80,$B0,$20,
$40,$B3,$24,$41,$B8,$20,$86,$F8,$DE,$C5,$BE,$BA,$BF,$68,$C7,$7F,$BF,$B7,$D0,$47,
$46,$39,$B3,$38,$78,$D5,$82,$35,$DD,$70,$6B,$18,$25,$EB,$6E,$6A,$DA,$13,$90,$90,
$61,$E5,$EB,$56,$50,$B3,$66,$0D,$CC,$BA,$35,$C1,$47,$01,$D7,$7F,$21,$F0,$24,$04,
$05,$A6,$F5,$93,$91,$97,$25,$24,$24,$97,$AD,$D3,$05,$E6,$05,$CB,$2D,$13,$9C,$CA,
$0F,$06,$19,$51,$C2,$83,$CE,$F6,$95,$84,$E1,$75,$1A,$98,$09,$EC,$05,$C3,$6C,$E9,
$54,$E2,$01,$5C,$91,$0D,$CB,$17,$55,$DA,$51,$4C,$EC,$BF,$46,$38,$98,$90,$FC,$98,
$83,$11,$E7,$F1,$1D,$20,$21,$17,$E0,$47,$4D,$95,$B7,$D2,$EB,$8F,$54,$7D,$A0,$AE,
$B0,$B9,$A3,$6F,$85,$2D,$7E,$D7,$99,$6B,$7A,$0A,$EC,$2B,$D5,$E1,$35,$5D,$FD,$87,
$79,$E9,$48,$82,$25,$41,$89,$62,$81,$DF,$3A,$4A,$7D,$52,$55,$FC,$CA,$E2,$23,$22,
$77,$CB,$23,$60,$BB,$9E,$F9,$75,$C0,$E2,$6A,$A8,$A4,$05,$AB,$C0,$96,$BA,$00,$19,
$F7,$C2,$72,$10,$66,$01,$5C,$61,$90,$A9,$EE,$E5,$EC,$D6,$EA,$E2,$32,$2E,$B7,$61,
$44,$C2,$C2,$C7,$B8,$02,$09,$6C,$BC,$39,$2B,$F6,$54,$2B,$62,$0F,$8C,$DE,$2D,$57,
$17,$7F,$D4,$E1,$88,$6E,$1F,$03,$09,$C9,$03,$97,$ED,$03,$40,$03,$68,$80,$0B,$F1,
$DF,$F3,$DB,$81,$DB,$00,$70,$16,$AE,$9E,$50,$8B,$FF,$7D,$FA,$E1,$E9,$48,$34,$E0,
$28,$D1,$19,$30,$18,$22,$1F,$27,$35,$58,$04,$83,$3B,$C6,$0B,$2F,$15,$8F,$7F,$BF,
$EE,$D3,$D0,$DD,$78,$A3,$16,$9A,$08,$58,$A7,$BF,$1A,$1E,$D8,$DF,$A9,$72,$4B,$DE,
$C1,$D9,$13,$C0,$8D,$A8,$13,$0D,$AC,$71,$D6,$4C,$EF,$B4,$81,$93,$26,$9A,$26,$62,
$7D,$6E,$69,$62,$2C,$68,$BD,$6A,$4C,$7D,$76,$2F,$EA,$29,$AB,$5B,$66,$F7,$FF,$C0,
$60,$AB,$34,$67,$B7,$4A,$4F,$57,$C6,$5B,$DD,$08,$97,$E7,$35,$B2,$62,$88,$AB,$60,
$D6,$44,$0F,$47,$AE,$5E,$95,$4A,$57,$7B,$BE,$9F,$95,$B0,$F1,$1B,$CC,$67,$AF,$B2,
$BA,$3B,$49,$F7,$AD,$39,$6C,$4C,$05,$E8,$01,$AA,$0C,$1B,$F7,$2B,$05,$AD,$AA,$19,
$CC,$0A,$26,$E6,$98,$D4,$9E,$E2,$2A,$8B,$D4,$36,$BA,$07,$E2,$E7,$AA,$26,$E2,$28,
$A5,$C4,$18,$91,$BD,$5B,$30,$1F,$49,$93,$2A,$78,$2E,$2E,$84,$45,$62,$EC,$A9,$9E,
$E1,$CC,$2B,$70,$B6,$EC,$EA,$D9,$B3,$E9,$BA,$07,$75,$55,$B0,$F7,$6D,$8E,$F9,$CA,
$DF,$9A,$92,$56,$1D,$A2,$1F,$75,$78,$B4,$12,$6E,$5D,$64,$92,$CB,$75,$AA,$73,$44,
$30,$20,$99,$76,$29,$2B,$2F,$84,$AA,$7A,$EF,$8F,$8C,$9E,$65,$E6,$78,$30,$08,$F3,
$28,$89,$7D,$67,$0C,$61,$A5,$2C,$34,$E2,$98,$1C,$26,$65,$DA,$C8,$0C,$8A,$00,$BE,
$40,$FF,$29,$68,$2C,$67,$A7,$6E,$9F,$76,$21,$63,$CB,$9E,$3D,$2B,$C2,$F8,$CB,$63,
$AD,$E4,$D8,$DD,$9C,$5F,$0A,$5A,$DB,$75,$4D,$93,$C3,$22,$C1,$F5,$7F,$71,$49,$49,
$34,$4D,$D3,$34,$5D,$15,$0D,$35,$23,$69,$9A,$24,$D3,$35,$C3,$F2,$DF,$E9,$89,$A6,
$69,$9A,$A6,$F7,$D7,$C3,$2B,$25,$07,$9A,$A6,$69,$9A,$09,$2D,$27,$53,$43,$24,$99,
$A6,$69,$51,$63,$75,$83,$BB,$6F,$D3,$34,$4D,$D3,$67,$47,$37,$39,$07,$4D,$D3,$34,
$4D,$E7,$FB,$FD,$F5,$E1,$9D,$0D,$33,$F0,$34,$97,$D7,$7D,$4F,$D3,$34,$4D,$31,$65,
$01,$13,$BF,$D3,$D4,$30,$03,$F1,$16,$BD,$A3,$4D,$D3,$34,$4D,$6D,$7D,$81,$5F,$4F,
$39,$34,$4D,$D3,$34,$23,$15,$F7,$71,$67,$69,$92,$4C,$D3,$C7,$7D,$8B,$D1,$81,$8F,
$A6,$69,$9A,$A6,$AF,$AF,$AD,$55,$5B,$53,$9B,$A6,$69,$9A,$59,$67,$15,$0B,$01,$88,
$EF,$11,$9B,$FF,$FF,$9A,$26,$87,$49,$9C,$E1,$B5,$81,$F7,$34,$4D,$93,$64,$77,$AB,
$5D,$4B,$2D,$6D,$F3,$D8,$C0,$D3,$ED,$4D,$1B,$03,$3C,$4D,$0E,$2D,$25,$3B,$2C,$00,
$60,$96,$39,$1B,$1E,$12,$91,$80,$41,$F8,$74,$09,$09,$18,$1E,$CD,$01,$D0,$3C,$2B,
$2E,$21,$20,$2F,$3A,$01,$3C,$3F,$00,$00,$00,$E0,$25,$84,$F0,$B3,$72,$27,$65,$B4,
$E7,$CD,$59,$91,$47,$A1,$E8,$CB,$80,$02,$7D,$D0,$19,$BC,$5E,$86,$2A,$C9,$89,$3E,
$0F,$48,$B5,$14,$28,$0A,$4D,$20,$29,$29,$AE,$D3,$44,$22,$C7,$D0,$67,$DC,$72,$C0,
$E4,$30,$63,$72,$B4,$E5,$D3,$D3,$34,$4D,$D3,$C9,$CF,$CD,$EB,$E7,$4D,$D3,$34,$4D,
$F1,$81,$EF,$DB,$C3,$3F,$92,$4C,$D3,$34,$07,$63,$49,$BF,$A3,$CF,$3C,$49,$A6,$69,
$17,$47,$99,$90,$CF,$F3,$2D,$87,$0D,$83,$8B,$6B,$AF,$D3,$44,$53,$45,$50,$A7,$C9,
$61,$2D,$07,$DB,$44,$35,$D3,$9B,$97,$51,$D3,$34,$4D,$D3,$97,$B9,$D5,$FB,$19,$59,
$43,$06,$4D,$41,$8D,$E3,$F9,$D7,$9A,$88,$6D,$EB,$E9,$F4,$88,$69,$11,$A7,$73,$CF,
$A1,$D3,$CD,$9D,$1D,$D3,$DB,$B1,$8B,$4B,$69,$0E,$45,$C5,$F6,$26,$0B,$03,$37,$E9,
$C5,$27,$86,$AD,$3F,$3A,$71,$AC,$9D,$9A,$26,$62,$7B,$23,$FF,$8D,$75,$6D,$AD,$98,
$7E,$A6,$45,$5C,$EB,$AD,$9B,$A6,$E9,$C7,$25,$F3,$C9,$17,$34,$51,$C7,$F4,$59,$5D,
$88,$61,$4D,$D3,$57,$2F,$3B,$DB,$7E,$A9,$69,$9A,$CB,$ED,$A9,$99,$1E,$31,$AC,$C3,
$11,$D3,$9A,$E8,$3F,$39,$57,$E8,$26,$62,$D1,$6B,$75,$0C,$AB,$F4,$71,$9E,$F8,$D4,
$64,$81,$A9,$A6,$69,$9A,$7E,$01,$4F,$93,$DB,$73,$7B,$0E,$7D,$9A,$89,$69,$9A,$3E,
$5C,$BD,$CD,$17,$A3,$34,$CF,$AE,$F1,$97,$E2,$70,$F5,$7F,$4C,$EF,$2C,$9E,$23,$F7,
$45,$19,$44,$E7,$D7,$69,$9A,$88,$4F,$A3,$F3,$1D,$7A,$93,$C3,$A6,$1F,$19,$23,$25,
$B7,$7E,$9E,$62,$1B,$97,$D8,$16,$C5,$CB,$4A,$5C,$EB,$ED,$8F,$98,$DE,$F4,$E7,$43,
$45,$B3,$83,$06,$A6,$2C,$45,$41,$06,$D1,$0C,$56,$5F,$64,$D0,$64,$90,$60,$69,$76,
$7F,$D3,$34,$4D,$D3,$74,$89,$8E,$84,$81,$4D,$D3,$34,$4D,$9F,$84,$8A,$88,$B7,$BD,
$34,$4D,$D3,$34,$B4,$B2,$92,$91,$90,$D3,$34,$4D,$D3,$90,$F0,$F0,$F1,$F2,$4D,$D3,
$34,$4D,$93,$9C,$96,$88,$BA,$84,$34,$4D,$D3,$34,$8F,$82,$84,$88,$7B,$D3,$34,$4D,
$D3,$76,$92,$9D,$A8,$A4,$4D,$D3,$34,$4D,$BF,$A2,$A5,$DF,$E9,$EB,$34,$4D,$D3,$34,
$FC,$F5,$ED,$D4,$DA,$34,$BD,$6C,$D0,$DF,$97,$90,$A6,$89,$78,$D4,$86,$9F,$E0,$D0,
$9A,$A6,$69,$9A,$C6,$F9,$12,$19,$26,$F8,$11,$D3,$6A,$40,$7D,$9A,$1E,$7E,$E2,$1C,
$F6,$2E,$AB,$A6,$69,$AE,$93,$45,$A3,$A6,$C9,$61,$04,$CA,$9C,$54,$64,$9A,$1C,$26,
$0A,$CE,$80,$48,$41,$49,$32,$4D,$93,$6F,$AC,$E8,$1B,$36,$5E,$D3,$34,$49,$A6,$91,
$24,$23,$6F,$8B,$C1,$92,$69,$9A,$24,$08,$10,$71,$AD,$D4,$1E,$01,$4C,$D3,$34,$4D,
$4D,$80,$51,$26,$03,$E6,$E6,$9A,$A6,$69,$92,$F0,$C2,$C4,$FF,$D4,$34,$4D,$93,$64,
$22,$D1,$03,$6F,$AE,$D9,$34,$49,$26,$C9,$08,$C4,$D3,$44,$BF,$31,$B3,$50,$4D,$12,
$C9,$C4,$AA,$61,$A9,$BD,$FE,$D5,$E6,$A5,$72,$0D,$22,$72,$AF,$5E,$54,$73,$9A,$A4,
$5E,$4D,$50,$59,$3E,$17,$4A,$32,$09,$BD,$1B,$51,$82,$91,$26,$C9,$24,$F2,$EA,$2B,
$9A,$82,$E0,$49,$64,$5E,$49,$97,$42,$E8,$B0,$17,$24,$12,$C9,$34,$88,$20,$B8,$46,
$A7,$E8,$AD,$04,$BB,$93,$F2,$50,$A0,$A6,$7B,$D5,$30,$12,$68,$D8,$2D,$A1,$4B,$22,
$91,$DC,$ED,$FA,$F0,$E6,$71,$98,$44,$22,$FD,$FA,$DE,$F9,$27,$94,$C0,$9A,$26,$C9,
$24,$16,$81,$CB,$4B,$12,$15,$7E,$9B,$A6,$69,$32,$86,$11,$7F,$94,$97,$72,$51,$A0,
$A2,$93,$4B,$E2,$B1,$FC,$33,$87,$02,$F7,$8F,$F3,$70,$6E,$F9,$85,$E9,$79,$3C,$89,
$6A,$3A,$97,$E4,$5C,$54,$7E,$CF,$87,$4A,$B4,$73,$59,$B9,$A9,$7D,$0D,$E7,$E4,$7E,
$A8,$E5,$12,$89,$C4,$45,$4F,$A6,$12,$B7,$19,$B4,$22,$91,$48,$24,$6D,$85,$C7,$BB,
$60,$B0,$2C,$BE,$3B,$BC,$24,$12,$89,$44,$5F,$B2,$9C,$B9,$04,$C7,$69,$32,$BE,$47,
$22,$91,$48,$28,$E6,$2F,$05,$12,$1D,$09,$EA,$04,$EA,$12,$C9,$C3,$13,$A8,$1E,$52,
$CB,$AA,$31,$D1,$22,$91,$48,$24,$26,$C4,$FB,$CB,$97,$EE,$B5,$ED,$52,$E9,$24,$12,
$89,$44,$5A,$F4,$39,$83,$E2,$F9,$BA,$FC,$2D,$44,$22,$91,$48,$E3,$A5,$F9,$E1,$F7,
$FA,$C5,$9D,$CB,$69,$24,$12,$89,$76,$F1,$C7,$EE,$04,$EC,$19,$ED,$34,$4C,$D0,$CF,
$0D,$26,$02,$53,$0A,$89,$44,$22,$91,$2C,$12,$41,$ED,$07,$EC,$1E,$EF,$44,$12,$F2,
$3B,$70,$28,$F0,$5F,$CA,$24,$69,$18,$89,$AE,$C4,$65,$C1,$B7,$FA,$2B,$22,$98,$00,
$C9,$C9,$F3,$49,$4B,$C8,$6F,$0C,$3B,$C5,$61,$76,$63,$B6,$F8,$9F,$D0,$15,$20,$02,
$4D,$03,$7D,$21,$51,$9A,$A5,$1D,$D1,$04,$04,$CD,$C7,$0F,$00,$00,$00,$70,$04,$04,
$07,$93,$66,$66,$65,$97,$9E,$28,$46,$9B,$86,$EB,$33,$9F,$16,$16,$15,$A3,$93,$BB,
$1D,$A7,$B6,$9E,$17,$22,$69,$18,$00,$AB,$97,$90,$10,$AF,$0E,$0E,$0D,$B3,$AB,$CA,
$8F,$A6,$81,$92,$91,$A6,$89,$44,$7E,$76,$7B,$7E,$74,$73,$EF,$6E,$48,$5D,$BE,$22,
$49,$3C,$3B,$E3,$5C,$3B,$5B,$8F,$91,$1B,$F2,$2B,$47,$D2,$30,$09,$42,$79,$AF,$60,
$0B,$55,$E0,$D1,$D5,$13,$0F,$CE,$E0,$3F,$83,$77,$EB,$92,$49,$77,$5B,$B3,$E4,$58,
$97,$3C,$AB,$F3,$3C,$C7,$BB,$80,$0F,$2E,$96,$F5,$B1,$DF,$51,$FB,$D9,$94,$FB,$EF,
$07,$FD,$F9,$34,$DB,$7B,$DF,$EB,$4F,$7D,$AB,$6B,$E5,$DA,$9D,$7C,$FF,$65,$AD,$E2,
$71,$9B,$FA,$58,$9B,$9F,$A8,$E6,$53,$14,$3B,$24,$D5,$D9,$C9,$EA,$C8,$AA,$0B,$F8,
$C8,$3E,$91,$54,$47,$35,$3C,$E1,$54,$6D,$FA,$55,$C3,$7A,$CC,$6E,$3B,$A6,$6D,$07,
$19,$83,$58,$0C,$2C,$85,$D6,$64,$79,$E2,$50,$35,$0B,$62,$7B,$6A,$7D,$86,$D4,$A1,
$AA,$22,$44,$56,$40,$3D,$54,$F4,$72,$78,$6A,$11,$34,$2B,$51,$41,$4F,$53,$9A,$C1,
$4D,$7A,$55,$C5,$14,$2E,$AA,$A8,$B0,$0A,$6F,$65,$37,$23,$16,$03,$97,$63,$FF,$D4,
$3B,$3F,$59,$36,$A7,$07,$6B,$B6,$14,$1A,$FE,$15,$C9,$BC,$BA,$D8,$8A,$65,$A3,$9A,
$12,$00,$A2,$8A,$A3,$08,$A6,$B4,$B9,$B8,$15,$64,$2A,$9A,$D2,$A1,$FA,$D4,$8F,$AA,
$5C,$CE,$62,$91,$D5,$EC,$84,$D4,$FB,$4D,$1E,$39,$CC,$9B,$84,$53,$14,$C9,$E6,$99,
$F9,$AD,$8C,$64,$9D,$76,$F4,$AD,$6A,$41,$44,$F3,$A2,$56,$48,$D6,$CF,$83,$A8,$E6,
$AD,$78,$B4,$6B,$55,$B4,$BE,$B6,$8E,$E8,$8D,$EA,$85,$EC,$F3,$6A,$BE,$18,$21,$D9,
$D1,$BF,$74,$53,$4C,$AF,$E8,$4C,$F4,$A0,$5A,$D1,$78,$65,$A3,$27,$A6,$67,$15,$49,
$92,$EF,$F9,$5D,$C4,$F6,$DE,$F6,$E2,$D9,$57,$FC,$F3,$2F,$C7,$FF,$7C,$DD,$35,$2F,
$83,$D5,$BC,$F1,$FC,$2E,$A1,$C9,$EE,$15,$34,$32,$20,$DD,$BD,$2E,$CA,$E4,$9D,$A3,
$7F,$DA,$E0,$A1,$9A,$FF,$F9,$4A,$BF,$3C,$64,$2F,$85,$67,$BA,$57,$97,$5C,$E9,$2F,
$FE,$EF,$FB,$79,$59,$F6,$96,$BA,$46,$F2,$46,$BE,$3F,$FB,$2C,$64,$3C,$AA,$57,$D4,
$AA,$4C,$7F,$51,$D2,$C2,$86,$08,$74,$05,$AF,$A0,$A2,$29,$3A,$50,$36,$58,$4D,$6E,
$59,$14,$C1,$A3,$46,$57,$68,$45,$5E,$8B,$20,$5D,$71,$46,$16,$8B,$7E,$B6,$72,$6A,
$51,$6C,$3F,$3B,$5C,$6E,$E3,$5A,$A3,$C8,$2E,$75,$DC,$69,$8A,$22,$99,$FC,$89,$97,
$6F,$FA,$DA,$0F,$EF,$B6,$75,$AF,$91,$8F,$F6,$50,$45,$D3,$CF,$A8,$E3,$F5,$5F,$A6,
$57,$E2,$36,$8B,$3C,$3A,$A1,$D4,$3A,$17,$06,$5D,$D1,$E3,$73,$AF,$F4,$AF,$9E,$36,
$C8,$93,$CB,$3B,$CF,$CF,$74,$BB,$44,$7A,$F3,$75,$AE,$17,$8F,$8A,$0C,$74,$45,$DA,
$F4,$9A,$A8,$42,$34,$9D,$2B,$A4,$4E,$7C,$E6,$BE,$B9,$44,$55,$F3,$36,$7C,$E1,$AD,
$78,$89,$CF,$55,$3E,$F7,$EC,$3A,$BC,$8C,$48,$3D,$D6,$B7,$DE,$24,$95,$E0,$ED,$78,
$BA,$BC,$8C,$C2,$F8,$15,$0E,$DD,$85,$D1,$DF,$07,$D7,$9F,$64,$F3,$75,$A2,$AB,$DE,
$F3,$C2,$A0,$5C,$C8,$54,$87,$A9,$97,$EF,$5C,$DF,$CD,$35,$BA,$F7,$B9,$4C,$F2,$92,
$6E,$6B,$F1,$FC,$DE,$AF,$54,$2B,$99,$0B,$3E,$25,$CD,$52,$7F,$F1,$FC,$32,$9D,$73,
$45,$51,$64,$DA,$C8,$E4,$82,$25,$2A,$57,$A1,$0B,$8F,$EB,$CF,$49,$82,$66,$1E,$C1,
$4E,$73,$C9,$E6,$6A,$E6,$4E,$4B,$86,$37,$71,$63,$43,$3F,$AE,$C7,$1E,$AE,$D2,$B8,
$93,$F8,$E6,$7C,$AF,$CD,$A3,$E1,$BA,$B8,$1C,$E5,$71,$99,$C1,$75,$B9,$9D,$0E,$D3,
$AA,$AF,$CB,$2F,$C7,$EB,$F3,$DA,$F4,$1A,$BC,$CB,$F6,$46,$F2,$DF,$E7,$1E,$17,$04,
$EA,$4A,$D4,$CC,$B2,$23,$2E,$78,$FE,$E5,$96,$BC,$28,$FE,$C9,$F1,$55,$0E,$5E,$63,
$9B,$63,$00,$50,$04,$AF,$54,$A8,$5C,$AA,$76,$AC,$3A,$AE,$FC,$B0,$5C,$DE,$45,$11,
$BA,$B2,$78,$2E,$CA,$88,$11,$13,$2D,$83,$CC,$CF,$79,$A9,$14,$45,$D3,$D0,$C6,$CA,
$A6,$08,$32,$17,$FC,$F3,$D4,$C9,$48,$BE,$35,$8A,$AA,$F6,$A2,$29,$9A,$A6,$C5,$DB,
$AC,$E8,$11,$26,$8A,$8C,$68,$8F,$0B,$22,$8A,$84,$A2,$29,$53,$02,$78,$18,$35,$A7,
$1E,$AE,$68,$66,$02,$45,$D3,$14,$49,$40,$35,$05,$6B,$5D,$2B,$9A,$E0,$7A,$33,$C6,
$C9,$D1,$04,$CD,$0D,$75,$06,$2A,$8A,$A0,$53,$15,$68,$57,$F0,$24,$81,$6E,$F0,$7D,
$08,$B6,$45,$53,$CC,$12,$54,$72,$A8,$5E,$64,$B3,$62,$2D,$C4,$F5,$C1,$B5,$88,$38,
$81,$A5,$87,$99,$AD,$C0,$98,$58,$BE,$FB,$56,$22,$EE,$B9,$60,$F9,$3B,$A1,$48,$78,
$A7,$21,$22,$62,$F0,$95,$44,$8A,$1F,$45,$11,$54,$8B,$94,$44,$E0,$7B,$28,$32,$A2,
$55,$E3,$FF,$59,$2C,$9A,$A6,$19,$9A,$84,$B7,$06,$F4,$16,$B7,$E2,$68,$3A,$50,$4D,
$FD,$B3,$91,$CD,$22,$A1,$E2,$E5,$73,$96,$16,$4D,$67,$47,$1A,$11,$C1,$E3,$CC,$A5,
$8A,$2C,$F7,$06,$91,$50,$34,$45,$3D,$86,$02,$A9,$08,$49,$77,$14,$4D,$80,$42,$7F,
$6B,$C8,$62,$D1,$14,$27,$10,$DB,$75,$B3,$1B,$FD,$A2,$8C,$74,$D1,$14,$45,$46,$70,
$DA,$B2,$49,$2B,$9A,$E0,$5B,$84,$24,$D3,$48,$5C,$45,$11,$1C,$1E,$FF,$40,$8B,$A2,
$88,$69,$DE,$E0,$3E,$A2,$F2,$50,$11,$64,$60,$BB,$ED,$91,$D1,$EC,$2E,$CD,$17,$42,
$D1,$14,$4D,$9D,$3E,$E5,$73,$61,$A2,$08,$8E,$45,$85,$1E,$8A,$B4,$27,$12,$AA,$5B,
$23,$3A,$EC,$C0,$EE,$1C,$66,$B1,$68,$B3,$25,$E5,$95,$45,$C4,$A2,$8B,$75,$B1,$6C,
$95,$C3,$8C,$16,$28,$BC,$83,$A4,$D1,$1A,$57,$2A,$8A,$A6,$29,$9A,$58,$92,$53,$8B,
$76,$DB,$37,$C1,$A1,$7F,$90,$BD,$A9,$85,$32,$51,$C0,$B6,$08,$16,$17,$68,$D8,$61,
$22,$36,$57,$64,$5B,$81,$F9,$28,$9A,$A2,$29,$62,$E4,$2E,$9D,$17,$D2,$A8,$5A,$BC,
$62,$50,$14,$09,$45,$B3,$06,$AB,$F7,$3D,$45,$42,$51,$64,$13,$DA,$02,$B2,$D1,$D6,
$A9,$CA,$48,$00,$AA,$50,$24,$8D,$52,$EB,$09,$82,$E7,$B1,$57,$EA,$3C,$9A,$65,$F5,
$26,$45,$42,$11,$D1,$54,$DA,$4C,$D3,$F4,$A4,$53,$34,$77,$B9,$47,$22,$8F,$45,$D1,
$77,$4B,$05,$AB,$3F,$AF,$2D,$BA,$8A,$F2,$4D,$51,$64,$44,$2E,$30,$02,$60,$22,$3E,
$55,$34,$58,$0C,$73,$C1,$B3,$A2,$29,$37,$9E,$BE,$A1,$24,$78,$DD,$14,$D5,$8D,$66,
$B3,$AD,$2E,$9A,$EB,$61,$5F,$6D,$73,$95,$D3,$37,$FF,$63,$22,$94,$B9,$0A,$CF,$BB,
$AF,$CA,$B4,$D0,$94,$9D,$AB,$06,$83,$D7,$F1,$2E,$C8,$E3,$89,$F7,$69,$6F,$5E,$E0,
$7D,$E2,$73,$B8,$AB,$93,$99,$4C,$97,$BF,$7A,$D1,$CC,$55,$00,$1C,$46,$A8,$16,$AA,
$CE,$AC,$A8,$AE,$06,$06,$5D,$BC,$AE,$F8,$B6,$B3,$58,$34,$45,$C2,$D4,$C9,$EA,$DF,
$88,$E5,$45,$0E,$D0,$E4,$DF,$66,$B1,$68,$8A,$FF,$F0,$A4,$EC,$44,$64,$8B,$1C,$DD,
$FD,$D4,$82,$C2,$45,$53,$A8,$F9,$BF,$10,$DC,$1D,$BD,$2A,$34,$6C,$E6,$72,$95,$99,
$29,$8A,$C9,$55,$4D,$14,$4D,$11,$D1,$22,$B6,$32,$6E,$E8,$55,$53,$24,$67,$07,$D8,
$B9,$0A,$8B,$EB,$BE,$5B,$F4,$31,$B1,$11,$75,$52,$B9,$2A,$32,$C6,$0A,$14,$19,$14,
$4D,$F1,$6C,$25,$4B,$C4,$82,$64,$51,$24,$A0,$FA,$3A,$9B,$68,$32,$73,$35,$9A,$BA,
$8A,$88,$C9,$D7,$BD,$76,$42,$A1,$A2,$69,$A7,$3F,$BF,$51,$C5,$3E,$AB,$DF,$E3,$55,
$22,$7A,$88,$55,$A6,$5A,$D5,$2A,$AA,$D8,$E6,$6B,$C7,$D1,$14,$31,$CF,$95,$DF,$2D,
$50,$34,$45,$42,$7C,$DD,$EA,$9E,$BA,$8A,$1E,$74,$65,$D5,$17,$ED,$16,$4D,$90,$B9,
$0C,$E7,$07,$BE,$28,$8A,$2C,$BE,$34,$0C,$3A,$45,$53,$C4,$24,$AF,$16,$80,$40,$AA,
$41,$D1,$34,$13,$7B,$5B,$95,$AB,$CC,$E7,$22,$E3,$D9,$97,$79,$8C,$92,$B0,$AD,$68,
$8A,$80,$E2,$20,$A2,$BF,$55,$4D,$40,$D1,$42,$0F,$14,$19,$9B,$EE,$D3,$35,$9A,$60,
$50,$D1,$B1,$18,$DB,$F0,$D0,$45,$07,$AB,$5F,$A2,$95,$CF,$22,$E2,$23,$F0,$F5,$61,
$16,$BB,$5A,$46,$8B,$14,$15,$BC,$CA,$69,$88,$DC,$53,$64,$0C,$6E,$80,$2F,$5C,$15,
$09,$45,$A6,$B5,$E6,$6E,$90,$6D,$B2,$F8,$2C,$A0,$18,$5E,$35,$45,$9A,$83,$2C,$8A,
$A6,$49,$C8,$4F,$EC,$42,$5F,$84,$87,$AB,$C4,$B4,$2A,$E5,$F5,$AA,$A5,$55,$91,$FA,
$0A,$50,$70,$99,$5C,$65,$22,$88,$A3,$71,$95,$11,$E3,$2A,$D1,$A9,$C7,$5A,$99,$EC,
$6A,$A6,$A2,$29,$9A,$60,$0A,$E2,$9A,$D7,$08,$31,$D3,$2E,$8A,$40,$6A,$56,$16,$93,
$61,$5D,$E5,$58,$76,$AB,$46,$E2,$FD,$D5,$6C,$55,$22,$D5,$88,$D9,$56,$6F,$48,$BA,
$89,$E9,$6F,$44,$3C,$8B,$A6,$C7,$59,$BE,$43,$85,$46,$45,$53,$3D,$B1,$79,$48,$65,
$2A,$77,$D5,$C8,$75,$8D,$E8,$66,$C8,$5C,$5C,$9D,$AB,$C2,$B1,$76,$78,$95,$08,$96,
$CB,$66,$28,$5E,$F5,$AE,$C2,$B1,$E8,$85,$F3,$27,$97,$5F,$56,$EE,$3A,$57,$89,$E2,
$55,$A1,$73,$55,$37,$8F,$89,$CC,$55,$CB,$F2,$72,$DD,$85,$95,$CD,$55,$11,$EA,$B9,
$2E,$8B,$77,$DC,$95,$48,$56,$9D,$93,$36,$57,$F5,$72,$95,$F8,$5C,$25,$75,$EB,$76,
$73,$73,$57,$9E,$CE,$FC,$5C,$95,$E2,$60,$6D,$AE,$22,$8A,$EC,$D6,$B1,$96,$AB,$4E,
$91,$41,$B8,$AE,$C1,$45,$B0,$68,$87,$FC,$CD,$30,$F9,$22,$9B,$92,$D0,$AB,$0A,$81,
$AB,$D8,$5E,$44,$1C,$EF,$9A,$5D,$8A,$A6,$88,$72,$FC,$68,$F3,$F9,$8B,$98,$43,$A6,
$02,$17,$DD,$F9,$FB,$1C,$26,$EB,$22,$19,$F4,$DA,$00,$9B,$AE,$C6,$F2,$AE,$90,$E8,
$AA,$2A,$72,$98,$D1,$22,$2D,$1C,$C1,$45,$F2,$F8,$50,$50,$57,$70,$2C,$82,$0B,$7E,
$71,$C4,$B6,$AB,$4A,$07,$2A,$B8,$16,$4D,$6D,$30,$41,$EB,$32,$55,$55,$E5,$5B,$55,
$9B,$AA,$32,$FA,$3E,$44,$F0,$9A,$56,$DC,$36,$AA,$4D,$57,$58,$6C,$53,$88,$FC,$45,
$9E,$A2,$AE,$3D,$6F,$BA,$FD,$E3,$62,$15,$39,$C7,$CC,$A8,$A5,$68,$8A,$88,$FC,$C8,
$99,$51,$76,$A3,$BE,$57,$A5,$AB,$A6,$C8,$78,$84,$97,$CC,$04,$AE,$2A,$C1,$A3,$57,
$F5,$35,$DF,$D6,$3D,$8A,$A6,$7C,$DB,$90,$B5,$B9,$8A,$A9,$46,$1A,$A6,$33,$9E,$55,
$58,$2A,$54,$35,$41,$90,$50,$00,$CD,$AB,$C4,$E2,$71,$14,$AF,$32,$76,$CA,$39,$FE,
$15,$12,$2F,$7A,$B3,$31,$BC,$E2,$53,$1E,$AE,$AE,$4A,$28,$9A,$22,$11,$31,$0C,$DF,
$3B,$9F,$47,$65,$AE,$B5,$F5,$4F,$55,$19,$24,$A0,$2A,$68,$54,$EB,$45,$14,$BF,$DA,
$79,$BB,$CA,$D8,$D4,$8E,$AA,$93,$90,$0C,$84,$74,$95,$D8,$96,$C1,$5A,$AB,$2A,$B6,
$D2,$FA,$17,$45,$D3,$DF,$1F,$ED,$98,$C2,$A2,$29,$62,$A6,$E0,$13,$50,$AD,$C1,$2F,
$8A,$84,$79,$B7,$BC,$B9,$6A,$14,$11,$5D,$A0,$FC,$32,$57,$D9,$4D,$D5,$CE,$55,$69,
$A2,$BB,$0D,$5C,$80,$71,$A2,$51,$91,$CD,$A9,$45,$64,$33,$7B,$55,$76,$AB,$76,$45,
$11,$F5,$94,$E1,$AF,$AF,$4D,$FF,$1A,$78,$55,$E4,$6C,$2C,$DF,$54,$2A,$8A,$64,$29,
$DA,$3F,$41,$57,$51,$44,$EA,$F6,$F8,$E1,$7B,$55,$A8,$60,$AF,$82,$CF,$55,$1A,$F1,
$B9,$AA,$24,$4D,$42,$51,$C4,$05,$78,$76,$F8,$F5,$AB,$53,$24,$14,$2B,$D9,$2E,$88,
$79,$9C,$9F,$B8,$2F,$3A,$D9,$CF,$D5,$78,$A8,$2A,$A1,$28,$49,$23,$B4,$BF,$E1,$55,
$D2,$25,$57,$85,$BC,$5C,$DE,$12,$B9,$3E,$97,$5D,$AF,$1A,$C9,$A6,$69,$E3,$79,$5D,
$06,$10,$55,$8B,$57,$27,$8C,$AD,$98,$8B,$E1,$A2,$25,$36,$57,$25,$B6,$57,$55,$78,
$7D,$F8,$5C,$05,$BA,$8A,$60,$AE,$BC,$0C,$AF,$FA,$B3,$C5,$E7,$AA,$7C,$AA,$4C,$F1,
$2A,$AA,$11,$B1,$BD,$7A,$55,$44,$CF,$E7,$6A,$DE,$99,$AB,$AA,$5C,$B6,$AB,$D3,$64,
$15,$D1,$88,$EA,$97,$0A,$97,$99,$AB,$50,$AC,$4B,$4C,$AE,$32,$98,$16,$5C,$FE,$42,
$C4,$7F,$A7,$88,$CC,$02,$FE,$9B,$2E,$D6,$14,$FE,$3E,$54,$75,$3D,$3A,$D8,$AE,$CA,
$B2,$EB,$A2,$F3,$05,$D1,$07,$73,$D5,$E8,$55,$AF,$2A,$12,$32,$52,$7E,$6D,$65,$36,
$75,$17,$41,$D3,$55,$83,$5D,$E9,$AA,$9B,$21,$7A,$0D,$8F,$AE,$16,$57,$35,$45,$D2,
$48,$0F,$95,$8A,$70,$48,$B6,$AC,$94,$6A,$7C,$16,$8F,$6B,$B7,$2F,$D6,$BA,$89,$AE,
$3A,$A6,$7F,$10,$BD,$B6,$34,$EB,$DB,$67,$A7,$6F,$56,$AF,$4E,$FC,$11,$87,$AA,$C8,
$6F,$95,$C2,$78,$55,$53,$34,$88,$5C,$CA,$26,$86,$57,$ED,$AA,$DB,$8F,$3E,$43,$37,
$B6,$68,$8A,$1C,$92,$2B,$1A,$6C,$8D,$E4,$55,$C1,$48,$6C,$AE,$4E,$BA,$00,$75,$E6,
$7A,$5E,$28,$F5,$66,$E6,$73,$7C,$8A,$08,$5E,$84,$32,$3A,$57,$45,$73,$6A,$36,$99,
$AB,$12,$CD,$B3,$DF,$AA,$4F,$E6,$C7,$06,$AE,$7E,$C1,$AA,$52,$D5,$BB,$5B,$5C,$DD,
$14,$11,$9C,$27,$FE,$48,$5C,$D5,$A9,$41,$A7,$3E,$7F,$98,$55,$27,$57,$95,$A5,$79,
$21,$72,$3C,$CA,$41,$57,$1C,$55,$AB,$45,$11,$91,$15,$07,$F8,$5C,$35,$79,$C1,$B1,
$E8,$6A,$72,$9E,$A3,$FF,$0E,$FB,$1B,$AA,$42,$91,$0C,$44,$7D,$25,$36,$E7,$F5,$59,
$57,$27,$AA,$57,$DF,$F2,$2A,$BF,$41,$6A,$C4,$64,$FE,$83,$04,$AF,$6E,$F4,$CA,$F1,
$BC,$2A,$ED,$79,$95,$64,$08,$E3,$55,$58,$5E,$A0,$72,$35,$82,$0D,$50,$57,$9D,$4C,
$8F,$C8,$CD,$55,$3F,$1A,$D0,$9D,$AB,$32,$E7,$FE,$9D,$C9,$74,$DE,$79,$3A,$57,$0D,
$5C,$A5,$68,$54,$1D,$D4,$87,$C8,$5D,$6F,$55,$27,$88,$32,$22,$78,$F5,$C8,$6E,$AE,
$33,$95,$2B,$61,$53,$BC,$AA,$87,$AA,$76,$AE,$2A,$2A,$DD,$70,$B9,$B9,$BA,$91,$AB,
$AA,$D2,$B8,$50,$97,$AB,$C2,$F0,$2F,$75,$57,$04,$02,$16,$E1,$55,$A9,$F4,$ED,$5C,
$75,$82,$AE,$95,$23,$7A,$5D,$FD,$22,$32,$D7,$89,$74,$EE,$2A,$11,$AE,$9E,$A8,$54,
$57,$AD,$C6,$7C,$61,$73,$5F,$69,$3A,$54,$EE,$2B,$E2,$B4,$0A,$45,$53,$E4,$40,$46,
$48,$4D,$F5,$58,$D5,$E0,$3E,$17,$FE,$92,$43,$32,$22,$57,$B1,$42,$27,$22,$64,$2E,
$7C,$0A,$15,$7D,$53,$2B,$65,$00,$9E,$A6,$48,$06,$0A,$F5,$F2,$B2,$6A,$59,$E9,$E9,
$52,$7D,$95,$C2,$80,$FF,$7C,$55,$E3,$41,$C4,$31,$78,$C8,$E5,$D0,$E8,$32,$88,$E6,
$9B,$F4,$D8,$10,$86,$20,$84,$0C,$68,$90,$BC,$10,$A7,$98,$0C,$22,$88,$38,$20,$56,
$41,$79,$96,$20,$83,$58,$B1,$C6,$FB,$8B,$6C,$19,$64,$50,$E4,$68,$4D,$44,$3B,$64,
$90,$41,$06,$31,$27,$2D,$22,$8E,$43,$19,$12,$2C,$0A,$41,$06,$11,$C7,$01,$F8,$06,
$19,$64,$90,$FF,$E6,$EC,$C5,$90,$90,$41,$D2,$D7,$90,$28,$64,$7D,$D0,$3F,$EB,$F8,
$40,$6D,$AE,$01,$67,$4C,$DC,$B3,$AC,$CD,$01,$4B,$18,$A8,$A8,$AB,$A7,$46,$44,$2C,
$72,$9F,$98,$9D,$FA,$E1,$36,$8F,$1B,$E4,$B3,$AA,$64,$36,$B6,$4F,$7F,$7C,$4A,$86,
$7E,$94,$78,$4D,$3C,$83,$6C,$C8,$51,$24,$3C,$8B,$02,$B0,$73,$A0,$89,$E2,$D9,$07,
$18,$32,$6C,$EB,$CB,$B5,$0D,$34,$93,$EF,$4F,$6F,$FF,$ED,$C0,$7D,$06,$77,$55,$FE,
$3C,$EF,$E5,$AF,$D6,$B6,$97,$05,$D1,$A1,$AF,$5B,$66,$51,$3D,$36,$16,$D7,$E2,$0C,
$B3,$AB,$00,$F2,$6C,$41,$06,$D1,$E1,$D8,$38,$8C,$00,$FF,$45,$FB,$7F,$BB,$60,$B3,
$59,$B8,$BE,$F7,$B7,$48,$BF,$F1,$AF,$65,$27,$5C,$BF,$32,$D9,$E7,$48,$64,$3F,$B7,
$7D,$45,$20,$9C,$48,$1A,$86,$D1,$98,$66,$9C,$68,$9F,$68,$82,$94,$44,$22,$91,$7C,
$85,$68,$88,$44,$93,$00,$76,$B5,$AB,$F8,$5B,$F4,$61,$2D,$BB,$38,$B6,$48,$B2,$AA,
$E7,$53,$FC,$8F,$6F,$3F,$28,$F5,$D9,$A1,$C8,$AA,$7D,$79,$1E,$5D,$AB,$E6,$EB,$58,
$74,$2D,$4F,$89,$49,$57,$8B,$E7,$B5,$9F,$F8,$B6,$E2,$53,$1E,$57,$ED,$AF,$D3,$87,
$9F,$7A,$6F,$D5,$FE,$E3,$47,$55,$FB,$9B,$E2,$F9,$6F,$8A,$FD,$2F,$B0,$BF,$24,$20,
$35,$30,$25,$A9,$2E,$00,$3F,$72,$C6,$03,$9B,$03,$1B,$CF,$CE,$B0,$C5,$B2,$43,$10,
$EC,$7C,$2A,$34,$F5,$DD,$C9,$B3,$B3,$D6,$89,$41,$38,$E4,$91,$1B,$96,$66,$B5,$02,
$78,$ED,$25,$16,$E1,$01,$65,$03,$7B,$4C,$36,$04,$0D,$7A,$70,$1E,$4C,$67,$1D,$60,
$47,$96,$AA,$15,$ED,$9D,$DA,$62,$67,$5A,$15,$ED,$05,$B7,$63,$E6,$19,$32,$1D,$61,
$21,$58,$A0,$41,$1A,$92,$BE,$5A,$C3,$75,$F1,$96,$6D,$27,$00,$06,$F8,$62,$00,$C8,
$D0,$CB,$E2,$CD,$BF,$00,$00,$00,$00,$CF,$64,$D1,$24,$D3,$E3,$EA,$91,$E8,$6C,$E6,
$18,$E4,$CC,$E3,$90,$E1,$3A,$9F,$76,$9D,$A8,$98,$8C,$9A,$D6,$0D,$D9,$D9,$90,$10,
$1B,$96,$C7,$33,$00,$F4,$2B,$81,$0F,$5C,$CC,$FA,$17,$C6,$C7,$F5,$03,$96,$03,$6A,
$91,$9C,$83,$B2,$D1,$F0,$0F,$1C,$D2,$22,$91,$48,$0E,$F5,$21,$69,$DC,$E4,$DD,$F1,
$91,$48,$13,$69,$E9,$C4,$4B,$30,$CE,$91,$CD,$6D,$00,$80,$68,$22,$EC,$3D,$27,$5F,
$5F,$5F,$5F,$5C,$5E,$59,$43,$41,$47,$4A,$6F,$65,$0D,$CC,$93,$60,$40,$AC,$39,$BF,
$86,$29,$4D,$00,$04,$E4,$70,$77,$68,$63,$20,$28,$34,$3D,$6C,$9A,$20,$2C,$0F,$0C,
$E1,$07,$25,$B0,$4B,$69,$18,$D0,$CC,$BF,$F4,$E6,$05,$E4,$11,$34,$91,$26,$8F,$13,
$43,$F1,$85,$76,$1C,$E6,$32,$D2,$7E,$CD,$0A,$CF,$88,$5C,$36,$91,$88,$CE,$FF,$23,
$F1,$31,$AC,$84,$4D,$24,$92,$C3,$6E,$7E,$D8,$9C,$11,$0B,$48,$0A,$8F,$34,$77,$87,
$87,$EE,$8E,$28,$9C,$D4,$C8,$91,$AC,$41,$BA,$02,$20,$91,$48,$A0,$70,$00,$6D,$3C,
$6A,$D8,$79,$4A,$81,$A8,$35,$A6,$0A,$C0,$80,$CB,$AE,$23,$3E,$61,$3A,$8F,$90,$E3,
$4E,$64,$C5,$D5,$81,$34,$3E,$A0,$48,$13,$2C,$6D,$B1,$46,$F8,$91,$0C,$D6,$DF,$95,
$1E,$A4,$0B,$2B,$A7,$B1,$EC,$37,$1C,$53,$33,$F4,$3E,$46,$DC,$3A,$E0,$35,$70,$74,
$40,$30,$0A,$11,$00,$01,$1B,$A0,$D2,$6C,$16,$04,$A6,$C9,$20,$C8,$28,$3E,$05,$60,
$F1,$F7,$83,$2E,$AF,$BF,$2C,$00,$10,$48,$F4,$02,$30,$3B,$16,$ED,$C2,$3E,$A1,$7D,
$91,$35,$03,$00,$00,$73,$A7,$31,$B0,$CF,$76,$01,$D5,$47,$95,$63,$A9,$07,$9D,$64,
$03,$33,$A1,$7E,$91,$2F,$A0,$E1,$98,$94,$73,$AC,$EC,$39,$F0,$E2,$FF,$8D,$98,$84,
$27,$C1,$EF,$83,$36,$57,$5D,$F9,$0D,$AB,$AC,$AC,$90,$3C,$DE,$61,$1E,$12,$09,$7C,
$88,$E4,$50,$E5,$AD,$B2,$33,$5F,$A8,$0B,$B4,$0D,$78,$4E,$57,$49,$A3,$35,$4A,$4A,
$C9,$39,$F9,$D6,$B3,$AB,$3C,$A3,$F8,$16,$22,$5D,$C9,$F5,$EA,$4E,$D7,$00,$3B,$99,
$CD,$5F,$0A,$11,$05,$F9,$0C,$8C,$67,$EA,$BC,$CC,$51,$C3,$11,$5F,$34,$F4,$70,$61,
$02,$8F,$81,$F9,$F8,$1C,$3B,$78,$41,$F2,$85,$CF,$0F,$79,$33,$7D,$EF,$3C,$06,$7E,
$1E,$6E,$16,$AE,$22,$60,$76,$5C,$3A,$E2,$1A,$C5,$F6,$E2,$C7,$9E,$9D,$38,$06,$59,
$CB,$F9,$5A,$A6,$61,$80,$6D,$F4,$7B,$C2,$38,$42,$4B,$C5,$C7,$CA,$F7,$B4,$73,$3B,
$9A,$DF,$57,$0C,$80,$C1,$D5,$2C,$D1,$87,$4E,$81,$C4,$D6,$37,$CF,$BA,$A9,$B0,$FD,
$DE,$AF,$9F,$E7,$ED,$3C,$94,$81,$B1,$80,$80,$88,$0F,$85,$31,$52,$C8,$05,$0C,$EC,
$4B,$8C,$02,$F8,$E3,$49,$00,$F8,$18,$F1,$A1,$EC,$70,$AB,$80,$C8,$EF,$84,$79,$03,
$D6,$18,$00,$00,$00,$00,$E1,$C3,$EA,$D4,$7D,$36,$66,$E7,$9B,$14,$06,$28,$ED,$9B,
$B4,$A7,$A5,$32,$D5,$23,$40,$6B,$55,$44,$FF,$9C,$EE,$8B,$69,$76,$97,$59,$68,$D8,
$05,$00,$12,$21,$FE,$6C,$61,$E8,$5D,$95,$6B,$69,$2E,$49,$54,$12,$3C,$10,$00,$80,
$98,$15,$C8,$E1,$F2,$89,$D4,$1F,$D7,$0A,$54,$AB,$5E,$8F,$0F,$08,$A9,$DB,$34,$F3,
$00,$00,$00,$00,$94,$AB,$13,$19,$1B,$A5,$0B,$DB,$38,$E6,$60,$7F,$A3,$E1,$12,$B4,
$DA,$98,$B4,$75,$B5,$1B,$EF,$CB,$FB,$FD,$53,$66,$B9,$1D,$69,$3C,$10,$01,$00,$00,
$92,$51,$B4,$80,$8B,$74,$F3,$FB,$E4,$93,$90,$52,$B2,$9F,$C4,$DA,$0F,$A3,$53,$FE,
$17,$84,$F8,$12,$55,$90,$4B,$08,$22,$00,$00,$60,$1D,$0A,$A7,$81,$18,$80,$47,$B5,
$C5,$B4,$36,$E8,$EE,$23,$E1,$7B,$1B,$2C,$A4,$28,$63,$22,$B0,$21,$9A,$E7,$E8,$FD,
$4A,$40,$00,$22,$00,$00,$82,$05,$CF,$22,$85,$08,$DE,$69,$52,$4A,$D6,$0A,$9D,$DD,
$DC,$A3,$FF,$D5,$42,$F3,$2F,$4D,$43,$CE,$2B,$74,$48,$00,$00,$44,$00,$0C,$59,$0F,
$99,$64,$33,$5C,$A5,$E2,$E6,$1F,$AF,$D7,$4B,$EE,$42,$C3,$87,$28,$DF,$65,$F0,$BD,
$DE,$2E,$D2,$5E,$00,$00,$00,$00,$3A,$4F,$9D,$7E,$28,$A1,$C5,$4A,$0A,$DC,$C7,$0A,
$CD,$C2,$D7,$F0,$21,$45,$E4,$47,$73,$A8,$F8,$A7,$FF,$A8,$22,$E3,$3E,$CD,$D3,$29,
$00,$00,$00,$00,$38,$E3,$BB,$84,$2A,$1F,$FE,$5B,$F4,$F1,$4E,$13,$20,$C4,$72,$B7,
$34,$AE,$63,$3E,$DB,$B4,$14,$5D,$DC,$0C,$46,$B7,$13,$E6,$7A,$EA,$3A,$DC,$01,$00,
$54,$4D,$AF,$4C,$0F,$15,$B5,$53,$92,$61,$94,$8F,$51,$95,$FB,$94,$70,$CF,$0E,$00,
$31,$A0,$9B,$07,$9A,$DA,$05,$6F,$63,$E1,$21,$86,$44,$7A,$06,$50,$4B,$97,$BB,$A6,
$21,$04,$94,$EE,$AB,$B0,$16,$BC,$D2,$00,$E9,$51,$00,$3F,$D4,$0E,$91,$EC,$8F,$33,
$92,$5B,$AA,$2F,$EC,$68,$03,$00,$9A,$67,$83,$64,$88,$FF,$31,$66,$01,$C5,$B8,$71,
$18,$92,$45,$76,$D0,$7C,$D3,$B4,$8E,$64,$C4,$7A,$9A,$6F,$01,$00,$69,$30,$4A,$AD,
$D9,$99,$55,$40,$B9,$2F,$74,$EE,$7F,$29,$47,$89,$00,$00,$00,$88,$7A,$B4,$8D,$06,
$36,$15,$FF,$15,$9B,$07,$2D,$D9,$12,$09,$33,$E1,$7F,$71,$E3,$4B,$C0,$6E,$0C,$22,
$58,$F8,$FE,$D7,$A6,$A9,$61,$A8,$97,$94,$DB,$B3,$0F,$DB,$37,$31,$FC,$8E,$CF,$4F,
$A2,$70,$FF,$03,$EC,$36,$18,$03,$C0,$66,$00,$1C,$01,$14,$38,$0E,$00,$09,$00,$0E,
$30,$07,$0C,$10,$25,$0D,$13,$33,$36,$30,$3A,$D3,$75,$07,$3D,$15,$3B,$32,$32,$35,
$F6,$5D,$2D,$33,$02,$2B,$1C,$55,$30,$D4,$18,$3D,$22,$11,$00,$DC,$A9,$8F,$33,$01,
$6F,$6A,$5D,$43,$62,$5D,$46,$56,$53,$55,$60,$56,$99,$46,$29,$5D,$47,$50,$BA,$00,
$9F,$7F,$55,$45,$5A,$68,$78,$72,$6F,$06,$1C,$D4,$8D,$52,$78,$73,$64,$4D,$62,$79,
$C0,$22,$9E,$83,$54,$0C,$28,$7A,$54,$8C,$92,$BE,$82,$B1,$91,$07,$68,$24,$6F,$85,
$95,$A6,$87,$EF,$3A,$7D,$9B,$87,$5B,$9C,$09,$85,$B7,$8E,$92,$BD,$B7,$0B,$5D,$93,
$47,$82,$AC,$8F,$A9,$A8,$01,$11,$2C,$61,$BA,$BB,$8D,$D0,$DA,$C8,$D0,$A0,$70,$A2,
$52,$E2,$40,$98,$43,$CE,$D8,$C2,$E8,$D0,$F2,$CA,$F3,$CA,$C6,$C4,$A2,$48,$59,$0D,
$E3,$F7,$FF,$EF,$CB,$E3,$F8,$F1,$E4,$53,$89,$A0,$8D,$F4,$2A,$46,$D5,$30,$FC,$D4,
$E7,$13,$50,$5F,$E5,$6D,$16,$C9,$9A,$33,$4C,$D6,$36,$17,$27,$03,$02,$13,$86,$0D,
$59,$1C,$3C,$2F,$30,$17,$26,$20,$BA,$53,$6C,$86,$A6,$AC,$54,$0C,$22,$3D,$4C,$E6,
$63,$4D,$1F,$F4,$86,$F1,$24,$DB,$CA,$6C,$57,$20,$BA,$CA,$14,$F3,$8B,$AA,$32,$C9,
$B6,$38,$47,$9A,$47,$3C,$EE,$9C,$CA,$33,$BE,$ED,$D6,$26,$2A,$3F,$EC,$07,$4A,$70,
$2A,$D4,$D3,$F1,$14,$FD,$D1,$D2,$C2,$22,$3D,$13,$C7,$CE,$D4,$E6,$47,$95,$46,$01,
$FD,$E5,$F8,$CB,$C7,$DB,$CE,$E2,$DC,$84,$B5,$1E,$64,$8C,$A3,$BD,$23,$01,$27,$03,
$78,$76,$3D,$2A,$0B,$1A,$1C,$68,$C8,$AE,$2D,$1A,$8B,$DA,$F6,$57,$1F,$55,$03,$57,
$01,$A8,$39,$EA,$6B,$0B,$E8,$54,$5C,$27,$8B,$44,$67,$73,$56,$2C,$3A,$00,$5E,$7D,
$1C,$C1,$B0,$6A,$BB,$86,$0A,$64,$E5,$8F,$AE,$88,$45,$D6,$A0,$8D,$15,$B6,$7C,$B6,
$8D,$AD,$23,$52,$89,$41,$CE,$F6,$0D,$D7,$EB,$87,$AB,$96,$75,$C5,$C5,$A4,$99,$A9,
$15,$FF,$C7,$E7,$2B,$E4,$F0,$6F,$2D,$51,$29,$D1,$CE,$53,$BD,$0C,$74,$09,$DB,$34,
$3F,$25,$37,$4F,$C3,$29,$AB,$21,$3A,$A0,$8B,$CD,$A5,$53,$6F,$E1,$79,$EB,$A1,$7A,
$53,$58,$93,$6F,$67,$53,$4E,$FD,$34,$D1,$3D,$7D,$D4,$A1,$92,$72,$A2,$1E,$CF,$5E,
$0E,$57,$A2,$1E,$AC,$2C,$ED,$AD,$D4,$85,$61,$03,$1E,$F1,$9B,$66,$9F,$23,$3A,$C3,
$C6,$9A,$82,$AF,$D0,$D5,$C3,$59,$E6,$39,$55,$8A,$7D,$B9,$A5,$A6,$F9,$25,$23,$E4,
$45,$91,$2D,$F4,$C1,$E8,$35,$F3,$92,$A2,$17,$66,$BA,$33,$0B,$48,$52,$8A,$EF,$1D,
$29,$08,$F4,$31,$D3,$42,$18,$17,$53,$2C,$AD,$EB,$20,$74,$4B,$0C,$4E,$5B,$6D,$2E,
$E7,$61,$99,$4B,$C4,$23,$72,$71,$43,$7B,$89,$66,$1A,$95,$66,$93,$B1,$04,$9D,$86,
$83,$93,$59,$27,$5D,$0D,$A7,$69,$3D,$1A,$0D,$38,$A6,$25,$2D,$AF,$A2,$98,$E6,$CE,
$47,$A3,$B7,$32,$CF,$C4,$AF,$16,$C0,$44,$6A,$7C,$AF,$29,$2F,$11,$CA,$02,$11,$B8,
$4E,$05,$44,$30,$08,$19,$F3,$41,$34,$F8,$25,$2C,$01,$1B,$12,$3E,$CF,$D0,$AC,$9B,
$23,$1E,$9D,$A0,$36,$9B,$E2,$16,$AC,$79,$C3,$2B,$5C,$34,$07,$93,$56,$5A,$6D,$24,
$07,$A8,$45,$BC,$A7,$2D,$33,$B6,$B8,$27,$07,$15,$89,$94,$C0,$63,$93,$92,$57,$E2,
$D0,$B8,$2A,$E2,$D0,$A4,$86,$18,$6B,$B2,$48,$C8,$B3,$67,$4B,$A3,$AA,$CD,$52,$89,
$F5,$A1,$F2,$50,$27,$5E,$CC,$15,$34,$22,$FD,$C4,$C7,$C5,$56,$F3,$4E,$2A,$DA,$CC,
$68,$5D,$61,$49,$EA,$CC,$2F,$9B,$D2,$58,$5F,$16,$B5,$E8,$28,$B7,$41,$49,$14,$08,
$E1,$A3,$B0,$8D,$1C,$1E,$00,$09,$19,$1B,$9D,$36,$88,$93,$11,$06,$17,$59,$88,$B5,
$48,$00,$98,$50,$7E,$A9,$0A,$00,$40,$62,$0C,$AE,$4E,$B4,$83,$93,$2C,$FB,$EF,$7F,
$77,$26,$65,$58,$46,$5D,$0D,$4A,$3D,$64,$54,$F8,$08,$4F,$47,$AF,$3A,$D6,$10,$3F,
$31,$9E,$A3,$1D,$A2,$3A,$55,$0E,$7D,$73,$36,$62,$7A,$31,$CB,$00,$20,$12,$07,$41,
$53,$29,$4A,$42,$26,$4C,$4A,$45,$47,$42,$54,$BA,$BA,$00,$10,$91,$73,$B8,$D8,$A1,
$A7,$A1,$A0,$D3,$F1,$C3,$2F,$B0,$B0,$67,$D7,$CE,$C7,$ED,$7D,$07,$16,$9F,$EF,$19,
$70,$61,$18,$1D,$00,$BB,$55,$B0,$D2,$81,$24,$72,$83,$83,$5E,$65,$84,$10,$01,$EA,
$F4,$46,$02,$E0,$05,$3A,$62,$44,$F8,$B0,$A0,$49,$BF,$80,$8D,$00,$00,$C8,$BC,$43,
$36,$F2,$B7,$6B,$40,$E9,$C5,$A3,$B6,$CA,$B7,$73,$48,$10,$C1,$40,$81,$5E,$07,$F2,
$29,$48,$AB,$62,$B7,$49,$78,$C1,$9A,$1E,$77,$9F,$01,$00,$00,$9D,$A9,$4B,$A3,$44,
$EB,$4A,$1E,$97,$A8,$D3,$AC,$67,$FA,$9F,$B0,$62,$FE,$87,$B4,$88,$F3,$69,$00,$A0,
$64,$00,$A5,$70,$43,$FE,$08,$9F,$39,$F1,$4B,$64,$00,$AF,$15,$B3,$99,$78,$AE,$AE,
$7D,$EA,$AF,$9A,$03,$00,$00,$E9,$AB,$6C,$4C,$A4,$EC,$20,$59,$9E,$8A,$A7,$04,$04,
$05,$36,$5F,$09,$6A,$83,$3F,$7A,$56,$1F,$AA,$74,$81,$5D,$74,$40,$F4,$AE,$45,$2D,
$C3,$72,$8A,$59,$6E,$75,$B6,$0C,$00,$88,$20,$78,$5B,$0F,$E5,$08,$29,$F6,$F5,$32,
$7D,$4E,$D0,$BC,$78,$04,$1F,$34,$1D,$72,$2E,$A4,$29,$20,$25,$2F,$28,$7A,$13,$7D,
$31,$1E,$97,$E9,$F7,$1D,$44,$00,$9B,$A3,$BE,$B5,$EB,$EA,$22,$03,$14,$65,$2E,$8F,
$E3,$8E,$63,$05,$A0,$EB,$07,$B1,$48,$03,$6F,$CA,$08,$67,$81,$3E,$00,$88,$51,$A1,
$CF,$E5,$29,$3A,$F2,$BC,$81,$05,$CB,$A9,$F4,$9B,$E6,$6E,$28,$21,$0A,$35,$0E,$C1,
$03,$13,$58,$68,$51,$83,$B7,$2E,$2A,$EB,$3B,$52,$53,$52,$00,$17,$3D,$17,$3E,$DB,
$57,$58,$9F,$9C,$AF,$67,$A6,$B2,$5A,$43,$05,$1D,$18,$00,$00,$0E,$35,$45,$BF,$FB,
$86,$32,$F8,$CF,$49,$C1,$8C,$AB,$39,$FD,$88,$8B,$AD,$62,$FD,$0E,$33,$7A,$D2,$88,
$B1,$4B,$45,$00,$11,$89,$17,$DF,$85,$9B,$50,$C6,$C3,$1F,$A5,$91,$64,$89,$80,$3A,
$95,$E9,$0B,$FF,$AA,$62,$9F,$F2,$56,$71,$CA,$BC,$54,$32,$A9,$01,$50,$3E,$5D,$74,
$78,$F4,$DE,$4A,$66,$29,$62,$86,$49,$EF,$CA,$A6,$86,$67,$67,$65,$EB,$5F,$1C,$60,
$F7,$94,$D5,$5D,$BC,$93,$56,$92,$03,$02,$06,$03,$00,$84,$DA,$DA,$3C,$38,$B9,$09,
$60,$6B,$3F,$5E,$CB,$6B,$1A,$19,$FA,$39,$D3,$EA,$18,$50,$A3,$B4,$DE,$30,$BD,$71,
$33,$BA,$EC,$94,$C6,$70,$5A,$AB,$C5,$21,$0A,$EA,$A7,$65,$D2,$98,$22,$D2,$E5,$27,
$B3,$48,$A0,$E5,$B8,$E8,$E3,$C2,$5D,$50,$F2,$E3,$E2,$32,$73,$D7,$5B,$97,$40,$90,
$1A,$16,$FC,$2B,$70,$BF,$CC,$40,$DA,$8F,$12,$75,$CF,$F4,$CA,$EA,$6C,$F6,$ED,$D5,
$2A,$85,$5F,$62,$E1,$25,$70,$FD,$42,$DC,$0A,$09,$18,$D8,$DC,$29,$C4,$B0,$5A,$1F,
$3B,$34,$3D,$AB,$AF,$91,$9E,$2E,$9B,$A5,$A4,$53,$B1,$A0,$E4,$E0,$6C,$40,$A4,$66,
$44,$AC,$BA,$B3,$6A,$FE,$20,$16,$97,$E0,$9B,$44,$C6,$4C,$A1,$FF,$C9,$74,$12,$53,
$D1,$7C,$9A,$69,$11,$83,$C1,$02,$42,$9F,$05,$5A,$07,$48,$63,$12,$D0,$EA,$E2,$E0,
$35,$FD,$8B,$A8,$5C,$A9,$17,$EC,$1E,$C7,$DF,$EE,$54,$00,$1A,$54,$4D,$49,$28,$0D,
$2B,$53,$41,$4F,$65,$5F,$B7,$4F,$03,$BF,$15,$1D,$A1,$23,$12,$B5,$9F,$20,$2F,$B1,
$45,$54,$C1,$E8,$05,$C4,$B7,$EE,$B1,$38,$14,$B0,$F3,$47,$0A,$89,$5D,$E2,$EE,$2A,
$C1,$2D,$69,$96,$5D,$10,$E0,$E5,$27,$F3,$A9,$23,$B2,$1E,$A0,$DD,$9E,$2F,$F5,$98,
$5F,$14,$B3,$4B,$C8,$8A,$56,$50,$F0,$B3,$4B,$00,$00,$00,$20,$ED,$E6,$61,$87,$25,
$F0,$B0,$A4,$61,$84,$FA,$18,$2D,$97,$21,$0D,$63,$05,$01,$C7,$4A,$F6,$31,$89,$19,
$8D,$C1,$48,$DC,$98,$D5,$BC,$EC,$60,$A8,$95,$88,$6B,$04,$69,$20,$B4,$EB,$98,$0C,
$C2,$58,$00,$95,$E4,$01,$94,$96,$44,$4D,$EF,$8D,$85,$D5,$65,$4D,$93,$C7,$34,$D6,
$21,$DD,$19,$C5,$34,$4D,$D3,$34,$01,$AD,$E9,$B5,$F1,$79,$8C,$DB,$D3,$AD,$05,$D5,
$11,$64,$4D,$D3,$34,$DD,$19,$35,$71,$36,$91,$1C,$26,$DD,$9D,$EB,$D2,$62,$B7,$E1,
$93,$C3,$9C,$0D,$39,$F4,$3E,$2B,$80,$41,$6A,$7A,$6E,$E5,$11,$45,$DC,$BF,$2B,$89,
$60,$02,$E6,$79,$86,$FC,$B8,$0D,$80,$C3,$75,$6C,$AA,$F4,$A6,$2C,$20,$FC,$53,$EA,
$B2,$BF,$00,$F1,$ED,$6B,$BF,$F2,$78,$2D,$35,$1E,$A1,$1F,$FA,$34,$B4,$0C,$02,$C0,
$64,$AA,$D6,$D3,$D2,$2F,$00,$0C,$6C,$6C,$D8,$FE,$A5,$39,$19,$E2,$7D,$A0,$37,$25,
$D3,$7C,$DF,$0D,$3A,$55,$AD,$6A,$A7,$98,$46,$3C,$C8,$99,$DE,$2A,$BE,$78,$7A,$78,
$B2,$58,$68,$18,$80,$4C,$1A,$BF,$42,$35,$73,$0D,$7C,$31,$23,$69,$7B,$D9,$65,$85,
$73,$11,$DB,$63,$B4,$7C,$55,$47,$18,$C4,$67,$9A,$86,$46,$39,$58,$75,$48,$24,$92,
$15,$21,$8E,$7F,$8B,$A7,$8B,$15,$A7,$F2,$93,$CB,$81,$B8,$72,$8D,$C4,$C1,$B3,$AF,
$B5,$EF,$6B,$15,$C9,$C3,$AF,$D5,$AE,$F1,$34,$EC,$6D,$D5,$A1,$C7,$71,$41,$F9,$6D,
$9A,$69,$41,$5C,$C3,$00,$F7,$90,$CD,$21,$E0,$24,$79,$2F,$75,$19,$49,$29,$FB,$2F,
$01,$18,$B5,$F9,$3C,$31,$3A,$42,$A3,$E9,$44,$22,$69,$BC,$65,$BE,$F9,$B3,$55,$1D,
$C6,$C5,$39,$A8,$D0,$59,$00,$3C,$C6,$E5,$DB,$D1,$2D,$1E,$1A,$09,$0A,$77,$65,$78,
$61,$F8,$01,$1C,$AA,$E2,$DA,$24,$A3,$D8,$EC,$00,$10,$E9,$EB,$8B,$E5,$8D,$61,$73,
$D7,$1C,$63,$10,$61,$4F,$42,$49,$1A,$C0,$DF,$68,$5F,$5A,$6F,$70,$58,$4F,$4D,$78,
$4F,$5D,$7B,$06,$49,$04,$68,$51,$41,$4E,$67,$53,$52,$70,$6C,$71,$68,$6E,$7A,$20,
$25,$00,$00,$00,$FE,$92,$23,$D1,$51,$12,$8F,$4C,$4C,$9F,$25,$0A,$F2,$44,$7B,$20,
$9B,$4C,$52,$47,$E1,$06,$20,$C8,$B5,$49,$00,$00,$00,$00,$8F,$34,$00,$9C,$54,$F1,
$43,$65,$EC,$30,$51,$C3,$0E,$96,$AF,$66,$DA,$22,$B2,$76,$72,$8B,$CF,$32,$BB,$88,
$74,$C8,$4D,$EF,$96,$7F,$01,$00,$00,$00,$91,$08,$58,$62,$E5,$C5,$37,$B4,$72,$63,
$05,$D2,$2C,$6A,$81,$6C,$19,$DE,$99,$FD,$9F,$11,$D6,$8C,$E6,$EC,$F4,$FF,$E8,$88,
$89,$4C,$82,$6A,$6E,$91,$C2,$8D,$07,$B8,$1C,$45,$87,$C1,$C4,$DF,$A5,$C7,$CC,$CC,
$22,$26,$E1,$86,$B0,$F0,$FE,$48,$7B,$9A,$06,$EC,$FF,$AC,$95,$DD,$BC,$DD,$EC,$C8,
$EA,$CD,$CF,$43,$C3,$B2,$B6,$8B,$8F,$D2,$1E,$4D,$4B,$14,$B4,$19,$41,$5A,$1B,$01,
$C5,$4D,$AF,$C6,$16,$5C,$44,$05,$41,$B5,$29,$0F,$0D,$5B,$B6,$A3,$D6,$81,$1E,$09,
$7B,$D0,$A6,$A8,$55,$87,$C3,$C7,$3F,$31,$2A,$29,$30,$E0,$51,$8A,$C2,$06,$4B,$4E,
$7A,$7C,$A0,$00,$CF,$D0,$65,$5C,$4E,$56,$6E,$43,$46,$47,$B7,$39,$2F,$93,$43,$67,
$6E,$50,$B2,$68,$CC,$73,$35,$1C,$76,$CB,$79,$DA,$A0,$6E,$7B,$44,$C7,$46,$77,$B9,
$8C,$51,$36,$13,$35,$B7,$95,$8C,$9A,$36,$65,$2B,$D2,$92,$A0,$93,$73,$86,$94,$11,
$B5,$96,$87,$96,$B0,$BB,$B3,$4E,$43,$14,$9E,$9D,$A7,$55,$23,$82,$AA,$BF,$0F,$B8,
$4C,$1B,$51,$72,$59,$4C,$F9,$DE,$C5,$3D,$35,$C0,$68,$D5,$C7,$C6,$CF,$F6,$D0,$CD,
$C5,$59,$2A,$33,$A1,$F7,$38,$54,$EC,$71,$CD,$3C,$8F,$32,$1E,$02,$1A,$4B,$4B,$BD,
$31,$0F,$36,$98,$DE,$B9,$1E,$FA,$5E,$06,$76,$06,$30,$2F,$EF,$6C,$27,$28,$23,$23,
$A3,$E5,$56,$1D,$53,$8C,$E5,$9C,$E9,$67,$F9,$8A,$AB,$14,$73,$71,$47,$8A,$2E,$C2,
$E2,$6F,$6D,$72,$B7,$1C,$DF,$2A,$A9,$1A,$A5,$44,$AD,$9D,$81,$ED,$F3,$1C,$87,$B9,
$C6,$34,$53,$06,$D5,$84,$BE,$CB,$A2,$8E,$A5,$B3,$D0,$9B,$DE,$C6,$89,$FD,$D4,$E9,
$CF,$C5,$ED,$DC,$46,$4F,$5A,$35,$70,$05,$9A,$80,$D2,$F1,$F9,$E9,$F7,$30,$1E,$03,
$0F,$D5,$D7,$C2,$D2,$DD,$86,$86,$5D,$14,$A7,$D2,$D3,$F7,$FD,$EB,$F8,$B9,$A4,$2A,
$22,$5F,$15,$44,$E3,$07,$9F,$1D,$03,$75,$1C,$4A,$40,$41,$6D,$31,$B7,$ED,$21,$0D,
$00,$2A,$08,$8C,$2B,$91,$FE,$09,$16,$F0,$C4,$6C,$16,$35,$24,$7B,$DC,$2B,$6A,$0B,
$23,$39,$5B,$A6,$55,$75,$33,$86,$03,$9B,$E2,$4C,$54,$F4,$01,$E9,$97,$1D,$32,$63,
$FF,$45,$05,$1F,$B7,$B2,$FC,$7B,$80,$40,$61,$F2,$46,$68,$26,$E3,$19,$00,$00,$00,
$E1,$F1,$E0,$D5,$84,$CF,$D4,$D6,$CD,$C8,$F9,$DF,$DA,$D8,$AC,$CF,$D5,$DF,$FA,$CF,
$D3,$CF,$CC,$EC,$CC,$DC,$6B,$00,$00,$00,$E8,$C3,$CC,$55,$E4,$D9,$61,$9E,$39,$C1,
$A1,$B2,$95,$9C,$BD,$A0,$B3,$0B,$79,$E9,$38,$AD,$95,$82,$BB,$88,$AB,$BF,$00,$80,
$48,$C2,$8A,$BE,$BF,$16,$80,$A6,$E3,$BA,$B2,$AF,$B2,$AA,$D7,$81,$97,$8A,$A1,$C4,
$B4,$4A,$01,$8C,$AB,$9C,$98,$82,$9A,$98,$BF,$12,$06,$00,$00,$82,$85,$8A,$A2,$9D,
$92,$85,$89,$86,$A9,$79,$7B,$67,$79,$5C,$5C,$6F,$5B,$7F,$7E,$72,$7A,$61,$12,$94,
$08,$78,$76,$69,$61,$7F,$7B,$75,$44,$C9,$00,$00,$A0,$74,$7A,$40,$5D,$F3,$77,$3F,
$56,$2B,$5B,$83,$58,$58,$40,$59,$03,$78,$2F,$57,$51,$C7,$45,$0F,$00,$40,$4B,$5B,
$4D,$72,$5C,$59,$57,$76,$60,$4F,$63,$4F,$41,$4C,$38,$3E,$3D,$9E,$A1,$20,$65,$00,
$31,$18,$3B,$1D,$3F,$66,$3C,$32,$07,$29,$FB,$0F,$2B,$ED,$3C,$A2,$16,$57,$08,$07,
$38,$A1,$64,$12,$00,$00,$74,$3F,$03,$3D,$1F,$12,$14,$04,$32,$02,$09,$03,$15,$06,
$03,$1E,$25,$51,$0B,$18,$16,$15,$61,$40,$D4,$00,$09,$08,$0D,$21,$26,$09,$22,$C1,
$9A,$EF,$CC,$D7,$F5,$F1,$F1,$2C,$55,$04,$23,$F9,$F7,$F9,$00,$51,$2F,$64,$D6,$83,
$FD,$AD,$E4,$EF,$78,$C4,$8D,$AE,$42,$AE,$29,$8F,$BA,$05,$BB,$97,$CC,$64,$69,$B6,
$E9,$B7,$2F,$49,$0F,$73,$F1,$61,$45,$DA,$1E,$11,$A3,$A8,$02,$AF,$49,$F1,$31,$00,
$80,$94,$9E,$C2,$98,$9B,$AB,$C6,$8E,$8F,$B5,$09,$9A,$99,$9A,$9B,$9A,$A1,$9C,$2A,
$D1,$B2,$71,$9B,$88,$F7,$CB,$A8,$14,$15,$B4,$F3,$DD,$92,$28,$4C,$49,$5C,$B8,$B3,
$73,$2D,$67,$22,$00,$66,$55,$66,$32,$7B,$3C,$D6,$64,$34,$6D,$3C,$60,$05,$99,$2E,
$E7,$E6,$75,$32,$16,$43,$50,$7A,$5D,$7E,$01,$5A,$6F,$E6,$97,$A2,$80,$40,$2F,$38,
$01,$0A,$29,$52,$71,$3D,$00,$39,$1A,$52,$94,$33,$44,$1D,$88,$33,$C6,$70,$17,$B0,
$40,$88,$2A,$0B,$26,$2F,$11,$2D,$06,$22,$B0,$6D,$27,$C8,$91,$15,$8E,$11,$14,$17,
$B8,$80,$BC,$B5,$18,$1B,$1E,$0A,$09,$1C,$17,$32,$94,$96,$65,$00,$07,$36,$15,$8D,
$8E,$3E,$17,$17,$55,$3C,$F4,$F0,$E4,$49,$E3,$29,$6C,$A0,$AF,$E2,$9C,$91,$22,$5E,
$E0,$50,$A5,$1B,$C0,$1E,$B4,$DB,$1C,$A1,$D3,$F6,$D1,$D6,$E3,$55,$9A,$46,$DA,$82,
$6E,$DA,$21,$CC,$E7,$C1,$CB,$C6,$64,$6D,$D7,$8A,$BA,$BC,$7A,$2A,$41,$A5,$28,$B8,
$DF,$1E,$2A,$21,$CA,$51,$A5,$92,$AD,$9E,$E2,$49,$A9,$CD,$25,$C5,$0D,$FA,$64,$A0,
$D9,$CA,$D8,$06,$38,$B2,$03,$18,$92,$87,$A4,$76,$96,$C8,$51,$A2,$30,$F0,$7F,$6F,
$72,$1A,$FA,$6D,$03,$A9,$1D,$80,$94,$75,$EE,$19,$7A,$6C,$6D,$E8,$7A,$61,$5D,$83,
$B0,$99,$3C,$AA,$60,$5C,$5F,$46,$75,$02,$80,$41,$C6,$51,$55,$7A,$5C,$0A,$10,$0A,
$D8,$E5,$95,$45,$29,$1B,$77,$84,$D7,$F9,$7D,$86,$2B,$50,$05,$54,$3B,$25,$34,$34,
$CA,$3A,$54,$74,$2B,$22,$20,$26,$41,$07,$8E,$40,$3C,$2F,$31,$25,$2B,$34,$4A,$51,
$35,$26,$1D,$19,$00,$BA,$1A,$67,$B9,$A6,$4A,$1B,$71,$03,$17,$40,$08,$41,$6B,$CF,
$12,$13,$13,$CF,$42,$DD,$2E,$3D,$F1,$E0,$E8,$F5,$50,$3E,$C8,$50,$47,$B8,$D9,$9B,
$C4,$CB,$F0,$E4,$FB,$8D,$44,$2D,$79,$A7,$E5,$CD,$DC,$5F,$8F,$0F,$2F,$A9,$F5,$8A,
$F5,$95,$AA,$74,$B9,$DB,$BC,$49,$75,$C5,$80,$A6,$77,$DC,$28,$8C,$CC,$90,$CE,$82,
$BA,$A5,$B0,$55,$23,$48,$1D,$FF,$DD,$B0,$E3,$B3,$D5,$48,$0D,$0B,$00,$00,$84,$86,
$EB,$91,$EE,$E3,$8B,$8B,$EF,$AE,$88,$B6,$B1,$EE,$5A,$91,$82,$14,$9C,$E8,$9E,$06,
$86,$35,$0B,$DE,$E4,$ED,$56,$56,$AF,$86,$97,$96,$0D,$AE,$4C,$D3,$8D,$8B,$C4,$2D,
$65,$71,$51,$28,$47,$E6,$25,$E5,$0C,$51,$A8,$70,$A3,$66,$3D,$61,$F2,$0E,$E0,$26,
$B7,$96,$D6,$87,$BC,$18,$B0,$C0,$96,$64,$49,$F0,$17,$B1,$B4,$9A,$0E,$71,$0E,$6F,
$C4,$B8,$41,$DE,$23,$AC,$DB,$11,$65,$28,$3C,$1D,$00,$1A,$1A,$1E,$56,$41,$D4,$00,
$AC,$60,$9E,$FF,$F5,$F2,$10,$70,$C3,$CA,$F2,$EF,$FF,$C4,$F4,$26,$AA,$30,$1F,$FD,
$E2,$67,$A6,$84,$1F,$BF,$61,$22,$C9,$F2,$FB,$8E,$7C,$90,$B3,$48,$B9,$C0,$98,$DA,
$FE,$D2,$D0,$F1,$01,$24,$AC,$CA,$93,$C9,$5C,$D5,$5A,$6C,$66,$B8,$C5,$9F,$BA,$CB,
$0F,$D3,$61,$BA,$D2,$EE,$92,$35,$CB,$5B,$48,$54,$9B,$FD,$C0,$8D,$6F,$51,$F6,$0E,
$F2,$87,$BA,$9F,$C9,$A1,$39,$49,$AC,$EA,$39,$4E,$A2,$53,$14,$1A,$36,$14,$D2,$83,
$B2,$5D,$C6,$40,$F2,$79,$D6,$E5,$98,$A0,$81,$FB,$51,$C1,$00,$40,$19,$DB,$49,$54,
$37,$6A,$30,$64,$4B,$20,$48,$53,$6C,$54,$71,$E5,$BD,$CB,$1A,$E2,$6A,$D8,$3B,$5B,
$7B,$80,$AA,$4B,$6E,$72,$07,$91,$9E,$4D,$38,$41,$65,$45,$63,$00,$00,$5A,$6E,$73,
$67,$42,$40,$7B,$46,$09,$17,$4B,$56,$4A,$75,$4C,$5F,$4F,$50,$25,$B8,$79,$2F,$1A,
$1B,$25,$30,$3B,$26,$63,$93,$34,$65,$0C,$2B,$28,$3C,$CD,$6B,$DB,$1E,$A9,$11,$8F,
$15,$C2,$20,$1C,$0F,$10,$45,$11,$91,$05,$3B,$B9,$10,$B9,$14,$4A,$5E,$4D,$7E,$22,
$54,$45,$9E,$2B,$03,$21,$2C,$01,$DA,$42,$E6,$F6,$5C,$7E,$8D,$9F,$5C,$25,$43,$8A,
$FB,$99,$EE,$BA,$5F,$25,$35,$29,$9A,$47,$A1,$C6,$AD,$D7,$DD,$2E,$80,$0E,$EE,$DD,
$C3,$F9,$D1,$CB,$DD,$CE,$C7,$BE,$31,$FB,$40,$89,$4D,$56,$C1,$C4,$DD,$2F,$95,$37,
$2D,$B8,$FB,$F0,$7C,$91,$DC,$16,$6B,$BD,$C9,$B0,$AB,$4C,$96,$B2,$EA,$81,$F7,$A6,
$15,$52,$D4,$11,$A2,$E9,$81,$23,$E4,$A1,$8A,$A1,$0D,$AF,$69,$8B,$7D,$21,$B3,$D0,
$B4,$3E,$96,$70,$D4,$90,$02,$E7,$B4,$AA,$3C,$B7,$CC,$8F,$14,$D7,$30,$E0,$8B,$74,
$45,$FB,$12,$E7,$6E,$78,$B5,$50,$32,$44,$78,$73,$F1,$73,$8F,$72,$46,$6D,$CC,$E6,
$8B,$0C,$A5,$54,$68,$EA,$DB,$1D,$94,$D6,$95,$FE,$C3,$5D,$79,$2A,$94,$F5,$23,$47,
$01,$46,$4E,$40,$26,$60,$BA,$86,$DD,$55,$43,$43,$4D,$48,$4A,$AB,$18,$77,$32,$EE,
$2A,$31,$52,$07,$A0,$F5,$30,$3A,$20,$33,$24,$3B,$21,$37,$3F,$B0,$A2,$01,$08,$20,
$0F,$05,$3C,$25,$20,$01,$2F,$14,$3F,$15,$A0,$95,$A3,$DA,$AF,$00,$48,$11,$80,$58,
$38,$11,$3F,$1A,$3A,$7E,$47,$03,$8C,$1E,$41,$97,$DF,$AE,$03,$10,$32,$18,$10,$33,
$DE,$0B,$5A,$76,$47,$84,$46,$48,$F4,$E1,$B7,$75,$48,$52,$F7,$C2,$8D,$83,$6C,$90,
$D2,$07,$80,$53,$FD,$E9,$EE,$EA,$CB,$C2,$F2,$C2,$7F,$C3,$AF,$F0,$D3,$C4,$D4,$1C,
$22,$1C,$D2,$CE,$CA,$C1,$C1,$CC,$E8,$FB,$98,$1E,$37,$62,$E2,$E5,$D4,$F6,$F3,$5E,
$C2,$43,$31,$83,$EB,$AD,$DF,$5E,$B0,$2C,$6D,$79,$83,$41,$84,$A1,$81,$A7,$AA,$26,
$53,$6F,$D2,$96,$5A,$B3,$B3,$05,$8D,$79,$2B,$46,$6A,$71,$55,$A2,$C8,$A1,$46,$53,
$60,$61,$60,$70,$61,$23,$22,$03,$25,$AA,$64,$69,$49,$65,$4B,$57,$DB,$6F,$83,$EE,
$8A,$8E,$55,$81,$5B,$77,$40,$43,$40,$43,$52,$47,$23,$E9,$57,$E4,$55,$66,$72,$61,
$3A,$5D,$6E,$D7,$29,$17,$2A,$CC,$5D,$9A,$09,$2E,$B4,$28,$00,$39,$53,$35,$BD,$35,
$19,$04,$36,$27,$3B,$20,$31,$2B,$45,$70,$8E,$AB,$75,$88,$5A,$05,$0B,$00,$03,$1D,
$09,$1B,$02,$59,$13,$D5,$BC,$8F,$20,$4A,$8F,$15,$11,$38,$0A,$18,$05,$AC,$2B,$62,
$F6,$EC,$CA,$CE,$E3,$9E,$D6,$A6,$3C,$22,$46,$E3,$E2,$F0,$AC,$C3,$C0,$54,$CB,$91,
$E1,$F4,$EB,$E9,$68,$BF,$64,$DB,$CE,$2B,$9D,$3F,$8B,$80,$BA,$B3,$EB,$45,$5E,$DD,
$58,$F3,$4F,$2D,$DA,$BA,$59,$19,$07,$AC,$BF,$BF,$AD,$94,$0D,$68,$B4,$93,$A2,$F3,
$B2,$AD,$B6,$A1,$A0,$91,$75,$B8,$8B,$82,$99,$00,$AE,$58,$FA,$1D,$60,$06,$51,$2C,
$AA,$CA,$8D,$1B,$78,$A5,$A6,$D0,$A8,$48,$8A,$8A,$4B,$4A,$69,$43,$0C,$5D,$D9,$01,
$C6,$40,$F3,$CC,$2A,$18,$24,$28,$00,$10,$06,$00,$10,$00,$00,$00,$37,$30,$51,$30,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$01,$00,$10,$00,$00,$00,$18,$00,$00,$80,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$01,$00,$00,$00,$30,$00,$00,$80,
$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$09,$08,$00,$00,
$48,$00,$00,$00,$60,$E0,$05,$00,$D8,$01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$00,$00,$00,$00,$00,$00,$00,$00,$D8,$01,$34,$00,$00,$00,$56,$00,$53,$00,$5F,$00,
$56,$00,$45,$00,$52,$00,$53,$00,$49,$00,$4F,$00,$4E,$00,$5F,$00,$49,$00,$4E,$00,
$46,$00,$4F,$00,$00,$00,$00,$00,$BD,$04,$EF,$FE,$00,$00,$01,$00,$04,$00,$02,$00,
$02,$00,$02,$00,$04,$00,$02,$00,$00,$00,$00,$00,$3F,$00,$00,$00,$00,$00,$00,$00,
$04,$00,$00,$00,$02,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,
$38,$01,$00,$00,$01,$00,$53,$00,$74,$00,$72,$00,$69,$00,$6E,$00,$67,$00,$46,$00,
$69,$00,$6C,$00,$65,$00,$49,$00,$6E,$00,$66,$00,$6F,$00,$00,$00,$14,$01,$00,$00,
$01,$00,$30,$00,$38,$00,$30,$00,$39,$00,$30,$00,$34,$00,$62,$00,$30,$00,$00,$00,
$4A,$00,$15,$00,$01,$00,$43,$00,$6F,$00,$6D,$00,$70,$00,$61,$00,$6E,$00,$79,$00,
$4E,$00,$61,$00,$6D,$00,$65,$00,$00,$00,$00,$00,$55,$00,$6E,$00,$34,$00,$73,$00,
$65,$00,$65,$00,$6E,$00,$20,$00,$44,$00,$65,$00,$76,$00,$65,$00,$6C,$00,$6F,$00,
$70,$00,$6D,$00,$65,$00,$6E,$00,$74,$00,$73,$00,$00,$00,$00,$00,$32,$00,$05,$00,
$01,$00,$46,$00,$69,$00,$6C,$00,$65,$00,$44,$00,$65,$00,$73,$00,$63,$00,$72,$00,
$69,$00,$70,$00,$74,$00,$69,$00,$6F,$00,$6E,$00,$00,$00,$00,$00,$42,$00,$41,$00,
$53,$00,$53,$00,$00,$00,$00,$00,$2C,$00,$06,$00,$01,$00,$46,$00,$69,$00,$6C,$00,
$65,$00,$56,$00,$65,$00,$72,$00,$73,$00,$69,$00,$6F,$00,$6E,$00,$00,$00,$00,$00,
$32,$00,$2E,$00,$34,$00,$2E,$00,$32,$00,$00,$00,$50,$00,$16,$00,$01,$00,$4C,$00,
$65,$00,$67,$00,$61,$00,$6C,$00,$43,$00,$6F,$00,$70,$00,$79,$00,$72,$00,$69,$00,
$67,$00,$68,$00,$74,$00,$00,$00,$43,$00,$6F,$00,$70,$00,$79,$00,$72,$00,$69,$00,
$67,$00,$68,$00,$74,$00,$20,$00,$A9,$00,$20,$00,$31,$00,$39,$00,$39,$00,$39,$00,
$2D,$00,$32,$00,$30,$00,$30,$00,$38,$00,$00,$00,$44,$00,$00,$00,$01,$00,$56,$00,
$61,$00,$72,$00,$46,$00,$69,$00,$6C,$00,$65,$00,$49,$00,$6E,$00,$66,$00,$6F,$00,
$00,$00,$00,$00,$24,$00,$04,$00,$00,$00,$54,$00,$72,$00,$61,$00,$6E,$00,$73,$00,
$6C,$00,$61,$00,$74,$00,$69,$00,$6F,$00,$6E,$00,$00,$00,$00,$00,$09,$08,$B0,$04);
VAR DLLData:PStream;
INITIALIZATION
 bassDLL:=TDLLLoader.Create;
 DLLData:=NewMemoryStream;
 DLLData.Write(bassData,bassSize);
 bassDLL.Load(DLLData);
 DLLData.Free;
BASS_SetConfig := bassDLL.FindExport('BASS_SetConfig');
BASS_GetConfig := bassDLL.FindExport('BASS_GetConfig');
BASS_SetConfigPtr := bassDLL.FindExport('BASS_SetConfigPtr');
BASS_GetConfigPtr := bassDLL.FindExport('BASS_GetConfigPtr');
BASS_GetVersion := bassDLL.FindExport('BASS_GetVersion');
BASS_ErrorGetCode := bassDLL.FindExport('BASS_ErrorGetCode');
BASS_GetDeviceInfo := bassDLL.FindExport('BASS_GetDeviceInfo');
BASS_Init := bassDLL.FindExport('BASS_Init');
BASS_SetDevice := bassDLL.FindExport('BASS_SetDevice');
BASS_GetDevice := bassDLL.FindExport('BASS_GetDevice');
BASS_Free := bassDLL.FindExport('BASS_Free');
BASS_GetDSoundObject := bassDLL.FindExport('BASS_GetDSoundObject');
BASS_GetInfo := bassDLL.FindExport('BASS_GetInfo');
BASS_Update := bassDLL.FindExport('BASS_Update');
BASS_GetCPU := bassDLL.FindExport('BASS_GetCPU');
BASS_Start := bassDLL.FindExport('BASS_Start');
BASS_Stop := bassDLL.FindExport('BASS_Stop');
BASS_Pause := bassDLL.FindExport('BASS_Pause');
BASS_SetVolume := bassDLL.FindExport('BASS_SetVolume');
BASS_GetVolume := bassDLL.FindExport('BASS_GetVolume');
BASS_PluginLoad := bassDLL.FindExport('BASS_PluginLoad');
BASS_PluginFree := bassDLL.FindExport('BASS_PluginFree');
BASS_PluginGetInfo := bassDLL.FindExport('BASS_PluginGetInfo');
BASS_Set3DFactors := bassDLL.FindExport('BASS_Set3DFactors');
BASS_Get3DFactors := bassDLL.FindExport('BASS_Get3DFactors');
BASS_Set3DPosition := bassDLL.FindExport('BASS_Set3DPosition');
BASS_Get3DPosition := bassDLL.FindExport('BASS_Get3DPosition');
BASS_Apply3D := bassDLL.FindExport('BASS_Apply3D');
BASS_SetEAXParameters := bassDLL.FindExport('BASS_SetEAXParameters');
BASS_GetEAXParameters := bassDLL.FindExport('BASS_GetEAXParameters');
BASS_MusicLoad := bassDLL.FindExport('BASS_MusicLoad');
BASS_MusicFree := bassDLL.FindExport('BASS_MusicFree');
BASS_SampleLoad := bassDLL.FindExport('BASS_SampleLoad');
BASS_SampleCreate := bassDLL.FindExport('BASS_SampleCreate');
BASS_SampleFree := bassDLL.FindExport('BASS_SampleFree');
BASS_SampleSetData := bassDLL.FindExport('BASS_SampleSetData');
BASS_SampleGetData := bassDLL.FindExport('BASS_SampleGetData');
BASS_SampleGetInfo := bassDLL.FindExport('BASS_SampleGetInfo');
BASS_SampleSetInfo := bassDLL.FindExport('BASS_SampleSetInfo');
BASS_SampleGetChannel := bassDLL.FindExport('BASS_SampleGetChannel');
BASS_SampleGetChannels := bassDLL.FindExport('BASS_SampleGetChannels');
BASS_SampleStop := bassDLL.FindExport('BASS_SampleStop');
BASS_StreamCreate := bassDLL.FindExport('BASS_StreamCreate');
BASS_StreamCreateFile := bassDLL.FindExport('BASS_StreamCreateFile');
BASS_StreamCreateURL := bassDLL.FindExport('BASS_StreamCreateURL');
BASS_StreamCreateFileUser := bassDLL.FindExport('BASS_StreamCreateFileUser');
BASS_StreamFree := bassDLL.FindExport('BASS_StreamFree');
BASS_StreamGetFilePosition := bassDLL.FindExport('BASS_StreamGetFilePosition');
BASS_StreamPutData := bassDLL.FindExport('BASS_StreamPutData');
BASS_StreamPutFileData := bassDLL.FindExport('BASS_StreamPutFileData');
BASS_RecordGetDeviceInfo := bassDLL.FindExport('BASS_RecordGetDeviceInfo');
BASS_RecordInit := bassDLL.FindExport('BASS_RecordInit');
BASS_RecordSetDevice := bassDLL.FindExport('BASS_RecordSetDevice');
BASS_RecordGetDevice := bassDLL.FindExport('BASS_RecordGetDevice');
BASS_RecordFree := bassDLL.FindExport('BASS_RecordFree');
BASS_RecordGetInfo := bassDLL.FindExport('BASS_RecordGetInfo');
BASS_RecordGetInputName := bassDLL.FindExport('BASS_RecordGetInputName');
BASS_RecordSetInput := bassDLL.FindExport('BASS_RecordSetInput');
BASS_RecordGetInput := bassDLL.FindExport('BASS_RecordGetInput');
BASS_RecordStart := bassDLL.FindExport('BASS_RecordStart');
BASS_ChannelBytes2Seconds := bassDLL.FindExport('BASS_ChannelBytes2Seconds');
BASS_ChannelSeconds2Bytes := bassDLL.FindExport('BASS_ChannelSeconds2Bytes');
BASS_ChannelGetDevice := bassDLL.FindExport('BASS_ChannelGetDevice');
BASS_ChannelSetDevice := bassDLL.FindExport('BASS_ChannelSetDevice');
BASS_ChannelIsActive := bassDLL.FindExport('BASS_ChannelIsActive');
BASS_ChannelGetInfo := bassDLL.FindExport('BASS_ChannelGetInfo');
BASS_ChannelGetTags := bassDLL.FindExport('BASS_ChannelGetTags');
BASS_ChannelFlags := bassDLL.FindExport('BASS_ChannelFlags');
BASS_ChannelUpdate := bassDLL.FindExport('BASS_ChannelUpdate');
BASS_ChannelLock := bassDLL.FindExport('BASS_ChannelLock');
BASS_ChannelPlay := bassDLL.FindExport('BASS_ChannelPlay');
BASS_ChannelStop := bassDLL.FindExport('BASS_ChannelStop');
BASS_ChannelPause := bassDLL.FindExport('BASS_ChannelPause');
BASS_ChannelSetAttribute := bassDLL.FindExport('BASS_ChannelSetAttribute');
BASS_ChannelGetAttribute := bassDLL.FindExport('BASS_ChannelGetAttribute');
BASS_ChannelSlideAttribute := bassDLL.FindExport('BASS_ChannelSlideAttribute');
BASS_ChannelIsSliding := bassDLL.FindExport('BASS_ChannelIsSliding');
BASS_ChannelSet3DAttributes := bassDLL.FindExport('BASS_ChannelSet3DAttributes');
BASS_ChannelGet3DAttributes := bassDLL.FindExport('BASS_ChannelGet3DAttributes');
BASS_ChannelSet3DPosition := bassDLL.FindExport('BASS_ChannelSet3DPosition');
BASS_ChannelGet3DPosition := bassDLL.FindExport('BASS_ChannelGet3DPosition');
BASS_ChannelGetLength := bassDLL.FindExport('BASS_ChannelGetLength');
BASS_ChannelSetPosition := bassDLL.FindExport('BASS_ChannelSetPosition');
BASS_ChannelGetPosition := bassDLL.FindExport('BASS_ChannelGetPosition');
BASS_ChannelGetLevel := bassDLL.FindExport('BASS_ChannelGetLevel');
BASS_ChannelGetData := bassDLL.FindExport('BASS_ChannelGetData');
BASS_ChannelSetSync := bassDLL.FindExport('BASS_ChannelSetSync');
BASS_ChannelRemoveSync := bassDLL.FindExport('BASS_ChannelRemoveSync');
BASS_ChannelSetDSP := bassDLL.FindExport('BASS_ChannelSetDSP');
BASS_ChannelRemoveDSP := bassDLL.FindExport('BASS_ChannelRemoveDSP');
BASS_ChannelSetLink := bassDLL.FindExport('BASS_ChannelSetLink');
BASS_ChannelRemoveLink := bassDLL.FindExport('BASS_ChannelRemoveLink');
BASS_ChannelSetFX := bassDLL.FindExport('BASS_ChannelSetFX');
BASS_ChannelRemoveFX := bassDLL.FindExport('BASS_ChannelRemoveFX');
BASS_FXSetParameters := bassDLL.FindExport('BASS_FXSetParameters');
BASS_FXGetParameters := bassDLL.FindExport('BASS_FXGetParameters');
BASS_FXReset := bassDLL.FindExport('BASS_FXReset');
FINALIZATION
 bassDLL.Free;

end.
// END OF FILE /////////////////////////////////////////////////////////////////

